/**
 * @license @metamist/lucide-react v0.0.1-patch - ISC
 *
 * This source code is licensed under the ISC license.
 * See the LICENSE file in the root directory of this source tree.
 */

'use strict';

var react = require('react');

var defaultAttributes = {
  xmlns: "http://www.w3.org/2000/svg",
  width: "1em",
  height: "1em",
  viewBox: "0 0 24 24",
  fill: "none",
  stroke: "currentColor",
  strokeWidth: 2,
  strokeLinecap: "round",
  strokeLinejoin: "round"
};

const toKebabCase = (string) => string.replace(/([a-z0-9])([A-Z])/g, "$1-$2").toLowerCase();

const createLucideIcon = (iconName, iconNode) => {
  const Component = react.forwardRef(
    ({
      color = "currentColor",
      size = "1em",
      strokeWidth = 2,
      absoluteStrokeWidth,
      className = "",
      children,
      ...rest
    }, ref) => {
      return react.createElement(
        "svg",
        {
          ref,
          ...defaultAttributes,
          width: size,
          height: size,
          stroke: color,
          strokeWidth: absoluteStrokeWidth ? Number(strokeWidth) * 24 / Number(size) : strokeWidth,
          className: ["lucide", `lucide-${toKebabCase(iconName)}`, className].join(" "),
          ...rest
        },
        [
          ...iconNode.map(([tag, attrs]) => react.createElement(tag, attrs)),
          ...Array.isArray(children) ? children : [children]
        ]
      );
    }
  );
  Component.displayName = `${iconName}`;
  return Component;
};

const LuAArrowDown = createLucideIcon("LuAArrowDown", [
  ["path", { d: "M3.5 13h6", key: "p1my2r" }],
  ["path", { d: "m2 16 4.5-9 4.5 9", key: "ndf0b3" }],
  ["path", { d: "M18 7v9", key: "pknjwm" }],
  ["path", { d: "m14 12 4 4 4-4", key: "buelq4" }]
]);

const LuAArrowUp = createLucideIcon("LuAArrowUp", [
  ["path", { d: "M3.5 13h6", key: "p1my2r" }],
  ["path", { d: "m2 16 4.5-9 4.5 9", key: "ndf0b3" }],
  ["path", { d: "M18 16V7", key: "ty0viw" }],
  ["path", { d: "m14 11 4-4 4 4", key: "1pu57t" }]
]);

const LuALargeSmall = createLucideIcon("LuALargeSmall", [
  ["path", { d: "M21 14h-5", key: "1vh23k" }],
  ["path", { d: "M16 16v-3.5a2.5 2.5 0 0 1 5 0V16", key: "1wh10o" }],
  ["path", { d: "M4.5 13h6", key: "dfilno" }],
  ["path", { d: "m3 16 4.5-9 4.5 9", key: "2dxa0e" }]
]);

const LuAccessibility = createLucideIcon("LuAccessibility", [
  ["circle", { cx: "16", cy: "4", r: "1", key: "1grugj" }],
  ["path", { d: "m18 19 1-7-6 1", key: "r0i19z" }],
  ["path", { d: "m5 8 3-3 5.5 3-2.36 3.5", key: "9ptxx2" }],
  ["path", { d: "M4.24 14.5a5 5 0 0 0 6.88 6", key: "10kmtu" }],
  ["path", { d: "M13.76 17.5a5 5 0 0 0-6.88-6", key: "2qq6rc" }]
]);

const LuActivity = createLucideIcon("LuActivity", [
  ["path", { d: "M22 12h-4l-3 9L9 3l-3 9H2", key: "d5dnw9" }]
]);

const LuAirVent = createLucideIcon("LuAirVent", [
  [
    "path",
    {
      d: "M6 12H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2h-2",
      key: "larmp2"
    }
  ],
  ["path", { d: "M6 8h12", key: "6g4wlu" }],
  ["path", { d: "M18.3 17.7a2.5 2.5 0 0 1-3.16 3.83 2.53 2.53 0 0 1-1.14-2V12", key: "1bo8pg" }],
  ["path", { d: "M6.6 15.6A2 2 0 1 0 10 17v-5", key: "t9h90c" }]
]);

const LuAirplay = createLucideIcon("LuAirplay", [
  [
    "path",
    {
      d: "M5 17H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-1",
      key: "ns4c3b"
    }
  ],
  ["path", { d: "m12 15 5 6H7Z", key: "14qnn2" }]
]);

const LuAlarmClockCheck = createLucideIcon("LuAlarmClockCheck", [
  ["circle", { cx: "12", cy: "13", r: "8", key: "3y4lt7" }],
  ["path", { d: "M5 3 2 6", key: "18tl5t" }],
  ["path", { d: "m22 6-3-3", key: "1opdir" }],
  ["path", { d: "M6.38 18.7 4 21", key: "17xu3x" }],
  ["path", { d: "M17.64 18.67 20 21", key: "kv2oe2" }],
  ["path", { d: "m9 13 2 2 4-4", key: "6343dt" }]
]);

const LuAlarmClockMinus = createLucideIcon("LuAlarmClockMinus", [
  ["circle", { cx: "12", cy: "13", r: "8", key: "3y4lt7" }],
  ["path", { d: "M5 3 2 6", key: "18tl5t" }],
  ["path", { d: "m22 6-3-3", key: "1opdir" }],
  ["path", { d: "M6.38 18.7 4 21", key: "17xu3x" }],
  ["path", { d: "M17.64 18.67 20 21", key: "kv2oe2" }],
  ["path", { d: "M9 13h6", key: "1uhe8q" }]
]);

const LuAlarmClockOff = createLucideIcon("LuAlarmClockOff", [
  ["path", { d: "M6.87 6.87a8 8 0 1 0 11.26 11.26", key: "3on8tj" }],
  ["path", { d: "M19.9 14.25a8 8 0 0 0-9.15-9.15", key: "15ghsc" }],
  ["path", { d: "m22 6-3-3", key: "1opdir" }],
  ["path", { d: "M6.26 18.67 4 21", key: "yzmioq" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M4 4 2 6", key: "1ycko6" }]
]);

const LuAlarmClockPlus = createLucideIcon("LuAlarmClockPlus", [
  ["circle", { cx: "12", cy: "13", r: "8", key: "3y4lt7" }],
  ["path", { d: "M5 3 2 6", key: "18tl5t" }],
  ["path", { d: "m22 6-3-3", key: "1opdir" }],
  ["path", { d: "M6.38 18.7 4 21", key: "17xu3x" }],
  ["path", { d: "M17.64 18.67 20 21", key: "kv2oe2" }],
  ["path", { d: "M12 10v6", key: "1bos4e" }],
  ["path", { d: "M9 13h6", key: "1uhe8q" }]
]);

const LuAlarmClock = createLucideIcon("LuAlarmClock", [
  ["circle", { cx: "12", cy: "13", r: "8", key: "3y4lt7" }],
  ["path", { d: "M12 9v4l2 2", key: "1c63tq" }],
  ["path", { d: "M5 3 2 6", key: "18tl5t" }],
  ["path", { d: "m22 6-3-3", key: "1opdir" }],
  ["path", { d: "M6.38 18.7 4 21", key: "17xu3x" }],
  ["path", { d: "M17.64 18.67 20 21", key: "kv2oe2" }]
]);

const LuAlarmSmoke = createLucideIcon("LuAlarmSmoke", [
  ["path", { d: "M4 8a2 2 0 0 1-2-2V3h20v3a2 2 0 0 1-2 2Z", key: "2c4fvq" }],
  ["path", { d: "m19 8-.8 3c-.1.6-.6 1-1.2 1H7c-.6 0-1.1-.4-1.2-1L5 8", key: "1vrndv" }],
  ["path", { d: "M16 21c0-2.5 2-2.5 2-5", key: "1o3eny" }],
  ["path", { d: "M11 21c0-2.5 2-2.5 2-5", key: "1sicvv" }],
  ["path", { d: "M6 21c0-2.5 2-2.5 2-5", key: "i3w1gp" }]
]);

const LuAlbum = createLucideIcon("LuAlbum", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["polyline", { points: "11 3 11 11 14 8 17 11 17 3", key: "1wcwz3" }]
]);

const LuAlignCenterHorizontal = createLucideIcon("LuAlignCenterHorizontal", [
  ["path", { d: "M2 12h20", key: "9i4pu4" }],
  ["path", { d: "M10 16v4a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-4", key: "11f1s0" }],
  ["path", { d: "M10 8V4a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v4", key: "t14dx9" }],
  ["path", { d: "M20 16v1a2 2 0 0 1-2 2h-2a2 2 0 0 1-2-2v-1", key: "1w07xs" }],
  ["path", { d: "M14 8V7c0-1.1.9-2 2-2h2a2 2 0 0 1 2 2v1", key: "1apec2" }]
]);

const LuAlignCenterVertical = createLucideIcon("LuAlignCenterVertical", [
  ["path", { d: "M12 2v20", key: "t6zp3m" }],
  ["path", { d: "M8 10H4a2 2 0 0 1-2-2V6c0-1.1.9-2 2-2h4", key: "14d6g8" }],
  ["path", { d: "M16 10h4a2 2 0 0 0 2-2V6a2 2 0 0 0-2-2h-4", key: "1e2lrw" }],
  ["path", { d: "M8 20H7a2 2 0 0 1-2-2v-2c0-1.1.9-2 2-2h1", key: "1fkdwx" }],
  ["path", { d: "M16 14h1a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2h-1", key: "1euafb" }]
]);

const LuAlignCenter = createLucideIcon("LuAlignCenter", [
  ["line", { x1: "21", x2: "3", y1: "6", y2: "6", key: "1fp77t" }],
  ["line", { x1: "17", x2: "7", y1: "12", y2: "12", key: "rsh8ii" }],
  ["line", { x1: "19", x2: "5", y1: "18", y2: "18", key: "1t0tuv" }]
]);

const LuAlignEndHorizontal = createLucideIcon("LuAlignEndHorizontal", [
  ["rect", { width: "6", height: "16", x: "4", y: "2", rx: "2", key: "z5wdxg" }],
  ["rect", { width: "6", height: "9", x: "14", y: "9", rx: "2", key: "um7a8w" }],
  ["path", { d: "M22 22H2", key: "19qnx5" }]
]);

const LuAlignEndVertical = createLucideIcon("LuAlignEndVertical", [
  ["rect", { width: "16", height: "6", x: "2", y: "4", rx: "2", key: "10wcwx" }],
  ["rect", { width: "9", height: "6", x: "9", y: "14", rx: "2", key: "4p5bwg" }],
  ["path", { d: "M22 22V2", key: "12ipfv" }]
]);

const LuAlignHorizontalDistributeCenter = createLucideIcon("LuAlignHorizontalDistributeCenter", [
  ["rect", { width: "6", height: "14", x: "4", y: "5", rx: "2", key: "1wwnby" }],
  ["rect", { width: "6", height: "10", x: "14", y: "7", rx: "2", key: "1fe6j6" }],
  ["path", { d: "M17 22v-5", key: "4b6g73" }],
  ["path", { d: "M17 7V2", key: "hnrr36" }],
  ["path", { d: "M7 22v-3", key: "1r4jpn" }],
  ["path", { d: "M7 5V2", key: "liy1u9" }]
]);

const LuAlignHorizontalDistributeEnd = createLucideIcon("LuAlignHorizontalDistributeEnd", [
  ["rect", { width: "6", height: "14", x: "4", y: "5", rx: "2", key: "1wwnby" }],
  ["rect", { width: "6", height: "10", x: "14", y: "7", rx: "2", key: "1fe6j6" }],
  ["path", { d: "M10 2v20", key: "uyc634" }],
  ["path", { d: "M20 2v20", key: "1tx262" }]
]);

const LuAlignHorizontalDistributeStart = createLucideIcon("LuAlignHorizontalDistributeStart", [
  ["rect", { width: "6", height: "14", x: "4", y: "5", rx: "2", key: "1wwnby" }],
  ["rect", { width: "6", height: "10", x: "14", y: "7", rx: "2", key: "1fe6j6" }],
  ["path", { d: "M4 2v20", key: "gtpd5x" }],
  ["path", { d: "M14 2v20", key: "tg6bpw" }]
]);

const LuAlignHorizontalJustifyCenter = createLucideIcon("LuAlignHorizontalJustifyCenter", [
  ["rect", { width: "6", height: "14", x: "2", y: "5", rx: "2", key: "dy24zr" }],
  ["rect", { width: "6", height: "10", x: "16", y: "7", rx: "2", key: "13zkjt" }],
  ["path", { d: "M12 2v20", key: "t6zp3m" }]
]);

const LuAlignHorizontalJustifyEnd = createLucideIcon("LuAlignHorizontalJustifyEnd", [
  ["rect", { width: "6", height: "14", x: "2", y: "5", rx: "2", key: "dy24zr" }],
  ["rect", { width: "6", height: "10", x: "12", y: "7", rx: "2", key: "1ht384" }],
  ["path", { d: "M22 2v20", key: "40qfg1" }]
]);

const LuAlignHorizontalJustifyStart = createLucideIcon("LuAlignHorizontalJustifyStart", [
  ["rect", { width: "6", height: "14", x: "6", y: "5", rx: "2", key: "hsirpf" }],
  ["rect", { width: "6", height: "10", x: "16", y: "7", rx: "2", key: "13zkjt" }],
  ["path", { d: "M2 2v20", key: "1ivd8o" }]
]);

const LuAlignHorizontalSpaceAround = createLucideIcon("LuAlignHorizontalSpaceAround", [
  ["rect", { width: "6", height: "10", x: "9", y: "7", rx: "2", key: "yn7j0q" }],
  ["path", { d: "M4 22V2", key: "tsjzd3" }],
  ["path", { d: "M20 22V2", key: "1bnhr8" }]
]);

const LuAlignHorizontalSpaceBetween = createLucideIcon("LuAlignHorizontalSpaceBetween", [
  ["rect", { width: "6", height: "14", x: "3", y: "5", rx: "2", key: "j77dae" }],
  ["rect", { width: "6", height: "10", x: "15", y: "7", rx: "2", key: "bq30hj" }],
  ["path", { d: "M3 2v20", key: "1d2pfg" }],
  ["path", { d: "M21 2v20", key: "p059bm" }]
]);

const LuAlignJustify = createLucideIcon("LuAlignJustify", [
  ["line", { x1: "3", x2: "21", y1: "6", y2: "6", key: "4m8b97" }],
  ["line", { x1: "3", x2: "21", y1: "12", y2: "12", key: "10d38w" }],
  ["line", { x1: "3", x2: "21", y1: "18", y2: "18", key: "kwyyxn" }]
]);

const LuAlignLeft = createLucideIcon("LuAlignLeft", [
  ["line", { x1: "21", x2: "3", y1: "6", y2: "6", key: "1fp77t" }],
  ["line", { x1: "15", x2: "3", y1: "12", y2: "12", key: "v6grx8" }],
  ["line", { x1: "17", x2: "3", y1: "18", y2: "18", key: "1awlsn" }]
]);

const LuAlignRight = createLucideIcon("LuAlignRight", [
  ["line", { x1: "21", x2: "3", y1: "6", y2: "6", key: "1fp77t" }],
  ["line", { x1: "21", x2: "9", y1: "12", y2: "12", key: "1uyos4" }],
  ["line", { x1: "21", x2: "7", y1: "18", y2: "18", key: "1g9eri" }]
]);

const LuAlignStartHorizontal = createLucideIcon("LuAlignStartHorizontal", [
  ["rect", { width: "6", height: "16", x: "4", y: "6", rx: "2", key: "1n4dg1" }],
  ["rect", { width: "6", height: "9", x: "14", y: "6", rx: "2", key: "17khns" }],
  ["path", { d: "M22 2H2", key: "fhrpnj" }]
]);

const LuAlignStartVertical = createLucideIcon("LuAlignStartVertical", [
  ["rect", { width: "9", height: "6", x: "6", y: "14", rx: "2", key: "lpm2y7" }],
  ["rect", { width: "16", height: "6", x: "6", y: "4", rx: "2", key: "rdj6ps" }],
  ["path", { d: "M2 2v20", key: "1ivd8o" }]
]);

const LuAlignVerticalDistributeCenter = createLucideIcon("LuAlignVerticalDistributeCenter", [
  ["rect", { width: "14", height: "6", x: "5", y: "14", rx: "2", key: "jmoj9s" }],
  ["rect", { width: "10", height: "6", x: "7", y: "4", rx: "2", key: "aza5on" }],
  ["path", { d: "M22 7h-5", key: "o2endc" }],
  ["path", { d: "M7 7H1", key: "105l6j" }],
  ["path", { d: "M22 17h-3", key: "1lwga1" }],
  ["path", { d: "M5 17H2", key: "1gx9xc" }]
]);

const LuAlignVerticalDistributeEnd = createLucideIcon("LuAlignVerticalDistributeEnd", [
  ["rect", { width: "14", height: "6", x: "5", y: "14", rx: "2", key: "jmoj9s" }],
  ["rect", { width: "10", height: "6", x: "7", y: "4", rx: "2", key: "aza5on" }],
  ["path", { d: "M2 20h20", key: "owomy5" }],
  ["path", { d: "M2 10h20", key: "1ir3d8" }]
]);

const LuAlignVerticalDistributeStart = createLucideIcon("LuAlignVerticalDistributeStart", [
  ["rect", { width: "14", height: "6", x: "5", y: "14", rx: "2", key: "jmoj9s" }],
  ["rect", { width: "10", height: "6", x: "7", y: "4", rx: "2", key: "aza5on" }],
  ["path", { d: "M2 14h20", key: "myj16y" }],
  ["path", { d: "M2 4h20", key: "mda7wb" }]
]);

const LuAlignVerticalJustifyCenter = createLucideIcon("LuAlignVerticalJustifyCenter", [
  ["rect", { width: "14", height: "6", x: "5", y: "16", rx: "2", key: "1i8z2d" }],
  ["rect", { width: "10", height: "6", x: "7", y: "2", rx: "2", key: "ypihtt" }],
  ["path", { d: "M2 12h20", key: "9i4pu4" }]
]);

const LuAlignVerticalJustifyEnd = createLucideIcon("LuAlignVerticalJustifyEnd", [
  ["rect", { width: "14", height: "6", x: "5", y: "12", rx: "2", key: "4l4tp2" }],
  ["rect", { width: "10", height: "6", x: "7", y: "2", rx: "2", key: "ypihtt" }],
  ["path", { d: "M2 22h20", key: "272qi7" }]
]);

const LuAlignVerticalJustifyStart = createLucideIcon("LuAlignVerticalJustifyStart", [
  ["rect", { width: "14", height: "6", x: "5", y: "16", rx: "2", key: "1i8z2d" }],
  ["rect", { width: "10", height: "6", x: "7", y: "6", rx: "2", key: "13squh" }],
  ["path", { d: "M2 2h20", key: "1ennik" }]
]);

const LuAlignVerticalSpaceAround = createLucideIcon("LuAlignVerticalSpaceAround", [
  ["rect", { width: "10", height: "6", x: "7", y: "9", rx: "2", key: "b1zbii" }],
  ["path", { d: "M22 20H2", key: "1p1f7z" }],
  ["path", { d: "M22 4H2", key: "1b7qnq" }]
]);

const LuAlignVerticalSpaceBetween = createLucideIcon("LuAlignVerticalSpaceBetween", [
  ["rect", { width: "14", height: "6", x: "5", y: "15", rx: "2", key: "1w91an" }],
  ["rect", { width: "10", height: "6", x: "7", y: "3", rx: "2", key: "17wqzy" }],
  ["path", { d: "M2 21h20", key: "1nyx9w" }],
  ["path", { d: "M2 3h20", key: "91anmk" }]
]);

const LuAmbulance = createLucideIcon("LuAmbulance", [
  ["path", { d: "M10 10H6", key: "1bsnug" }],
  ["path", { d: "M14 18V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v11a1 1 0 0 0 1 1h2", key: "wrbu53" }],
  [
    "path",
    {
      d: "M19 18h2a1 1 0 0 0 1-1v-3.28a1 1 0 0 0-.684-.948l-1.923-.641a1 1 0 0 1-.578-.502l-1.539-3.076A1 1 0 0 0 16.382 8H14",
      key: "lrkjwd"
    }
  ],
  ["path", { d: "M8 8v4", key: "1fwk8c" }],
  ["path", { d: "M9 18h6", key: "x1upvd" }],
  ["circle", { cx: "17", cy: "18", r: "2", key: "332jqn" }],
  ["circle", { cx: "7", cy: "18", r: "2", key: "19iecd" }]
]);

const LuAmpersand = createLucideIcon("LuAmpersand", [
  [
    "path",
    {
      d: "M17.5 12c0 4.4-3.6 8-8 8A4.5 4.5 0 0 1 5 15.5c0-6 8-4 8-8.5a3 3 0 1 0-6 0c0 3 2.5 8.5 12 13",
      key: "1o9ehi"
    }
  ],
  ["path", { d: "M16 12h3", key: "4uvgyw" }]
]);

const LuAmpersands = createLucideIcon("LuAmpersands", [
  [
    "path",
    {
      d: "M10 17c-5-3-7-7-7-9a2 2 0 0 1 4 0c0 2.5-5 2.5-5 6 0 1.7 1.3 3 3 3 2.8 0 5-2.2 5-5",
      key: "12lh1k"
    }
  ],
  [
    "path",
    {
      d: "M22 17c-5-3-7-7-7-9a2 2 0 0 1 4 0c0 2.5-5 2.5-5 6 0 1.7 1.3 3 3 3 2.8 0 5-2.2 5-5",
      key: "173c68"
    }
  ]
]);

const LuAnchor = createLucideIcon("LuAnchor", [
  ["path", { d: "M12 22V8", key: "qkxhtm" }],
  ["path", { d: "M5 12H2a10 10 0 0 0 20 0h-3", key: "1hv3nh" }],
  ["circle", { cx: "12", cy: "5", r: "3", key: "rqqgnr" }]
]);

const LuAngry = createLucideIcon("LuAngry", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M16 16s-1.5-2-4-2-4 2-4 2", key: "epbg0q" }],
  ["path", { d: "M7.5 8 10 9", key: "olxxln" }],
  ["path", { d: "m14 9 2.5-1", key: "1j6cij" }],
  ["path", { d: "M9 10h0", key: "1vxvly" }],
  ["path", { d: "M15 10h0", key: "1j6oav" }]
]);

const LuAnnoyed = createLucideIcon("LuAnnoyed", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M8 15h8", key: "45n4r" }],
  ["path", { d: "M8 9h2", key: "1g203m" }],
  ["path", { d: "M14 9h2", key: "116p9w" }]
]);

const LuAntenna = createLucideIcon("LuAntenna", [
  ["path", { d: "M2 12 7 2", key: "117k30" }],
  ["path", { d: "m7 12 5-10", key: "1tvx22" }],
  ["path", { d: "m12 12 5-10", key: "ev1o1a" }],
  ["path", { d: "m17 12 5-10", key: "1e4ti3" }],
  ["path", { d: "M4.5 7h15", key: "vlsxkz" }],
  ["path", { d: "M12 16v6", key: "c8a4gj" }]
]);

const LuAnvil = createLucideIcon("LuAnvil", [
  ["path", { d: "M7 10H6a4 4 0 0 1-4-4 1 1 0 0 1 1-1h4", key: "1hjpb6" }],
  [
    "path",
    { d: "M7 5a1 1 0 0 1 1-1h13a1 1 0 0 1 1 1 7 7 0 0 1-7 7H8a1 1 0 0 1-1-1z", key: "1qn45f" }
  ],
  ["path", { d: "M9 12v5", key: "3anwtq" }],
  ["path", { d: "M15 12v5", key: "5xh3zn" }],
  [
    "path",
    { d: "M5 20a3 3 0 0 1 3-3h8a3 3 0 0 1 3 3 1 1 0 0 1-1 1H6a1 1 0 0 1-1-1", key: "1fi4x8" }
  ]
]);

const LuAperture = createLucideIcon("LuAperture", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m14.31 8 5.74 9.94", key: "1y6ab4" }],
  ["path", { d: "M9.69 8h11.48", key: "1wxppr" }],
  ["path", { d: "m7.38 12 5.74-9.94", key: "1grp0k" }],
  ["path", { d: "M9.69 16 3.95 6.06", key: "libnyf" }],
  ["path", { d: "M14.31 16H2.83", key: "x5fava" }],
  ["path", { d: "m16.62 12-5.74 9.94", key: "1vwawt" }]
]);

const LuAppWindowMac = createLucideIcon("LuAppWindowMac", [
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }],
  ["path", { d: "M6 8h.01", key: "x9i8wu" }],
  ["path", { d: "M10 8h.01", key: "1r9ogq" }],
  ["path", { d: "M14 8h.01", key: "1primd" }]
]);

const LuAppWindow = createLucideIcon("LuAppWindow", [
  ["rect", { x: "2", y: "4", width: "20", height: "16", rx: "2", key: "izxlao" }],
  ["path", { d: "M10 4v4", key: "pp8u80" }],
  ["path", { d: "M2 8h20", key: "d11cs7" }],
  ["path", { d: "M6 4v4", key: "1svtjw" }]
]);

const LuApple = createLucideIcon("LuApple", [
  [
    "path",
    {
      d: "M12 20.94c1.5 0 2.75 1.06 4 1.06 3 0 6-8 6-12.22A4.91 4.91 0 0 0 17 5c-2.22 0-4 1.44-5 2-1-.56-2.78-2-5-2a4.9 4.9 0 0 0-5 4.78C2 14 5 22 8 22c1.25 0 2.5-1.06 4-1.06Z",
      key: "3s7exb"
    }
  ],
  ["path", { d: "M10 2c1 .5 2 2 2 5", key: "fcco2y" }]
]);

const LuArchiveRestore = createLucideIcon("LuArchiveRestore", [
  ["rect", { width: "20", height: "5", x: "2", y: "3", rx: "1", key: "1wp1u1" }],
  ["path", { d: "M4 8v11a2 2 0 0 0 2 2h2", key: "tvwodi" }],
  ["path", { d: "M20 8v11a2 2 0 0 1-2 2h-2", key: "1gkqxj" }],
  ["path", { d: "m9 15 3-3 3 3", key: "1pd0qc" }],
  ["path", { d: "M12 12v9", key: "192myk" }]
]);

const LuArchiveX = createLucideIcon("LuArchiveX", [
  ["rect", { width: "20", height: "5", x: "2", y: "3", rx: "1", key: "1wp1u1" }],
  ["path", { d: "M4 8v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8", key: "1s80jp" }],
  ["path", { d: "m9.5 17 5-5", key: "nakeu6" }],
  ["path", { d: "m9.5 12 5 5", key: "1hccrj" }]
]);

const LuArchive = createLucideIcon("LuArchive", [
  ["rect", { width: "20", height: "5", x: "2", y: "3", rx: "1", key: "1wp1u1" }],
  ["path", { d: "M4 8v11a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V8", key: "1s80jp" }],
  ["path", { d: "M10 12h4", key: "a56b0p" }]
]);

const LuAreaChart = createLucideIcon("LuAreaChart", [
  ["path", { d: "M3 3v18h18", key: "1s2lah" }],
  ["path", { d: "M7 12v5h12V8l-5 5-4-4Z", key: "zxz28u" }]
]);

const LuArmchair = createLucideIcon("LuArmchair", [
  ["path", { d: "M19 9V6a2 2 0 0 0-2-2H7a2 2 0 0 0-2 2v3", key: "irtipd" }],
  [
    "path",
    {
      d: "M3 16a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-5a2 2 0 0 0-4 0v2H7v-2a2 2 0 0 0-4 0Z",
      key: "1e01m0"
    }
  ],
  ["path", { d: "M5 18v2", key: "ppbyun" }],
  ["path", { d: "M19 18v2", key: "gy7782" }]
]);

const LuArrowBigDownDash = createLucideIcon("LuArrowBigDownDash", [
  ["path", { d: "M15 5H9", key: "1tp3ed" }],
  ["path", { d: "M15 9v3h4l-7 7-7-7h4V9z", key: "ncdc4b" }]
]);

const LuArrowBigDown = createLucideIcon("LuArrowBigDown", [
  ["path", { d: "M15 6v6h4l-7 7-7-7h4V6h6z", key: "1thax2" }]
]);

const LuArrowBigLeftDash = createLucideIcon("LuArrowBigLeftDash", [
  ["path", { d: "M19 15V9", key: "1hci5f" }],
  ["path", { d: "M15 15h-3v4l-7-7 7-7v4h3v6z", key: "16tjna" }]
]);

const LuArrowBigLeft = createLucideIcon("LuArrowBigLeft", [
  ["path", { d: "M18 15h-6v4l-7-7 7-7v4h6v6z", key: "lbrdak" }]
]);

const LuArrowBigRightDash = createLucideIcon("LuArrowBigRightDash", [
  ["path", { d: "M5 9v6", key: "158jrl" }],
  ["path", { d: "M9 9h3V5l7 7-7 7v-4H9V9z", key: "1sg2xn" }]
]);

const LuArrowBigRight = createLucideIcon("LuArrowBigRight", [
  ["path", { d: "M6 9h6V5l7 7-7 7v-4H6V9z", key: "7fvt9c" }]
]);

const LuArrowBigUpDash = createLucideIcon("LuArrowBigUpDash", [
  ["path", { d: "M9 19h6", key: "456am0" }],
  ["path", { d: "M9 15v-3H5l7-7 7 7h-4v3H9z", key: "1r2uve" }]
]);

const LuArrowBigUp = createLucideIcon("LuArrowBigUp", [
  ["path", { d: "M9 18v-6H5l7-7 7 7h-4v6H9z", key: "1x06kx" }]
]);

const LuArrowDown01 = createLucideIcon("LuArrowDown01", [
  ["path", { d: "m3 16 4 4 4-4", key: "1co6wj" }],
  ["path", { d: "M7 20V4", key: "1yoxec" }],
  ["rect", { x: "15", y: "4", width: "4", height: "6", ry: "2", key: "1bwicg" }],
  ["path", { d: "M17 20v-6h-2", key: "1qp1so" }],
  ["path", { d: "M15 20h4", key: "1j968p" }]
]);

const LuArrowDown10 = createLucideIcon("LuArrowDown10", [
  ["path", { d: "m3 16 4 4 4-4", key: "1co6wj" }],
  ["path", { d: "M7 20V4", key: "1yoxec" }],
  ["path", { d: "M17 10V4h-2", key: "zcsr5x" }],
  ["path", { d: "M15 10h4", key: "id2lce" }],
  ["rect", { x: "15", y: "14", width: "4", height: "6", ry: "2", key: "33xykx" }]
]);

const LuArrowDownAZ = createLucideIcon("LuArrowDownAZ", [
  ["path", { d: "m3 16 4 4 4-4", key: "1co6wj" }],
  ["path", { d: "M7 20V4", key: "1yoxec" }],
  ["path", { d: "M20 8h-5", key: "1vsyxs" }],
  ["path", { d: "M15 10V6.5a2.5 2.5 0 0 1 5 0V10", key: "ag13bf" }],
  ["path", { d: "M15 14h5l-5 6h5", key: "ur5jdg" }]
]);

const LuArrowDownFromLine = createLucideIcon("LuArrowDownFromLine", [
  ["path", { d: "M19 3H5", key: "1236rx" }],
  ["path", { d: "M12 21V7", key: "gj6g52" }],
  ["path", { d: "m6 15 6 6 6-6", key: "h15q88" }]
]);

const LuArrowDownLeft = createLucideIcon("LuArrowDownLeft", [
  ["path", { d: "M17 7 7 17", key: "15tmo1" }],
  ["path", { d: "M17 17H7V7", key: "1org7z" }]
]);

const LuArrowDownNarrowWide = createLucideIcon("LuArrowDownNarrowWide", [
  ["path", { d: "m3 16 4 4 4-4", key: "1co6wj" }],
  ["path", { d: "M7 20V4", key: "1yoxec" }],
  ["path", { d: "M11 4h4", key: "6d7r33" }],
  ["path", { d: "M11 8h7", key: "djye34" }],
  ["path", { d: "M11 12h10", key: "1438ji" }]
]);

const LuArrowDownRight = createLucideIcon("LuArrowDownRight", [
  ["path", { d: "m7 7 10 10", key: "1fmybs" }],
  ["path", { d: "M17 7v10H7", key: "6fjiku" }]
]);

const LuArrowDownToDot = createLucideIcon("LuArrowDownToDot", [
  ["path", { d: "M12 2v14", key: "jyx4ut" }],
  ["path", { d: "m19 9-7 7-7-7", key: "1oe3oy" }],
  ["circle", { cx: "12", cy: "21", r: "1", key: "o0uj5v" }]
]);

const LuArrowDownToLine = createLucideIcon("LuArrowDownToLine", [
  ["path", { d: "M12 17V3", key: "1cwfxf" }],
  ["path", { d: "m6 11 6 6 6-6", key: "12ii2o" }],
  ["path", { d: "M19 21H5", key: "150jfl" }]
]);

const LuArrowDownUp = createLucideIcon("LuArrowDownUp", [
  ["path", { d: "m3 16 4 4 4-4", key: "1co6wj" }],
  ["path", { d: "M7 20V4", key: "1yoxec" }],
  ["path", { d: "m21 8-4-4-4 4", key: "1c9v7m" }],
  ["path", { d: "M17 4v16", key: "7dpous" }]
]);

const LuArrowDownWideNarrow = createLucideIcon("LuArrowDownWideNarrow", [
  ["path", { d: "m3 16 4 4 4-4", key: "1co6wj" }],
  ["path", { d: "M7 20V4", key: "1yoxec" }],
  ["path", { d: "M11 4h10", key: "1w87gc" }],
  ["path", { d: "M11 8h7", key: "djye34" }],
  ["path", { d: "M11 12h4", key: "q8tih4" }]
]);

const LuArrowDownZA = createLucideIcon("LuArrowDownZA", [
  ["path", { d: "m3 16 4 4 4-4", key: "1co6wj" }],
  ["path", { d: "M7 4v16", key: "1glfcx" }],
  ["path", { d: "M15 4h5l-5 6h5", key: "8asdl1" }],
  ["path", { d: "M15 20v-3.5a2.5 2.5 0 0 1 5 0V20", key: "r6l5cz" }],
  ["path", { d: "M20 18h-5", key: "18j1r2" }]
]);

const LuArrowDown = createLucideIcon("LuArrowDown", [
  ["path", { d: "M12 5v14", key: "s699le" }],
  ["path", { d: "m19 12-7 7-7-7", key: "1idqje" }]
]);

const LuArrowLeftFromLine = createLucideIcon("LuArrowLeftFromLine", [
  ["path", { d: "m9 6-6 6 6 6", key: "7v63n9" }],
  ["path", { d: "M3 12h14", key: "13k4hi" }],
  ["path", { d: "M21 19V5", key: "b4bplr" }]
]);

const LuArrowLeftRight = createLucideIcon("LuArrowLeftRight", [
  ["path", { d: "M8 3 4 7l4 4", key: "9rb6wj" }],
  ["path", { d: "M4 7h16", key: "6tx8e3" }],
  ["path", { d: "m16 21 4-4-4-4", key: "siv7j2" }],
  ["path", { d: "M20 17H4", key: "h6l3hr" }]
]);

const LuArrowLeftToLine = createLucideIcon("LuArrowLeftToLine", [
  ["path", { d: "M3 19V5", key: "rwsyhb" }],
  ["path", { d: "m13 6-6 6 6 6", key: "1yhaz7" }],
  ["path", { d: "M7 12h14", key: "uoisry" }]
]);

const LuArrowLeft = createLucideIcon("LuArrowLeft", [
  ["path", { d: "m12 19-7-7 7-7", key: "1l729n" }],
  ["path", { d: "M19 12H5", key: "x3x0zl" }]
]);

const LuArrowRightFromLine = createLucideIcon("LuArrowRightFromLine", [
  ["path", { d: "M3 5v14", key: "1nt18q" }],
  ["path", { d: "M21 12H7", key: "13ipq5" }],
  ["path", { d: "m15 18 6-6-6-6", key: "6tx3qv" }]
]);

const LuArrowRightLeft = createLucideIcon("LuArrowRightLeft", [
  ["path", { d: "m16 3 4 4-4 4", key: "1x1c3m" }],
  ["path", { d: "M20 7H4", key: "zbl0bi" }],
  ["path", { d: "m8 21-4-4 4-4", key: "h9nckh" }],
  ["path", { d: "M4 17h16", key: "g4d7ey" }]
]);

const LuArrowRightToLine = createLucideIcon("LuArrowRightToLine", [
  ["path", { d: "M17 12H3", key: "8awo09" }],
  ["path", { d: "m11 18 6-6-6-6", key: "8c2y43" }],
  ["path", { d: "M21 5v14", key: "nzette" }]
]);

const LuArrowRight = createLucideIcon("LuArrowRight", [
  ["path", { d: "M5 12h14", key: "1ays0h" }],
  ["path", { d: "m12 5 7 7-7 7", key: "xquz4c" }]
]);

const LuArrowUp01 = createLucideIcon("LuArrowUp01", [
  ["path", { d: "m3 8 4-4 4 4", key: "11wl7u" }],
  ["path", { d: "M7 4v16", key: "1glfcx" }],
  ["rect", { x: "15", y: "4", width: "4", height: "6", ry: "2", key: "1bwicg" }],
  ["path", { d: "M17 20v-6h-2", key: "1qp1so" }],
  ["path", { d: "M15 20h4", key: "1j968p" }]
]);

const LuArrowUp10 = createLucideIcon("LuArrowUp10", [
  ["path", { d: "m3 8 4-4 4 4", key: "11wl7u" }],
  ["path", { d: "M7 4v16", key: "1glfcx" }],
  ["path", { d: "M17 10V4h-2", key: "zcsr5x" }],
  ["path", { d: "M15 10h4", key: "id2lce" }],
  ["rect", { x: "15", y: "14", width: "4", height: "6", ry: "2", key: "33xykx" }]
]);

const LuArrowUpAZ = createLucideIcon("LuArrowUpAZ", [
  ["path", { d: "m3 8 4-4 4 4", key: "11wl7u" }],
  ["path", { d: "M7 4v16", key: "1glfcx" }],
  ["path", { d: "M20 8h-5", key: "1vsyxs" }],
  ["path", { d: "M15 10V6.5a2.5 2.5 0 0 1 5 0V10", key: "ag13bf" }],
  ["path", { d: "M15 14h5l-5 6h5", key: "ur5jdg" }]
]);

const LuArrowUpDown = createLucideIcon("LuArrowUpDown", [
  ["path", { d: "m21 16-4 4-4-4", key: "f6ql7i" }],
  ["path", { d: "M17 20V4", key: "1ejh1v" }],
  ["path", { d: "m3 8 4-4 4 4", key: "11wl7u" }],
  ["path", { d: "M7 4v16", key: "1glfcx" }]
]);

const LuArrowUpFromDot = createLucideIcon("LuArrowUpFromDot", [
  ["path", { d: "m5 9 7-7 7 7", key: "1hw5ic" }],
  ["path", { d: "M12 16V2", key: "ywoabb" }],
  ["circle", { cx: "12", cy: "21", r: "1", key: "o0uj5v" }]
]);

const LuArrowUpFromLine = createLucideIcon("LuArrowUpFromLine", [
  ["path", { d: "m18 9-6-6-6 6", key: "kcunyi" }],
  ["path", { d: "M12 3v14", key: "7cf3v8" }],
  ["path", { d: "M5 21h14", key: "11awu3" }]
]);

const LuArrowUpLeft = createLucideIcon("LuArrowUpLeft", [
  ["path", { d: "M7 17V7h10", key: "11bw93" }],
  ["path", { d: "M17 17 7 7", key: "2786uv" }]
]);

const LuArrowUpNarrowWide = createLucideIcon("LuArrowUpNarrowWide", [
  ["path", { d: "m3 8 4-4 4 4", key: "11wl7u" }],
  ["path", { d: "M7 4v16", key: "1glfcx" }],
  ["path", { d: "M11 12h4", key: "q8tih4" }],
  ["path", { d: "M11 16h7", key: "uosisv" }],
  ["path", { d: "M11 20h10", key: "jvxblo" }]
]);

const LuArrowUpRight = createLucideIcon("LuArrowUpRight", [
  ["path", { d: "M7 7h10v10", key: "1tivn9" }],
  ["path", { d: "M7 17 17 7", key: "1vkiza" }]
]);

const LuArrowUpToLine = createLucideIcon("LuArrowUpToLine", [
  ["path", { d: "M5 3h14", key: "7usisc" }],
  ["path", { d: "m18 13-6-6-6 6", key: "1kf1n9" }],
  ["path", { d: "M12 7v14", key: "1akyts" }]
]);

const LuArrowUpWideNarrow = createLucideIcon("LuArrowUpWideNarrow", [
  ["path", { d: "m3 8 4-4 4 4", key: "11wl7u" }],
  ["path", { d: "M7 4v16", key: "1glfcx" }],
  ["path", { d: "M11 12h10", key: "1438ji" }],
  ["path", { d: "M11 16h7", key: "uosisv" }],
  ["path", { d: "M11 20h4", key: "1krc32" }]
]);

const LuArrowUpZA = createLucideIcon("LuArrowUpZA", [
  ["path", { d: "m3 8 4-4 4 4", key: "11wl7u" }],
  ["path", { d: "M7 4v16", key: "1glfcx" }],
  ["path", { d: "M15 4h5l-5 6h5", key: "8asdl1" }],
  ["path", { d: "M15 20v-3.5a2.5 2.5 0 0 1 5 0V20", key: "r6l5cz" }],
  ["path", { d: "M20 18h-5", key: "18j1r2" }]
]);

const LuArrowUp = createLucideIcon("LuArrowUp", [
  ["path", { d: "m5 12 7-7 7 7", key: "hav0vg" }],
  ["path", { d: "M12 19V5", key: "x0mq9r" }]
]);

const LuArrowsUpFromLine = createLucideIcon("LuArrowsUpFromLine", [
  ["path", { d: "m4 6 3-3 3 3", key: "9aidw8" }],
  ["path", { d: "M7 17V3", key: "19qxw1" }],
  ["path", { d: "m14 6 3-3 3 3", key: "6iy689" }],
  ["path", { d: "M17 17V3", key: "o0fmgi" }],
  ["path", { d: "M4 21h16", key: "1h09gz" }]
]);

const LuAsterisk = createLucideIcon("LuAsterisk", [
  ["path", { d: "M12 6v12", key: "1vza4d" }],
  ["path", { d: "M17.196 9 6.804 15", key: "1ah31z" }],
  ["path", { d: "m6.804 9 10.392 6", key: "1b6pxd" }]
]);

const LuAtSign = createLucideIcon("LuAtSign", [
  ["circle", { cx: "12", cy: "12", r: "4", key: "4exip2" }],
  ["path", { d: "M16 8v5a3 3 0 0 0 6 0v-1a10 10 0 1 0-4 8", key: "7n84p3" }]
]);

const LuAtom = createLucideIcon("LuAtom", [
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }],
  [
    "path",
    {
      d: "M20.2 20.2c2.04-2.03.02-7.36-4.5-11.9-4.54-4.52-9.87-6.54-11.9-4.5-2.04 2.03-.02 7.36 4.5 11.9 4.54 4.52 9.87 6.54 11.9 4.5Z",
      key: "1l2ple"
    }
  ],
  [
    "path",
    {
      d: "M15.7 15.7c4.52-4.54 6.54-9.87 4.5-11.9-2.03-2.04-7.36-.02-11.9 4.5-4.52 4.54-6.54 9.87-4.5 11.9 2.03 2.04 7.36.02 11.9-4.5Z",
      key: "1wam0m"
    }
  ]
]);

const LuAudioLines = createLucideIcon("LuAudioLines", [
  ["path", { d: "M2 10v3", key: "1fnikh" }],
  ["path", { d: "M6 6v11", key: "11sgs0" }],
  ["path", { d: "M10 3v18", key: "yhl04a" }],
  ["path", { d: "M14 8v7", key: "3a1oy3" }],
  ["path", { d: "M18 5v13", key: "123xd1" }],
  ["path", { d: "M22 10v3", key: "154ddg" }]
]);

const LuAudioWaveform = createLucideIcon("LuAudioWaveform", [
  [
    "path",
    {
      d: "M2 13a2 2 0 0 0 2-2V7a2 2 0 0 1 4 0v13a2 2 0 0 0 4 0V4a2 2 0 0 1 4 0v13a2 2 0 0 0 4 0v-4a2 2 0 0 1 2-2",
      key: "57tc96"
    }
  ]
]);

const LuAward = createLucideIcon("LuAward", [
  ["circle", { cx: "12", cy: "8", r: "6", key: "1vp47v" }],
  ["path", { d: "M15.477 12.89 17 22l-5-3-5 3 1.523-9.11", key: "em7aur" }]
]);

const LuAxe = createLucideIcon("LuAxe", [
  ["path", { d: "m14 12-8.5 8.5a2.12 2.12 0 1 1-3-3L11 9", key: "csbz4o" }],
  ["path", { d: "M15 13 9 7l4-4 6 6h3a8 8 0 0 1-7 7z", key: "113wfo" }]
]);

const LuAxis3d = createLucideIcon("LuAxis3d", [
  ["path", { d: "M4 4v16h16", key: "1s015l" }],
  ["path", { d: "m4 20 7-7", key: "17qe9y" }]
]);

const LuBaby = createLucideIcon("LuBaby", [
  ["path", { d: "M9 12h.01", key: "157uk2" }],
  ["path", { d: "M15 12h.01", key: "1k8ypt" }],
  ["path", { d: "M10 16c.5.3 1.2.5 2 .5s1.5-.2 2-.5", key: "1u7htd" }],
  [
    "path",
    {
      d: "M19 6.3a9 9 0 0 1 1.8 3.9 2 2 0 0 1 0 3.6 9 9 0 0 1-17.6 0 2 2 0 0 1 0-3.6A9 9 0 0 1 12 3c2 0 3.5 1.1 3.5 2.5s-.9 2.5-2 2.5c-.8 0-1.5-.4-1.5-1",
      key: "5yv0yz"
    }
  ]
]);

const LuBackpack = createLucideIcon("LuBackpack", [
  [
    "path",
    { d: "M4 10a4 4 0 0 1 4-4h8a4 4 0 0 1 4 4v10a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2Z", key: "wvr1b5" }
  ],
  ["path", { d: "M9 6V4a2 2 0 0 1 2-2h2a2 2 0 0 1 2 2v2", key: "donm21" }],
  ["path", { d: "M8 21v-5a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v5", key: "xk3gvk" }],
  ["path", { d: "M8 10h8", key: "c7uz4u" }],
  ["path", { d: "M8 18h8", key: "1no2b1" }]
]);

const LuBadgeAlert = createLucideIcon("LuBadgeAlert", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["line", { x1: "12", x2: "12", y1: "8", y2: "12", key: "1pkeuh" }],
  ["line", { x1: "12", x2: "12.01", y1: "16", y2: "16", key: "4dfq90" }]
]);

const LuBadgeCent = createLucideIcon("LuBadgeCent", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "M12 7v10", key: "jspqdw" }],
  ["path", { d: "M15.4 10a4 4 0 1 0 0 4", key: "2eqtx8" }]
]);

const LuBadgeCheck = createLucideIcon("LuBadgeCheck", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "m9 12 2 2 4-4", key: "dzmm74" }]
]);

const LuBadgeDollarSign = createLucideIcon("LuBadgeDollarSign", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "M16 8h-6a2 2 0 1 0 0 4h4a2 2 0 1 1 0 4H8", key: "1h4pet" }],
  ["path", { d: "M12 18V6", key: "zqpxq5" }]
]);

const LuBadgeEuro = createLucideIcon("LuBadgeEuro", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "M7 12h5", key: "gblrwe" }],
  ["path", { d: "M15 9.4a4 4 0 1 0 0 5.2", key: "1makmb" }]
]);

const LuBadgeHelp = createLucideIcon("LuBadgeHelp", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "M9.09 9a3 3 0 0 1 5.83 1c0 2-3 3-3 3", key: "1u773s" }],
  ["line", { x1: "12", x2: "12.01", y1: "17", y2: "17", key: "io3f8k" }]
]);

const LuBadgeIndianRupee = createLucideIcon("LuBadgeIndianRupee", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "M8 8h8", key: "1bis0t" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["path", { d: "m13 17-5-1h1a4 4 0 0 0 0-8", key: "nu2bwa" }]
]);

const LuBadgeInfo = createLucideIcon("LuBadgeInfo", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["line", { x1: "12", x2: "12", y1: "16", y2: "12", key: "1y1yb1" }],
  ["line", { x1: "12", x2: "12.01", y1: "8", y2: "8", key: "110wyk" }]
]);

const LuBadgeJapaneseYen = createLucideIcon("LuBadgeJapaneseYen", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "m9 8 3 3v7", key: "17yadx" }],
  ["path", { d: "m12 11 3-3", key: "p4cfq1" }],
  ["path", { d: "M9 12h6", key: "1c52cq" }],
  ["path", { d: "M9 16h6", key: "8wimt3" }]
]);

const LuBadgeMinus = createLucideIcon("LuBadgeMinus", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["line", { x1: "8", x2: "16", y1: "12", y2: "12", key: "1jonct" }]
]);

const LuBadgePercent = createLucideIcon("LuBadgePercent", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "m15 9-6 6", key: "1uzhvr" }],
  ["path", { d: "M9 9h.01", key: "1q5me6" }],
  ["path", { d: "M15 15h.01", key: "lqbp3k" }]
]);

const LuBadgePlus = createLucideIcon("LuBadgePlus", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["line", { x1: "12", x2: "12", y1: "8", y2: "16", key: "10p56q" }],
  ["line", { x1: "8", x2: "16", y1: "12", y2: "12", key: "1jonct" }]
]);

const LuBadgePoundSterling = createLucideIcon("LuBadgePoundSterling", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "M8 12h4", key: "qz6y1c" }],
  ["path", { d: "M10 16V9.5a2.5 2.5 0 0 1 5 0", key: "3mlbjk" }],
  ["path", { d: "M8 16h7", key: "sbedsn" }]
]);

const LuBadgeRussianRuble = createLucideIcon("LuBadgeRussianRuble", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "M9 16h5", key: "1syiyw" }],
  ["path", { d: "M9 12h5a2 2 0 1 0 0-4h-3v9", key: "1ge9c1" }]
]);

const LuBadgeSwissFranc = createLucideIcon("LuBadgeSwissFranc", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["path", { d: "M11 17V8h4", key: "1bfq6y" }],
  ["path", { d: "M11 12h3", key: "2eqnfz" }],
  ["path", { d: "M9 16h4", key: "1skf3a" }]
]);

const LuBadgeX = createLucideIcon("LuBadgeX", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ],
  ["line", { x1: "15", x2: "9", y1: "9", y2: "15", key: "f7djnv" }],
  ["line", { x1: "9", x2: "15", y1: "9", y2: "15", key: "1shsy8" }]
]);

const LuBadge = createLucideIcon("LuBadge", [
  [
    "path",
    {
      d: "M3.85 8.62a4 4 0 0 1 4.78-4.77 4 4 0 0 1 6.74 0 4 4 0 0 1 4.78 4.78 4 4 0 0 1 0 6.74 4 4 0 0 1-4.77 4.78 4 4 0 0 1-6.75 0 4 4 0 0 1-4.78-4.77 4 4 0 0 1 0-6.76Z",
      key: "3c2336"
    }
  ]
]);

const LuBaggageClaim = createLucideIcon("LuBaggageClaim", [
  ["path", { d: "M22 18H6a2 2 0 0 1-2-2V7a2 2 0 0 0-2-2", key: "4irg2o" }],
  ["path", { d: "M17 14V4a2 2 0 0 0-2-2h-1a2 2 0 0 0-2 2v10", key: "14fcyx" }],
  ["rect", { width: "13", height: "8", x: "8", y: "6", rx: "1", key: "o6oiis" }],
  ["circle", { cx: "18", cy: "20", r: "2", key: "t9985n" }],
  ["circle", { cx: "9", cy: "20", r: "2", key: "e5v82j" }]
]);

const LuBan = createLucideIcon("LuBan", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m4.9 4.9 14.2 14.2", key: "1m5liu" }]
]);

const LuBanana = createLucideIcon("LuBanana", [
  ["path", { d: "M4 13c3.5-2 8-2 10 2a5.5 5.5 0 0 1 8 5", key: "1cscit" }],
  [
    "path",
    {
      d: "M5.15 17.89c5.52-1.52 8.65-6.89 7-12C11.55 4 11.5 2 13 2c3.22 0 5 5.5 5 8 0 6.5-4.2 12-10.49 12C5.11 22 2 22 2 20c0-1.5 1.14-1.55 3.15-2.11Z",
      key: "1y1nbv"
    }
  ]
]);

const LuBanknote = createLucideIcon("LuBanknote", [
  ["rect", { width: "20", height: "12", x: "2", y: "6", rx: "2", key: "9lu3g6" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }],
  ["path", { d: "M6 12h.01M18 12h.01", key: "113zkx" }]
]);

const LuBarChart2 = createLucideIcon("LuBarChart2", [
  ["line", { x1: "18", x2: "18", y1: "20", y2: "10", key: "1xfpm4" }],
  ["line", { x1: "12", x2: "12", y1: "20", y2: "4", key: "be30l9" }],
  ["line", { x1: "6", x2: "6", y1: "20", y2: "14", key: "1r4le6" }]
]);

const LuBarChart3 = createLucideIcon("LuBarChart3", [
  ["path", { d: "M3 3v18h18", key: "1s2lah" }],
  ["path", { d: "M18 17V9", key: "2bz60n" }],
  ["path", { d: "M13 17V5", key: "1frdt8" }],
  ["path", { d: "M8 17v-3", key: "17ska0" }]
]);

const LuBarChart4 = createLucideIcon("LuBarChart4", [
  ["path", { d: "M3 3v18h18", key: "1s2lah" }],
  ["path", { d: "M13 17V9", key: "1fwyjl" }],
  ["path", { d: "M18 17V5", key: "sfb6ij" }],
  ["path", { d: "M8 17v-3", key: "17ska0" }]
]);

const LuBarChartBig = createLucideIcon("LuBarChartBig", [
  ["path", { d: "M3 3v18h18", key: "1s2lah" }],
  ["rect", { width: "4", height: "7", x: "7", y: "10", rx: "1", key: "14u6mf" }],
  ["rect", { width: "4", height: "12", x: "15", y: "5", rx: "1", key: "b3pek6" }]
]);

const LuBarChartHorizontalBig = createLucideIcon("LuBarChartHorizontalBig", [
  ["path", { d: "M3 3v18h18", key: "1s2lah" }],
  ["rect", { width: "12", height: "4", x: "7", y: "5", rx: "1", key: "936jl1" }],
  ["rect", { width: "7", height: "4", x: "7", y: "13", rx: "1", key: "jqfkpy" }]
]);

const LuBarChartHorizontal = createLucideIcon("LuBarChartHorizontal", [
  ["path", { d: "M3 3v18h18", key: "1s2lah" }],
  ["path", { d: "M7 16h8", key: "srdodz" }],
  ["path", { d: "M7 11h12", key: "127s9w" }],
  ["path", { d: "M7 6h3", key: "w9rmul" }]
]);

const LuBarChart = createLucideIcon("LuBarChart", [
  ["line", { x1: "12", x2: "12", y1: "20", y2: "10", key: "1vz5eb" }],
  ["line", { x1: "18", x2: "18", y1: "20", y2: "4", key: "cun8e5" }],
  ["line", { x1: "6", x2: "6", y1: "20", y2: "16", key: "hq0ia6" }]
]);

const LuBarcode = createLucideIcon("LuBarcode", [
  ["path", { d: "M3 5v14", key: "1nt18q" }],
  ["path", { d: "M8 5v14", key: "1ybrkv" }],
  ["path", { d: "M12 5v14", key: "s699le" }],
  ["path", { d: "M17 5v14", key: "ycjyhj" }],
  ["path", { d: "M21 5v14", key: "nzette" }]
]);

const LuBaseline = createLucideIcon("LuBaseline", [
  ["path", { d: "M4 20h16", key: "14thso" }],
  ["path", { d: "m6 16 6-12 6 12", key: "1b4byz" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }]
]);

const LuBath = createLucideIcon("LuBath", [
  [
    "path",
    {
      d: "M9 6 6.5 3.5a1.5 1.5 0 0 0-1-.5C4.683 3 4 3.683 4 4.5V17a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-5",
      key: "1r8yf5"
    }
  ],
  ["line", { x1: "10", x2: "8", y1: "5", y2: "7", key: "h5g8z4" }],
  ["line", { x1: "2", x2: "22", y1: "12", y2: "12", key: "1dnqot" }],
  ["line", { x1: "7", x2: "7", y1: "19", y2: "21", key: "16jp00" }],
  ["line", { x1: "17", x2: "17", y1: "19", y2: "21", key: "1pxrnk" }]
]);

const LuBatteryCharging = createLucideIcon("LuBatteryCharging", [
  ["path", { d: "M15 7h1a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2h-2", key: "1sdynx" }],
  ["path", { d: "M6 7H4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h1", key: "1gkd3k" }],
  ["path", { d: "m11 7-3 5h4l-3 5", key: "b4a64w" }],
  ["line", { x1: "22", x2: "22", y1: "11", y2: "13", key: "4dh1rd" }]
]);

const LuBatteryFull = createLucideIcon("LuBatteryFull", [
  ["rect", { width: "16", height: "10", x: "2", y: "7", rx: "2", ry: "2", key: "1w10f2" }],
  ["line", { x1: "22", x2: "22", y1: "11", y2: "13", key: "4dh1rd" }],
  ["line", { x1: "6", x2: "6", y1: "11", y2: "13", key: "1wd6dw" }],
  ["line", { x1: "10", x2: "10", y1: "11", y2: "13", key: "haxvl5" }],
  ["line", { x1: "14", x2: "14", y1: "11", y2: "13", key: "c6fn6x" }]
]);

const LuBatteryLow = createLucideIcon("LuBatteryLow", [
  ["rect", { width: "16", height: "10", x: "2", y: "7", rx: "2", ry: "2", key: "1w10f2" }],
  ["line", { x1: "22", x2: "22", y1: "11", y2: "13", key: "4dh1rd" }],
  ["line", { x1: "6", x2: "6", y1: "11", y2: "13", key: "1wd6dw" }]
]);

const LuBatteryMedium = createLucideIcon("LuBatteryMedium", [
  ["rect", { width: "16", height: "10", x: "2", y: "7", rx: "2", ry: "2", key: "1w10f2" }],
  ["line", { x1: "22", x2: "22", y1: "11", y2: "13", key: "4dh1rd" }],
  ["line", { x1: "6", x2: "6", y1: "11", y2: "13", key: "1wd6dw" }],
  ["line", { x1: "10", x2: "10", y1: "11", y2: "13", key: "haxvl5" }]
]);

const LuBatteryWarning = createLucideIcon("LuBatteryWarning", [
  ["path", { d: "M14 7h2a2 2 0 0 1 2 2v6c0 1-1 2-2 2h-2", key: "1if82c" }],
  ["path", { d: "M6 7H4a2 2 0 0 0-2 2v6c0 1 1 2 2 2h2", key: "2pdlyl" }],
  ["line", { x1: "22", x2: "22", y1: "11", y2: "13", key: "4dh1rd" }],
  ["line", { x1: "10", x2: "10", y1: "7", y2: "13", key: "1uzyus" }],
  ["line", { x1: "10", x2: "10", y1: "17", y2: "17.01", key: "1y8k4g" }]
]);

const LuBattery = createLucideIcon("LuBattery", [
  ["rect", { width: "16", height: "10", x: "2", y: "7", rx: "2", ry: "2", key: "1w10f2" }],
  ["line", { x1: "22", x2: "22", y1: "11", y2: "13", key: "4dh1rd" }]
]);

const LuBeaker = createLucideIcon("LuBeaker", [
  ["path", { d: "M4.5 3h15", key: "c7n0jr" }],
  ["path", { d: "M6 3v16a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V3", key: "m1uhx7" }],
  ["path", { d: "M6 14h12", key: "4cwo0f" }]
]);

const LuBeanOff = createLucideIcon("LuBeanOff", [
  [
    "path",
    {
      d: "M9 9c-.64.64-1.521.954-2.402 1.165A6 6 0 0 0 8 22a13.96 13.96 0 0 0 9.9-4.1",
      key: "bq3udt"
    }
  ],
  ["path", { d: "M10.75 5.093A6 6 0 0 1 22 8c0 2.411-.61 4.68-1.683 6.66", key: "17ccse" }],
  [
    "path",
    {
      d: "M5.341 10.62a4 4 0 0 0 6.487 1.208M10.62 5.341a4.015 4.015 0 0 1 2.039 2.04",
      key: "18zqgq"
    }
  ],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuBean = createLucideIcon("LuBean", [
  [
    "path",
    {
      d: "M10.165 6.598C9.954 7.478 9.64 8.36 9 9c-.64.64-1.521.954-2.402 1.165A6 6 0 0 0 8 22c7.732 0 14-6.268 14-14a6 6 0 0 0-11.835-1.402Z",
      key: "1tvzk7"
    }
  ],
  ["path", { d: "M5.341 10.62a4 4 0 1 0 5.279-5.28", key: "2cyri2" }]
]);

const LuBedDouble = createLucideIcon("LuBedDouble", [
  ["path", { d: "M2 20v-8a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v8", key: "1k78r4" }],
  ["path", { d: "M4 10V6a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v4", key: "fb3tl2" }],
  ["path", { d: "M12 4v6", key: "1dcgq2" }],
  ["path", { d: "M2 18h20", key: "ajqnye" }]
]);

const LuBedSingle = createLucideIcon("LuBedSingle", [
  ["path", { d: "M3 20v-8a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v8", key: "1wm6mi" }],
  ["path", { d: "M5 10V6a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v4", key: "4k93s5" }],
  ["path", { d: "M3 18h18", key: "1h113x" }]
]);

const LuBed = createLucideIcon("LuBed", [
  ["path", { d: "M2 4v16", key: "vw9hq8" }],
  ["path", { d: "M2 8h18a2 2 0 0 1 2 2v10", key: "1dgv2r" }],
  ["path", { d: "M2 17h20", key: "18nfp3" }],
  ["path", { d: "M6 8v9", key: "1yriud" }]
]);

const LuBeef = createLucideIcon("LuBeef", [
  ["circle", { cx: "12.5", cy: "8.5", r: "2.5", key: "9738u8" }],
  [
    "path",
    {
      d: "M12.5 2a6.5 6.5 0 0 0-6.22 4.6c-1.1 3.13-.78 3.9-3.18 6.08A3 3 0 0 0 5 18c4 0 8.4-1.8 11.4-4.3A6.5 6.5 0 0 0 12.5 2Z",
      key: "o0f6za"
    }
  ],
  [
    "path",
    {
      d: "m18.5 6 2.19 4.5a6.48 6.48 0 0 1 .31 2 6.49 6.49 0 0 1-2.6 5.2C15.4 20.2 11 22 7 22a3 3 0 0 1-2.68-1.66L2.4 16.5",
      key: "k7p6i0"
    }
  ]
]);

const LuBeer = createLucideIcon("LuBeer", [
  ["path", { d: "M17 11h1a3 3 0 0 1 0 6h-1", key: "1yp76v" }],
  ["path", { d: "M9 12v6", key: "1u1cab" }],
  ["path", { d: "M13 12v6", key: "1sugkk" }],
  [
    "path",
    {
      d: "M14 7.5c-1 0-1.44.5-3 .5s-2-.5-3-.5-1.72.5-2.5.5a2.5 2.5 0 0 1 0-5c.78 0 1.57.5 2.5.5S9.44 2 11 2s2 1.5 3 1.5 1.72-.5 2.5-.5a2.5 2.5 0 0 1 0 5c-.78 0-1.5-.5-2.5-.5Z",
      key: "1510fo"
    }
  ],
  ["path", { d: "M5 8v12a2 2 0 0 0 2 2h8a2 2 0 0 0 2-2V8", key: "19jb7n" }]
]);

const LuBellDot = createLucideIcon("LuBellDot", [
  [
    "path",
    {
      d: "M19.4 14.9C20.2 16.4 21 17 21 17H3s3-2 3-9c0-3.3 2.7-6 6-6 .7 0 1.3.1 1.9.3",
      key: "xcehk"
    }
  ],
  ["path", { d: "M10.3 21a1.94 1.94 0 0 0 3.4 0", key: "qgo35s" }],
  ["circle", { cx: "18", cy: "8", r: "3", key: "1g0gzu" }]
]);

const LuBellElectric = createLucideIcon("LuBellElectric", [
  ["path", { d: "M18.8 4A6.3 8.7 0 0 1 20 9", key: "xve1fh" }],
  ["path", { d: "M9 9h.01", key: "1q5me6" }],
  ["circle", { cx: "9", cy: "9", r: "7", key: "p2h5vp" }],
  ["rect", { width: "10", height: "6", x: "4", y: "16", rx: "2", key: "17f3te" }],
  ["path", { d: "M14 19c3 0 4.6-1.6 4.6-1.6", key: "n7odp6" }],
  ["circle", { cx: "20", cy: "16", r: "2", key: "1v9bxh" }]
]);

const LuBellMinus = createLucideIcon("LuBellMinus", [
  [
    "path",
    { d: "M18.4 12c.8 3.8 2.6 5 2.6 5H3s3-2 3-9c0-3.3 2.7-6 6-6 1.8 0 3.4.8 4.5 2", key: "eck70s" }
  ],
  ["path", { d: "M10.3 21a1.94 1.94 0 0 0 3.4 0", key: "qgo35s" }],
  ["path", { d: "M15 8h6", key: "8ybuxh" }]
]);

const LuBellOff = createLucideIcon("LuBellOff", [
  ["path", { d: "M8.7 3A6 6 0 0 1 18 8a21.3 21.3 0 0 0 .6 5", key: "o7mx20" }],
  ["path", { d: "M17 17H3s3-2 3-9a4.67 4.67 0 0 1 .3-1.7", key: "16f1lm" }],
  ["path", { d: "M10.3 21a1.94 1.94 0 0 0 3.4 0", key: "qgo35s" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuBellPlus = createLucideIcon("LuBellPlus", [
  [
    "path",
    {
      d: "M19.3 14.8C20.1 16.4 21 17 21 17H3s3-2 3-9c0-3.3 2.7-6 6-6 1 0 1.9.2 2.8.7",
      key: "guizqy"
    }
  ],
  ["path", { d: "M10.3 21a1.94 1.94 0 0 0 3.4 0", key: "qgo35s" }],
  ["path", { d: "M15 8h6", key: "8ybuxh" }],
  ["path", { d: "M18 5v6", key: "g5ayrv" }]
]);

const LuBellRing = createLucideIcon("LuBellRing", [
  ["path", { d: "M6 8a6 6 0 0 1 12 0c0 7 3 9 3 9H3s3-2 3-9", key: "1qo2s2" }],
  ["path", { d: "M10.3 21a1.94 1.94 0 0 0 3.4 0", key: "qgo35s" }],
  ["path", { d: "M4 2C2.8 3.7 2 5.7 2 8", key: "tap9e0" }],
  ["path", { d: "M22 8c0-2.3-.8-4.3-2-6", key: "5bb3ad" }]
]);

const LuBell = createLucideIcon("LuBell", [
  ["path", { d: "M6 8a6 6 0 0 1 12 0c0 7 3 9 3 9H3s3-2 3-9", key: "1qo2s2" }],
  ["path", { d: "M10.3 21a1.94 1.94 0 0 0 3.4 0", key: "qgo35s" }]
]);

const LuBetweenHorizontalEnd = createLucideIcon("LuBetweenHorizontalEnd", [
  ["rect", { width: "13", height: "7", x: "3", y: "3", rx: "1", key: "11xb64" }],
  ["path", { d: "m22 15-3-3 3-3", key: "26chmm" }],
  ["rect", { width: "13", height: "7", x: "3", y: "14", rx: "1", key: "k6ky7n" }]
]);

const LuBetweenHorizontalStart = createLucideIcon("LuBetweenHorizontalStart", [
  ["rect", { width: "13", height: "7", x: "8", y: "3", rx: "1", key: "pkso9a" }],
  ["path", { d: "m2 9 3 3-3 3", key: "1agib5" }],
  ["rect", { width: "13", height: "7", x: "8", y: "14", rx: "1", key: "1q5fc1" }]
]);

const LuBetweenVerticalEnd = createLucideIcon("LuBetweenVerticalEnd", [
  ["rect", { width: "7", height: "13", x: "3", y: "3", rx: "1", key: "1fdu0f" }],
  ["path", { d: "m9 22 3-3 3 3", key: "17z65a" }],
  ["rect", { width: "7", height: "13", x: "14", y: "3", rx: "1", key: "1squn4" }]
]);

const LuBetweenVerticalStart = createLucideIcon("LuBetweenVerticalStart", [
  ["rect", { width: "7", height: "13", x: "3", y: "8", rx: "1", key: "1fjrkv" }],
  ["path", { d: "m15 2-3 3-3-3", key: "1uh6eb" }],
  ["rect", { width: "7", height: "13", x: "14", y: "8", rx: "1", key: "w3fjg8" }]
]);

const LuBike = createLucideIcon("LuBike", [
  ["circle", { cx: "18.5", cy: "17.5", r: "3.5", key: "15x4ox" }],
  ["circle", { cx: "5.5", cy: "17.5", r: "3.5", key: "1noe27" }],
  ["circle", { cx: "15", cy: "5", r: "1", key: "19l28e" }],
  ["path", { d: "M12 17.5V14l-3-3 4-3 2 3h2", key: "1npguv" }]
]);

const LuBinary = createLucideIcon("LuBinary", [
  ["rect", { x: "14", y: "14", width: "4", height: "6", rx: "2", key: "p02svl" }],
  ["rect", { x: "6", y: "4", width: "4", height: "6", rx: "2", key: "xm4xkj" }],
  ["path", { d: "M6 20h4", key: "1i6q5t" }],
  ["path", { d: "M14 10h4", key: "ru81e7" }],
  ["path", { d: "M6 14h2v6", key: "16z9wg" }],
  ["path", { d: "M14 4h2v6", key: "1idq9u" }]
]);

const LuBiohazard = createLucideIcon("LuBiohazard", [
  ["circle", { cx: "12", cy: "11.9", r: "2", key: "e8h31w" }],
  ["path", { d: "M6.7 3.4c-.9 2.5 0 5.2 2.2 6.7C6.5 9 3.7 9.6 2 11.6", key: "17bolr" }],
  ["path", { d: "m8.9 10.1 1.4.8", key: "15ezny" }],
  ["path", { d: "M17.3 3.4c.9 2.5 0 5.2-2.2 6.7 2.4-1.2 5.2-.6 6.9 1.5", key: "wtwa5u" }],
  ["path", { d: "m15.1 10.1-1.4.8", key: "1r0b28" }],
  ["path", { d: "M16.7 20.8c-2.6-.4-4.6-2.6-4.7-5.3-.2 2.6-2.1 4.8-4.7 5.2", key: "m7qszh" }],
  ["path", { d: "M12 13.9v1.6", key: "zfyyim" }],
  ["path", { d: "M13.5 5.4c-1-.2-2-.2-3 0", key: "1bi9q0" }],
  ["path", { d: "M17 16.4c.7-.7 1.2-1.6 1.5-2.5", key: "1rhjqw" }],
  ["path", { d: "M5.5 13.9c.3.9.8 1.8 1.5 2.5", key: "8gsud3" }]
]);

const LuBird = createLucideIcon("LuBird", [
  ["path", { d: "M16 7h.01", key: "1kdx03" }],
  ["path", { d: "M3.4 18H12a8 8 0 0 0 8-8V7a4 4 0 0 0-7.28-2.3L2 20", key: "oj1oa8" }],
  ["path", { d: "m20 7 2 .5-2 .5", key: "12nv4d" }],
  ["path", { d: "M10 18v3", key: "1yea0a" }],
  ["path", { d: "M14 17.75V21", key: "1pymcb" }],
  ["path", { d: "M7 18a6 6 0 0 0 3.84-10.61", key: "1npnn0" }]
]);

const LuBitcoin = createLucideIcon("LuBitcoin", [
  [
    "path",
    {
      d: "M11.767 19.089c4.924.868 6.14-6.025 1.216-6.894m-1.216 6.894L5.86 18.047m5.908 1.042-.347 1.97m1.563-8.864c4.924.869 6.14-6.025 1.215-6.893m-1.215 6.893-3.94-.694m5.155-6.2L8.29 4.26m5.908 1.042.348-1.97M7.48 20.364l3.126-17.727",
      key: "yr8idg"
    }
  ]
]);

const LuBlend = createLucideIcon("LuBlend", [
  ["circle", { cx: "9", cy: "9", r: "7", key: "p2h5vp" }],
  ["circle", { cx: "15", cy: "15", r: "7", key: "19ennj" }]
]);

const LuBlinds = createLucideIcon("LuBlinds", [
  ["path", { d: "M3 3h18", key: "o7r712" }],
  ["path", { d: "M20 7H8", key: "gd2fo2" }],
  ["path", { d: "M20 11H8", key: "1ynp89" }],
  ["path", { d: "M10 19h10", key: "19hjk5" }],
  ["path", { d: "M8 15h12", key: "1yqzne" }],
  ["path", { d: "M4 3v14", key: "fggqzn" }],
  ["circle", { cx: "4", cy: "19", r: "2", key: "p3m9r0" }]
]);

const LuBlocks = createLucideIcon("LuBlocks", [
  ["rect", { width: "7", height: "7", x: "14", y: "3", rx: "1", key: "6d4xhi" }],
  [
    "path",
    {
      d: "M10 21V8a1 1 0 0 0-1-1H4a1 1 0 0 0-1 1v12a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-5a1 1 0 0 0-1-1H3",
      key: "1fpvtg"
    }
  ]
]);

const LuBluetoothConnected = createLucideIcon("LuBluetoothConnected", [
  ["path", { d: "m7 7 10 10-5 5V2l5 5L7 17", key: "1q5490" }],
  ["line", { x1: "18", x2: "21", y1: "12", y2: "12", key: "1rsjjs" }],
  ["line", { x1: "3", x2: "6", y1: "12", y2: "12", key: "11yl8c" }]
]);

const LuBluetoothOff = createLucideIcon("LuBluetoothOff", [
  ["path", { d: "m17 17-5 5V12l-5 5", key: "v5aci6" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M14.5 9.5 17 7l-5-5v4.5", key: "1kddfz" }]
]);

const LuBluetoothSearching = createLucideIcon("LuBluetoothSearching", [
  ["path", { d: "m7 7 10 10-5 5V2l5 5L7 17", key: "1q5490" }],
  ["path", { d: "M20.83 14.83a4 4 0 0 0 0-5.66", key: "k8tn1j" }],
  ["path", { d: "M18 12h.01", key: "yjnet6" }]
]);

const LuBluetooth = createLucideIcon("LuBluetooth", [
  ["path", { d: "m7 7 10 10-5 5V2l5 5L7 17", key: "1q5490" }]
]);

const LuBold = createLucideIcon("LuBold", [
  ["path", { d: "M14 12a4 4 0 0 0 0-8H6v8", key: "v2sylx" }],
  ["path", { d: "M15 20a4 4 0 0 0 0-8H6v8Z", key: "1ef5ya" }]
]);

const LuBolt = createLucideIcon("LuBolt", [
  [
    "path",
    {
      d: "M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z",
      key: "yt0hxn"
    }
  ],
  ["circle", { cx: "12", cy: "12", r: "4", key: "4exip2" }]
]);

const LuBomb = createLucideIcon("LuBomb", [
  ["circle", { cx: "11", cy: "13", r: "9", key: "hd149" }],
  [
    "path",
    {
      d: "M14.35 4.65 16.3 2.7a2.41 2.41 0 0 1 3.4 0l1.6 1.6a2.4 2.4 0 0 1 0 3.4l-1.95 1.95",
      key: "jp4j1b"
    }
  ],
  ["path", { d: "m22 2-1.5 1.5", key: "ay92ug" }]
]);

const LuBone = createLucideIcon("LuBone", [
  [
    "path",
    {
      d: "M17 10c.7-.7 1.69 0 2.5 0a2.5 2.5 0 1 0 0-5 .5.5 0 0 1-.5-.5 2.5 2.5 0 1 0-5 0c0 .81.7 1.8 0 2.5l-7 7c-.7.7-1.69 0-2.5 0a2.5 2.5 0 0 0 0 5c.28 0 .5.22.5.5a2.5 2.5 0 1 0 5 0c0-.81-.7-1.8 0-2.5Z",
      key: "w610uw"
    }
  ]
]);

const LuBookA = createLucideIcon("LuBookA", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "m8 13 4-7 4 7", key: "4rari8" }],
  ["path", { d: "M9.1 11h5.7", key: "1gkovt" }]
]);

const LuBookAudio = createLucideIcon("LuBookAudio", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "M8 8v3", key: "1qzp49" }],
  ["path", { d: "M12 6v7", key: "1f6ttz" }],
  ["path", { d: "M16 8v3", key: "gejaml" }]
]);

const LuBookCheck = createLucideIcon("LuBookCheck", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "m9 9.5 2 2 4-4", key: "1dth82" }]
]);

const LuBookCopy = createLucideIcon("LuBookCopy", [
  ["path", { d: "M2 16V4a2 2 0 0 1 2-2h11", key: "spzkk5" }],
  ["path", { d: "M5 14H4a2 2 0 1 0 0 4h1", key: "16gqf9" }],
  ["path", { d: "M22 18H11a2 2 0 1 0 0 4h11V6H11a2 2 0 0 0-2 2v12", key: "1owzki" }]
]);

const LuBookDashed = createLucideIcon("LuBookDashed", [
  ["path", { d: "M20 22h-2", key: "1rpnb6" }],
  ["path", { d: "M20 15v2h-2", key: "fph276" }],
  ["path", { d: "M4 19.5V15", key: "6gr39e" }],
  ["path", { d: "M20 8v3", key: "deu0bs" }],
  ["path", { d: "M18 2h2v2", key: "180o53" }],
  ["path", { d: "M4 11V9", key: "v3xsx8" }],
  ["path", { d: "M12 2h2", key: "cvn524" }],
  ["path", { d: "M12 22h2", key: "kn7ki6" }],
  ["path", { d: "M12 17h2", key: "13u4lk" }],
  ["path", { d: "M8 22H6.5a2.5 2.5 0 0 1 0-5H8", key: "fiseg2" }],
  ["path", { d: "M4 5v-.5A2.5 2.5 0 0 1 6.5 2H8", key: "wywhs9" }]
]);

const LuBookDown = createLucideIcon("LuBookDown", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "M12 13V7", key: "h0r20n" }],
  ["path", { d: "m9 10 3 3 3-3", key: "zt5b4y" }]
]);

const LuBookHeadphones = createLucideIcon("LuBookHeadphones", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["circle", { cx: "9", cy: "12", r: "1", key: "1vctgf" }],
  ["path", { d: "M8 12v-2a4 4 0 0 1 8 0v2", key: "1vsqkj" }],
  ["circle", { cx: "15", cy: "12", r: "1", key: "1tmaij" }]
]);

const LuBookHeart = createLucideIcon("LuBookHeart", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  [
    "path",
    {
      d: "M16 8.2C16 7 15 6 13.8 6c-.8 0-1.4.3-1.8.9-.4-.6-1-.9-1.8-.9C9 6 8 7 8 8.2c0 .6.3 1.2.7 1.6h0C10 11.1 12 13 12 13s2-1.9 3.3-3.1h0c.4-.4.7-1 .7-1.7z",
      key: "1dlbw1"
    }
  ]
]);

const LuBookImage = createLucideIcon("LuBookImage", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["circle", { cx: "10", cy: "8", r: "2", key: "2qkj4p" }],
  ["path", { d: "m20 13.7-2.1-2.1c-.8-.8-2-.8-2.8 0L9.7 17", key: "160say" }]
]);

const LuBookKey = createLucideIcon("LuBookKey", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H14", key: "1gfsgw" }],
  ["path", { d: "M20 8v14H6.5a2.5 2.5 0 0 1 0-5H20", key: "zb0ngp" }],
  ["circle", { cx: "14", cy: "8", r: "2", key: "u49eql" }],
  ["path", { d: "m20 2-4.5 4.5", key: "1sppr8" }],
  ["path", { d: "m19 3 1 1", key: "ze14oc" }]
]);

const LuBookLock = createLucideIcon("LuBookLock", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H10", key: "18wgow" }],
  ["path", { d: "M20 15v7H6.5a2.5 2.5 0 0 1 0-5H20", key: "dpch1j" }],
  ["rect", { width: "8", height: "5", x: "12", y: "6", rx: "1", key: "9nqwug" }],
  ["path", { d: "M18 6V4a2 2 0 1 0-4 0v2", key: "1aquzs" }]
]);

const LuBookMarked = createLucideIcon("LuBookMarked", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["polyline", { points: "10 2 10 10 13 7 16 10 16 2", key: "13o6vz" }]
]);

const LuBookMinus = createLucideIcon("LuBookMinus", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "M9 10h6", key: "9gxzsh" }]
]);

const LuBookOpenCheck = createLucideIcon("LuBookOpenCheck", [
  ["path", { d: "M8 3H2v15h7c1.7 0 3 1.3 3 3V7c0-2.2-1.8-4-4-4Z", key: "1i8u0n" }],
  ["path", { d: "m16 12 2 2 4-4", key: "mdajum" }],
  ["path", { d: "M22 6V3h-6c-2.2 0-4 1.8-4 4v14c0-1.7 1.3-3 3-3h7v-2.3", key: "jb5l51" }]
]);

const LuBookOpenText = createLucideIcon("LuBookOpenText", [
  ["path", { d: "M2 3h6a4 4 0 0 1 4 4v14a3 3 0 0 0-3-3H2z", key: "vv98re" }],
  ["path", { d: "M22 3h-6a4 4 0 0 0-4 4v14a3 3 0 0 1 3-3h7z", key: "1cyq3y" }],
  ["path", { d: "M6 8h2", key: "30oboj" }],
  ["path", { d: "M6 12h2", key: "32wvfc" }],
  ["path", { d: "M16 8h2", key: "msurwy" }],
  ["path", { d: "M16 12h2", key: "7q9ll5" }]
]);

const LuBookOpen = createLucideIcon("LuBookOpen", [
  ["path", { d: "M2 3h6a4 4 0 0 1 4 4v14a3 3 0 0 0-3-3H2z", key: "vv98re" }],
  ["path", { d: "M22 3h-6a4 4 0 0 0-4 4v14a3 3 0 0 1 3-3h7z", key: "1cyq3y" }]
]);

const LuBookPlus = createLucideIcon("LuBookPlus", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "M9 10h6", key: "9gxzsh" }],
  ["path", { d: "M12 7v6", key: "lw1j43" }]
]);

const LuBookText = createLucideIcon("LuBookText", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "M8 7h6", key: "1f0q6e" }],
  ["path", { d: "M8 11h8", key: "vwpz6n" }]
]);

const LuBookType = createLucideIcon("LuBookType", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "M16 8V6H8v2", key: "x8j6u4" }],
  ["path", { d: "M12 6v7", key: "1f6ttz" }],
  ["path", { d: "M10 13h4", key: "ytezjc" }]
]);

const LuBookUp2 = createLucideIcon("LuBookUp2", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2", key: "1lorq7" }],
  ["path", { d: "M18 2h2v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "1nfm9i" }],
  ["path", { d: "M12 13V7", key: "h0r20n" }],
  ["path", { d: "m9 10 3-3 3 3", key: "11gsxs" }],
  ["path", { d: "m9 5 3-3 3 3", key: "l8vdw6" }]
]);

const LuBookUp = createLucideIcon("LuBookUp", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "M12 13V7", key: "h0r20n" }],
  ["path", { d: "m9 10 3-3 3 3", key: "11gsxs" }]
]);

const LuBookUser = createLucideIcon("LuBookUser", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["circle", { cx: "12", cy: "8", r: "2", key: "1822b1" }],
  ["path", { d: "M15 13a3 3 0 1 0-6 0", key: "10j68g" }]
]);

const LuBookX = createLucideIcon("LuBookX", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }],
  ["path", { d: "m14.5 7-5 5", key: "dy991v" }],
  ["path", { d: "m9.5 7 5 5", key: "s45iea" }]
]);

const LuBook = createLucideIcon("LuBook", [
  ["path", { d: "M4 19.5v-15A2.5 2.5 0 0 1 6.5 2H20v20H6.5a2.5 2.5 0 0 1 0-5H20", key: "t4utmx" }]
]);

const LuBookmarkCheck = createLucideIcon("LuBookmarkCheck", [
  ["path", { d: "m19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2Z", key: "169p4p" }],
  ["path", { d: "m9 10 2 2 4-4", key: "1gnqz4" }]
]);

const LuBookmarkMinus = createLucideIcon("LuBookmarkMinus", [
  ["path", { d: "m19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v16z", key: "1fy3hk" }],
  ["line", { x1: "15", x2: "9", y1: "10", y2: "10", key: "1gty7f" }]
]);

const LuBookmarkPlus = createLucideIcon("LuBookmarkPlus", [
  ["path", { d: "m19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v16z", key: "1fy3hk" }],
  ["line", { x1: "12", x2: "12", y1: "7", y2: "13", key: "1cppfj" }],
  ["line", { x1: "15", x2: "9", y1: "10", y2: "10", key: "1gty7f" }]
]);

const LuBookmarkX = createLucideIcon("LuBookmarkX", [
  ["path", { d: "m19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2Z", key: "169p4p" }],
  ["path", { d: "m14.5 7.5-5 5", key: "3lb6iw" }],
  ["path", { d: "m9.5 7.5 5 5", key: "ko136h" }]
]);

const LuBookmark = createLucideIcon("LuBookmark", [
  ["path", { d: "m19 21-7-4-7 4V5a2 2 0 0 1 2-2h10a2 2 0 0 1 2 2v16z", key: "1fy3hk" }]
]);

const LuBoomBox = createLucideIcon("LuBoomBox", [
  ["path", { d: "M4 9V5a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v4", key: "vvzvr1" }],
  ["path", { d: "M8 8v1", key: "xcqmfk" }],
  ["path", { d: "M12 8v1", key: "1rj8u4" }],
  ["path", { d: "M16 8v1", key: "1q12zr" }],
  ["rect", { width: "20", height: "12", x: "2", y: "9", rx: "2", key: "igpb89" }],
  ["circle", { cx: "8", cy: "15", r: "2", key: "fa4a8s" }],
  ["circle", { cx: "16", cy: "15", r: "2", key: "14c3ya" }]
]);

const LuBotMessageSquare = createLucideIcon("LuBotMessageSquare", [
  ["path", { d: "M12 6V2H8", key: "1155em" }],
  ["path", { d: "m8 18-4 4V8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2Z", key: "w2lp3e" }],
  ["path", { d: "M2 12h2", key: "1t8f8n" }],
  ["path", { d: "M9 11v2", key: "1ueba0" }],
  ["path", { d: "M15 11v2", key: "i11awn" }],
  ["path", { d: "M20 12h2", key: "1q8mjw" }]
]);

const LuBot = createLucideIcon("LuBot", [
  ["path", { d: "M12 8V4H8", key: "hb8ula" }],
  ["rect", { width: "16", height: "12", x: "4", y: "8", rx: "2", key: "enze0r" }],
  ["path", { d: "M2 14h2", key: "vft8re" }],
  ["path", { d: "M20 14h2", key: "4cs60a" }],
  ["path", { d: "M15 13v2", key: "1xurst" }],
  ["path", { d: "M9 13v2", key: "rq6x2g" }]
]);

const LuBoxSelect = createLucideIcon("LuBoxSelect", [
  ["path", { d: "M5 3a2 2 0 0 0-2 2", key: "y57alp" }],
  ["path", { d: "M19 3a2 2 0 0 1 2 2", key: "18rm91" }],
  ["path", { d: "M21 19a2 2 0 0 1-2 2", key: "1j7049" }],
  ["path", { d: "M5 21a2 2 0 0 1-2-2", key: "sbafld" }],
  ["path", { d: "M9 3h1", key: "1yesri" }],
  ["path", { d: "M9 21h1", key: "15o7lz" }],
  ["path", { d: "M14 3h1", key: "1ec4yj" }],
  ["path", { d: "M14 21h1", key: "v9vybs" }],
  ["path", { d: "M3 9v1", key: "1r0deq" }],
  ["path", { d: "M21 9v1", key: "mxsmne" }],
  ["path", { d: "M3 14v1", key: "vnatye" }],
  ["path", { d: "M21 14v1", key: "169vum" }]
]);

const LuBox = createLucideIcon("LuBox", [
  [
    "path",
    {
      d: "M21 8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16Z",
      key: "hh9hay"
    }
  ],
  ["path", { d: "m3.3 7 8.7 5 8.7-5", key: "g66t2b" }],
  ["path", { d: "M12 22V12", key: "d0xqtd" }]
]);

const LuBoxes = createLucideIcon("LuBoxes", [
  [
    "path",
    {
      d: "M2.97 12.92A2 2 0 0 0 2 14.63v3.24a2 2 0 0 0 .97 1.71l3 1.8a2 2 0 0 0 2.06 0L12 19v-5.5l-5-3-4.03 2.42Z",
      key: "lc1i9w"
    }
  ],
  ["path", { d: "m7 16.5-4.74-2.85", key: "1o9zyk" }],
  ["path", { d: "m7 16.5 5-3", key: "va8pkn" }],
  ["path", { d: "M7 16.5v5.17", key: "jnp8gn" }],
  [
    "path",
    {
      d: "M12 13.5V19l3.97 2.38a2 2 0 0 0 2.06 0l3-1.8a2 2 0 0 0 .97-1.71v-3.24a2 2 0 0 0-.97-1.71L17 10.5l-5 3Z",
      key: "8zsnat"
    }
  ],
  ["path", { d: "m17 16.5-5-3", key: "8arw3v" }],
  ["path", { d: "m17 16.5 4.74-2.85", key: "8rfmw" }],
  ["path", { d: "M17 16.5v5.17", key: "k6z78m" }],
  [
    "path",
    {
      d: "M7.97 4.42A2 2 0 0 0 7 6.13v4.37l5 3 5-3V6.13a2 2 0 0 0-.97-1.71l-3-1.8a2 2 0 0 0-2.06 0l-3 1.8Z",
      key: "1xygjf"
    }
  ],
  ["path", { d: "M12 8 7.26 5.15", key: "1vbdud" }],
  ["path", { d: "m12 8 4.74-2.85", key: "3rx089" }],
  ["path", { d: "M12 13.5V8", key: "1io7kd" }]
]);

const LuBraces = createLucideIcon("LuBraces", [
  [
    "path",
    { d: "M8 3H7a2 2 0 0 0-2 2v5a2 2 0 0 1-2 2 2 2 0 0 1 2 2v5c0 1.1.9 2 2 2h1", key: "ezmyqa" }
  ],
  [
    "path",
    {
      d: "M16 21h1a2 2 0 0 0 2-2v-5c0-1.1.9-2 2-2a2 2 0 0 1-2-2V5a2 2 0 0 0-2-2h-1",
      key: "e1hn23"
    }
  ]
]);

const LuBrackets = createLucideIcon("LuBrackets", [
  ["path", { d: "M16 3h3v18h-3", key: "1yor1f" }],
  ["path", { d: "M8 21H5V3h3", key: "1qrfwo" }]
]);

const LuBrainCircuit = createLucideIcon("LuBrainCircuit", [
  [
    "path",
    {
      d: "M12 5a3 3 0 1 0-5.997.125 4 4 0 0 0-2.526 5.77 4 4 0 0 0 .556 6.588A4 4 0 1 0 12 18Z",
      key: "l5xja"
    }
  ],
  ["path", { d: "M9 13a4.5 4.5 0 0 0 3-4", key: "10igwf" }],
  ["path", { d: "M6.003 5.125A3 3 0 0 0 6.401 6.5", key: "105sqy" }],
  ["path", { d: "M3.477 10.896a4 4 0 0 1 .585-.396", key: "ql3yin" }],
  ["path", { d: "M6 18a4 4 0 0 1-1.967-.516", key: "2e4loj" }],
  ["path", { d: "M12 13h4", key: "1ku699" }],
  ["path", { d: "M12 18h6a2 2 0 0 1 2 2v1", key: "105ag5" }],
  ["path", { d: "M12 8h8", key: "1lhi5i" }],
  ["path", { d: "M16 8V5a2 2 0 0 1 2-2", key: "u6izg6" }],
  ["circle", { cx: "16", cy: "13", r: ".5", key: "ry7gng" }],
  ["circle", { cx: "18", cy: "3", r: ".5", key: "1aiba7" }],
  ["circle", { cx: "20", cy: "21", r: ".5", key: "yhc1fs" }],
  ["circle", { cx: "20", cy: "8", r: ".5", key: "1e43v0" }]
]);

const LuBrainCog = createLucideIcon("LuBrainCog", [
  [
    "path",
    {
      d: "M12 5a3 3 0 1 0-5.997.142 4 4 0 0 0-2.526 5.77 4 4 0 0 0 .556 6.588 4 4 0 0 0 7.636 2.106 3.2 3.2 0 0 0 .164-.546c.028-.13.306-.13.335 0a3.2 3.2 0 0 0 .163.546 4 4 0 0 0 7.636-2.106 4 4 0 0 0 .556-6.588 4 4 0 0 0-2.526-5.77A3 3 0 1 0 12 5",
      key: "1kgmhc"
    }
  ],
  ["path", { d: "M17.599 6.5a3 3 0 0 0 .399-1.375", key: "tmeiqw" }],
  ["path", { d: "M6.003 5.125A3 3 0 0 0 6.401 6.5", key: "105sqy" }],
  ["path", { d: "M3.477 10.896a4 4 0 0 1 .585-.396", key: "ql3yin" }],
  ["path", { d: "M19.938 10.5a4 4 0 0 1 .585.396", key: "1qfode" }],
  ["path", { d: "M6 18a4 4 0 0 1-1.967-.516", key: "2e4loj" }],
  ["path", { d: "M19.967 17.484A4 4 0 0 1 18 18", key: "159ez6" }],
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  ["path", { d: "m15.7 10.4-.9.4", key: "ayzo6p" }],
  ["path", { d: "m9.2 13.2-.9.4", key: "1uzb3g" }],
  ["path", { d: "m13.6 15.7-.4-.9", key: "11ifqf" }],
  ["path", { d: "m10.8 9.2-.4-.9", key: "1pmk2v" }],
  ["path", { d: "m15.7 13.5-.9-.4", key: "7ng02m" }],
  ["path", { d: "m9.2 10.9-.9-.4", key: "1x66zd" }],
  ["path", { d: "m10.5 15.7.4-.9", key: "3js94g" }],
  ["path", { d: "m13.1 9.2.4-.9", key: "18n7mc" }]
]);

const LuBrain = createLucideIcon("LuBrain", [
  [
    "path",
    {
      d: "M12 5a3 3 0 1 0-5.997.125 4 4 0 0 0-2.526 5.77 4 4 0 0 0 .556 6.588A4 4 0 1 0 12 18Z",
      key: "l5xja"
    }
  ],
  [
    "path",
    {
      d: "M12 5a3 3 0 1 1 5.997.125 4 4 0 0 1 2.526 5.77 4 4 0 0 1-.556 6.588A4 4 0 1 1 12 18Z",
      key: "ep3f8r"
    }
  ],
  ["path", { d: "M15 13a4.5 4.5 0 0 1-3-4 4.5 4.5 0 0 1-3 4", key: "1p4c4q" }],
  ["path", { d: "M17.599 6.5a3 3 0 0 0 .399-1.375", key: "tmeiqw" }],
  ["path", { d: "M6.003 5.125A3 3 0 0 0 6.401 6.5", key: "105sqy" }],
  ["path", { d: "M3.477 10.896a4 4 0 0 1 .585-.396", key: "ql3yin" }],
  ["path", { d: "M19.938 10.5a4 4 0 0 1 .585.396", key: "1qfode" }],
  ["path", { d: "M6 18a4 4 0 0 1-1.967-.516", key: "2e4loj" }],
  ["path", { d: "M19.967 17.484A4 4 0 0 1 18 18", key: "159ez6" }]
]);

const LuBrickWall = createLucideIcon("LuBrickWall", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M12 9v6", key: "199k2o" }],
  ["path", { d: "M16 15v6", key: "8rj2es" }],
  ["path", { d: "M16 3v6", key: "1j6rpj" }],
  ["path", { d: "M3 15h18", key: "5xshup" }],
  ["path", { d: "M3 9h18", key: "1pudct" }],
  ["path", { d: "M8 15v6", key: "1stoo3" }],
  ["path", { d: "M8 3v6", key: "vlvjmk" }]
]);

const LuBriefcaseBusiness = createLucideIcon("LuBriefcaseBusiness", [
  ["path", { d: "M12 12h.01", key: "1mp3jc" }],
  ["path", { d: "M16 6V4a2 2 0 0 0-2-2h-4a2 2 0 0 0-2 2v2", key: "1ksdt3" }],
  ["path", { d: "M22 13a18.15 18.15 0 0 1-20 0", key: "12hx5q" }],
  ["rect", { width: "20", height: "14", x: "2", y: "6", rx: "2", key: "i6l2r4" }]
]);

const LuBriefcaseMedical = createLucideIcon("LuBriefcaseMedical", [
  ["path", { d: "M12 11v4", key: "a6ujw6" }],
  ["path", { d: "M14 13h-4", key: "1pl8zg" }],
  ["path", { d: "M16 6V4a2 2 0 0 0-2-2h-4a2 2 0 0 0-2 2v2", key: "1ksdt3" }],
  ["path", { d: "M18 6v14", key: "1mu4gy" }],
  ["path", { d: "M6 6v14", key: "1s15cj" }],
  ["rect", { width: "20", height: "14", x: "2", y: "6", rx: "2", key: "i6l2r4" }]
]);

const LuBriefcase = createLucideIcon("LuBriefcase", [
  ["path", { d: "M16 20V4a2 2 0 0 0-2-2h-4a2 2 0 0 0-2 2v16", key: "jecpp" }],
  ["rect", { width: "20", height: "14", x: "2", y: "6", rx: "2", key: "i6l2r4" }]
]);

const LuBringToFront = createLucideIcon("LuBringToFront", [
  ["rect", { x: "8", y: "8", width: "8", height: "8", rx: "2", key: "yj20xf" }],
  ["path", { d: "M4 10a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2", key: "1ltk23" }],
  ["path", { d: "M14 20a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2", key: "1q24h9" }]
]);

const LuBrush = createLucideIcon("LuBrush", [
  ["path", { d: "m9.06 11.9 8.07-8.06a2.85 2.85 0 1 1 4.03 4.03l-8.06 8.08", key: "1styjt" }],
  [
    "path",
    {
      d: "M7.07 14.94c-1.66 0-3 1.35-3 3.02 0 1.33-2.5 1.52-2 2.02 1.08 1.1 2.49 2.02 4 2.02 2.2 0 4-1.8 4-4.04a3.01 3.01 0 0 0-3-3.02z",
      key: "z0l1mu"
    }
  ]
]);

const LuBugOff = createLucideIcon("LuBugOff", [
  ["path", { d: "M15 7.13V6a3 3 0 0 0-5.14-2.1L8 2", key: "vl8zik" }],
  ["path", { d: "M14.12 3.88 16 2", key: "qol33r" }],
  ["path", { d: "M22 13h-4v-2a4 4 0 0 0-4-4h-1.3", key: "1ou0bd" }],
  ["path", { d: "M20.97 5c0 2.1-1.6 3.8-3.5 4", key: "18gb23" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M7.7 7.7A4 4 0 0 0 6 11v3a6 6 0 0 0 11.13 3.13", key: "1njkjs" }],
  ["path", { d: "M12 20v-8", key: "i3yub9" }],
  ["path", { d: "M6 13H2", key: "82j7cp" }],
  ["path", { d: "M3 21c0-2.1 1.7-3.9 3.8-4", key: "4p0ekp" }]
]);

const LuBugPlay = createLucideIcon("LuBugPlay", [
  ["path", { d: "m8 2 1.88 1.88", key: "fmnt4t" }],
  ["path", { d: "M14.12 3.88 16 2", key: "qol33r" }],
  ["path", { d: "M9 7.13v-1a3.003 3.003 0 1 1 6 0v1", key: "d7y7pr" }],
  ["path", { d: "M18 11a4 4 0 0 0-4-4h-4a4 4 0 0 0-4 4v3a6.1 6.1 0 0 0 2 4.5", key: "1tjixy" }],
  ["path", { d: "M6.53 9C4.6 8.8 3 7.1 3 5", key: "32zzws" }],
  ["path", { d: "M6 13H2", key: "82j7cp" }],
  ["path", { d: "M3 21c0-2.1 1.7-3.9 3.8-4", key: "4p0ekp" }],
  ["path", { d: "M20.97 5c0 2.1-1.6 3.8-3.5 4", key: "18gb23" }],
  ["path", { d: "m12 12 8 5-8 5Z", key: "1ydf81" }]
]);

const LuBug = createLucideIcon("LuBug", [
  ["path", { d: "m8 2 1.88 1.88", key: "fmnt4t" }],
  ["path", { d: "M14.12 3.88 16 2", key: "qol33r" }],
  ["path", { d: "M9 7.13v-1a3.003 3.003 0 1 1 6 0v1", key: "d7y7pr" }],
  [
    "path",
    {
      d: "M12 20c-3.3 0-6-2.7-6-6v-3a4 4 0 0 1 4-4h4a4 4 0 0 1 4 4v3c0 3.3-2.7 6-6 6",
      key: "xs1cw7"
    }
  ],
  ["path", { d: "M12 20v-9", key: "1qisl0" }],
  ["path", { d: "M6.53 9C4.6 8.8 3 7.1 3 5", key: "32zzws" }],
  ["path", { d: "M6 13H2", key: "82j7cp" }],
  ["path", { d: "M3 21c0-2.1 1.7-3.9 3.8-4", key: "4p0ekp" }],
  ["path", { d: "M20.97 5c0 2.1-1.6 3.8-3.5 4", key: "18gb23" }],
  ["path", { d: "M22 13h-4", key: "1jl80f" }],
  ["path", { d: "M17.2 17c2.1.1 3.8 1.9 3.8 4", key: "k3fwyw" }]
]);

const LuBuilding2 = createLucideIcon("LuBuilding2", [
  ["path", { d: "M6 22V4a2 2 0 0 1 2-2h8a2 2 0 0 1 2 2v18Z", key: "1b4qmf" }],
  ["path", { d: "M6 12H4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h2", key: "i71pzd" }],
  ["path", { d: "M18 9h2a2 2 0 0 1 2 2v9a2 2 0 0 1-2 2h-2", key: "10jefs" }],
  ["path", { d: "M10 6h4", key: "1itunk" }],
  ["path", { d: "M10 10h4", key: "tcdvrf" }],
  ["path", { d: "M10 14h4", key: "kelpxr" }],
  ["path", { d: "M10 18h4", key: "1ulq68" }]
]);

const LuBuilding = createLucideIcon("LuBuilding", [
  ["rect", { width: "16", height: "20", x: "4", y: "2", rx: "2", ry: "2", key: "76otgf" }],
  ["path", { d: "M9 22v-4h6v4", key: "r93iot" }],
  ["path", { d: "M8 6h.01", key: "1dz90k" }],
  ["path", { d: "M16 6h.01", key: "1x0f13" }],
  ["path", { d: "M12 6h.01", key: "1vi96p" }],
  ["path", { d: "M12 10h.01", key: "1nrarc" }],
  ["path", { d: "M12 14h.01", key: "1etili" }],
  ["path", { d: "M16 10h.01", key: "1m94wz" }],
  ["path", { d: "M16 14h.01", key: "1gbofw" }],
  ["path", { d: "M8 10h.01", key: "19clt8" }],
  ["path", { d: "M8 14h.01", key: "6423bh" }]
]);

const LuBusFront = createLucideIcon("LuBusFront", [
  ["path", { d: "M4 6 2 7", key: "1mqr15" }],
  ["path", { d: "M10 6h4", key: "1itunk" }],
  ["path", { d: "m22 7-2-1", key: "1umjhc" }],
  ["rect", { width: "16", height: "16", x: "4", y: "3", rx: "2", key: "1wxw4b" }],
  ["path", { d: "M4 11h16", key: "mpoxn0" }],
  ["path", { d: "M8 15h.01", key: "a7atzg" }],
  ["path", { d: "M16 15h.01", key: "rnfrdf" }],
  ["path", { d: "M6 19v2", key: "1loha6" }],
  ["path", { d: "M18 21v-2", key: "sqyl04" }]
]);

const LuBus = createLucideIcon("LuBus", [
  ["path", { d: "M8 6v6", key: "18i7km" }],
  ["path", { d: "M15 6v6", key: "1sg6z9" }],
  ["path", { d: "M2 12h19.6", key: "de5uta" }],
  [
    "path",
    {
      d: "M18 18h3s.5-1.7.8-2.8c.1-.4.2-.8.2-1.2 0-.4-.1-.8-.2-1.2l-1.4-5C20.1 6.8 19.1 6 18 6H4a2 2 0 0 0-2 2v10h3",
      key: "1wwztk"
    }
  ],
  ["circle", { cx: "7", cy: "18", r: "2", key: "19iecd" }],
  ["path", { d: "M9 18h5", key: "lrx6i" }],
  ["circle", { cx: "16", cy: "18", r: "2", key: "1v4tcr" }]
]);

const LuCableCar = createLucideIcon("LuCableCar", [
  ["path", { d: "M10 3h.01", key: "lbucoy" }],
  ["path", { d: "M14 2h.01", key: "1k8aa1" }],
  ["path", { d: "m2 9 20-5", key: "1kz0j5" }],
  ["path", { d: "M12 12V6.5", key: "1vbrij" }],
  ["rect", { width: "16", height: "10", x: "4", y: "12", rx: "3", key: "if91er" }],
  ["path", { d: "M9 12v5", key: "3anwtq" }],
  ["path", { d: "M15 12v5", key: "5xh3zn" }],
  ["path", { d: "M4 17h16", key: "g4d7ey" }]
]);

const LuCable = createLucideIcon("LuCable", [
  ["path", { d: "M4 9a2 2 0 0 1-2-2V5h6v2a2 2 0 0 1-2 2Z", key: "1s6oa5" }],
  ["path", { d: "M3 5V3", key: "1k5hjh" }],
  ["path", { d: "M7 5V3", key: "1t1388" }],
  ["path", { d: "M19 15V6.5a3.5 3.5 0 0 0-7 0v11a3.5 3.5 0 0 1-7 0V9", key: "1ytv72" }],
  ["path", { d: "M17 21v-2", key: "ds4u3f" }],
  ["path", { d: "M21 21v-2", key: "eo0ou" }],
  ["path", { d: "M22 19h-6v-2a2 2 0 0 1 2-2h2a2 2 0 0 1 2 2Z", key: "sdz6o8" }]
]);

const LuCakeSlice = createLucideIcon("LuCakeSlice", [
  ["circle", { cx: "9", cy: "7", r: "2", key: "1305pl" }],
  [
    "path",
    { d: "M7.2 7.9 3 11v9c0 .6.4 1 1 1h16c.6 0 1-.4 1-1v-9c0-2-3-6-7-8l-3.6 2.6", key: "xle13f" }
  ],
  ["path", { d: "M16 13H3", key: "1wpj08" }],
  ["path", { d: "M16 17H3", key: "3lvfcd" }]
]);

const LuCake = createLucideIcon("LuCake", [
  ["path", { d: "M20 21v-8a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v8", key: "1w3rig" }],
  ["path", { d: "M4 16s.5-1 2-1 2.5 2 4 2 2.5-2 4-2 2.5 2 4 2 2-1 2-1", key: "n2jgmb" }],
  ["path", { d: "M2 21h20", key: "1nyx9w" }],
  ["path", { d: "M7 8v3", key: "1qtyvj" }],
  ["path", { d: "M12 8v3", key: "hwp4zt" }],
  ["path", { d: "M17 8v3", key: "1i6e5u" }],
  ["path", { d: "M7 4h0.01", key: "hsw7lv" }],
  ["path", { d: "M12 4h0.01", key: "1e3d8f" }],
  ["path", { d: "M17 4h0.01", key: "p7cxgy" }]
]);

const LuCalculator = createLucideIcon("LuCalculator", [
  ["rect", { width: "16", height: "20", x: "4", y: "2", rx: "2", key: "1nb95v" }],
  ["line", { x1: "8", x2: "16", y1: "6", y2: "6", key: "x4nwl0" }],
  ["line", { x1: "16", x2: "16", y1: "14", y2: "18", key: "wjye3r" }],
  ["path", { d: "M16 10h.01", key: "1m94wz" }],
  ["path", { d: "M12 10h.01", key: "1nrarc" }],
  ["path", { d: "M8 10h.01", key: "19clt8" }],
  ["path", { d: "M12 14h.01", key: "1etili" }],
  ["path", { d: "M8 14h.01", key: "6423bh" }],
  ["path", { d: "M12 18h.01", key: "mhygvu" }],
  ["path", { d: "M8 18h.01", key: "lrp35t" }]
]);

const LuCalendarCheck2 = createLucideIcon("LuCalendarCheck2", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M21 14V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h8", key: "bce9hv" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "m16 20 2 2 4-4", key: "13tcca" }]
]);

const LuCalendarCheck = createLucideIcon("LuCalendarCheck", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "m9 16 2 2 4-4", key: "19s6y9" }]
]);

const LuCalendarClock = createLucideIcon("LuCalendarClock", [
  ["path", { d: "M21 7.5V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h3.5", key: "1osxxc" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M3 10h5", key: "r794hk" }],
  ["path", { d: "M17.5 17.5 16 16.3V14", key: "akvzfd" }],
  ["circle", { cx: "16", cy: "16", r: "6", key: "qoo3c4" }]
]);

const LuCalendarDays = createLucideIcon("LuCalendarDays", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "M8 14h.01", key: "6423bh" }],
  ["path", { d: "M12 14h.01", key: "1etili" }],
  ["path", { d: "M16 14h.01", key: "1gbofw" }],
  ["path", { d: "M8 18h.01", key: "lrp35t" }],
  ["path", { d: "M12 18h.01", key: "mhygvu" }],
  ["path", { d: "M16 18h.01", key: "kzsmim" }]
]);

const LuCalendarFold = createLucideIcon("LuCalendarFold", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M21 17V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h11Z", key: "kg77oy" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "M15 22v-4a2 2 0 0 1 2-2h4", key: "1gnbqr" }]
]);

const LuCalendarHeart = createLucideIcon("LuCalendarHeart", [
  ["path", { d: "M3 10h18V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h7", key: "136lmk" }],
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  [
    "path",
    {
      d: "M21.29 14.7a2.43 2.43 0 0 0-2.65-.52c-.3.12-.57.3-.8.53l-.34.34-.35-.34a2.43 2.43 0 0 0-2.65-.53c-.3.12-.56.3-.79.53-.95.94-1 2.53.2 3.74L17.5 22l3.6-3.55c1.2-1.21 1.14-2.8.19-3.74Z",
      key: "1t7hil"
    }
  ]
]);

const LuCalendarMinus2 = createLucideIcon("LuCalendarMinus2", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "M10 16h4", key: "17e571" }]
]);

const LuCalendarMinus = createLucideIcon("LuCalendarMinus", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M21 13V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h8", key: "3spt84" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "M16 19h6", key: "xwg31i" }]
]);

const LuCalendarOff = createLucideIcon("LuCalendarOff", [
  ["path", { d: "M4.2 4.2A2 2 0 0 0 3 6v14a2 2 0 0 0 2 2h14a2 2 0 0 0 1.82-1.18", key: "16swn3" }],
  ["path", { d: "M21 15.5V6a2 2 0 0 0-2-2H9.5", key: "yhw86o" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M3 10h7", key: "1wap6i" }],
  ["path", { d: "M21 10h-5.5", key: "quycpq" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuCalendarPlus2 = createLucideIcon("LuCalendarPlus2", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "M10 16h4", key: "17e571" }],
  ["path", { d: "M12 14v4", key: "1thi36" }]
]);

const LuCalendarPlus = createLucideIcon("LuCalendarPlus", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M21 13V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h8", key: "3spt84" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "M16 19h6", key: "xwg31i" }],
  ["path", { d: "M19 16v6", key: "tddt3s" }]
]);

const LuCalendarRange = createLucideIcon("LuCalendarRange", [
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M17 14h-6", key: "bkmgh3" }],
  ["path", { d: "M13 18H7", key: "bb0bb7" }],
  ["path", { d: "M7 14h.01", key: "1qa3f1" }],
  ["path", { d: "M17 18h.01", key: "1bdyru" }]
]);

const LuCalendarSearch = createLucideIcon("LuCalendarSearch", [
  ["path", { d: "M21 12V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h7.5", key: "1e09qw" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  ["path", { d: "m22 22-1.5-1.5", key: "1x83k4" }]
]);

const LuCalendarX2 = createLucideIcon("LuCalendarX2", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M21 13V6a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h8", key: "3spt84" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "m17 22 5-5", key: "1k6ppv" }],
  ["path", { d: "m17 17 5 5", key: "p7ous7" }]
]);

const LuCalendarX = createLucideIcon("LuCalendarX", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["path", { d: "M3 10h18", key: "8toen8" }],
  ["path", { d: "m14 14-4 4", key: "rymu2i" }],
  ["path", { d: "m10 14 4 4", key: "3sz06r" }]
]);

const LuCalendar = createLucideIcon("LuCalendar", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["path", { d: "M3 10h18", key: "8toen8" }]
]);

const LuCameraOff = createLucideIcon("LuCameraOff", [
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }],
  ["path", { d: "M7 7H4a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2h16", key: "qmtpty" }],
  ["path", { d: "M9.5 4h5L17 7h3a2 2 0 0 1 2 2v7.5", key: "1ufyfc" }],
  ["path", { d: "M14.121 15.121A3 3 0 1 1 9.88 10.88", key: "11zox6" }]
]);

const LuCamera = createLucideIcon("LuCamera", [
  [
    "path",
    {
      d: "M14.5 4h-5L7 7H4a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2V9a2 2 0 0 0-2-2h-3l-2.5-3z",
      key: "1tc9qg"
    }
  ],
  ["circle", { cx: "12", cy: "13", r: "3", key: "1vg3eu" }]
]);

const LuCandlestickChart = createLucideIcon("LuCandlestickChart", [
  ["path", { d: "M9 5v4", key: "14uxtq" }],
  ["rect", { width: "4", height: "6", x: "7", y: "9", rx: "1", key: "f4fvz0" }],
  ["path", { d: "M9 15v2", key: "r5rk32" }],
  ["path", { d: "M17 3v2", key: "1l2re6" }],
  ["rect", { width: "4", height: "8", x: "15", y: "5", rx: "1", key: "z38je5" }],
  ["path", { d: "M17 13v3", key: "5l0wba" }],
  ["path", { d: "M3 3v18h18", key: "1s2lah" }]
]);

const LuCandyCane = createLucideIcon("LuCandyCane", [
  [
    "path",
    {
      d: "M5.7 21a2 2 0 0 1-3.5-2l8.6-14a6 6 0 0 1 10.4 6 2 2 0 1 1-3.464-2 2 2 0 1 0-3.464-2Z",
      key: "isaq8g"
    }
  ],
  ["path", { d: "M17.75 7 15 2.1", key: "12x7e8" }],
  ["path", { d: "M10.9 4.8 13 9", key: "100a87" }],
  ["path", { d: "m7.9 9.7 2 4.4", key: "ntfhaj" }],
  ["path", { d: "M4.9 14.7 7 18.9", key: "1x43jy" }]
]);

const LuCandyOff = createLucideIcon("LuCandyOff", [
  ["path", { d: "m8.5 8.5-1 1a4.95 4.95 0 0 0 7 7l1-1", key: "1ff4ui" }],
  [
    "path",
    { d: "M11.843 6.187A4.947 4.947 0 0 1 16.5 7.5a4.947 4.947 0 0 1 1.313 4.657", key: "1sbrv4" }
  ],
  ["path", { d: "M14 16.5V14", key: "1maf8j" }],
  ["path", { d: "M14 6.5v1.843", key: "1a6u6t" }],
  ["path", { d: "M10 10v7.5", key: "80pj65" }],
  [
    "path",
    {
      d: "m16 7 1-5 1.367.683A3 3 0 0 0 19.708 3H21v1.292a3 3 0 0 0 .317 1.341L22 7l-5 1",
      key: "11a9mt"
    }
  ],
  [
    "path",
    {
      d: "m8 17-1 5-1.367-.683A3 3 0 0 0 4.292 21H3v-1.292a3 3 0 0 0-.317-1.341L2 17l5-1",
      key: "3mjmon"
    }
  ],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuCandy = createLucideIcon("LuCandy", [
  ["path", { d: "m9.5 7.5-2 2a4.95 4.95 0 1 0 7 7l2-2a4.95 4.95 0 1 0-7-7Z", key: "ue6khb" }],
  ["path", { d: "M14 6.5v10", key: "5xnk7c" }],
  ["path", { d: "M10 7.5v10", key: "1uew51" }],
  [
    "path",
    { d: "m16 7 1-5 1.37.68A3 3 0 0 0 19.7 3H21v1.3c0 .46.1.92.32 1.33L22 7l-5 1", key: "b9cp6k" }
  ],
  [
    "path",
    { d: "m8 17-1 5-1.37-.68A3 3 0 0 0 4.3 21H3v-1.3a3 3 0 0 0-.32-1.33L2 17l5-1", key: "5lney8" }
  ]
]);

const LuCannabis = createLucideIcon("LuCannabis", [
  ["path", { d: "M12 22v-4", key: "1utk9m" }],
  [
    "path",
    {
      d: "M7 12c-1.5 0-4.5 1.5-5 3 3.5 1.5 6 1 6 1-1.5 1.5-2 3.5-2 5 2.5 0 4.5-1.5 6-3 1.5 1.5 3.5 3 6 3 0-1.5-.5-3.5-2-5 0 0 2.5.5 6-1-.5-1.5-3.5-3-5-3 1.5-1 4-4 4-6-2.5 0-5.5 1.5-7 3 0-2.5-.5-5-2-7-1.5 2-2 4.5-2 7-1.5-1.5-4.5-3-7-3 0 2 2.5 5 4 6",
      key: "1mezod"
    }
  ]
]);

const LuCaptionsOff = createLucideIcon("LuCaptionsOff", [
  ["path", { d: "M10.5 5H19a2 2 0 0 1 2 2v8.5", key: "jqtk4d" }],
  ["path", { d: "M17 11h-.5", key: "1961ue" }],
  ["path", { d: "M19 19H5a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2", key: "1keqsi" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M7 11h4", key: "1o1z6v" }],
  ["path", { d: "M7 15h2.5", key: "1ina1g" }]
]);

const LuCaptions = createLucideIcon("LuCaptions", [
  ["rect", { width: "18", height: "14", x: "3", y: "5", rx: "2", ry: "2", key: "12ruh7" }],
  ["path", { d: "M7 15h4M15 15h2M7 11h2M13 11h4", key: "1ueiar" }]
]);

const LuCarFront = createLucideIcon("LuCarFront", [
  [
    "path",
    { d: "m21 8-2 2-1.5-3.7A2 2 0 0 0 15.646 5H8.4a2 2 0 0 0-1.903 1.257L5 10 3 8", key: "1imjwt" }
  ],
  ["path", { d: "M7 14h.01", key: "1qa3f1" }],
  ["path", { d: "M17 14h.01", key: "7oqj8z" }],
  ["rect", { width: "18", height: "8", x: "3", y: "10", rx: "2", key: "a7itu8" }],
  ["path", { d: "M5 18v2", key: "ppbyun" }],
  ["path", { d: "M19 18v2", key: "gy7782" }]
]);

const LuCarTaxiFront = createLucideIcon("LuCarTaxiFront", [
  ["path", { d: "M10 2h4", key: "n1abiw" }],
  [
    "path",
    { d: "m21 8-2 2-1.5-3.7A2 2 0 0 0 15.646 5H8.4a2 2 0 0 0-1.903 1.257L5 10 3 8", key: "1imjwt" }
  ],
  ["path", { d: "M7 14h.01", key: "1qa3f1" }],
  ["path", { d: "M17 14h.01", key: "7oqj8z" }],
  ["rect", { width: "18", height: "8", x: "3", y: "10", rx: "2", key: "a7itu8" }],
  ["path", { d: "M5 18v2", key: "ppbyun" }],
  ["path", { d: "M19 18v2", key: "gy7782" }]
]);

const LuCar = createLucideIcon("LuCar", [
  [
    "path",
    {
      d: "M19 17h2c.6 0 1-.4 1-1v-3c0-.9-.7-1.7-1.5-1.9C18.7 10.6 16 10 16 10s-1.3-1.4-2.2-2.3c-.5-.4-1.1-.7-1.8-.7H5c-.6 0-1.1.4-1.4.9l-1.4 2.9A3.7 3.7 0 0 0 2 12v4c0 .6.4 1 1 1h2",
      key: "5owen"
    }
  ],
  ["circle", { cx: "7", cy: "17", r: "2", key: "u2ysq9" }],
  ["path", { d: "M9 17h6", key: "r8uit2" }],
  ["circle", { cx: "17", cy: "17", r: "2", key: "axvx0g" }]
]);

const LuCaravan = createLucideIcon("LuCaravan", [
  ["rect", { width: "4", height: "4", x: "2", y: "9", key: "1vcvhd" }],
  ["rect", { width: "4", height: "10", x: "10", y: "9", key: "1b7ev2" }],
  ["path", { d: "M18 19V9a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v8a2 2 0 0 0 2 2h2", key: "19jm3t" }],
  ["circle", { cx: "8", cy: "19", r: "2", key: "t8fc5s" }],
  ["path", { d: "M10 19h12v-2", key: "1yu2qx" }]
]);

const LuCarrot = createLucideIcon("LuCarrot", [
  [
    "path",
    {
      d: "M2.27 21.7s9.87-3.5 12.73-6.36a4.5 4.5 0 0 0-6.36-6.37C5.77 11.84 2.27 21.7 2.27 21.7zM8.64 14l-2.05-2.04M15.34 15l-2.46-2.46",
      key: "rfqxbe"
    }
  ],
  ["path", { d: "M22 9s-1.33-2-3.5-2C16.86 7 15 9 15 9s1.33 2 3.5 2S22 9 22 9z", key: "6b25w4" }],
  ["path", { d: "M15 2s-2 1.33-2 3.5S15 9 15 9s2-1.84 2-3.5C17 3.33 15 2 15 2z", key: "fn65lo" }]
]);

const LuCaseLower = createLucideIcon("LuCaseLower", [
  ["circle", { cx: "7", cy: "12", r: "3", key: "12clwm" }],
  ["path", { d: "M10 9v6", key: "17i7lo" }],
  ["circle", { cx: "17", cy: "12", r: "3", key: "gl7c2s" }],
  ["path", { d: "M14 7v8", key: "dl84cr" }]
]);

const LuCaseSensitive = createLucideIcon("LuCaseSensitive", [
  ["path", { d: "m3 15 4-8 4 8", key: "1vwr6u" }],
  ["path", { d: "M4 13h6", key: "1r9ots" }],
  ["circle", { cx: "18", cy: "12", r: "3", key: "1kchzo" }],
  ["path", { d: "M21 9v6", key: "anns31" }]
]);

const LuCaseUpper = createLucideIcon("LuCaseUpper", [
  ["path", { d: "m3 15 4-8 4 8", key: "1vwr6u" }],
  ["path", { d: "M4 13h6", key: "1r9ots" }],
  ["path", { d: "M15 11h4.5a2 2 0 0 1 0 4H15V7h4a2 2 0 0 1 0 4", key: "1sqfas" }]
]);

const LuCassetteTape = createLucideIcon("LuCassetteTape", [
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }],
  ["circle", { cx: "8", cy: "10", r: "2", key: "1xl4ub" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["circle", { cx: "16", cy: "10", r: "2", key: "r14t7q" }],
  ["path", { d: "m6 20 .7-2.9A1.4 1.4 0 0 1 8.1 16h7.8a1.4 1.4 0 0 1 1.4 1l.7 3", key: "l01ucn" }]
]);

const LuCast = createLucideIcon("LuCast", [
  ["path", { d: "M2 8V6a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v12a2 2 0 0 1-2 2h-6", key: "3zrzxg" }],
  ["path", { d: "M2 12a9 9 0 0 1 8 8", key: "g6cvee" }],
  ["path", { d: "M2 16a5 5 0 0 1 4 4", key: "1y1dii" }],
  ["line", { x1: "2", x2: "2.01", y1: "20", y2: "20", key: "xu2jvo" }]
]);

const LuCastle = createLucideIcon("LuCastle", [
  ["path", { d: "M22 20v-9H2v9a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2Z", key: "109fe4" }],
  ["path", { d: "M18 11V4H6v7", key: "mon5oj" }],
  ["path", { d: "M15 22v-4a3 3 0 0 0-3-3v0a3 3 0 0 0-3 3v4", key: "jdggr9" }],
  ["path", { d: "M22 11V9", key: "3zbp94" }],
  ["path", { d: "M2 11V9", key: "1x5rnq" }],
  ["path", { d: "M6 4V2", key: "1rsq15" }],
  ["path", { d: "M18 4V2", key: "1jsdo1" }],
  ["path", { d: "M10 4V2", key: "75d9ly" }],
  ["path", { d: "M14 4V2", key: "8nj3z6" }]
]);

const LuCat = createLucideIcon("LuCat", [
  [
    "path",
    {
      d: "M12 5c.67 0 1.35.09 2 .26 1.78-2 5.03-2.84 6.42-2.26 1.4.58-.42 7-.42 7 .57 1.07 1 2.24 1 3.44C21 17.9 16.97 21 12 21s-9-3-9-7.56c0-1.25.5-2.4 1-3.44 0 0-1.89-6.42-.5-7 1.39-.58 4.72.23 6.5 2.23A9.04 9.04 0 0 1 12 5Z",
      key: "x6xyqk"
    }
  ],
  ["path", { d: "M8 14v.5", key: "1nzgdb" }],
  ["path", { d: "M16 14v.5", key: "1lajdz" }],
  ["path", { d: "M11.25 16.25h1.5L12 17l-.75-.75Z", key: "12kq1m" }]
]);

const LuCctv = createLucideIcon("LuCctv", [
  ["path", { d: "M7 9h.01", key: "19b3jx" }],
  ["path", { d: "M16.75 12H22l-3.5 7-3.09-4.32", key: "1h9vqe" }],
  [
    "path",
    {
      d: "M18 9.5l-4 8-10.39-5.2a2.92 2.92 0 0 1-1.3-3.91L3.69 5.6a2.92 2.92 0 0 1 3.92-1.3Z",
      key: "q5d122"
    }
  ],
  ["path", { d: "M2 19h3.76a2 2 0 0 0 1.8-1.1L9 15", key: "19bib8" }],
  ["path", { d: "M2 21v-4", key: "l40lih" }]
]);

const LuCheckCheck = createLucideIcon("LuCheckCheck", [
  ["path", { d: "M18 6 7 17l-5-5", key: "116fxf" }],
  ["path", { d: "m22 10-7.5 7.5L13 16", key: "ke71qq" }]
]);

const LuCheck = createLucideIcon("LuCheck", [["path", { d: "M20 6 9 17l-5-5", key: "1gmf2c" }]]);

const LuChefHat = createLucideIcon("LuChefHat", [
  [
    "path",
    {
      d: "M6 13.87A4 4 0 0 1 7.41 6a5.11 5.11 0 0 1 1.05-1.54 5 5 0 0 1 7.08 0A5.11 5.11 0 0 1 16.59 6 4 4 0 0 1 18 13.87V21H6Z",
      key: "z3ra2g"
    }
  ],
  ["line", { x1: "6", x2: "18", y1: "17", y2: "17", key: "12q60k" }]
]);

const LuCherry = createLucideIcon("LuCherry", [
  ["path", { d: "M2 17a5 5 0 0 0 10 0c0-2.76-2.5-5-5-3-2.5-2-5 .24-5 3Z", key: "cvxqlc" }],
  ["path", { d: "M12 17a5 5 0 0 0 10 0c0-2.76-2.5-5-5-3-2.5-2-5 .24-5 3Z", key: "1ostrc" }],
  ["path", { d: "M7 14c3.22-2.91 4.29-8.75 5-12 1.66 2.38 4.94 9 5 12", key: "hqx58h" }],
  ["path", { d: "M22 9c-4.29 0-7.14-2.33-10-7 5.71 0 10 4.67 10 7Z", key: "eykp1o" }]
]);

const LuChevronDown = createLucideIcon("LuChevronDown", [
  ["path", { d: "m6 9 6 6 6-6", key: "qrunsl" }]
]);

const LuChevronFirst = createLucideIcon("LuChevronFirst", [
  ["path", { d: "m17 18-6-6 6-6", key: "1yerx2" }],
  ["path", { d: "M7 6v12", key: "1p53r6" }]
]);

const LuChevronLast = createLucideIcon("LuChevronLast", [
  ["path", { d: "m7 18 6-6-6-6", key: "lwmzdw" }],
  ["path", { d: "M17 6v12", key: "1o0aio" }]
]);

const LuChevronLeft = createLucideIcon("LuChevronLeft", [
  ["path", { d: "m15 18-6-6 6-6", key: "1wnfg3" }]
]);

const LuChevronRight = createLucideIcon("LuChevronRight", [
  ["path", { d: "m9 18 6-6-6-6", key: "mthhwq" }]
]);

const LuChevronUp = createLucideIcon("LuChevronUp", [
  ["path", { d: "m18 15-6-6-6 6", key: "153udz" }]
]);

const LuChevronsDownUp = createLucideIcon("LuChevronsDownUp", [
  ["path", { d: "m7 20 5-5 5 5", key: "13a0gw" }],
  ["path", { d: "m7 4 5 5 5-5", key: "1kwcof" }]
]);

const LuChevronsDown = createLucideIcon("LuChevronsDown", [
  ["path", { d: "m7 6 5 5 5-5", key: "1lc07p" }],
  ["path", { d: "m7 13 5 5 5-5", key: "1d48rs" }]
]);

const LuChevronsLeftRight = createLucideIcon("LuChevronsLeftRight", [
  ["path", { d: "m9 7-5 5 5 5", key: "j5w590" }],
  ["path", { d: "m15 7 5 5-5 5", key: "1bl6da" }]
]);

const LuChevronsLeft = createLucideIcon("LuChevronsLeft", [
  ["path", { d: "m11 17-5-5 5-5", key: "13zhaf" }],
  ["path", { d: "m18 17-5-5 5-5", key: "h8a8et" }]
]);

const LuChevronsRightLeft = createLucideIcon("LuChevronsRightLeft", [
  ["path", { d: "m20 17-5-5 5-5", key: "30x0n2" }],
  ["path", { d: "m4 17 5-5-5-5", key: "16spf4" }]
]);

const LuChevronsRight = createLucideIcon("LuChevronsRight", [
  ["path", { d: "m6 17 5-5-5-5", key: "xnjwq" }],
  ["path", { d: "m13 17 5-5-5-5", key: "17xmmf" }]
]);

const LuChevronsUpDown = createLucideIcon("LuChevronsUpDown", [
  ["path", { d: "m7 15 5 5 5-5", key: "1hf1tw" }],
  ["path", { d: "m7 9 5-5 5 5", key: "sgt6xg" }]
]);

const LuChevronsUp = createLucideIcon("LuChevronsUp", [
  ["path", { d: "m17 11-5-5-5 5", key: "e8nh98" }],
  ["path", { d: "m17 18-5-5-5 5", key: "2avn1x" }]
]);

const LuChrome = createLucideIcon("LuChrome", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["circle", { cx: "12", cy: "12", r: "4", key: "4exip2" }],
  ["line", { x1: "21.17", x2: "12", y1: "8", y2: "8", key: "a0cw5f" }],
  ["line", { x1: "3.95", x2: "8.54", y1: "6.06", y2: "14", key: "1kftof" }],
  ["line", { x1: "10.88", x2: "15.46", y1: "21.94", y2: "14", key: "1ymyh8" }]
]);

const LuChurch = createLucideIcon("LuChurch", [
  ["path", { d: "m18 7 4 2v11a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V9l4-2", key: "gy5gyo" }],
  ["path", { d: "M14 22v-4a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v4", key: "cpkuc4" }],
  ["path", { d: "M18 22V5l-6-3-6 3v17", key: "1hsnhq" }],
  ["path", { d: "M12 7v5", key: "ma6bk" }],
  ["path", { d: "M10 9h4", key: "u4k05v" }]
]);

const LuCigaretteOff = createLucideIcon("LuCigaretteOff", [
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }],
  ["path", { d: "M12 12H2v4h14", key: "91gsaq" }],
  ["path", { d: "M22 12v4", key: "142cbu" }],
  ["path", { d: "M18 12h-.5", key: "12ymji" }],
  ["path", { d: "M7 12v4", key: "jqww69" }],
  ["path", { d: "M18 8c0-2.5-2-2.5-2-5", key: "1il607" }],
  ["path", { d: "M22 8c0-2.5-2-2.5-2-5", key: "1gah44" }]
]);

const LuCigarette = createLucideIcon("LuCigarette", [
  ["path", { d: "M18 12H2v4h16", key: "2rt1hm" }],
  ["path", { d: "M22 12v4", key: "142cbu" }],
  ["path", { d: "M7 12v4", key: "jqww69" }],
  ["path", { d: "M18 8c0-2.5-2-2.5-2-5", key: "1il607" }],
  ["path", { d: "M22 8c0-2.5-2-2.5-2-5", key: "1gah44" }]
]);

const LuCircleAlert = createLucideIcon("LuCircleAlert", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["line", { x1: "12", x2: "12", y1: "8", y2: "12", key: "1pkeuh" }],
  ["line", { x1: "12", x2: "12.01", y1: "16", y2: "16", key: "4dfq90" }]
]);

const LuCircleArrowDown = createLucideIcon("LuCircleArrowDown", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M12 8v8", key: "napkw2" }],
  ["path", { d: "m8 12 4 4 4-4", key: "k98ssh" }]
]);

const LuCircleArrowLeft = createLucideIcon("LuCircleArrowLeft", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M16 12H8", key: "1fr5h0" }],
  ["path", { d: "m12 8-4 4 4 4", key: "15vm53" }]
]);

const LuCircleArrowOutDownLeft = createLucideIcon("LuCircleArrowOutDownLeft", [
  ["path", { d: "M2 12a10 10 0 1 1 10 10", key: "1yn6ov" }],
  ["path", { d: "m2 22 10-10", key: "28ilpk" }],
  ["path", { d: "M8 22H2v-6", key: "sulq54" }]
]);

const LuCircleArrowOutDownRight = createLucideIcon("LuCircleArrowOutDownRight", [
  ["path", { d: "M12 22a10 10 0 1 1 10-10", key: "130bv5" }],
  ["path", { d: "M22 22 12 12", key: "131aw7" }],
  ["path", { d: "M22 16v6h-6", key: "1gvm70" }]
]);

const LuCircleArrowOutUpLeft = createLucideIcon("LuCircleArrowOutUpLeft", [
  ["path", { d: "M2 8V2h6", key: "hiwtdz" }],
  ["path", { d: "m2 2 10 10", key: "1oh8rs" }],
  ["path", { d: "M12 2A10 10 0 1 1 2 12", key: "rrk4fa" }]
]);

const LuCircleArrowOutUpRight = createLucideIcon("LuCircleArrowOutUpRight", [
  ["path", { d: "M22 12A10 10 0 1 1 12 2", key: "1fm58d" }],
  ["path", { d: "M22 2 12 12", key: "yg2myt" }],
  ["path", { d: "M16 2h6v6", key: "zan5cs" }]
]);

const LuCircleArrowRight = createLucideIcon("LuCircleArrowRight", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["path", { d: "m12 16 4-4-4-4", key: "1i9zcv" }]
]);

const LuCircleArrowUp = createLucideIcon("LuCircleArrowUp", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m16 12-4-4-4 4", key: "177agl" }],
  ["path", { d: "M12 16V8", key: "1sbj14" }]
]);

const LuCircleCheckBig = createLucideIcon("LuCircleCheckBig", [
  ["path", { d: "M22 11.08V12a10 10 0 1 1-5.93-9.14", key: "g774vq" }],
  ["path", { d: "m9 11 3 3L22 4", key: "1pflzl" }]
]);

const LuCircleCheck = createLucideIcon("LuCircleCheck", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m9 12 2 2 4-4", key: "dzmm74" }]
]);

const LuCircleChevronDown = createLucideIcon("LuCircleChevronDown", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m16 10-4 4-4-4", key: "894hmk" }]
]);

const LuCircleChevronLeft = createLucideIcon("LuCircleChevronLeft", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m14 16-4-4 4-4", key: "ojs7w8" }]
]);

const LuCircleChevronRight = createLucideIcon("LuCircleChevronRight", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m10 8 4 4-4 4", key: "1wy4r4" }]
]);

const LuCircleChevronUp = createLucideIcon("LuCircleChevronUp", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m8 14 4-4 4 4", key: "fy2ptz" }]
]);

const LuCircleDashed = createLucideIcon("LuCircleDashed", [
  ["path", { d: "M10.1 2.182a10 10 0 0 1 3.8 0", key: "5ilxe3" }],
  ["path", { d: "M13.9 21.818a10 10 0 0 1-3.8 0", key: "11zvb9" }],
  ["path", { d: "M17.609 3.721a10 10 0 0 1 2.69 2.7", key: "1iw5b2" }],
  ["path", { d: "M2.182 13.9a10 10 0 0 1 0-3.8", key: "c0bmvh" }],
  ["path", { d: "M20.279 17.609a10 10 0 0 1-2.7 2.69", key: "1ruxm7" }],
  ["path", { d: "M21.818 10.1a10 10 0 0 1 0 3.8", key: "qkgqxc" }],
  ["path", { d: "M3.721 6.391a10 10 0 0 1 2.7-2.69", key: "1mcia2" }],
  ["path", { d: "M6.391 20.279a10 10 0 0 1-2.69-2.7", key: "1fvljs" }]
]);

const LuCircleDivide = createLucideIcon("LuCircleDivide", [
  ["line", { x1: "8", x2: "16", y1: "12", y2: "12", key: "1jonct" }],
  ["line", { x1: "12", x2: "12", y1: "16", y2: "16", key: "aqc6ln" }],
  ["line", { x1: "12", x2: "12", y1: "8", y2: "8", key: "1mkcni" }],
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }]
]);

const LuCircleDollarSign = createLucideIcon("LuCircleDollarSign", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M16 8h-6a2 2 0 1 0 0 4h4a2 2 0 1 1 0 4H8", key: "1h4pet" }],
  ["path", { d: "M12 18V6", key: "zqpxq5" }]
]);

const LuCircleDotDashed = createLucideIcon("LuCircleDotDashed", [
  ["path", { d: "M10.1 2.18a9.93 9.93 0 0 1 3.8 0", key: "1qdqn0" }],
  ["path", { d: "M17.6 3.71a9.95 9.95 0 0 1 2.69 2.7", key: "1bq7p6" }],
  ["path", { d: "M21.82 10.1a9.93 9.93 0 0 1 0 3.8", key: "1rlaqf" }],
  ["path", { d: "M20.29 17.6a9.95 9.95 0 0 1-2.7 2.69", key: "1xk03u" }],
  ["path", { d: "M13.9 21.82a9.94 9.94 0 0 1-3.8 0", key: "l7re25" }],
  ["path", { d: "M6.4 20.29a9.95 9.95 0 0 1-2.69-2.7", key: "1v18p6" }],
  ["path", { d: "M2.18 13.9a9.93 9.93 0 0 1 0-3.8", key: "xdo6bj" }],
  ["path", { d: "M3.71 6.4a9.95 9.95 0 0 1 2.7-2.69", key: "1jjmaz" }],
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }]
]);

const LuCircleDot = createLucideIcon("LuCircleDot", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }]
]);

const LuCircleEllipsis = createLucideIcon("LuCircleEllipsis", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M17 12h.01", key: "1m0b6t" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }],
  ["path", { d: "M7 12h.01", key: "eqddd0" }]
]);

const LuCircleEqual = createLucideIcon("LuCircleEqual", [
  ["path", { d: "M7 10h10", key: "1101jm" }],
  ["path", { d: "M7 14h10", key: "1mhdw3" }],
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }]
]);

const LuCircleFadingPlus = createLucideIcon("LuCircleFadingPlus", [
  ["path", { d: "M12 2a10 10 0 0 1 7.38 16.75", key: "175t95" }],
  ["path", { d: "M12 8v8", key: "napkw2" }],
  ["path", { d: "M16 12H8", key: "1fr5h0" }],
  ["path", { d: "M2.5 8.875a10 10 0 0 0-.5 3", key: "1vce0s" }],
  ["path", { d: "M2.83 16a10 10 0 0 0 2.43 3.4", key: "o3fkw4" }],
  ["path", { d: "M4.636 5.235a10 10 0 0 1 .891-.857", key: "1szpfk" }],
  ["path", { d: "M8.644 21.42a10 10 0 0 0 7.631-.38", key: "9yhvd4" }]
]);

const LuCircleGauge = createLucideIcon("LuCircleGauge", [
  ["path", { d: "M15.6 2.7a10 10 0 1 0 5.7 5.7", key: "1e0p6d" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }],
  ["path", { d: "M13.4 10.6 19 5", key: "1kr7tw" }]
]);

const LuCircleHelp = createLucideIcon("LuCircleHelp", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M9.09 9a3 3 0 0 1 5.83 1c0 2-3 3-3 3", key: "1u773s" }],
  ["path", { d: "M12 17h.01", key: "p32p05" }]
]);

const LuCircleMinus = createLucideIcon("LuCircleMinus", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }]
]);

const LuCircleOff = createLucideIcon("LuCircleOff", [
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M8.35 2.69A10 10 0 0 1 21.3 15.65", key: "1pfsoa" }],
  ["path", { d: "M19.08 19.08A10 10 0 1 1 4.92 4.92", key: "1ablyi" }]
]);

const LuCircleParkingOff = createLucideIcon("LuCircleParkingOff", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m5 5 14 14", key: "11anup" }],
  ["path", { d: "M13 13a3 3 0 1 0 0-6H9v2", key: "uoagbd" }],
  ["path", { d: "M9 17v-2.34", key: "a9qo08" }]
]);

const LuCircleParking = createLucideIcon("LuCircleParking", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M9 17V7h4a3 3 0 0 1 0 6H9", key: "1dfk2c" }]
]);

const LuCirclePause = createLucideIcon("LuCirclePause", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["line", { x1: "10", x2: "10", y1: "15", y2: "9", key: "c1nkhi" }],
  ["line", { x1: "14", x2: "14", y1: "15", y2: "9", key: "h65svq" }]
]);

const LuCirclePercent = createLucideIcon("LuCirclePercent", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m15 9-6 6", key: "1uzhvr" }],
  ["path", { d: "M9 9h.01", key: "1q5me6" }],
  ["path", { d: "M15 15h.01", key: "lqbp3k" }]
]);

const LuCirclePlay = createLucideIcon("LuCirclePlay", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polygon", { points: "10 8 16 12 10 16 10 8", key: "1cimsy" }]
]);

const LuCirclePlus = createLucideIcon("LuCirclePlus", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["path", { d: "M12 8v8", key: "napkw2" }]
]);

const LuCirclePower = createLucideIcon("LuCirclePower", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M12 12V7", key: "1tf3mz" }],
  ["path", { d: "M16 9a5 5 0 1 1-8 0", key: "174bae" }]
]);

const LuCircleSlash2 = createLucideIcon("LuCircleSlash2", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M22 2 2 22", key: "y4kqgn" }]
]);

const LuCircleSlash = createLucideIcon("LuCircleSlash", [
  ["line", { x1: "9", x2: "15", y1: "15", y2: "9", key: "1dfufj" }],
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }]
]);

const LuCircleStop = createLucideIcon("LuCircleStop", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["rect", { width: "6", height: "6", x: "9", y: "9", key: "1wrtvo" }]
]);

const LuCircleUserRound = createLucideIcon("LuCircleUserRound", [
  ["path", { d: "M18 20a6 6 0 0 0-12 0", key: "1qehca" }],
  ["circle", { cx: "12", cy: "10", r: "4", key: "1h16sb" }],
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }]
]);

const LuCircleUser = createLucideIcon("LuCircleUser", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["circle", { cx: "12", cy: "10", r: "3", key: "ilqhr7" }],
  ["path", { d: "M7 20.662V19a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v1.662", key: "154egf" }]
]);

const LuCircleX = createLucideIcon("LuCircleX", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m15 9-6 6", key: "1uzhvr" }],
  ["path", { d: "m9 9 6 6", key: "z0biqf" }]
]);

const LuCircle = createLucideIcon("LuCircle", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }]
]);

const LuCircuitBoard = createLucideIcon("LuCircuitBoard", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M11 9h4a2 2 0 0 0 2-2V3", key: "1ve2rv" }],
  ["circle", { cx: "9", cy: "9", r: "2", key: "af1f0g" }],
  ["path", { d: "M7 21v-4a2 2 0 0 1 2-2h4", key: "1fwkro" }],
  ["circle", { cx: "15", cy: "15", r: "2", key: "3i40o0" }]
]);

const LuCitrus = createLucideIcon("LuCitrus", [
  [
    "path",
    {
      d: "M21.66 17.67a1.08 1.08 0 0 1-.04 1.6A12 12 0 0 1 4.73 2.38a1.1 1.1 0 0 1 1.61-.04z",
      key: "4ite01"
    }
  ],
  ["path", { d: "M19.65 15.66A8 8 0 0 1 8.35 4.34", key: "1gxipu" }],
  ["path", { d: "m14 10-5.5 5.5", key: "92pfem" }],
  ["path", { d: "M14 17.85V10H6.15", key: "xqmtsk" }]
]);

const LuClapperboard = createLucideIcon("LuClapperboard", [
  [
    "path",
    { d: "M20.2 6 3 11l-.9-2.4c-.3-1.1.3-2.2 1.3-2.5l13.5-4c1.1-.3 2.2.3 2.5 1.3Z", key: "1tn4o7" }
  ],
  ["path", { d: "m6.2 5.3 3.1 3.9", key: "iuk76l" }],
  ["path", { d: "m12.4 3.4 3.1 4", key: "6hsd6n" }],
  ["path", { d: "M3 11h18v8a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2Z", key: "ltgou9" }]
]);

const LuClipboardCheck = createLucideIcon("LuClipboardCheck", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", ry: "1", key: "tgr4d6" }],
  [
    "path",
    {
      d: "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2",
      key: "116196"
    }
  ],
  ["path", { d: "m9 14 2 2 4-4", key: "df797q" }]
]);

const LuClipboardCopy = createLucideIcon("LuClipboardCopy", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", ry: "1", key: "tgr4d6" }],
  ["path", { d: "M8 4H6a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-2", key: "4jdomd" }],
  ["path", { d: "M16 4h2a2 2 0 0 1 2 2v4", key: "3hqy98" }],
  ["path", { d: "M21 14H11", key: "1bme5i" }],
  ["path", { d: "m15 10-4 4 4 4", key: "5dvupr" }]
]);

const LuClipboardList = createLucideIcon("LuClipboardList", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", ry: "1", key: "tgr4d6" }],
  [
    "path",
    {
      d: "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2",
      key: "116196"
    }
  ],
  ["path", { d: "M12 11h4", key: "1jrz19" }],
  ["path", { d: "M12 16h4", key: "n85exb" }],
  ["path", { d: "M8 11h.01", key: "1dfujw" }],
  ["path", { d: "M8 16h.01", key: "18s6g9" }]
]);

const LuClipboardMinus = createLucideIcon("LuClipboardMinus", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", ry: "1", key: "tgr4d6" }],
  [
    "path",
    {
      d: "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2",
      key: "116196"
    }
  ],
  ["path", { d: "M9 14h6", key: "159ibu" }]
]);

const LuClipboardPaste = createLucideIcon("LuClipboardPaste", [
  [
    "path",
    { d: "M15 2H9a1 1 0 0 0-1 1v2c0 .6.4 1 1 1h6c.6 0 1-.4 1-1V3c0-.6-.4-1-1-1Z", key: "1pp7kr" }
  ],
  [
    "path",
    {
      d: "M8 4H6a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2M16 4h2a2 2 0 0 1 2 2v2M11 14h10",
      key: "2ik1ml"
    }
  ],
  ["path", { d: "m17 10 4 4-4 4", key: "vp2hj1" }]
]);

const LuClipboardPenLine = createLucideIcon("LuClipboardPenLine", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", key: "1oijnt" }],
  ["path", { d: "M8 4H6a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-.5", key: "1but9f" }],
  ["path", { d: "M16 4h2a2 2 0 0 1 1.73 1", key: "1p8n7l" }],
  ["path", { d: "M8 18h1", key: "13wk12" }],
  ["path", { d: "M18.4 9.6a2 2 0 0 1 3 3L17 17l-4 1 1-4Z", key: "yg2pdb" }]
]);

const LuClipboardPen = createLucideIcon("LuClipboardPen", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", key: "1oijnt" }],
  ["path", { d: "M10.4 12.6a2 2 0 0 1 3 3L8 21l-4 1 1-4Z", key: "hnx206" }],
  ["path", { d: "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-5.5", key: "cereej" }],
  ["path", { d: "M4 13.5V6a2 2 0 0 1 2-2h2", key: "5ua5vh" }]
]);

const LuClipboardPlus = createLucideIcon("LuClipboardPlus", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", ry: "1", key: "tgr4d6" }],
  [
    "path",
    {
      d: "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2",
      key: "116196"
    }
  ],
  ["path", { d: "M9 14h6", key: "159ibu" }],
  ["path", { d: "M12 17v-6", key: "1y8rbf" }]
]);

const LuClipboardType = createLucideIcon("LuClipboardType", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", ry: "1", key: "tgr4d6" }],
  [
    "path",
    {
      d: "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2",
      key: "116196"
    }
  ],
  ["path", { d: "M9 12v-1h6v1", key: "iehl6m" }],
  ["path", { d: "M11 17h2", key: "12w5me" }],
  ["path", { d: "M12 11v6", key: "1bwqyc" }]
]);

const LuClipboardX = createLucideIcon("LuClipboardX", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", ry: "1", key: "tgr4d6" }],
  [
    "path",
    {
      d: "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2",
      key: "116196"
    }
  ],
  ["path", { d: "m15 11-6 6", key: "1toa9n" }],
  ["path", { d: "m9 11 6 6", key: "wlibny" }]
]);

const LuClipboard = createLucideIcon("LuClipboard", [
  ["rect", { width: "8", height: "4", x: "8", y: "2", rx: "1", ry: "1", key: "tgr4d6" }],
  [
    "path",
    {
      d: "M16 4h2a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V6a2 2 0 0 1 2-2h2",
      key: "116196"
    }
  ]
]);

const LuClock1 = createLucideIcon("LuClock1", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 14.5 8", key: "12zbmj" }]
]);

const LuClock10 = createLucideIcon("LuClock10", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 8 10", key: "atfzqc" }]
]);

const LuClock11 = createLucideIcon("LuClock11", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 9.5 8", key: "l5bg6f" }]
]);

const LuClock12 = createLucideIcon("LuClock12", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12", key: "1fub01" }]
]);

const LuClock2 = createLucideIcon("LuClock2", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 16 10", key: "1g230d" }]
]);

const LuClock3 = createLucideIcon("LuClock3", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 16.5 12", key: "1aq6pp" }]
]);

const LuClock4 = createLucideIcon("LuClock4", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 16 14", key: "68esgv" }]
]);

const LuClock5 = createLucideIcon("LuClock5", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 14.5 16", key: "1pcbox" }]
]);

const LuClock6 = createLucideIcon("LuClock6", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 12 16.5", key: "hb2qv6" }]
]);

const LuClock7 = createLucideIcon("LuClock7", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 9.5 16", key: "ka3394" }]
]);

const LuClock8 = createLucideIcon("LuClock8", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 8 14", key: "tmc9b4" }]
]);

const LuClock9 = createLucideIcon("LuClock9", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 7.5 12", key: "1k60p0" }]
]);

const LuClock = createLucideIcon("LuClock", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polyline", { points: "12 6 12 12 16 14", key: "68esgv" }]
]);

const LuCloudCog = createLucideIcon("LuCloudCog", [
  ["circle", { cx: "12", cy: "17", r: "3", key: "1spfwm" }],
  ["path", { d: "M4.2 15.1A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.2", key: "zaobp" }],
  ["path", { d: "m15.7 18.4-.9-.3", key: "4qxpbn" }],
  ["path", { d: "m9.2 15.9-.9-.3", key: "17q7o2" }],
  ["path", { d: "m10.6 20.7.3-.9", key: "1pf4s2" }],
  ["path", { d: "m13.1 14.2.3-.9", key: "1mnuqm" }],
  ["path", { d: "m13.6 20.7-.4-1", key: "1jpd1m" }],
  ["path", { d: "m10.8 14.3-.4-1", key: "17ugyy" }],
  ["path", { d: "m8.3 18.6 1-.4", key: "s42vdx" }],
  ["path", { d: "m14.7 15.8 1-.4", key: "2wizun" }]
]);

const LuCloudDownload = createLucideIcon("LuCloudDownload", [
  ["path", { d: "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242", key: "1pljnt" }],
  ["path", { d: "M12 12v9", key: "192myk" }],
  ["path", { d: "m8 17 4 4 4-4", key: "1ul180" }]
]);

const LuCloudDrizzle = createLucideIcon("LuCloudDrizzle", [
  ["path", { d: "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242", key: "1pljnt" }],
  ["path", { d: "M8 19v1", key: "1dk2by" }],
  ["path", { d: "M8 14v1", key: "84yxot" }],
  ["path", { d: "M16 19v1", key: "v220m7" }],
  ["path", { d: "M16 14v1", key: "g12gj6" }],
  ["path", { d: "M12 21v1", key: "q8vafk" }],
  ["path", { d: "M12 16v1", key: "1mx6rx" }]
]);

const LuCloudFog = createLucideIcon("LuCloudFog", [
  ["path", { d: "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242", key: "1pljnt" }],
  ["path", { d: "M16 17H7", key: "pygtm1" }],
  ["path", { d: "M17 21H9", key: "1u2q02" }]
]);

const LuCloudHail = createLucideIcon("LuCloudHail", [
  ["path", { d: "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242", key: "1pljnt" }],
  ["path", { d: "M16 14v2", key: "a1is7l" }],
  ["path", { d: "M8 14v2", key: "1e9m6t" }],
  ["path", { d: "M16 20h.01", key: "xwek51" }],
  ["path", { d: "M8 20h.01", key: "1vjney" }],
  ["path", { d: "M12 16v2", key: "z66u1j" }],
  ["path", { d: "M12 22h.01", key: "1urd7a" }]
]);

const LuCloudLightning = createLucideIcon("LuCloudLightning", [
  ["path", { d: "M6 16.326A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 .5 8.973", key: "1cez44" }],
  ["path", { d: "m13 12-3 5h4l-3 5", key: "1t22er" }]
]);

const LuCloudMoonRain = createLucideIcon("LuCloudMoonRain", [
  [
    "path",
    {
      d: "M10.083 9A6.002 6.002 0 0 1 16 4a4.243 4.243 0 0 0 6 6c0 2.22-1.206 4.16-3 5.197",
      key: "u82z8m"
    }
  ],
  ["path", { d: "M3 20a5 5 0 1 1 8.9-4H13a3 3 0 0 1 2 5.24", key: "1qmrp3" }],
  ["path", { d: "M11 20v2", key: "174qtz" }],
  ["path", { d: "M7 19v2", key: "12npes" }]
]);

const LuCloudMoon = createLucideIcon("LuCloudMoon", [
  ["path", { d: "M13 16a3 3 0 1 1 0 6H7a5 5 0 1 1 4.9-6Z", key: "p44pc9" }],
  ["path", { d: "M10.1 9A6 6 0 0 1 16 4a4.24 4.24 0 0 0 6 6 6 6 0 0 1-3 5.197", key: "16nha0" }]
]);

const LuCloudOff = createLucideIcon("LuCloudOff", [
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M5.782 5.782A7 7 0 0 0 9 19h8.5a4.5 4.5 0 0 0 1.307-.193", key: "yfwify" }],
  [
    "path",
    { d: "M21.532 16.5A4.5 4.5 0 0 0 17.5 10h-1.79A7.008 7.008 0 0 0 10 5.07", key: "jlfiyv" }
  ]
]);

const LuCloudRainWind = createLucideIcon("LuCloudRainWind", [
  ["path", { d: "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242", key: "1pljnt" }],
  ["path", { d: "m9.2 22 3-7", key: "sb5f6j" }],
  ["path", { d: "m9 13-3 7", key: "500co5" }],
  ["path", { d: "m17 13-3 7", key: "8t2fiy" }]
]);

const LuCloudRain = createLucideIcon("LuCloudRain", [
  ["path", { d: "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242", key: "1pljnt" }],
  ["path", { d: "M16 14v6", key: "1j4efv" }],
  ["path", { d: "M8 14v6", key: "17c4r9" }],
  ["path", { d: "M12 16v6", key: "c8a4gj" }]
]);

const LuCloudSnow = createLucideIcon("LuCloudSnow", [
  ["path", { d: "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242", key: "1pljnt" }],
  ["path", { d: "M8 15h.01", key: "a7atzg" }],
  ["path", { d: "M8 19h.01", key: "puxtts" }],
  ["path", { d: "M12 17h.01", key: "p32p05" }],
  ["path", { d: "M12 21h.01", key: "h35vbk" }],
  ["path", { d: "M16 15h.01", key: "rnfrdf" }],
  ["path", { d: "M16 19h.01", key: "1vcnzz" }]
]);

const LuCloudSunRain = createLucideIcon("LuCloudSunRain", [
  ["path", { d: "M12 2v2", key: "tus03m" }],
  ["path", { d: "m4.93 4.93 1.41 1.41", key: "149t6j" }],
  ["path", { d: "M20 12h2", key: "1q8mjw" }],
  ["path", { d: "m19.07 4.93-1.41 1.41", key: "1shlcs" }],
  ["path", { d: "M15.947 12.65a4 4 0 0 0-5.925-4.128", key: "dpwdj0" }],
  ["path", { d: "M3 20a5 5 0 1 1 8.9-4H13a3 3 0 0 1 2 5.24", key: "1qmrp3" }],
  ["path", { d: "M11 20v2", key: "174qtz" }],
  ["path", { d: "M7 19v2", key: "12npes" }]
]);

const LuCloudSun = createLucideIcon("LuCloudSun", [
  ["path", { d: "M12 2v2", key: "tus03m" }],
  ["path", { d: "m4.93 4.93 1.41 1.41", key: "149t6j" }],
  ["path", { d: "M20 12h2", key: "1q8mjw" }],
  ["path", { d: "m19.07 4.93-1.41 1.41", key: "1shlcs" }],
  ["path", { d: "M15.947 12.65a4 4 0 0 0-5.925-4.128", key: "dpwdj0" }],
  ["path", { d: "M13 22H7a5 5 0 1 1 4.9-6H13a3 3 0 0 1 0 6Z", key: "s09mg5" }]
]);

const LuCloudUpload = createLucideIcon("LuCloudUpload", [
  ["path", { d: "M4 14.899A7 7 0 1 1 15.71 8h1.79a4.5 4.5 0 0 1 2.5 8.242", key: "1pljnt" }],
  ["path", { d: "M12 12v9", key: "192myk" }],
  ["path", { d: "m16 16-4-4-4 4", key: "119tzi" }]
]);

const LuCloud = createLucideIcon("LuCloud", [
  ["path", { d: "M17.5 19H9a7 7 0 1 1 6.71-9h1.79a4.5 4.5 0 1 1 0 9Z", key: "p7xjir" }]
]);

const LuCloudy = createLucideIcon("LuCloudy", [
  ["path", { d: "M17.5 21H9a7 7 0 1 1 6.71-9h1.79a4.5 4.5 0 1 1 0 9Z", key: "gqqjvc" }],
  ["path", { d: "M22 10a3 3 0 0 0-3-3h-2.207a5.502 5.502 0 0 0-10.702.5", key: "1p2s76" }]
]);

const LuClover = createLucideIcon("LuClover", [
  ["path", { d: "M16.17 7.83 2 22", key: "t58vo8" }],
  [
    "path",
    {
      d: "M4.02 12a2.827 2.827 0 1 1 3.81-4.17A2.827 2.827 0 1 1 12 4.02a2.827 2.827 0 1 1 4.17 3.81A2.827 2.827 0 1 1 19.98 12a2.827 2.827 0 1 1-3.81 4.17A2.827 2.827 0 1 1 12 19.98a2.827 2.827 0 1 1-4.17-3.81A1 1 0 1 1 4 12",
      key: "17k36q"
    }
  ],
  ["path", { d: "m7.83 7.83 8.34 8.34", key: "1d7sxk" }]
]);

const LuClub = createLucideIcon("LuClub", [
  [
    "path",
    {
      d: "M17.28 9.05a5.5 5.5 0 1 0-10.56 0A5.5 5.5 0 1 0 12 17.66a5.5 5.5 0 1 0 5.28-8.6Z",
      key: "27yuqz"
    }
  ],
  ["path", { d: "M12 17.66L12 22", key: "ogfahf" }]
]);

const LuCodeXml = createLucideIcon("LuCodeXml", [
  ["path", { d: "m18 16 4-4-4-4", key: "1inbqp" }],
  ["path", { d: "m6 8-4 4 4 4", key: "15zrgr" }],
  ["path", { d: "m14.5 4-5 16", key: "e7oirm" }]
]);

const LuCode = createLucideIcon("LuCode", [
  ["polyline", { points: "16 18 22 12 16 6", key: "z7tu5w" }],
  ["polyline", { points: "8 6 2 12 8 18", key: "1eg1df" }]
]);

const LuCodepen = createLucideIcon("LuCodepen", [
  ["polygon", { points: "12 2 22 8.5 22 15.5 12 22 2 15.5 2 8.5 12 2", key: "srzb37" }],
  ["line", { x1: "12", x2: "12", y1: "22", y2: "15.5", key: "1t73f2" }],
  ["polyline", { points: "22 8.5 12 15.5 2 8.5", key: "ajlxae" }],
  ["polyline", { points: "2 15.5 12 8.5 22 15.5", key: "susrui" }],
  ["line", { x1: "12", x2: "12", y1: "2", y2: "8.5", key: "2cldga" }]
]);

const LuCodesandbox = createLucideIcon("LuCodesandbox", [
  [
    "path",
    {
      d: "M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z",
      key: "yt0hxn"
    }
  ],
  ["polyline", { points: "7.5 4.21 12 6.81 16.5 4.21", key: "fabo96" }],
  ["polyline", { points: "7.5 19.79 7.5 14.6 3 12", key: "z377f1" }],
  ["polyline", { points: "21 12 16.5 14.6 16.5 19.79", key: "9nrev1" }],
  ["polyline", { points: "3.27 6.96 12 12.01 20.73 6.96", key: "1180pa" }],
  ["line", { x1: "12", x2: "12", y1: "22.08", y2: "12", key: "3z3uq6" }]
]);

const LuCoffee = createLucideIcon("LuCoffee", [
  ["path", { d: "M17 8h1a4 4 0 1 1 0 8h-1", key: "jx4kbh" }],
  ["path", { d: "M3 8h14v9a4 4 0 0 1-4 4H7a4 4 0 0 1-4-4Z", key: "1bxrl0" }],
  ["line", { x1: "6", x2: "6", y1: "2", y2: "4", key: "1cr9l3" }],
  ["line", { x1: "10", x2: "10", y1: "2", y2: "4", key: "170wym" }],
  ["line", { x1: "14", x2: "14", y1: "2", y2: "4", key: "1c5f70" }]
]);

const LuCog = createLucideIcon("LuCog", [
  ["path", { d: "M12 20a8 8 0 1 0 0-16 8 8 0 0 0 0 16Z", key: "sobvz5" }],
  ["path", { d: "M12 14a2 2 0 1 0 0-4 2 2 0 0 0 0 4Z", key: "11i496" }],
  ["path", { d: "M12 2v2", key: "tus03m" }],
  ["path", { d: "M12 22v-2", key: "1osdcq" }],
  ["path", { d: "m17 20.66-1-1.73", key: "eq3orb" }],
  ["path", { d: "M11 10.27 7 3.34", key: "16pf9h" }],
  ["path", { d: "m20.66 17-1.73-1", key: "sg0v6f" }],
  ["path", { d: "m3.34 7 1.73 1", key: "1ulond" }],
  ["path", { d: "M14 12h8", key: "4f43i9" }],
  ["path", { d: "M2 12h2", key: "1t8f8n" }],
  ["path", { d: "m20.66 7-1.73 1", key: "1ow05n" }],
  ["path", { d: "m3.34 17 1.73-1", key: "nuk764" }],
  ["path", { d: "m17 3.34-1 1.73", key: "2wel8s" }],
  ["path", { d: "m11 13.73-4 6.93", key: "794ttg" }]
]);

const LuCoins = createLucideIcon("LuCoins", [
  ["circle", { cx: "8", cy: "8", r: "6", key: "3yglwk" }],
  ["path", { d: "M18.09 10.37A6 6 0 1 1 10.34 18", key: "t5s6rm" }],
  ["path", { d: "M7 6h1v4", key: "1obek4" }],
  ["path", { d: "m16.71 13.88.7.71-2.82 2.82", key: "1rbuyh" }]
]);

const LuColumns2 = createLucideIcon("LuColumns2", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M12 3v18", key: "108xh3" }]
]);

const LuColumns3 = createLucideIcon("LuColumns3", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M9 3v18", key: "fh3hqa" }],
  ["path", { d: "M15 3v18", key: "14nvp0" }]
]);

const LuColumns4 = createLucideIcon("LuColumns4", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M7.5 3v18", key: "w0wo6v" }],
  ["path", { d: "M12 3v18", key: "108xh3" }],
  ["path", { d: "M16.5 3v18", key: "10tjh1" }]
]);

const LuCombine = createLucideIcon("LuCombine", [
  ["rect", { width: "8", height: "8", x: "2", y: "2", rx: "2", key: "z1hh3n" }],
  ["path", { d: "M14 2c1.1 0 2 .9 2 2v4c0 1.1-.9 2-2 2", key: "83orz6" }],
  ["path", { d: "M20 2c1.1 0 2 .9 2 2v4c0 1.1-.9 2-2 2", key: "k86dmt" }],
  ["path", { d: "M10 18H5c-1.7 0-3-1.3-3-3v-1", key: "6vokjl" }],
  ["polyline", { points: "7 21 10 18 7 15", key: "1k02g0" }],
  ["rect", { width: "8", height: "8", x: "14", y: "14", rx: "2", key: "1fa9i4" }]
]);

const LuCommand = createLucideIcon("LuCommand", [
  [
    "path",
    { d: "M15 6v12a3 3 0 1 0 3-3H6a3 3 0 1 0 3 3V6a3 3 0 1 0-3 3h12a3 3 0 1 0-3-3", key: "11bfej" }
  ]
]);

const LuCompass = createLucideIcon("LuCompass", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["polygon", { points: "16.24 7.76 14.12 14.12 7.76 16.24 9.88 9.88 16.24 7.76", key: "m9r19z" }]
]);

const LuComponent = createLucideIcon("LuComponent", [
  ["path", { d: "M5.5 8.5 9 12l-3.5 3.5L2 12l3.5-3.5Z", key: "1kciei" }],
  ["path", { d: "m12 2 3.5 3.5L12 9 8.5 5.5 12 2Z", key: "1ome0g" }],
  ["path", { d: "M18.5 8.5 22 12l-3.5 3.5L15 12l3.5-3.5Z", key: "vbupec" }],
  ["path", { d: "m12 15 3.5 3.5L12 22l-3.5-3.5L12 15Z", key: "16csic" }]
]);

const LuComputer = createLucideIcon("LuComputer", [
  ["rect", { width: "14", height: "8", x: "5", y: "2", rx: "2", key: "wc9tft" }],
  ["rect", { width: "20", height: "8", x: "2", y: "14", rx: "2", key: "w68u3i" }],
  ["path", { d: "M6 18h2", key: "rwmk9e" }],
  ["path", { d: "M12 18h6", key: "aqd8w3" }]
]);

const LuConciergeBell = createLucideIcon("LuConciergeBell", [
  [
    "path",
    { d: "M3 20a1 1 0 0 1-1-1v-1a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v1a1 1 0 0 1-1 1Z", key: "1pvr1r" }
  ],
  ["path", { d: "M20 16a8 8 0 1 0-16 0", key: "1pa543" }],
  ["path", { d: "M12 4v4", key: "1bq03y" }],
  ["path", { d: "M10 4h4", key: "1xpv9s" }]
]);

const LuCone = createLucideIcon("LuCone", [
  ["path", { d: "m20.9 18.55-8-15.98a1 1 0 0 0-1.8 0l-8 15.98", key: "53pte7" }],
  ["ellipse", { cx: "12", cy: "19", rx: "9", ry: "3", key: "1ji25f" }]
]);

const LuConstruction = createLucideIcon("LuConstruction", [
  ["rect", { x: "2", y: "6", width: "20", height: "8", rx: "1", key: "1estib" }],
  ["path", { d: "M17 14v7", key: "7m2elx" }],
  ["path", { d: "M7 14v7", key: "1cm7wv" }],
  ["path", { d: "M17 3v3", key: "1v4jwn" }],
  ["path", { d: "M7 3v3", key: "7o6guu" }],
  ["path", { d: "M10 14 2.3 6.3", key: "1023jk" }],
  ["path", { d: "m14 6 7.7 7.7", key: "1s8pl2" }],
  ["path", { d: "m8 6 8 8", key: "hl96qh" }]
]);

const LuContactRound = createLucideIcon("LuContactRound", [
  ["path", { d: "M16 18a4 4 0 0 0-8 0", key: "1lzouq" }],
  ["circle", { cx: "12", cy: "11", r: "3", key: "itu57m" }],
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["line", { x1: "8", x2: "8", y1: "2", y2: "4", key: "1ff9gb" }],
  ["line", { x1: "16", x2: "16", y1: "2", y2: "4", key: "1ufoma" }]
]);

const LuContact = createLucideIcon("LuContact", [
  ["path", { d: "M17 18a2 2 0 0 0-2-2H9a2 2 0 0 0-2 2", key: "1mghuy" }],
  ["rect", { width: "18", height: "18", x: "3", y: "4", rx: "2", key: "1hopcy" }],
  ["circle", { cx: "12", cy: "10", r: "2", key: "1yojzk" }],
  ["line", { x1: "8", x2: "8", y1: "2", y2: "4", key: "1ff9gb" }],
  ["line", { x1: "16", x2: "16", y1: "2", y2: "4", key: "1ufoma" }]
]);

const LuContainer = createLucideIcon("LuContainer", [
  [
    "path",
    {
      d: "M22 7.7c0-.6-.4-1.2-.8-1.5l-6.3-3.9a1.72 1.72 0 0 0-1.7 0l-10.3 6c-.5.2-.9.8-.9 1.4v6.6c0 .5.4 1.2.8 1.5l6.3 3.9a1.72 1.72 0 0 0 1.7 0l10.3-6c.5-.3.9-1 .9-1.5Z",
      key: "1t2lqe"
    }
  ],
  ["path", { d: "M10 21.9V14L2.1 9.1", key: "o7czzq" }],
  ["path", { d: "m10 14 11.9-6.9", key: "zm5e20" }],
  ["path", { d: "M14 19.8v-8.1", key: "159ecu" }],
  ["path", { d: "M18 17.5V9.4", key: "11uown" }]
]);

const LuContrast = createLucideIcon("LuContrast", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M12 18a6 6 0 0 0 0-12v12z", key: "j4l70d" }]
]);

const LuCookie = createLucideIcon("LuCookie", [
  ["path", { d: "M12 2a10 10 0 1 0 10 10 4 4 0 0 1-5-5 4 4 0 0 1-5-5", key: "laymnq" }],
  ["path", { d: "M8.5 8.5v.01", key: "ue8clq" }],
  ["path", { d: "M16 15.5v.01", key: "14dtrp" }],
  ["path", { d: "M12 12v.01", key: "u5ubse" }],
  ["path", { d: "M11 17v.01", key: "1hyl5a" }],
  ["path", { d: "M7 14v.01", key: "uct60s" }]
]);

const LuCookingPot = createLucideIcon("LuCookingPot", [
  ["path", { d: "M2 12h20", key: "9i4pu4" }],
  ["path", { d: "M20 12v8a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-8", key: "u0tga0" }],
  ["path", { d: "m4 8 16-4", key: "16g0ng" }],
  [
    "path",
    {
      d: "m8.86 6.78-.45-1.81a2 2 0 0 1 1.45-2.43l1.94-.48a2 2 0 0 1 2.43 1.46l.45 1.8",
      key: "12cejc"
    }
  ]
]);

const LuCopyCheck = createLucideIcon("LuCopyCheck", [
  ["path", { d: "m12 15 2 2 4-4", key: "2c609p" }],
  ["rect", { width: "14", height: "14", x: "8", y: "8", rx: "2", ry: "2", key: "17jyea" }],
  ["path", { d: "M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2", key: "zix9uf" }]
]);

const LuCopyMinus = createLucideIcon("LuCopyMinus", [
  ["line", { x1: "12", x2: "18", y1: "15", y2: "15", key: "1nscbv" }],
  ["rect", { width: "14", height: "14", x: "8", y: "8", rx: "2", ry: "2", key: "17jyea" }],
  ["path", { d: "M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2", key: "zix9uf" }]
]);

const LuCopyPlus = createLucideIcon("LuCopyPlus", [
  ["line", { x1: "15", x2: "15", y1: "12", y2: "18", key: "1p7wdc" }],
  ["line", { x1: "12", x2: "18", y1: "15", y2: "15", key: "1nscbv" }],
  ["rect", { width: "14", height: "14", x: "8", y: "8", rx: "2", ry: "2", key: "17jyea" }],
  ["path", { d: "M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2", key: "zix9uf" }]
]);

const LuCopySlash = createLucideIcon("LuCopySlash", [
  ["line", { x1: "12", x2: "18", y1: "18", y2: "12", key: "ebkxgr" }],
  ["rect", { width: "14", height: "14", x: "8", y: "8", rx: "2", ry: "2", key: "17jyea" }],
  ["path", { d: "M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2", key: "zix9uf" }]
]);

const LuCopyX = createLucideIcon("LuCopyX", [
  ["line", { x1: "12", x2: "18", y1: "12", y2: "18", key: "1rg63v" }],
  ["line", { x1: "12", x2: "18", y1: "18", y2: "12", key: "ebkxgr" }],
  ["rect", { width: "14", height: "14", x: "8", y: "8", rx: "2", ry: "2", key: "17jyea" }],
  ["path", { d: "M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2", key: "zix9uf" }]
]);

const LuCopy = createLucideIcon("LuCopy", [
  ["rect", { width: "14", height: "14", x: "8", y: "8", rx: "2", ry: "2", key: "17jyea" }],
  ["path", { d: "M4 16c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h10c1.1 0 2 .9 2 2", key: "zix9uf" }]
]);

const LuCopyleft = createLucideIcon("LuCopyleft", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M9.17 14.83a4 4 0 1 0 0-5.66", key: "1sveal" }]
]);

const LuCopyright = createLucideIcon("LuCopyright", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M14.83 14.83a4 4 0 1 1 0-5.66", key: "1i56pz" }]
]);

const LuCornerDownLeft = createLucideIcon("LuCornerDownLeft", [
  ["polyline", { points: "9 10 4 15 9 20", key: "r3jprv" }],
  ["path", { d: "M20 4v7a4 4 0 0 1-4 4H4", key: "6o5b7l" }]
]);

const LuCornerDownRight = createLucideIcon("LuCornerDownRight", [
  ["polyline", { points: "15 10 20 15 15 20", key: "1q7qjw" }],
  ["path", { d: "M4 4v7a4 4 0 0 0 4 4h12", key: "z08zvw" }]
]);

const LuCornerLeftDown = createLucideIcon("LuCornerLeftDown", [
  ["polyline", { points: "14 15 9 20 4 15", key: "nkc4i" }],
  ["path", { d: "M20 4h-7a4 4 0 0 0-4 4v12", key: "nbpdq2" }]
]);

const LuCornerLeftUp = createLucideIcon("LuCornerLeftUp", [
  ["polyline", { points: "14 9 9 4 4 9", key: "m9oyvo" }],
  ["path", { d: "M20 20h-7a4 4 0 0 1-4-4V4", key: "1blwi3" }]
]);

const LuCornerRightDown = createLucideIcon("LuCornerRightDown", [
  ["polyline", { points: "10 15 15 20 20 15", key: "axus6l" }],
  ["path", { d: "M4 4h7a4 4 0 0 1 4 4v12", key: "wcbgct" }]
]);

const LuCornerRightUp = createLucideIcon("LuCornerRightUp", [
  ["polyline", { points: "10 9 15 4 20 9", key: "1lr6px" }],
  ["path", { d: "M4 20h7a4 4 0 0 0 4-4V4", key: "1plgdj" }]
]);

const LuCornerUpLeft = createLucideIcon("LuCornerUpLeft", [
  ["polyline", { points: "9 14 4 9 9 4", key: "881910" }],
  ["path", { d: "M20 20v-7a4 4 0 0 0-4-4H4", key: "1nkjon" }]
]);

const LuCornerUpRight = createLucideIcon("LuCornerUpRight", [
  ["polyline", { points: "15 14 20 9 15 4", key: "1tbx3s" }],
  ["path", { d: "M4 20v-7a4 4 0 0 1 4-4h12", key: "1lu4f8" }]
]);

const LuCpu = createLucideIcon("LuCpu", [
  ["rect", { x: "4", y: "4", width: "16", height: "16", rx: "2", key: "1vbyd7" }],
  ["rect", { x: "9", y: "9", width: "6", height: "6", key: "o3kz5p" }],
  ["path", { d: "M15 2v2", key: "13l42r" }],
  ["path", { d: "M15 20v2", key: "15mkzm" }],
  ["path", { d: "M2 15h2", key: "1gxd5l" }],
  ["path", { d: "M2 9h2", key: "1bbxkp" }],
  ["path", { d: "M20 15h2", key: "19e6y8" }],
  ["path", { d: "M20 9h2", key: "19tzq7" }],
  ["path", { d: "M9 2v2", key: "165o2o" }],
  ["path", { d: "M9 20v2", key: "i2bqo8" }]
]);

const LuCreativeCommons = createLucideIcon("LuCreativeCommons", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  [
    "path",
    { d: "M10 9.3a2.8 2.8 0 0 0-3.5 1 3.1 3.1 0 0 0 0 3.4 2.7 2.7 0 0 0 3.5 1", key: "1ss3eq" }
  ],
  [
    "path",
    { d: "M17 9.3a2.8 2.8 0 0 0-3.5 1 3.1 3.1 0 0 0 0 3.4 2.7 2.7 0 0 0 3.5 1", key: "1od56t" }
  ]
]);

const LuCreditCard = createLucideIcon("LuCreditCard", [
  ["rect", { width: "20", height: "14", x: "2", y: "5", rx: "2", key: "ynyp8z" }],
  ["line", { x1: "2", x2: "22", y1: "10", y2: "10", key: "1b3vmo" }]
]);

const LuCroissant = createLucideIcon("LuCroissant", [
  [
    "path",
    {
      d: "m4.6 13.11 5.79-3.21c1.89-1.05 4.79 1.78 3.71 3.71l-3.22 5.81C8.8 23.16.79 15.23 4.6 13.11Z",
      key: "1ozxlb"
    }
  ],
  [
    "path",
    {
      d: "m10.5 9.5-1-2.29C9.2 6.48 8.8 6 8 6H4.5C2.79 6 2 6.5 2 8.5a7.71 7.71 0 0 0 2 4.83",
      key: "ffuyb5"
    }
  ],
  ["path", { d: "M8 6c0-1.55.24-4-2-4-2 0-2.5 2.17-2.5 4", key: "osnpzi" }],
  [
    "path",
    {
      d: "m14.5 13.5 2.29 1c.73.3 1.21.7 1.21 1.5v3.5c0 1.71-.5 2.5-2.5 2.5a7.71 7.71 0 0 1-4.83-2",
      key: "1vubaw"
    }
  ],
  ["path", { d: "M18 16c1.55 0 4-.24 4 2 0 2-2.17 2.5-4 2.5", key: "wxr772" }]
]);

const LuCrop = createLucideIcon("LuCrop", [
  ["path", { d: "M6 2v14a2 2 0 0 0 2 2h14", key: "ron5a4" }],
  ["path", { d: "M18 22V8a2 2 0 0 0-2-2H2", key: "7s9ehn" }]
]);

const LuCross = createLucideIcon("LuCross", [
  [
    "path",
    {
      d: "M11 2a2 2 0 0 0-2 2v5H4a2 2 0 0 0-2 2v2c0 1.1.9 2 2 2h5v5c0 1.1.9 2 2 2h2a2 2 0 0 0 2-2v-5h5a2 2 0 0 0 2-2v-2a2 2 0 0 0-2-2h-5V4a2 2 0 0 0-2-2h-2z",
      key: "1t5g7j"
    }
  ]
]);

const LuCrosshair = createLucideIcon("LuCrosshair", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["line", { x1: "22", x2: "18", y1: "12", y2: "12", key: "l9bcsi" }],
  ["line", { x1: "6", x2: "2", y1: "12", y2: "12", key: "13hhkx" }],
  ["line", { x1: "12", x2: "12", y1: "6", y2: "2", key: "10w3f3" }],
  ["line", { x1: "12", x2: "12", y1: "22", y2: "18", key: "15g9kq" }]
]);

const LuCrown = createLucideIcon("LuCrown", [
  [
    "path",
    {
      d: "M11.562 3.266a.5.5 0 0 1 .876 0L15.39 8.87a1 1 0 0 0 1.516.294L21.183 5.5a.5.5 0 0 1 .798.519l-2.834 10.246a1 1 0 0 1-.956.734H5.81a1 1 0 0 1-.957-.734L2.02 6.02a.5.5 0 0 1 .798-.519l4.276 3.664a1 1 0 0 0 1.516-.294z",
      key: "1vdc57"
    }
  ],
  ["path", { d: "M5 21h14", key: "11awu3" }]
]);

const LuCuboid = createLucideIcon("LuCuboid", [
  [
    "path",
    {
      d: "m21.12 6.4-6.05-4.06a2 2 0 0 0-2.17-.05L2.95 8.41a2 2 0 0 0-.95 1.7v5.82a2 2 0 0 0 .88 1.66l6.05 4.07a2 2 0 0 0 2.17.05l9.95-6.12a2 2 0 0 0 .95-1.7V8.06a2 2 0 0 0-.88-1.66Z",
      key: "1u2ovd"
    }
  ],
  ["path", { d: "M10 22v-8L2.25 9.15", key: "11pn4q" }],
  ["path", { d: "m10 14 11.77-6.87", key: "1kt1wh" }]
]);

const LuCupSoda = createLucideIcon("LuCupSoda", [
  ["path", { d: "m6 8 1.75 12.28a2 2 0 0 0 2 1.72h4.54a2 2 0 0 0 2-1.72L18 8", key: "8166m8" }],
  ["path", { d: "M5 8h14", key: "pcz4l3" }],
  ["path", { d: "M7 15a6.47 6.47 0 0 1 5 0 6.47 6.47 0 0 0 5 0", key: "yjz344" }],
  ["path", { d: "m12 8 1-6h2", key: "3ybfa4" }]
]);

const LuCurrency = createLucideIcon("LuCurrency", [
  ["circle", { cx: "12", cy: "12", r: "8", key: "46899m" }],
  ["line", { x1: "3", x2: "6", y1: "3", y2: "6", key: "1jkytn" }],
  ["line", { x1: "21", x2: "18", y1: "3", y2: "6", key: "14zfjt" }],
  ["line", { x1: "3", x2: "6", y1: "21", y2: "18", key: "iusuec" }],
  ["line", { x1: "21", x2: "18", y1: "21", y2: "18", key: "yj2dd7" }]
]);

const LuCylinder = createLucideIcon("LuCylinder", [
  ["ellipse", { cx: "12", cy: "5", rx: "9", ry: "3", key: "msslwz" }],
  ["path", { d: "M3 5v14a9 3 0 0 0 18 0V5", key: "aqi0yr" }]
]);

const LuDatabaseBackup = createLucideIcon("LuDatabaseBackup", [
  ["ellipse", { cx: "12", cy: "5", rx: "9", ry: "3", key: "msslwz" }],
  ["path", { d: "M3 12a9 3 0 0 0 5 2.69", key: "1ui2ym" }],
  ["path", { d: "M21 9.3V5", key: "6k6cib" }],
  ["path", { d: "M3 5v14a9 3 0 0 0 6.47 2.88", key: "i62tjy" }],
  ["path", { d: "M12 12v4h4", key: "1bxaet" }],
  [
    "path",
    {
      d: "M13 20a5 5 0 0 0 9-3 4.5 4.5 0 0 0-4.5-4.5c-1.33 0-2.54.54-3.41 1.41L12 16",
      key: "1f4ei9"
    }
  ]
]);

const LuDatabaseZap = createLucideIcon("LuDatabaseZap", [
  ["ellipse", { cx: "12", cy: "5", rx: "9", ry: "3", key: "msslwz" }],
  ["path", { d: "M3 5V19A9 3 0 0 0 15 21.84", key: "14ibmq" }],
  ["path", { d: "M21 5V8", key: "1marbg" }],
  ["path", { d: "M21 12L18 17H22L19 22", key: "zafso" }],
  ["path", { d: "M3 12A9 3 0 0 0 14.59 14.87", key: "1y4wr8" }]
]);

const LuDatabase = createLucideIcon("LuDatabase", [
  ["ellipse", { cx: "12", cy: "5", rx: "9", ry: "3", key: "msslwz" }],
  ["path", { d: "M3 5V19A9 3 0 0 0 21 19V5", key: "1wlel7" }],
  ["path", { d: "M3 12A9 3 0 0 0 21 12", key: "mv7ke4" }]
]);

const LuDelete = createLucideIcon("LuDelete", [
  ["path", { d: "M20 5H9l-7 7 7 7h11a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2Z", key: "1oy587" }],
  ["line", { x1: "18", x2: "12", y1: "9", y2: "15", key: "1olkx5" }],
  ["line", { x1: "12", x2: "18", y1: "9", y2: "15", key: "1n50pc" }]
]);

const LuDessert = createLucideIcon("LuDessert", [
  ["circle", { cx: "12", cy: "4", r: "2", key: "muu5ef" }],
  [
    "path",
    {
      d: "M10.2 3.2C5.5 4 2 8.1 2 13a2 2 0 0 0 4 0v-1a2 2 0 0 1 4 0v4a2 2 0 0 0 4 0v-4a2 2 0 0 1 4 0v1a2 2 0 0 0 4 0c0-4.9-3.5-9-8.2-9.8",
      key: "lfo06j"
    }
  ],
  ["path", { d: "M3.2 14.8a9 9 0 0 0 17.6 0", key: "12xarc" }]
]);

const LuDiameter = createLucideIcon("LuDiameter", [
  ["circle", { cx: "19", cy: "19", r: "2", key: "17f5cg" }],
  ["circle", { cx: "5", cy: "5", r: "2", key: "1gwv83" }],
  ["path", { d: "M6.48 3.66a10 10 0 0 1 13.86 13.86", key: "xr8kdq" }],
  ["path", { d: "m6.41 6.41 11.18 11.18", key: "uhpjw7" }],
  ["path", { d: "M3.66 6.48a10 10 0 0 0 13.86 13.86", key: "cldpwv" }]
]);

const LuDiamondPercent = createLucideIcon("LuDiamondPercent", [
  [
    "path",
    {
      d: "M2.7 10.3a2.41 2.41 0 0 0 0 3.41l7.59 7.59a2.41 2.41 0 0 0 3.41 0l7.59-7.59a2.41 2.41 0 0 0 0-3.41L13.7 2.71a2.41 2.41 0 0 0-3.41 0Z",
      key: "1tpxz2"
    }
  ],
  ["path", { d: "M9.2 9.2h.01", key: "1b7bvt" }],
  ["path", { d: "m14.5 9.5-5 5", key: "17q4r4" }],
  ["path", { d: "M14.7 14.8h.01", key: "17nsh4" }]
]);

const LuDiamond = createLucideIcon("LuDiamond", [
  [
    "path",
    {
      d: "M2.7 10.3a2.41 2.41 0 0 0 0 3.41l7.59 7.59a2.41 2.41 0 0 0 3.41 0l7.59-7.59a2.41 2.41 0 0 0 0-3.41l-7.59-7.59a2.41 2.41 0 0 0-3.41 0Z",
      key: "1f1r0c"
    }
  ]
]);

const LuDice1 = createLucideIcon("LuDice1", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }]
]);

const LuDice2 = createLucideIcon("LuDice2", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["path", { d: "M15 9h.01", key: "x1ddxp" }],
  ["path", { d: "M9 15h.01", key: "fzyn71" }]
]);

const LuDice3 = createLucideIcon("LuDice3", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["path", { d: "M16 8h.01", key: "cr5u4v" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }],
  ["path", { d: "M8 16h.01", key: "18s6g9" }]
]);

const LuDice4 = createLucideIcon("LuDice4", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["path", { d: "M16 8h.01", key: "cr5u4v" }],
  ["path", { d: "M8 8h.01", key: "1e4136" }],
  ["path", { d: "M8 16h.01", key: "18s6g9" }],
  ["path", { d: "M16 16h.01", key: "1f9h7w" }]
]);

const LuDice5 = createLucideIcon("LuDice5", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["path", { d: "M16 8h.01", key: "cr5u4v" }],
  ["path", { d: "M8 8h.01", key: "1e4136" }],
  ["path", { d: "M8 16h.01", key: "18s6g9" }],
  ["path", { d: "M16 16h.01", key: "1f9h7w" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }]
]);

const LuDice6 = createLucideIcon("LuDice6", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["path", { d: "M16 8h.01", key: "cr5u4v" }],
  ["path", { d: "M16 12h.01", key: "1l6xoz" }],
  ["path", { d: "M16 16h.01", key: "1f9h7w" }],
  ["path", { d: "M8 8h.01", key: "1e4136" }],
  ["path", { d: "M8 12h.01", key: "czm47f" }],
  ["path", { d: "M8 16h.01", key: "18s6g9" }]
]);

const LuDices = createLucideIcon("LuDices", [
  ["rect", { width: "12", height: "12", x: "2", y: "10", rx: "2", ry: "2", key: "6agr2n" }],
  [
    "path",
    { d: "m17.92 14 3.5-3.5a2.24 2.24 0 0 0 0-3l-5-4.92a2.24 2.24 0 0 0-3 0L10 6", key: "1o487t" }
  ],
  ["path", { d: "M6 18h.01", key: "uhywen" }],
  ["path", { d: "M10 14h.01", key: "ssrbsk" }],
  ["path", { d: "M15 6h.01", key: "cblpky" }],
  ["path", { d: "M18 9h.01", key: "2061c0" }]
]);

const LuDiff = createLucideIcon("LuDiff", [
  ["path", { d: "M12 3v14", key: "7cf3v8" }],
  ["path", { d: "M5 10h14", key: "elsbfy" }],
  ["path", { d: "M5 21h14", key: "11awu3" }]
]);

const LuDisc2 = createLucideIcon("LuDisc2", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["circle", { cx: "12", cy: "12", r: "4", key: "4exip2" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }]
]);

const LuDisc3 = createLucideIcon("LuDisc3", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M6 12c0-1.7.7-3.2 1.8-4.2", key: "oqkarx" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }],
  ["path", { d: "M18 12c0 1.7-.7 3.2-1.8 4.2", key: "1eah9h" }]
]);

const LuDiscAlbum = createLucideIcon("LuDiscAlbum", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["circle", { cx: "12", cy: "12", r: "5", key: "nd82uf" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }]
]);

const LuDisc = createLucideIcon("LuDisc", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }]
]);

const LuDivide = createLucideIcon("LuDivide", [
  ["circle", { cx: "12", cy: "6", r: "1", key: "1bh7o1" }],
  ["line", { x1: "5", x2: "19", y1: "12", y2: "12", key: "13b5wn" }],
  ["circle", { cx: "12", cy: "18", r: "1", key: "lqb9t5" }]
]);

const LuDnaOff = createLucideIcon("LuDnaOff", [
  ["path", { d: "M15 2c-1.35 1.5-2.092 3-2.5 4.5M9 22c1.35-1.5 2.092-3 2.5-4.5", key: "sxiaad" }],
  ["path", { d: "M2 15c3.333-3 6.667-3 10-3m10-3c-1.5 1.35-3 2.092-4.5 2.5", key: "yn4bs1" }],
  ["path", { d: "m17 6-2.5-2.5", key: "5cdfhj" }],
  ["path", { d: "m14 8-1.5-1.5", key: "1ohn8i" }],
  ["path", { d: "m7 18 2.5 2.5", key: "16tu1a" }],
  ["path", { d: "m3.5 14.5.5.5", key: "hapbhd" }],
  ["path", { d: "m20 9 .5.5", key: "1n7z02" }],
  ["path", { d: "m6.5 12.5 1 1", key: "cs35ky" }],
  ["path", { d: "m16.5 10.5 1 1", key: "696xn5" }],
  ["path", { d: "m10 16 1.5 1.5", key: "11lckj" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuDna = createLucideIcon("LuDna", [
  ["path", { d: "M2 15c6.667-6 13.333 0 20-6", key: "1pyr53" }],
  ["path", { d: "M9 22c1.798-1.998 2.518-3.995 2.807-5.993", key: "q3hbxp" }],
  ["path", { d: "M15 2c-1.798 1.998-2.518 3.995-2.807 5.993", key: "80uv8i" }],
  ["path", { d: "m17 6-2.5-2.5", key: "5cdfhj" }],
  ["path", { d: "m14 8-1-1", key: "15nbz5" }],
  ["path", { d: "m7 18 2.5 2.5", key: "16tu1a" }],
  ["path", { d: "m3.5 14.5.5.5", key: "hapbhd" }],
  ["path", { d: "m20 9 .5.5", key: "1n7z02" }],
  ["path", { d: "m6.5 12.5 1 1", key: "cs35ky" }],
  ["path", { d: "m16.5 10.5 1 1", key: "696xn5" }],
  ["path", { d: "m10 16 1.5 1.5", key: "11lckj" }]
]);

const LuDock = createLucideIcon("LuDock", [
  ["path", { d: "M2 8h20", key: "d11cs7" }],
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }],
  ["path", { d: "M6 16h12", key: "u522kt" }]
]);

const LuDog = createLucideIcon("LuDog", [
  [
    "path",
    {
      d: "M10 5.172C10 3.782 8.423 2.679 6.5 3c-2.823.47-4.113 6.006-4 7 .08.703 1.725 1.722 3.656 1 1.261-.472 1.96-1.45 2.344-2.5",
      key: "19br0u"
    }
  ],
  [
    "path",
    {
      d: "M14.267 5.172c0-1.39 1.577-2.493 3.5-2.172 2.823.47 4.113 6.006 4 7-.08.703-1.725 1.722-3.656 1-1.261-.472-1.855-1.45-2.239-2.5",
      key: "11n1an"
    }
  ],
  ["path", { d: "M8 14v.5", key: "1nzgdb" }],
  ["path", { d: "M16 14v.5", key: "1lajdz" }],
  ["path", { d: "M11.25 16.25h1.5L12 17l-.75-.75Z", key: "12kq1m" }],
  [
    "path",
    {
      d: "M4.42 11.247A13.152 13.152 0 0 0 4 14.556C4 18.728 7.582 21 12 21s8-2.272 8-6.444c0-1.061-.162-2.2-.493-3.309m-9.243-6.082A8.801 8.801 0 0 1 12 5c.78 0 1.5.108 2.161.306",
      key: "wsu29d"
    }
  ]
]);

const LuDollarSign = createLucideIcon("LuDollarSign", [
  ["line", { x1: "12", x2: "12", y1: "2", y2: "22", key: "7eqyqh" }],
  ["path", { d: "M17 5H9.5a3.5 3.5 0 0 0 0 7h5a3.5 3.5 0 0 1 0 7H6", key: "1b0p4s" }]
]);

const LuDonut = createLucideIcon("LuDonut", [
  [
    "path",
    {
      d: "M20.5 10a2.5 2.5 0 0 1-2.4-3H18a2.95 2.95 0 0 1-2.6-4.4 10 10 0 1 0 6.3 7.1c-.3.2-.8.3-1.2.3",
      key: "19sr3x"
    }
  ],
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }]
]);

const LuDoorClosed = createLucideIcon("LuDoorClosed", [
  ["path", { d: "M18 20V6a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v14", key: "36qu9e" }],
  ["path", { d: "M2 20h20", key: "owomy5" }],
  ["path", { d: "M14 12v.01", key: "xfcn54" }]
]);

const LuDoorOpen = createLucideIcon("LuDoorOpen", [
  ["path", { d: "M13 4h3a2 2 0 0 1 2 2v14", key: "hrm0s9" }],
  ["path", { d: "M2 20h3", key: "1gaodv" }],
  ["path", { d: "M13 20h9", key: "s90cdi" }],
  ["path", { d: "M10 12v.01", key: "vx6srw" }],
  [
    "path",
    {
      d: "M13 4.562v16.157a1 1 0 0 1-1.242.97L5 20V5.562a2 2 0 0 1 1.515-1.94l4-1A2 2 0 0 1 13 4.561Z",
      key: "199qr4"
    }
  ]
]);

const LuDot = createLucideIcon("LuDot", [
  ["circle", { cx: "12.1", cy: "12.1", r: "1", key: "18d7e5" }]
]);

const LuDownload = createLucideIcon("LuDownload", [
  ["path", { d: "M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4", key: "ih7n3h" }],
  ["polyline", { points: "7 10 12 15 17 10", key: "2ggqvy" }],
  ["line", { x1: "12", x2: "12", y1: "15", y2: "3", key: "1vk2je" }]
]);

const LuDraftingCompass = createLucideIcon("LuDraftingCompass", [
  ["circle", { cx: "12", cy: "5", r: "2", key: "f1ur92" }],
  ["path", { d: "m3 21 8.02-14.26", key: "1ssaw4" }],
  ["path", { d: "m12.99 6.74 1.93 3.44", key: "iwagvd" }],
  ["path", { d: "M19 12c-3.87 4-10.13 4-14 0", key: "1tsu18" }],
  ["path", { d: "m21 21-2.16-3.84", key: "vylbct" }]
]);

const LuDrama = createLucideIcon("LuDrama", [
  ["path", { d: "M10 11h.01", key: "d2at3l" }],
  ["path", { d: "M14 6h.01", key: "k028ub" }],
  ["path", { d: "M18 6h.01", key: "1v4wsw" }],
  ["path", { d: "M6.5 13.1h.01", key: "1748ia" }],
  ["path", { d: "M22 5c0 9-4 12-6 12s-6-3-6-12c0-2 2-3 6-3s6 1 6 3", key: "172yzv" }],
  ["path", { d: "M17.4 9.9c-.8.8-2 .8-2.8 0", key: "1obv0w" }],
  [
    "path",
    {
      d: "M10.1 7.1C9 7.2 7.7 7.7 6 8.6c-3.5 2-4.7 3.9-3.7 5.6 4.5 7.8 9.5 8.4 11.2 7.4.9-.5 1.9-2.1 1.9-4.7",
      key: "rqjl8i"
    }
  ],
  ["path", { d: "M9.1 16.5c.3-1.1 1.4-1.7 2.4-1.4", key: "1mr6wy" }]
]);

const LuDribbble = createLucideIcon("LuDribbble", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M19.13 5.09C15.22 9.14 10 10.44 2.25 10.94", key: "hpej1" }],
  ["path", { d: "M21.75 12.84c-6.62-1.41-12.14 1-16.38 6.32", key: "1tr44o" }],
  ["path", { d: "M8.56 2.75c4.37 6 6 9.42 8 17.72", key: "kbh691" }]
]);

const LuDrill = createLucideIcon("LuDrill", [
  [
    "path",
    { d: "M14 9c0 .6-.4 1-1 1H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h9c.6 0 1 .4 1 1Z", key: "b6nnkj" }
  ],
  ["path", { d: "M18 6h4", key: "66u95g" }],
  ["path", { d: "M14 4h3a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-3", key: "105ega" }],
  ["path", { d: "m5 10-2 8", key: "xt2lic" }],
  ["path", { d: "M12 10v3c0 .6-.4 1-1 1H8", key: "mwpjnk" }],
  ["path", { d: "m7 18 2-8", key: "1bzku2" }],
  [
    "path",
    { d: "M5 22c-1.7 0-3-1.3-3-3 0-.6.4-1 1-1h7c.6 0 1 .4 1 1v2c0 .6-.4 1-1 1Z", key: "117add" }
  ]
]);

const LuDroplet = createLucideIcon("LuDroplet", [
  [
    "path",
    {
      d: "M12 22a7 7 0 0 0 7-7c0-2-1-3.9-3-5.5s-3.5-4-4-6.5c-.5 2.5-2 4.9-4 6.5C6 11.1 5 13 5 15a7 7 0 0 0 7 7z",
      key: "c7niix"
    }
  ]
]);

const LuDroplets = createLucideIcon("LuDroplets", [
  [
    "path",
    {
      d: "M7 16.3c2.2 0 4-1.83 4-4.05 0-1.16-.57-2.26-1.71-3.19S7.29 6.75 7 5.3c-.29 1.45-1.14 2.84-2.29 3.76S3 11.1 3 12.25c0 2.22 1.8 4.05 4 4.05z",
      key: "1ptgy4"
    }
  ],
  [
    "path",
    {
      d: "M12.56 6.6A10.97 10.97 0 0 0 14 3.02c.5 2.5 2 4.9 4 6.5s3 3.5 3 5.5a6.98 6.98 0 0 1-11.91 4.97",
      key: "1sl1rz"
    }
  ]
]);

const LuDrum = createLucideIcon("LuDrum", [
  ["path", { d: "m2 2 8 8", key: "1v6059" }],
  ["path", { d: "m22 2-8 8", key: "173r8a" }],
  ["ellipse", { cx: "12", cy: "9", rx: "10", ry: "5", key: "liohsx" }],
  ["path", { d: "M7 13.4v7.9", key: "1yi6u9" }],
  ["path", { d: "M12 14v8", key: "1tn2tj" }],
  ["path", { d: "M17 13.4v7.9", key: "eqz2v3" }],
  ["path", { d: "M2 9v8a10 5 0 0 0 20 0V9", key: "1750ul" }]
]);

const LuDrumstick = createLucideIcon("LuDrumstick", [
  [
    "path",
    {
      d: "M15.45 15.4c-2.13.65-4.3.32-5.7-1.1-2.29-2.27-1.76-6.5 1.17-9.42 2.93-2.93 7.15-3.46 9.43-1.18 1.41 1.41 1.74 3.57 1.1 5.71-1.4-.51-3.26-.02-4.64 1.36-1.38 1.38-1.87 3.23-1.36 4.63z",
      key: "1o96s0"
    }
  ],
  [
    "path",
    {
      d: "m11.25 15.6-2.16 2.16a2.5 2.5 0 1 1-4.56 1.73 2.49 2.49 0 0 1-1.41-4.24 2.5 2.5 0 0 1 3.14-.32l2.16-2.16",
      key: "14vv5h"
    }
  ]
]);

const LuDumbbell = createLucideIcon("LuDumbbell", [
  ["path", { d: "m6.5 6.5 11 11", key: "f7oqzb" }],
  ["path", { d: "m21 21-1-1", key: "cpc6if" }],
  ["path", { d: "m3 3 1 1", key: "d3rpuf" }],
  ["path", { d: "m18 22 4-4", key: "1e32o6" }],
  ["path", { d: "m2 6 4-4", key: "189tqz" }],
  ["path", { d: "m3 10 7-7", key: "1bxui2" }],
  ["path", { d: "m14 21 7-7", key: "16x78n" }]
]);

const LuEarOff = createLucideIcon("LuEarOff", [
  ["path", { d: "M6 18.5a3.5 3.5 0 1 0 7 0c0-1.57.92-2.52 2.04-3.46", key: "1qngmn" }],
  ["path", { d: "M6 8.5c0-.75.13-1.47.36-2.14", key: "b06bma" }],
  ["path", { d: "M8.8 3.15A6.5 6.5 0 0 1 19 8.5c0 1.63-.44 2.81-1.09 3.76", key: "g10hsz" }],
  ["path", { d: "M12.5 6A2.5 2.5 0 0 1 15 8.5M10 13a2 2 0 0 0 1.82-1.18", key: "ygzou7" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuEar = createLucideIcon("LuEar", [
  ["path", { d: "M6 8.5a6.5 6.5 0 1 1 13 0c0 6-6 6-6 10a3.5 3.5 0 1 1-7 0", key: "1dfaln" }],
  ["path", { d: "M15 8.5a2.5 2.5 0 0 0-5 0v1a2 2 0 1 1 0 4", key: "1qnva7" }]
]);

const LuEarthLock = createLucideIcon("LuEarthLock", [
  ["path", { d: "M7 3.34V5a3 3 0 0 0 3 3", key: "w732o8" }],
  ["path", { d: "M11 21.95V18a2 2 0 0 0-2-2 2 2 0 0 1-2-2v-1a2 2 0 0 0-2-2H2.05", key: "f02343" }],
  ["path", { d: "M21.54 15H17a2 2 0 0 0-2 2v4.54", key: "1djwo0" }],
  ["path", { d: "M12 2a10 10 0 1 0 9.54 13", key: "zjsr6q" }],
  ["path", { d: "M20 6V4a2 2 0 1 0-4 0v2", key: "1of5e8" }],
  ["rect", { width: "8", height: "5", x: "14", y: "6", rx: "1", key: "1fmf51" }]
]);

const LuEarth = createLucideIcon("LuEarth", [
  ["path", { d: "M21.54 15H17a2 2 0 0 0-2 2v4.54", key: "1djwo0" }],
  [
    "path",
    {
      d: "M7 3.34V5a3 3 0 0 0 3 3v0a2 2 0 0 1 2 2v0c0 1.1.9 2 2 2v0a2 2 0 0 0 2-2v0c0-1.1.9-2 2-2h3.17",
      key: "1fi5u6"
    }
  ],
  [
    "path",
    { d: "M11 21.95V18a2 2 0 0 0-2-2v0a2 2 0 0 1-2-2v-1a2 2 0 0 0-2-2H2.05", key: "xsiumc" }
  ],
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }]
]);

const LuEclipse = createLucideIcon("LuEclipse", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M12 2a7 7 0 1 0 10 10", key: "1yuj32" }]
]);

const LuEggFried = createLucideIcon("LuEggFried", [
  ["circle", { cx: "11.5", cy: "12.5", r: "3.5", key: "1cl1mi" }],
  [
    "path",
    {
      d: "M3 8c0-3.5 2.5-6 6.5-6 5 0 4.83 3 7.5 5s5 2 5 6c0 4.5-2.5 6.5-7 6.5-2.5 0-2.5 2.5-6 2.5s-7-2-7-5.5c0-3 1.5-3 1.5-5C3.5 10 3 9 3 8Z",
      key: "165ef9"
    }
  ]
]);

const LuEggOff = createLucideIcon("LuEggOff", [
  [
    "path",
    {
      d: "M6.399 6.399C5.362 8.157 4.65 10.189 4.5 12c-.37 4.43 1.27 9.95 7.5 10 3.256-.026 5.259-1.547 6.375-3.625",
      key: "6et380"
    }
  ],
  [
    "path",
    {
      d: "M19.532 13.875A14.07 14.07 0 0 0 19.5 12c-.36-4.34-3.95-9.96-7.5-10-1.04.012-2.082.502-3.046 1.297",
      key: "gcdc3f"
    }
  ],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuEgg = createLucideIcon("LuEgg", [
  [
    "path",
    {
      d: "M12 22c6.23-.05 7.87-5.57 7.5-10-.36-4.34-3.95-9.96-7.5-10-3.55.04-7.14 5.66-7.5 10-.37 4.43 1.27 9.95 7.5 10z",
      key: "1c39pg"
    }
  ]
]);

const LuEllipsisVertical = createLucideIcon("LuEllipsisVertical", [
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }],
  ["circle", { cx: "12", cy: "5", r: "1", key: "gxeob9" }],
  ["circle", { cx: "12", cy: "19", r: "1", key: "lyex9k" }]
]);

const LuEllipsis = createLucideIcon("LuEllipsis", [
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }],
  ["circle", { cx: "19", cy: "12", r: "1", key: "1wjl8i" }],
  ["circle", { cx: "5", cy: "12", r: "1", key: "1pcz8c" }]
]);

const LuEqualNot = createLucideIcon("LuEqualNot", [
  ["line", { x1: "5", x2: "19", y1: "9", y2: "9", key: "1nwqeh" }],
  ["line", { x1: "5", x2: "19", y1: "15", y2: "15", key: "g8yjpy" }],
  ["line", { x1: "19", x2: "5", y1: "5", y2: "19", key: "1x9vlm" }]
]);

const LuEqual = createLucideIcon("LuEqual", [
  ["line", { x1: "5", x2: "19", y1: "9", y2: "9", key: "1nwqeh" }],
  ["line", { x1: "5", x2: "19", y1: "15", y2: "15", key: "g8yjpy" }]
]);

const LuEraser = createLucideIcon("LuEraser", [
  [
    "path",
    {
      d: "m7 21-4.3-4.3c-1-1-1-2.5 0-3.4l9.6-9.6c1-1 2.5-1 3.4 0l5.6 5.6c1 1 1 2.5 0 3.4L13 21",
      key: "182aya"
    }
  ],
  ["path", { d: "M22 21H7", key: "t4ddhn" }],
  ["path", { d: "m5 11 9 9", key: "1mo9qw" }]
]);

const LuEuro = createLucideIcon("LuEuro", [
  ["path", { d: "M4 10h12", key: "1y6xl8" }],
  ["path", { d: "M4 14h9", key: "1loblj" }],
  [
    "path",
    {
      d: "M19 6a7.7 7.7 0 0 0-5.2-2A7.9 7.9 0 0 0 6 12c0 4.4 3.5 8 7.8 8 2 0 3.8-.8 5.2-2",
      key: "1j6lzo"
    }
  ]
]);

const LuExpand = createLucideIcon("LuExpand", [
  ["path", { d: "m21 21-6-6m6 6v-4.8m0 4.8h-4.8", key: "1c15vz" }],
  ["path", { d: "M3 16.2V21m0 0h4.8M3 21l6-6", key: "1fsnz2" }],
  ["path", { d: "M21 7.8V3m0 0h-4.8M21 3l-6 6", key: "hawz9i" }],
  ["path", { d: "M3 7.8V3m0 0h4.8M3 3l6 6", key: "u9ee12" }]
]);

const LuExternalLink = createLucideIcon("LuExternalLink", [
  ["path", { d: "M15 3h6v6", key: "1q9fwt" }],
  ["path", { d: "M10 14 21 3", key: "gplh6r" }],
  ["path", { d: "M18 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h6", key: "a6xqqp" }]
]);

const LuEyeOff = createLucideIcon("LuEyeOff", [
  ["path", { d: "M9.88 9.88a3 3 0 1 0 4.24 4.24", key: "1jxqfv" }],
  [
    "path",
    {
      d: "M10.73 5.08A10.43 10.43 0 0 1 12 5c7 0 10 7 10 7a13.16 13.16 0 0 1-1.67 2.68",
      key: "9wicm4"
    }
  ],
  [
    "path",
    { d: "M6.61 6.61A13.526 13.526 0 0 0 2 12s3 7 10 7a9.74 9.74 0 0 0 5.39-1.61", key: "1jreej" }
  ],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuEye = createLucideIcon("LuEye", [
  ["path", { d: "M2 12s3-7 10-7 10 7 10 7-3 7-10 7-10-7-10-7Z", key: "rwhkz3" }],
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }]
]);

const LuFacebook = createLucideIcon("LuFacebook", [
  [
    "path",
    { d: "M18 2h-3a5 5 0 0 0-5 5v3H7v4h3v8h4v-8h3l1-4h-4V7a1 1 0 0 1 1-1h3z", key: "1jg4f8" }
  ]
]);

const LuFactory = createLucideIcon("LuFactory", [
  [
    "path",
    {
      d: "M2 20a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2V8l-7 5V8l-7 5V4a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z",
      key: "159hny"
    }
  ],
  ["path", { d: "M17 18h1", key: "uldtlt" }],
  ["path", { d: "M12 18h1", key: "s9uhes" }],
  ["path", { d: "M7 18h1", key: "1neino" }]
]);

const LuFan = createLucideIcon("LuFan", [
  [
    "path",
    {
      d: "M10.827 16.379a6.082 6.082 0 0 1-8.618-7.002l5.412 1.45a6.082 6.082 0 0 1 7.002-8.618l-1.45 5.412a6.082 6.082 0 0 1 8.618 7.002l-5.412-1.45a6.082 6.082 0 0 1-7.002 8.618l1.45-5.412Z",
      key: "484a7f"
    }
  ],
  ["path", { d: "M12 12v.01", key: "u5ubse" }]
]);

const LuFastForward = createLucideIcon("LuFastForward", [
  ["polygon", { points: "13 19 22 12 13 5 13 19", key: "587y9g" }],
  ["polygon", { points: "2 19 11 12 2 5 2 19", key: "3pweh0" }]
]);

const LuFeather = createLucideIcon("LuFeather", [
  ["path", { d: "M20.24 12.24a6 6 0 0 0-8.49-8.49L5 10.5V19h8.5z", key: "u4sw5n" }],
  ["line", { x1: "16", x2: "2", y1: "8", y2: "22", key: "1c47m2" }],
  ["line", { x1: "17.5", x2: "9", y1: "15", y2: "15", key: "2fj3pr" }]
]);

const LuFence = createLucideIcon("LuFence", [
  ["path", { d: "M4 3 2 5v15c0 .6.4 1 1 1h2c.6 0 1-.4 1-1V5Z", key: "1n2rgs" }],
  ["path", { d: "M6 8h4", key: "utf9t1" }],
  ["path", { d: "M6 18h4", key: "12yh4b" }],
  ["path", { d: "m12 3-2 2v15c0 .6.4 1 1 1h2c.6 0 1-.4 1-1V5Z", key: "3ha7mj" }],
  ["path", { d: "M14 8h4", key: "1r8wg2" }],
  ["path", { d: "M14 18h4", key: "1t3kbu" }],
  ["path", { d: "m20 3-2 2v15c0 .6.4 1 1 1h2c.6 0 1-.4 1-1V5Z", key: "dfd4e2" }]
]);

const LuFerrisWheel = createLucideIcon("LuFerrisWheel", [
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }],
  ["path", { d: "M12 2v4", key: "3427ic" }],
  ["path", { d: "m6.8 15-3.5 2", key: "hjy98k" }],
  ["path", { d: "m20.7 7-3.5 2", key: "f08gto" }],
  ["path", { d: "M6.8 9 3.3 7", key: "1aevh4" }],
  ["path", { d: "m20.7 17-3.5-2", key: "1liqo3" }],
  ["path", { d: "m9 22 3-8 3 8", key: "wees03" }],
  ["path", { d: "M8 22h8", key: "rmew8v" }],
  ["path", { d: "M18 18.7a9 9 0 1 0-12 0", key: "dhzg4g" }]
]);

const LuFigma = createLucideIcon("LuFigma", [
  ["path", { d: "M5 5.5A3.5 3.5 0 0 1 8.5 2H12v7H8.5A3.5 3.5 0 0 1 5 5.5z", key: "1340ok" }],
  ["path", { d: "M12 2h3.5a3.5 3.5 0 1 1 0 7H12V2z", key: "1hz3m3" }],
  ["path", { d: "M12 12.5a3.5 3.5 0 1 1 7 0 3.5 3.5 0 1 1-7 0z", key: "1oz8n2" }],
  ["path", { d: "M5 19.5A3.5 3.5 0 0 1 8.5 16H12v3.5a3.5 3.5 0 1 1-7 0z", key: "1ff65i" }],
  ["path", { d: "M5 12.5A3.5 3.5 0 0 1 8.5 9H12v7H8.5A3.5 3.5 0 0 1 5 12.5z", key: "pdip6e" }]
]);

const LuFileArchive = createLucideIcon("LuFileArchive", [
  ["path", { d: "M16 22h2a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v18", key: "1oywqq" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["circle", { cx: "10", cy: "20", r: "2", key: "1xzdoj" }],
  ["path", { d: "M10 7V6", key: "dljcrl" }],
  ["path", { d: "M10 12v-1", key: "v7bkov" }],
  ["path", { d: "M10 18v-2", key: "1cjy8d" }]
]);

const LuFileAudio2 = createLucideIcon("LuFileAudio2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v2", key: "17k7jt" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["circle", { cx: "3", cy: "17", r: "1", key: "vo6nti" }],
  ["path", { d: "M2 17v-3a4 4 0 0 1 8 0v3", key: "1ggdre" }],
  ["circle", { cx: "9", cy: "17", r: "1", key: "bc1fq4" }]
]);

const LuFileAudio = createLucideIcon("LuFileAudio", [
  ["path", { d: "M17.5 22h.5a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v3", key: "rslqgf" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  [
    "path",
    {
      d: "M2 19a2 2 0 1 1 4 0v1a2 2 0 1 1-4 0v-4a6 6 0 0 1 12 0v4a2 2 0 1 1-4 0v-1a2 2 0 1 1 4 0",
      key: "9f7x3i"
    }
  ]
]);

const LuFileAxis3d = createLucideIcon("LuFileAxis3d", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m8 18 4-4", key: "12zab0" }],
  ["path", { d: "M8 10v8h8", key: "tlaukw" }]
]);

const LuFileBadge2 = createLucideIcon("LuFileBadge2", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["circle", { cx: "12", cy: "10", r: "3", key: "ilqhr7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m14 12.5 1 5.5-3-1-3 1 1-5.5", key: "14xlky" }]
]);

const LuFileBadge = createLucideIcon("LuFileBadge", [
  ["path", { d: "M12 22h6a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v3", key: "12ixgl" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M5 17a3 3 0 1 0 0-6 3 3 0 0 0 0 6Z", key: "u0c8gj" }],
  ["path", { d: "M7 16.5 8 22l-3-1-3 1 1-5.5", key: "5gm2nr" }]
]);

const LuFileBarChart2 = createLucideIcon("LuFileBarChart2", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M8 18v-1", key: "zg0ygc" }],
  ["path", { d: "M12 18v-6", key: "17g6i2" }],
  ["path", { d: "M16 18v-3", key: "j5jt4h" }]
]);

const LuFileBarChart = createLucideIcon("LuFileBarChart", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M8 18v-2", key: "qcmpov" }],
  ["path", { d: "M12 18v-4", key: "q1q25u" }],
  ["path", { d: "M16 18v-6", key: "15y0np" }]
]);

const LuFileBox = createLucideIcon("LuFileBox", [
  ["path", { d: "M14.5 22H18a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "16lz6z" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  [
    "path",
    {
      d: "M3 13.1a2 2 0 0 0-1 1.76v3.24a2 2 0 0 0 .97 1.78L6 21.7a2 2 0 0 0 2.03.01L11 19.9a2 2 0 0 0 1-1.76V14.9a2 2 0 0 0-.97-1.78L8 11.3a2 2 0 0 0-2.03-.01Z",
      key: "99pj1s"
    }
  ],
  ["path", { d: "M7 17v5", key: "1yj1jh" }],
  ["path", { d: "M11.7 14.2 7 17l-4.7-2.8", key: "1yk8tc" }]
]);

const LuFileCheck2 = createLucideIcon("LuFileCheck2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m3 15 2 2 4-4", key: "1lhrkk" }]
]);

const LuFileCheck = createLucideIcon("LuFileCheck", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m9 15 2 2 4-4", key: "1grp1n" }]
]);

const LuFileClock = createLucideIcon("LuFileClock", [
  ["path", { d: "M16 22h2a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v3", key: "37hlfg" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["circle", { cx: "8", cy: "16", r: "6", key: "10v15b" }],
  ["path", { d: "M9.5 17.5 8 16.25V14", key: "1o80t2" }]
]);

const LuFileCode2 = createLucideIcon("LuFileCode2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m5 12-3 3 3 3", key: "oke12k" }],
  ["path", { d: "m9 18 3-3-3-3", key: "112psh" }]
]);

const LuFileCode = createLucideIcon("LuFileCode", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m10 13-2 2 2 2", key: "17smn8" }],
  ["path", { d: "m14 17 2-2-2-2", key: "14mezr" }]
]);

const LuFileCog = createLucideIcon("LuFileCog", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v2", key: "17k7jt" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["circle", { cx: "6", cy: "14", r: "3", key: "a1xfv6" }],
  ["path", { d: "M6 10v1", key: "xs0f9j" }],
  ["path", { d: "M6 17v1", key: "idyhc0" }],
  ["path", { d: "M10 14H9", key: "m5fm2q" }],
  ["path", { d: "M3 14H2", key: "19ot09" }],
  ["path", { d: "m9 11-.88.88", key: "lhul2b" }],
  ["path", { d: "M3.88 16.12 3 17", key: "169z9n" }],
  ["path", { d: "m9 17-.88-.88", key: "5io96w" }],
  ["path", { d: "M3.88 11.88 3 11", key: "1ynhy1" }]
]);

const LuFileDiff = createLucideIcon("LuFileDiff", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M9 10h6", key: "9gxzsh" }],
  ["path", { d: "M12 13V7", key: "h0r20n" }],
  ["path", { d: "M9 17h6", key: "r8uit2" }]
]);

const LuFileDigit = createLucideIcon("LuFileDigit", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["rect", { width: "4", height: "6", x: "2", y: "12", rx: "2", key: "jm304g" }],
  ["path", { d: "M10 12h2v6", key: "12zw74" }],
  ["path", { d: "M10 18h4", key: "1ulq68" }]
]);

const LuFileDown = createLucideIcon("LuFileDown", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M12 18v-6", key: "17g6i2" }],
  ["path", { d: "m9 15 3 3 3-3", key: "1npd3o" }]
]);

const LuFileHeart = createLucideIcon("LuFileHeart", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v2", key: "17k7jt" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  [
    "path",
    {
      d: "M10.29 10.7a2.43 2.43 0 0 0-2.66-.52c-.29.12-.56.3-.78.53l-.35.34-.35-.34a2.43 2.43 0 0 0-2.65-.53c-.3.12-.56.3-.79.53-.95.94-1 2.53.2 3.74L6.5 18l3.6-3.55c1.2-1.21 1.14-2.8.19-3.74Z",
      key: "1c1fso"
    }
  ]
]);

const LuFileImage = createLucideIcon("LuFileImage", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["circle", { cx: "10", cy: "12", r: "2", key: "737tya" }],
  ["path", { d: "m20 17-1.296-1.296a2.41 2.41 0 0 0-3.408 0L9 22", key: "wt3hpn" }]
]);

const LuFileInput = createLucideIcon("LuFileInput", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M2 15h10", key: "jfw4w8" }],
  ["path", { d: "m9 18 3-3-3-3", key: "112psh" }]
]);

const LuFileJson2 = createLucideIcon("LuFileJson2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  [
    "path",
    { d: "M4 12a1 1 0 0 0-1 1v1a1 1 0 0 1-1 1 1 1 0 0 1 1 1v1a1 1 0 0 0 1 1", key: "fq0c9t" }
  ],
  [
    "path",
    { d: "M8 18a1 1 0 0 0 1-1v-1a1 1 0 0 1 1-1 1 1 0 0 1-1-1v-1a1 1 0 0 0-1-1", key: "4gibmv" }
  ]
]);

const LuFileJson = createLucideIcon("LuFileJson", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  [
    "path",
    { d: "M10 12a1 1 0 0 0-1 1v1a1 1 0 0 1-1 1 1 1 0 0 1 1 1v1a1 1 0 0 0 1 1", key: "1oajmo" }
  ],
  [
    "path",
    { d: "M14 18a1 1 0 0 0 1-1v-1a1 1 0 0 1 1-1 1 1 0 0 1-1-1v-1a1 1 0 0 0-1-1", key: "mpwhp6" }
  ]
]);

const LuFileKey2 = createLucideIcon("LuFileKey2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v6", key: "rc0qvx" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["circle", { cx: "4", cy: "16", r: "2", key: "1ehqvc" }],
  ["path", { d: "m10 10-4.5 4.5", key: "7fwrp6" }],
  ["path", { d: "m9 11 1 1", key: "wa6s5q" }]
]);

const LuFileKey = createLucideIcon("LuFileKey", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["circle", { cx: "10", cy: "16", r: "2", key: "4ckbqe" }],
  ["path", { d: "m16 10-4.5 4.5", key: "7p3ebg" }],
  ["path", { d: "m15 11 1 1", key: "1bsyx3" }]
]);

const LuFileLineChart = createLucideIcon("LuFileLineChart", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m16 13-3.5 3.5-2-2L8 17", key: "zz7yod" }]
]);

const LuFileLock2 = createLucideIcon("LuFileLock2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v1", key: "jmtmu2" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["rect", { width: "8", height: "5", x: "2", y: "13", rx: "1", key: "10y5wo" }],
  ["path", { d: "M8 13v-2a2 2 0 1 0-4 0v2", key: "1pdxzg" }]
]);

const LuFileLock = createLucideIcon("LuFileLock", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["rect", { width: "8", height: "6", x: "8", y: "12", rx: "1", key: "3yr8at" }],
  ["path", { d: "M10 12v-2a2 2 0 1 1 4 0v2", key: "j4i8d" }]
]);

const LuFileMinus2 = createLucideIcon("LuFileMinus2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M3 15h6", key: "4e2qda" }]
]);

const LuFileMinus = createLucideIcon("LuFileMinus", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M9 15h6", key: "cctwl0" }]
]);

const LuFileMusic = createLucideIcon("LuFileMusic", [
  ["circle", { cx: "14", cy: "16", r: "2", key: "1bzzi3" }],
  ["circle", { cx: "6", cy: "18", r: "2", key: "1fncim" }],
  ["path", { d: "M4 12.4V4a2 2 0 0 1 2-2h8.5L20 7.5V20a2 2 0 0 1-2 2h-7.5", key: "skc018" }],
  ["path", { d: "M8 18v-7.7L16 9v7", key: "1oie6o" }]
]);

const LuFileOutput = createLucideIcon("LuFileOutput", [
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M4 7V4a2 2 0 0 1 2-2 2 2 0 0 0-2 2", key: "1vk7w2" }],
  ["path", { d: "M4.063 20.999a2 2 0 0 0 2 1L18 22a2 2 0 0 0 2-2V7l-5-5H6", key: "1jink5" }],
  ["path", { d: "m5 11-3 3", key: "1dgrs4" }],
  ["path", { d: "m5 17-3-3h10", key: "1mvvaf" }]
]);

const LuFilePenLine = createLucideIcon("LuFilePenLine", [
  ["path", { d: "m18 5-3-3H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2", key: "h0fsxq" }],
  ["path", { d: "M8 18h1", key: "13wk12" }],
  ["path", { d: "M18.4 9.6a2 2 0 1 1 3 3L17 17l-4 1 1-4Z", key: "dyo8mm" }]
]);

const LuFilePen = createLucideIcon("LuFilePen", [
  ["path", { d: "M12 22h6a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v10", key: "x7tsz2" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M10.4 12.6a2 2 0 1 1 3 3L8 21l-4 1 1-4Z", key: "o3xyfb" }]
]);

const LuFilePieChart = createLucideIcon("LuFilePieChart", [
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M16 22h2a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v3.5", key: "13ddob" }],
  ["path", { d: "M4.017 11.512a6 6 0 1 0 8.466 8.475", key: "s6vs5t" }],
  ["path", { d: "M8 16v-6a6 6 0 0 1 6 6z", key: "zfixgv" }]
]);

const LuFilePlus2 = createLucideIcon("LuFilePlus2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M3 15h6", key: "4e2qda" }],
  ["path", { d: "M6 12v6", key: "1u72j0" }]
]);

const LuFilePlus = createLucideIcon("LuFilePlus", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M9 15h6", key: "cctwl0" }],
  ["path", { d: "M12 18v-6", key: "17g6i2" }]
]);

const LuFileQuestion = createLucideIcon("LuFileQuestion", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  [
    "path",
    {
      d: "M10 10.3c.2-.4.5-.8.9-1a2.1 2.1 0 0 1 2.6.4c.3.4.5.8.5 1.3 0 1.3-2 2-2 2",
      key: "1umxtm"
    }
  ],
  ["path", { d: "M12 17h.01", key: "p32p05" }]
]);

const LuFileScan = createLucideIcon("LuFileScan", [
  ["path", { d: "M20 10V7l-5-5H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h4", key: "1rdf37" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M16 14a2 2 0 0 0-2 2", key: "ceaadl" }],
  ["path", { d: "M20 14a2 2 0 0 1 2 2", key: "1ny6zw" }],
  ["path", { d: "M20 22a2 2 0 0 0 2-2", key: "1l9q4k" }],
  ["path", { d: "M16 22a2 2 0 0 1-2-2", key: "1wqh5n" }]
]);

const LuFileSearch2 = createLucideIcon("LuFileSearch2", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["circle", { cx: "11.5", cy: "14.5", r: "2.5", key: "1bq0ko" }],
  ["path", { d: "M13.3 16.3 15 18", key: "2quom7" }]
]);

const LuFileSearch = createLucideIcon("LuFileSearch", [
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  [
    "path",
    { d: "M4.268 21a2 2 0 0 0 1.727 1H18a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v3", key: "ms7g94" }
  ],
  ["path", { d: "m9 18-1.5-1.5", key: "1j6qii" }],
  ["circle", { cx: "5", cy: "14", r: "3", key: "ufru5t" }]
]);

const LuFileSliders = createLucideIcon("LuFileSliders", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["path", { d: "M10 11v2", key: "1s651w" }],
  ["path", { d: "M8 17h8", key: "wh5c61" }],
  ["path", { d: "M14 16v2", key: "12fp5e" }]
]);

const LuFileSpreadsheet = createLucideIcon("LuFileSpreadsheet", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M8 13h2", key: "yr2amv" }],
  ["path", { d: "M14 13h2", key: "un5t4a" }],
  ["path", { d: "M8 17h2", key: "2yhykz" }],
  ["path", { d: "M14 17h2", key: "10kma7" }]
]);

const LuFileStack = createLucideIcon("LuFileStack", [
  ["path", { d: "M21 7h-3a2 2 0 0 1-2-2V2", key: "9rb54x" }],
  [
    "path",
    {
      d: "M21 6v6.5c0 .8-.7 1.5-1.5 1.5h-7c-.8 0-1.5-.7-1.5-1.5v-9c0-.8.7-1.5 1.5-1.5H17Z",
      key: "1059l0"
    }
  ],
  ["path", { d: "M7 8v8.8c0 .3.2.6.4.8.2.2.5.4.8.4H15", key: "16874u" }],
  ["path", { d: "M3 12v8.8c0 .3.2.6.4.8.2.2.5.4.8.4H11", key: "k2ox98" }]
]);

const LuFileSymlink = createLucideIcon("LuFileSymlink", [
  ["path", { d: "m10 18 3-3-3-3", key: "18f6ys" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  [
    "path",
    {
      d: "M4 11V4a2 2 0 0 1 2-2h9l5 5v13a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h7",
      key: "50q2rw"
    }
  ]
]);

const LuFileTerminal = createLucideIcon("LuFileTerminal", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m8 16 2-2-2-2", key: "10vzyd" }],
  ["path", { d: "M12 18h4", key: "1wd2n7" }]
]);

const LuFileText = createLucideIcon("LuFileText", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M10 9H8", key: "b1mrlr" }],
  ["path", { d: "M16 13H8", key: "t4e002" }],
  ["path", { d: "M16 17H8", key: "z1uh3a" }]
]);

const LuFileType2 = createLucideIcon("LuFileType2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M2 13v-1h6v1", key: "1dh9dg" }],
  ["path", { d: "M5 12v6", key: "150t9c" }],
  ["path", { d: "M4 18h2", key: "1xrofg" }]
]);

const LuFileType = createLucideIcon("LuFileType", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M9 13v-1h6v1", key: "1bb014" }],
  ["path", { d: "M12 12v6", key: "3ahymv" }],
  ["path", { d: "M11 18h2", key: "12mj7e" }]
]);

const LuFileUp = createLucideIcon("LuFileUp", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M12 12v6", key: "3ahymv" }],
  ["path", { d: "m15 15-3-3-3 3", key: "15xj92" }]
]);

const LuFileVideo2 = createLucideIcon("LuFileVideo2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["rect", { width: "8", height: "6", x: "2", y: "12", rx: "1", key: "1a6c1e" }],
  ["path", { d: "m10 15.5 4 2.5v-6l-4 2.5", key: "t7cp39" }]
]);

const LuFileVideo = createLucideIcon("LuFileVideo", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m10 11 5 3-5 3v-6Z", key: "7ntvm4" }]
]);

const LuFileVolume2 = createLucideIcon("LuFileVolume2", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "M8 15h.01", key: "a7atzg" }],
  ["path", { d: "M11.5 13.5a2.5 2.5 0 0 1 0 3", key: "1fccat" }],
  ["path", { d: "M15 12a5 5 0 0 1 0 6", key: "ps46cm" }]
]);

const LuFileVolume = createLucideIcon("LuFileVolume", [
  ["path", { d: "M11 11a5 5 0 0 1 0 6", key: "193qb2" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  [
    "path",
    { d: "M4.268 21A2 2 0 0 0 6 22h12a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v3", key: "1x9xgf" }
  ],
  ["path", { d: "m7 10-3 2H2v4h2l3 2z", key: "1ln807" }]
]);

const LuFileWarning = createLucideIcon("LuFileWarning", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M12 9v4", key: "juzpu7" }],
  ["path", { d: "M12 17h.01", key: "p32p05" }]
]);

const LuFileX2 = createLucideIcon("LuFileX2", [
  ["path", { d: "M4 22h14a2 2 0 0 0 2-2V7l-5-5H6a2 2 0 0 0-2 2v4", key: "1pf5j1" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m8 12.5-5 5", key: "b853mi" }],
  ["path", { d: "m3 12.5 5 5", key: "1qls4r" }]
]);

const LuFileX = createLucideIcon("LuFileX", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }],
  ["path", { d: "m14.5 12.5-5 5", key: "b62r18" }],
  ["path", { d: "m9.5 12.5 5 5", key: "1rk7el" }]
]);

const LuFile = createLucideIcon("LuFile", [
  ["path", { d: "M15 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7Z", key: "1rqfz7" }],
  ["path", { d: "M14 2v4a2 2 0 0 0 2 2h4", key: "tnqrlb" }]
]);

const LuFiles = createLucideIcon("LuFiles", [
  ["path", { d: "M20 7h-3a2 2 0 0 1-2-2V2", key: "x099mo" }],
  ["path", { d: "M9 18a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h7l4 4v10a2 2 0 0 1-2 2Z", key: "18t6ie" }],
  ["path", { d: "M3 7.6v12.8A1.6 1.6 0 0 0 4.6 22h9.8", key: "1nja0z" }]
]);

const LuFilm = createLucideIcon("LuFilm", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M7 3v18", key: "bbkbws" }],
  ["path", { d: "M3 7.5h4", key: "zfgn84" }],
  ["path", { d: "M3 12h18", key: "1i2n21" }],
  ["path", { d: "M3 16.5h4", key: "1230mu" }],
  ["path", { d: "M17 3v18", key: "in4fa5" }],
  ["path", { d: "M17 7.5h4", key: "myr1c1" }],
  ["path", { d: "M17 16.5h4", key: "go4c1d" }]
]);

const LuFilterX = createLucideIcon("LuFilterX", [
  ["path", { d: "M13.013 3H2l8 9.46V19l4 2v-8.54l.9-1.055", key: "1fi1da" }],
  ["path", { d: "m22 3-5 5", key: "12jva0" }],
  ["path", { d: "m17 3 5 5", key: "k36vhe" }]
]);

const LuFilter = createLucideIcon("LuFilter", [
  ["polygon", { points: "22 3 2 3 10 12.46 10 19 14 21 14 12.46 22 3", key: "1yg77f" }]
]);

const LuFingerprint = createLucideIcon("LuFingerprint", [
  ["path", { d: "M2 12C2 6.5 6.5 2 12 2a10 10 0 0 1 8 4", key: "1jc9o5" }],
  ["path", { d: "M5 19.5C5.5 18 6 15 6 12c0-.7.12-1.37.34-2", key: "1mxgy1" }],
  ["path", { d: "M17.29 21.02c.12-.6.43-2.3.5-3.02", key: "ptglia" }],
  ["path", { d: "M12 10a2 2 0 0 0-2 2c0 1.02-.1 2.51-.26 4", key: "1nerag" }],
  ["path", { d: "M8.65 22c.21-.66.45-1.32.57-2", key: "13wd9y" }],
  ["path", { d: "M14 13.12c0 2.38 0 6.38-1 8.88", key: "o46ks0" }],
  ["path", { d: "M2 16h.01", key: "1gqxmh" }],
  ["path", { d: "M21.8 16c.2-2 .131-5.354 0-6", key: "drycrb" }],
  ["path", { d: "M9 6.8a6 6 0 0 1 9 5.2c0 .47 0 1.17-.02 2", key: "1fgabc" }]
]);

const LuFireExtinguisher = createLucideIcon("LuFireExtinguisher", [
  ["path", { d: "M15 6.5V3a1 1 0 0 0-1-1h-2a1 1 0 0 0-1 1v3.5", key: "sqyvz" }],
  ["path", { d: "M9 18h8", key: "i7pszb" }],
  ["path", { d: "M18 3h-3", key: "7idoqj" }],
  ["path", { d: "M11 3a6 6 0 0 0-6 6v11", key: "1v5je3" }],
  ["path", { d: "M5 13h4", key: "svpcxo" }],
  ["path", { d: "M17 10a4 4 0 0 0-8 0v10a2 2 0 0 0 2 2h4a2 2 0 0 0 2-2Z", key: "vsjego" }]
]);

const LuFishOff = createLucideIcon("LuFishOff", [
  [
    "path",
    {
      d: "M18 12.47v.03m0-.5v.47m-.475 5.056A6.744 6.744 0 0 1 15 18c-3.56 0-7.56-2.53-8.5-6 .348-1.28 1.114-2.433 2.121-3.38m3.444-2.088A8.802 8.802 0 0 1 15 6c3.56 0 6.06 2.54 7 6-.309 1.14-.786 2.177-1.413 3.058",
      key: "1j1hse"
    }
  ],
  [
    "path",
    {
      d: "M7 10.67C7 8 5.58 5.97 2.73 5.5c-1 1.5-1 5 .23 6.5-1.24 1.5-1.24 5-.23 6.5C5.58 18.03 7 16 7 13.33m7.48-4.372A9.77 9.77 0 0 1 16 6.07m0 11.86a9.77 9.77 0 0 1-1.728-3.618",
      key: "1q46z8"
    }
  ],
  [
    "path",
    {
      d: "m16.01 17.93-.23 1.4A2 2 0 0 1 13.8 21H9.5a5.96 5.96 0 0 0 1.49-3.98M8.53 3h5.27a2 2 0 0 1 1.98 1.67l.23 1.4M2 2l20 20",
      key: "1407gh"
    }
  ]
]);

const LuFishSymbol = createLucideIcon("LuFishSymbol", [
  ["path", { d: "M2 16s9-15 20-4C11 23 2 8 2 8", key: "h4oh4o" }]
]);

const LuFish = createLucideIcon("LuFish", [
  [
    "path",
    {
      d: "M6.5 12c.94-3.46 4.94-6 8.5-6 3.56 0 6.06 2.54 7 6-.94 3.47-3.44 6-7 6s-7.56-2.53-8.5-6Z",
      key: "15baut"
    }
  ],
  ["path", { d: "M18 12v.5", key: "18hhni" }],
  ["path", { d: "M16 17.93a9.77 9.77 0 0 1 0-11.86", key: "16dt7o" }],
  [
    "path",
    {
      d: "M7 10.67C7 8 5.58 5.97 2.73 5.5c-1 1.5-1 5 .23 6.5-1.24 1.5-1.24 5-.23 6.5C5.58 18.03 7 16 7 13.33",
      key: "l9di03"
    }
  ],
  [
    "path",
    { d: "M10.46 7.26C10.2 5.88 9.17 4.24 8 3h5.8a2 2 0 0 1 1.98 1.67l.23 1.4", key: "1kjonw" }
  ],
  [
    "path",
    { d: "m16.01 17.93-.23 1.4A2 2 0 0 1 13.8 21H9.5a5.96 5.96 0 0 0 1.49-3.98", key: "1zlm23" }
  ]
]);

const LuFlagOff = createLucideIcon("LuFlagOff", [
  ["path", { d: "M8 2c3 0 5 2 8 2s4-1 4-1v11", key: "9rwyz9" }],
  ["path", { d: "M4 22V4", key: "1plyxx" }],
  ["path", { d: "M4 15s1-1 4-1 5 2 8 2", key: "1myooe" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuFlagTriangleLeft = createLucideIcon("LuFlagTriangleLeft", [
  ["path", { d: "M17 22V2L7 7l10 5", key: "1rmf0r" }]
]);

const LuFlagTriangleRight = createLucideIcon("LuFlagTriangleRight", [
  ["path", { d: "M7 22V2l10 5-10 5", key: "17n18y" }]
]);

const LuFlag = createLucideIcon("LuFlag", [
  ["path", { d: "M4 15s1-1 4-1 5 2 8 2 4-1 4-1V3s-1 1-4 1-5-2-8-2-4 1-4 1z", key: "i9b6wo" }],
  ["line", { x1: "4", x2: "4", y1: "22", y2: "15", key: "1cm3nv" }]
]);

const LuFlameKindling = createLucideIcon("LuFlameKindling", [
  [
    "path",
    {
      d: "M12 2c1 3 2.5 3.5 3.5 4.5A5 5 0 0 1 17 10a5 5 0 1 1-10 0c0-.3 0-.6.1-.9a2 2 0 1 0 3.3-2C8 4.5 11 2 12 2Z",
      key: "1ir223"
    }
  ],
  ["path", { d: "m5 22 14-4", key: "1brv4h" }],
  ["path", { d: "m5 18 14 4", key: "lgyyje" }]
]);

const LuFlame = createLucideIcon("LuFlame", [
  [
    "path",
    {
      d: "M8.5 14.5A2.5 2.5 0 0 0 11 12c0-1.38-.5-2-1-3-1.072-2.143-.224-4.054 2-6 .5 2.5 2 4.9 4 6.5 2 1.6 3 3.5 3 5.5a7 7 0 1 1-14 0c0-1.153.433-2.294 1-3a2.5 2.5 0 0 0 2.5 2.5z",
      key: "96xj49"
    }
  ]
]);

const LuFlashlightOff = createLucideIcon("LuFlashlightOff", [
  ["path", { d: "M16 16v4a2 2 0 0 1-2 2h-4a2 2 0 0 1-2-2V10c0-2-2-2-2-4", key: "1r120k" }],
  ["path", { d: "M7 2h11v4c0 2-2 2-2 4v1", key: "dz1920" }],
  ["line", { x1: "11", x2: "18", y1: "6", y2: "6", key: "bi1vpe" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuFlashlight = createLucideIcon("LuFlashlight", [
  [
    "path",
    {
      d: "M18 6c0 2-2 2-2 4v10a2 2 0 0 1-2 2h-4a2 2 0 0 1-2-2V10c0-2-2-2-2-4V2h12z",
      key: "1orkel"
    }
  ],
  ["line", { x1: "6", x2: "18", y1: "6", y2: "6", key: "1z11jq" }],
  ["line", { x1: "12", x2: "12", y1: "12", y2: "12", key: "1f4yc1" }]
]);

const LuFlaskConicalOff = createLucideIcon("LuFlaskConicalOff", [
  [
    "path",
    {
      d: "M10 10 4.72 20.55a1 1 0 0 0 .9 1.45h12.76a1 1 0 0 0 .9-1.45l-1.272-2.542",
      key: "59ek9y"
    }
  ],
  ["path", { d: "M10 2v2.343", key: "15t272" }],
  ["path", { d: "M14 2v6.343", key: "sxr80q" }],
  ["path", { d: "M8.5 2h7", key: "csnxdl" }],
  ["path", { d: "M7 16h9", key: "t5njau" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuFlaskConical = createLucideIcon("LuFlaskConical", [
  [
    "path",
    {
      d: "M10 2v7.527a2 2 0 0 1-.211.896L4.72 20.55a1 1 0 0 0 .9 1.45h12.76a1 1 0 0 0 .9-1.45l-5.069-10.127A2 2 0 0 1 14 9.527V2",
      key: "pzvekw"
    }
  ],
  ["path", { d: "M8.5 2h7", key: "csnxdl" }],
  ["path", { d: "M7 16h10", key: "wp8him" }]
]);

const LuFlaskRound = createLucideIcon("LuFlaskRound", [
  ["path", { d: "M10 2v7.31", key: "5d1hyh" }],
  ["path", { d: "M14 9.3V1.99", key: "14k4l0" }],
  ["path", { d: "M8.5 2h7", key: "csnxdl" }],
  ["path", { d: "M14 9.3a6.5 6.5 0 1 1-4 0", key: "1r8fvy" }],
  ["path", { d: "M5.52 16h12.96", key: "46hh1i" }]
]);

const LuFlipHorizontal2 = createLucideIcon("LuFlipHorizontal2", [
  ["path", { d: "m3 7 5 5-5 5V7", key: "couhi7" }],
  ["path", { d: "m21 7-5 5 5 5V7", key: "6ouia7" }],
  ["path", { d: "M12 20v2", key: "1lh1kg" }],
  ["path", { d: "M12 14v2", key: "8jcxud" }],
  ["path", { d: "M12 8v2", key: "1woqiv" }],
  ["path", { d: "M12 2v2", key: "tus03m" }]
]);

const LuFlipHorizontal = createLucideIcon("LuFlipHorizontal", [
  ["path", { d: "M8 3H5a2 2 0 0 0-2 2v14c0 1.1.9 2 2 2h3", key: "1i73f7" }],
  ["path", { d: "M16 3h3a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-3", key: "saxlbk" }],
  ["path", { d: "M12 20v2", key: "1lh1kg" }],
  ["path", { d: "M12 14v2", key: "8jcxud" }],
  ["path", { d: "M12 8v2", key: "1woqiv" }],
  ["path", { d: "M12 2v2", key: "tus03m" }]
]);

const LuFlipVertical2 = createLucideIcon("LuFlipVertical2", [
  ["path", { d: "m17 3-5 5-5-5h10", key: "1ftt6x" }],
  ["path", { d: "m17 21-5-5-5 5h10", key: "1m0wmu" }],
  ["path", { d: "M4 12H2", key: "rhcxmi" }],
  ["path", { d: "M10 12H8", key: "s88cx1" }],
  ["path", { d: "M16 12h-2", key: "10asgb" }],
  ["path", { d: "M22 12h-2", key: "14jgyd" }]
]);

const LuFlipVertical = createLucideIcon("LuFlipVertical", [
  ["path", { d: "M21 8V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v3", key: "14bfxa" }],
  ["path", { d: "M21 16v3a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-3", key: "14rx03" }],
  ["path", { d: "M4 12H2", key: "rhcxmi" }],
  ["path", { d: "M10 12H8", key: "s88cx1" }],
  ["path", { d: "M16 12h-2", key: "10asgb" }],
  ["path", { d: "M22 12h-2", key: "14jgyd" }]
]);

const LuFlower2 = createLucideIcon("LuFlower2", [
  [
    "path",
    {
      d: "M12 5a3 3 0 1 1 3 3m-3-3a3 3 0 1 0-3 3m3-3v1M9 8a3 3 0 1 0 3 3M9 8h1m5 0a3 3 0 1 1-3 3m3-3h-1m-2 3v-1",
      key: "3pnvol"
    }
  ],
  ["circle", { cx: "12", cy: "8", r: "2", key: "1822b1" }],
  ["path", { d: "M12 10v12", key: "6ubwww" }],
  ["path", { d: "M12 22c4.2 0 7-1.667 7-5-4.2 0-7 1.667-7 5Z", key: "9hd38g" }],
  ["path", { d: "M12 22c-4.2 0-7-1.667-7-5 4.2 0 7 1.667 7 5Z", key: "ufn41s" }]
]);

const LuFlower = createLucideIcon("LuFlower", [
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  [
    "path",
    {
      d: "M12 16.5A4.5 4.5 0 1 1 7.5 12 4.5 4.5 0 1 1 12 7.5a4.5 4.5 0 1 1 4.5 4.5 4.5 4.5 0 1 1-4.5 4.5",
      key: "14wa3c"
    }
  ],
  ["path", { d: "M12 7.5V9", key: "1oy5b0" }],
  ["path", { d: "M7.5 12H9", key: "eltsq1" }],
  ["path", { d: "M16.5 12H15", key: "vk5kw4" }],
  ["path", { d: "M12 16.5V15", key: "k7eayi" }],
  ["path", { d: "m8 8 1.88 1.88", key: "nxy4qf" }],
  ["path", { d: "M14.12 9.88 16 8", key: "1lst6k" }],
  ["path", { d: "m8 16 1.88-1.88", key: "h2eex1" }],
  ["path", { d: "M14.12 14.12 16 16", key: "uqkrx3" }]
]);

const LuFocus = createLucideIcon("LuFocus", [
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }]
]);

const LuFoldHorizontal = createLucideIcon("LuFoldHorizontal", [
  ["path", { d: "M2 12h6", key: "1wqiqv" }],
  ["path", { d: "M22 12h-6", key: "1eg9hc" }],
  ["path", { d: "M12 2v2", key: "tus03m" }],
  ["path", { d: "M12 8v2", key: "1woqiv" }],
  ["path", { d: "M12 14v2", key: "8jcxud" }],
  ["path", { d: "M12 20v2", key: "1lh1kg" }],
  ["path", { d: "m19 9-3 3 3 3", key: "12ol22" }],
  ["path", { d: "m5 15 3-3-3-3", key: "1kdhjc" }]
]);

const LuFoldVertical = createLucideIcon("LuFoldVertical", [
  ["path", { d: "M12 22v-6", key: "6o8u61" }],
  ["path", { d: "M12 8V2", key: "1wkif3" }],
  ["path", { d: "M4 12H2", key: "rhcxmi" }],
  ["path", { d: "M10 12H8", key: "s88cx1" }],
  ["path", { d: "M16 12h-2", key: "10asgb" }],
  ["path", { d: "M22 12h-2", key: "14jgyd" }],
  ["path", { d: "m15 19-3-3-3 3", key: "e37ymu" }],
  ["path", { d: "m15 5-3 3-3-3", key: "19d6lf" }]
]);

const LuFolderArchive = createLucideIcon("LuFolderArchive", [
  ["circle", { cx: "15", cy: "19", r: "2", key: "u2pros" }],
  [
    "path",
    {
      d: "M20.9 19.8A2 2 0 0 0 22 18V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2h5.1",
      key: "1jj40k"
    }
  ],
  ["path", { d: "M15 11v-1", key: "cntcp" }],
  ["path", { d: "M15 17v-2", key: "1279jj" }]
]);

const LuFolderCheck = createLucideIcon("LuFolderCheck", [
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ],
  ["path", { d: "m9 13 2 2 4-4", key: "6343dt" }]
]);

const LuFolderClock = createLucideIcon("LuFolderClock", [
  ["circle", { cx: "16", cy: "16", r: "6", key: "qoo3c4" }],
  [
    "path",
    {
      d: "M7 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2",
      key: "1urifu"
    }
  ],
  ["path", { d: "M16 14v2l1 1", key: "xth2jh" }]
]);

const LuFolderClosed = createLucideIcon("LuFolderClosed", [
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ],
  ["path", { d: "M2 10h20", key: "1ir3d8" }]
]);

const LuFolderCog = createLucideIcon("LuFolderCog", [
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  [
    "path",
    {
      d: "M10.3 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v3.3",
      key: "1k8050"
    }
  ],
  ["path", { d: "m21.7 19.4-.9-.3", key: "1qgwi9" }],
  ["path", { d: "m15.2 16.9-.9-.3", key: "1t7mvx" }],
  ["path", { d: "m16.6 21.7.3-.9", key: "1j67ps" }],
  ["path", { d: "m19.1 15.2.3-.9", key: "18r7jp" }],
  ["path", { d: "m19.6 21.7-.4-1", key: "z2vh2" }],
  ["path", { d: "m16.8 15.3-.4-1", key: "1ei7r6" }],
  ["path", { d: "m14.3 19.6 1-.4", key: "11sv9r" }],
  ["path", { d: "m20.7 16.8 1-.4", key: "19m87a" }]
]);

const LuFolderDot = createLucideIcon("LuFolderDot", [
  [
    "path",
    {
      d: "M4 20h16a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.93a2 2 0 0 1-1.66-.9l-.82-1.2A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13c0 1.1.9 2 2 2Z",
      key: "1fr9dc"
    }
  ],
  ["circle", { cx: "12", cy: "13", r: "1", key: "49l61u" }]
]);

const LuFolderDown = createLucideIcon("LuFolderDown", [
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ],
  ["path", { d: "M12 10v6", key: "1bos4e" }],
  ["path", { d: "m15 13-3 3-3-3", key: "6j2sf0" }]
]);

const LuFolderGit2 = createLucideIcon("LuFolderGit2", [
  [
    "path",
    {
      d: "M9 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v5",
      key: "1w6njk"
    }
  ],
  ["circle", { cx: "13", cy: "12", r: "2", key: "1j92g6" }],
  ["path", { d: "M18 19c-2.8 0-5-2.2-5-5v8", key: "pkpw2h" }],
  ["circle", { cx: "20", cy: "19", r: "2", key: "1obnsp" }]
]);

const LuFolderGit = createLucideIcon("LuFolderGit", [
  ["circle", { cx: "12", cy: "13", r: "2", key: "1c1ljs" }],
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ],
  ["path", { d: "M14 13h3", key: "1dgedf" }],
  ["path", { d: "M7 13h3", key: "1pygq7" }]
]);

const LuFolderHeart = createLucideIcon("LuFolderHeart", [
  [
    "path",
    {
      d: "M11 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v1.5",
      key: "6hud8k"
    }
  ],
  [
    "path",
    {
      d: "M13.9 17.45c-1.2-1.2-1.14-2.8-.2-3.73a2.43 2.43 0 0 1 3.44 0l.36.34.34-.34a2.43 2.43 0 0 1 3.45-.01v0c.95.95 1 2.53-.2 3.74L17.5 21Z",
      key: "vgq86i"
    }
  ]
]);

const LuFolderInput = createLucideIcon("LuFolderInput", [
  [
    "path",
    {
      d: "M2 9V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-1",
      key: "fm4g5t"
    }
  ],
  ["path", { d: "M2 13h10", key: "pgb2dq" }],
  ["path", { d: "m9 16 3-3-3-3", key: "6m91ic" }]
]);

const LuFolderKanban = createLucideIcon("LuFolderKanban", [
  [
    "path",
    {
      d: "M4 20h16a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.93a2 2 0 0 1-1.66-.9l-.82-1.2A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13c0 1.1.9 2 2 2Z",
      key: "1fr9dc"
    }
  ],
  ["path", { d: "M8 10v4", key: "tgpxqk" }],
  ["path", { d: "M12 10v2", key: "hh53o1" }],
  ["path", { d: "M16 10v6", key: "1d6xys" }]
]);

const LuFolderKey = createLucideIcon("LuFolderKey", [
  ["circle", { cx: "16", cy: "20", r: "2", key: "1vifvg" }],
  [
    "path",
    {
      d: "M10 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v2",
      key: "3hgo9p"
    }
  ],
  ["path", { d: "m22 14-4.5 4.5", key: "1ef6z8" }],
  ["path", { d: "m21 15 1 1", key: "1ejcpy" }]
]);

const LuFolderLock = createLucideIcon("LuFolderLock", [
  ["rect", { width: "8", height: "5", x: "14", y: "17", rx: "1", key: "19aais" }],
  [
    "path",
    {
      d: "M10 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v2.5",
      key: "1w6v7t"
    }
  ],
  ["path", { d: "M20 17v-2a2 2 0 1 0-4 0v2", key: "pwaxnr" }]
]);

const LuFolderMinus = createLucideIcon("LuFolderMinus", [
  ["path", { d: "M9 13h6", key: "1uhe8q" }],
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ]
]);

const LuFolderOpenDot = createLucideIcon("LuFolderOpenDot", [
  [
    "path",
    {
      d: "m6 14 1.45-2.9A2 2 0 0 1 9.24 10H20a2 2 0 0 1 1.94 2.5l-1.55 6a2 2 0 0 1-1.94 1.5H4a2 2 0 0 1-2-2V5c0-1.1.9-2 2-2h3.93a2 2 0 0 1 1.66.9l.82 1.2a2 2 0 0 0 1.66.9H18a2 2 0 0 1 2 2v2",
      key: "1nmvlm"
    }
  ],
  ["circle", { cx: "14", cy: "15", r: "1", key: "1gm4qj" }]
]);

const LuFolderOpen = createLucideIcon("LuFolderOpen", [
  [
    "path",
    {
      d: "m6 14 1.5-2.9A2 2 0 0 1 9.24 10H20a2 2 0 0 1 1.94 2.5l-1.54 6a2 2 0 0 1-1.95 1.5H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H18a2 2 0 0 1 2 2v2",
      key: "usdka0"
    }
  ]
]);

const LuFolderOutput = createLucideIcon("LuFolderOutput", [
  [
    "path",
    {
      d: "M2 7.5V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-1.5",
      key: "1yk7aj"
    }
  ],
  ["path", { d: "M2 13h10", key: "pgb2dq" }],
  ["path", { d: "m5 10-3 3 3 3", key: "1r8ie0" }]
]);

const LuFolderPen = createLucideIcon("LuFolderPen", [
  ["path", { d: "M8.4 10.6a2 2 0 0 1 3 3L6 19l-4 1 1-4Z", key: "dakro8" }],
  [
    "path",
    {
      d: "M2 11.5V5a2 2 0 0 1 2-2h3.9c.7 0 1.3.3 1.7.9l.8 1.2c.4.6 1 .9 1.7.9H20a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-9.5",
      key: "a8xqs0"
    }
  ]
]);

const LuFolderPlus = createLucideIcon("LuFolderPlus", [
  ["path", { d: "M12 10v6", key: "1bos4e" }],
  ["path", { d: "M9 13h6", key: "1uhe8q" }],
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ]
]);

const LuFolderRoot = createLucideIcon("LuFolderRoot", [
  [
    "path",
    {
      d: "M4 20h16a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.93a2 2 0 0 1-1.66-.9l-.82-1.2A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13c0 1.1.9 2 2 2Z",
      key: "1fr9dc"
    }
  ],
  ["circle", { cx: "12", cy: "13", r: "2", key: "1c1ljs" }],
  ["path", { d: "M12 15v5", key: "11xva1" }]
]);

const LuFolderSearch2 = createLucideIcon("LuFolderSearch2", [
  ["circle", { cx: "11.5", cy: "12.5", r: "2.5", key: "1ea5ju" }],
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ],
  ["path", { d: "M13.3 14.3 15 16", key: "1y4v1n" }]
]);

const LuFolderSearch = createLucideIcon("LuFolderSearch", [
  ["circle", { cx: "17", cy: "17", r: "3", key: "18b49y" }],
  [
    "path",
    {
      d: "M10.7 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v4.1",
      key: "1bw5m7"
    }
  ],
  ["path", { d: "m21 21-1.5-1.5", key: "3sg1j" }]
]);

const LuFolderSymlink = createLucideIcon("LuFolderSymlink", [
  [
    "path",
    {
      d: "M2 9V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h7",
      key: "x1c07l"
    }
  ],
  ["path", { d: "m8 16 3-3-3-3", key: "rlqrt1" }]
]);

const LuFolderSync = createLucideIcon("LuFolderSync", [
  [
    "path",
    {
      d: "M9 20H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h3.9a2 2 0 0 1 1.69.9l.81 1.2a2 2 0 0 0 1.67.9H20a2 2 0 0 1 2 2v.5",
      key: "1dkoa9"
    }
  ],
  ["path", { d: "M12 10v4h4", key: "1czhmt" }],
  ["path", { d: "m12 14 1.535-1.605a5 5 0 0 1 8 1.5", key: "lvuxfi" }],
  ["path", { d: "M22 22v-4h-4", key: "1ewp4q" }],
  ["path", { d: "m22 18-1.535 1.605a5 5 0 0 1-8-1.5", key: "14ync0" }]
]);

const LuFolderTree = createLucideIcon("LuFolderTree", [
  [
    "path",
    {
      d: "M20 10a1 1 0 0 0 1-1V6a1 1 0 0 0-1-1h-2.5a1 1 0 0 1-.8-.4l-.9-1.2A1 1 0 0 0 15 3h-2a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1Z",
      key: "hod4my"
    }
  ],
  [
    "path",
    {
      d: "M20 21a1 1 0 0 0 1-1v-3a1 1 0 0 0-1-1h-2.9a1 1 0 0 1-.88-.55l-.42-.85a1 1 0 0 0-.92-.6H13a1 1 0 0 0-1 1v5a1 1 0 0 0 1 1Z",
      key: "w4yl2u"
    }
  ],
  ["path", { d: "M3 5a2 2 0 0 0 2 2h3", key: "f2jnh7" }],
  ["path", { d: "M3 3v13a2 2 0 0 0 2 2h3", key: "k8epm1" }]
]);

const LuFolderUp = createLucideIcon("LuFolderUp", [
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ],
  ["path", { d: "M12 10v6", key: "1bos4e" }],
  ["path", { d: "m9 13 3-3 3 3", key: "1pxg3c" }]
]);

const LuFolderX = createLucideIcon("LuFolderX", [
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ],
  ["path", { d: "m9.5 10.5 5 5", key: "ra9qjz" }],
  ["path", { d: "m14.5 10.5-5 5", key: "l2rkpq" }]
]);

const LuFolder = createLucideIcon("LuFolder", [
  [
    "path",
    {
      d: "M20 20a2 2 0 0 0 2-2V8a2 2 0 0 0-2-2h-7.9a2 2 0 0 1-1.69-.9L9.6 3.9A2 2 0 0 0 7.93 3H4a2 2 0 0 0-2 2v13a2 2 0 0 0 2 2Z",
      key: "1kt360"
    }
  ]
]);

const LuFolders = createLucideIcon("LuFolders", [
  [
    "path",
    {
      d: "M20 17a2 2 0 0 0 2-2V9a2 2 0 0 0-2-2h-3.9a2 2 0 0 1-1.69-.9l-.81-1.2a2 2 0 0 0-1.67-.9H8a2 2 0 0 0-2 2v9a2 2 0 0 0 2 2Z",
      key: "4u7rpt"
    }
  ],
  ["path", { d: "M2 8v11a2 2 0 0 0 2 2h14", key: "1eicx1" }]
]);

const LuFootprints = createLucideIcon("LuFootprints", [
  [
    "path",
    {
      d: "M4 16v-2.38C4 11.5 2.97 10.5 3 8c.03-2.72 1.49-6 4.5-6C9.37 2 10 3.8 10 5.5c0 3.11-2 5.66-2 8.68V16a2 2 0 1 1-4 0Z",
      key: "1dudjm"
    }
  ],
  [
    "path",
    {
      d: "M20 20v-2.38c0-2.12 1.03-3.12 1-5.62-.03-2.72-1.49-6-4.5-6C14.63 6 14 7.8 14 9.5c0 3.11 2 5.66 2 8.68V20a2 2 0 1 0 4 0Z",
      key: "l2t8xc"
    }
  ],
  ["path", { d: "M16 17h4", key: "1dejxt" }],
  ["path", { d: "M4 13h4", key: "1bwh8b" }]
]);

const LuForklift = createLucideIcon("LuForklift", [
  ["path", { d: "M12 12H5a2 2 0 0 0-2 2v5", key: "7zsz91" }],
  ["circle", { cx: "13", cy: "19", r: "2", key: "wjnkru" }],
  ["circle", { cx: "5", cy: "19", r: "2", key: "v8kfzx" }],
  ["path", { d: "M8 19h3m5-17v17h6M6 12V7c0-1.1.9-2 2-2h3l5 5", key: "13bk1p" }]
]);

const LuForward = createLucideIcon("LuForward", [
  ["polyline", { points: "15 17 20 12 15 7", key: "1w3sku" }],
  ["path", { d: "M4 18v-2a4 4 0 0 1 4-4h12", key: "jmiej9" }]
]);

const LuFrame = createLucideIcon("LuFrame", [
  ["line", { x1: "22", x2: "2", y1: "6", y2: "6", key: "15w7dq" }],
  ["line", { x1: "22", x2: "2", y1: "18", y2: "18", key: "1ip48p" }],
  ["line", { x1: "6", x2: "6", y1: "2", y2: "22", key: "a2lnyx" }],
  ["line", { x1: "18", x2: "18", y1: "2", y2: "22", key: "8vb6jd" }]
]);

const LuFramer = createLucideIcon("LuFramer", [
  ["path", { d: "M5 16V9h14V2H5l14 14h-7m-7 0 7 7v-7m-7 0h7", key: "1a2nng" }]
]);

const LuFrown = createLucideIcon("LuFrown", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M16 16s-1.5-2-4-2-4 2-4 2", key: "epbg0q" }],
  ["line", { x1: "9", x2: "9.01", y1: "9", y2: "9", key: "yxxnd0" }],
  ["line", { x1: "15", x2: "15.01", y1: "9", y2: "9", key: "1p4y9e" }]
]);

const LuFuel = createLucideIcon("LuFuel", [
  ["line", { x1: "3", x2: "15", y1: "22", y2: "22", key: "xegly4" }],
  ["line", { x1: "4", x2: "14", y1: "9", y2: "9", key: "xcnuvu" }],
  ["path", { d: "M14 22V4a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v18", key: "16j0yd" }],
  [
    "path",
    {
      d: "M14 13h2a2 2 0 0 1 2 2v2a2 2 0 0 0 2 2h0a2 2 0 0 0 2-2V9.83a2 2 0 0 0-.59-1.42L18 5",
      key: "8ur5zv"
    }
  ]
]);

const LuFullscreen = createLucideIcon("LuFullscreen", [
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }],
  ["rect", { width: "10", height: "8", x: "7", y: "8", rx: "1", key: "vys8me" }]
]);

const LuGalleryHorizontalEnd = createLucideIcon("LuGalleryHorizontalEnd", [
  ["path", { d: "M2 7v10", key: "a2pl2d" }],
  ["path", { d: "M6 5v14", key: "1kq3d7" }],
  ["rect", { width: "12", height: "18", x: "10", y: "3", rx: "2", key: "13i7bc" }]
]);

const LuGalleryHorizontal = createLucideIcon("LuGalleryHorizontal", [
  ["path", { d: "M2 3v18", key: "pzttux" }],
  ["rect", { width: "12", height: "18", x: "6", y: "3", rx: "2", key: "btr8bg" }],
  ["path", { d: "M22 3v18", key: "6jf3v" }]
]);

const LuGalleryThumbnails = createLucideIcon("LuGalleryThumbnails", [
  ["rect", { width: "18", height: "14", x: "3", y: "3", rx: "2", key: "74y24f" }],
  ["path", { d: "M4 21h1", key: "16zlid" }],
  ["path", { d: "M9 21h1", key: "15o7lz" }],
  ["path", { d: "M14 21h1", key: "v9vybs" }],
  ["path", { d: "M19 21h1", key: "edywat" }]
]);

const LuGalleryVerticalEnd = createLucideIcon("LuGalleryVerticalEnd", [
  ["path", { d: "M7 2h10", key: "nczekb" }],
  ["path", { d: "M5 6h14", key: "u2x4p" }],
  ["rect", { width: "18", height: "12", x: "3", y: "10", rx: "2", key: "l0tzu3" }]
]);

const LuGalleryVertical = createLucideIcon("LuGalleryVertical", [
  ["path", { d: "M3 2h18", key: "15qxfx" }],
  ["rect", { width: "18", height: "12", x: "3", y: "6", rx: "2", key: "1439r6" }],
  ["path", { d: "M3 22h18", key: "8prr45" }]
]);

const LuGamepad2 = createLucideIcon("LuGamepad2", [
  ["line", { x1: "6", x2: "10", y1: "11", y2: "11", key: "1gktln" }],
  ["line", { x1: "8", x2: "8", y1: "9", y2: "13", key: "qnk9ow" }],
  ["line", { x1: "15", x2: "15.01", y1: "12", y2: "12", key: "krot7o" }],
  ["line", { x1: "18", x2: "18.01", y1: "10", y2: "10", key: "1lcuu1" }],
  [
    "path",
    {
      d: "M17.32 5H6.68a4 4 0 0 0-3.978 3.59c-.006.052-.01.101-.017.152C2.604 9.416 2 14.456 2 16a3 3 0 0 0 3 3c1 0 1.5-.5 2-1l1.414-1.414A2 2 0 0 1 9.828 16h4.344a2 2 0 0 1 1.414.586L17 18c.5.5 1 1 2 1a3 3 0 0 0 3-3c0-1.545-.604-6.584-.685-7.258-.007-.05-.011-.1-.017-.151A4 4 0 0 0 17.32 5z",
      key: "mfqc10"
    }
  ]
]);

const LuGamepad = createLucideIcon("LuGamepad", [
  ["line", { x1: "6", x2: "10", y1: "12", y2: "12", key: "161bw2" }],
  ["line", { x1: "8", x2: "8", y1: "10", y2: "14", key: "1i6ji0" }],
  ["line", { x1: "15", x2: "15.01", y1: "13", y2: "13", key: "dqpgro" }],
  ["line", { x1: "18", x2: "18.01", y1: "11", y2: "11", key: "meh2c" }],
  ["rect", { width: "20", height: "12", x: "2", y: "6", rx: "2", key: "9lu3g6" }]
]);

const LuGanttChart = createLucideIcon("LuGanttChart", [
  ["path", { d: "M8 6h10", key: "9lnwnk" }],
  ["path", { d: "M6 12h9", key: "1g9pqf" }],
  ["path", { d: "M11 18h7", key: "c8dzvl" }]
]);

const LuGauge = createLucideIcon("LuGauge", [
  ["path", { d: "m12 14 4-4", key: "9kzdfg" }],
  ["path", { d: "M3.34 19a10 10 0 1 1 17.32 0", key: "19p75a" }]
]);

const LuGavel = createLucideIcon("LuGavel", [
  ["path", { d: "m14.5 12.5-8 8a2.119 2.119 0 1 1-3-3l8-8", key: "15492f" }],
  ["path", { d: "m16 16 6-6", key: "vzrcl6" }],
  ["path", { d: "m8 8 6-6", key: "18bi4p" }],
  ["path", { d: "m9 7 8 8", key: "5jnvq1" }],
  ["path", { d: "m21 11-8-8", key: "z4y7zo" }]
]);

const LuGem = createLucideIcon("LuGem", [
  ["path", { d: "M6 3h12l4 6-10 13L2 9Z", key: "1pcd5k" }],
  ["path", { d: "M11 3 8 9l4 13 4-13-3-6", key: "1fcu3u" }],
  ["path", { d: "M2 9h20", key: "16fsjt" }]
]);

const LuGhost = createLucideIcon("LuGhost", [
  ["path", { d: "M9 10h.01", key: "qbtxuw" }],
  ["path", { d: "M15 10h.01", key: "1qmjsl" }],
  [
    "path",
    {
      d: "M12 2a8 8 0 0 0-8 8v12l3-3 2.5 2.5L12 19l2.5 2.5L17 19l3 3V10a8 8 0 0 0-8-8z",
      key: "uwwb07"
    }
  ]
]);

const LuGift = createLucideIcon("LuGift", [
  ["rect", { x: "3", y: "8", width: "18", height: "4", rx: "1", key: "bkv52" }],
  ["path", { d: "M12 8v13", key: "1c76mn" }],
  ["path", { d: "M19 12v7a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2v-7", key: "6wjy6b" }],
  [
    "path",
    {
      d: "M7.5 8a2.5 2.5 0 0 1 0-5A4.8 8 0 0 1 12 8a4.8 8 0 0 1 4.5-5 2.5 2.5 0 0 1 0 5",
      key: "1ihvrl"
    }
  ]
]);

const LuGitBranchPlus = createLucideIcon("LuGitBranchPlus", [
  ["path", { d: "M6 3v12", key: "qpgusn" }],
  ["path", { d: "M18 9a3 3 0 1 0 0-6 3 3 0 0 0 0 6z", key: "1d02ji" }],
  ["path", { d: "M6 21a3 3 0 1 0 0-6 3 3 0 0 0 0 6z", key: "chk6ph" }],
  ["path", { d: "M15 6a9 9 0 0 0-9 9", key: "or332x" }],
  ["path", { d: "M18 15v6", key: "9wciyi" }],
  ["path", { d: "M21 18h-6", key: "139f0c" }]
]);

const LuGitBranch = createLucideIcon("LuGitBranch", [
  ["line", { x1: "6", x2: "6", y1: "3", y2: "15", key: "17qcm7" }],
  ["circle", { cx: "18", cy: "6", r: "3", key: "1h7g24" }],
  ["circle", { cx: "6", cy: "18", r: "3", key: "fqmcym" }],
  ["path", { d: "M18 9a9 9 0 0 1-9 9", key: "n2h4wq" }]
]);

const LuGitCommitHorizontal = createLucideIcon("LuGitCommitHorizontal", [
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  ["line", { x1: "3", x2: "9", y1: "12", y2: "12", key: "1dyftd" }],
  ["line", { x1: "15", x2: "21", y1: "12", y2: "12", key: "oup4p8" }]
]);

const LuGitCommitVertical = createLucideIcon("LuGitCommitVertical", [
  ["path", { d: "M12 3v6", key: "1holv5" }],
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  ["path", { d: "M12 15v6", key: "a9ows0" }]
]);

const LuGitCompareArrows = createLucideIcon("LuGitCompareArrows", [
  ["circle", { cx: "5", cy: "6", r: "3", key: "1qnov2" }],
  ["path", { d: "M12 6h5a2 2 0 0 1 2 2v7", key: "1yj91y" }],
  ["path", { d: "m15 9-3-3 3-3", key: "1lwv8l" }],
  ["circle", { cx: "19", cy: "18", r: "3", key: "1qljk2" }],
  ["path", { d: "M12 18H7a2 2 0 0 1-2-2V9", key: "16sdep" }],
  ["path", { d: "m9 15 3 3-3 3", key: "1m3kbl" }]
]);

const LuGitCompare = createLucideIcon("LuGitCompare", [
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  ["circle", { cx: "6", cy: "6", r: "3", key: "1lh9wr" }],
  ["path", { d: "M13 6h3a2 2 0 0 1 2 2v7", key: "1yeb86" }],
  ["path", { d: "M11 18H8a2 2 0 0 1-2-2V9", key: "19pyzm" }]
]);

const LuGitFork = createLucideIcon("LuGitFork", [
  ["circle", { cx: "12", cy: "18", r: "3", key: "1mpf1b" }],
  ["circle", { cx: "6", cy: "6", r: "3", key: "1lh9wr" }],
  ["circle", { cx: "18", cy: "6", r: "3", key: "1h7g24" }],
  ["path", { d: "M18 9v2c0 .6-.4 1-1 1H7c-.6 0-1-.4-1-1V9", key: "1uq4wg" }],
  ["path", { d: "M12 12v3", key: "158kv8" }]
]);

const LuGitGraph = createLucideIcon("LuGitGraph", [
  ["circle", { cx: "5", cy: "6", r: "3", key: "1qnov2" }],
  ["path", { d: "M5 9v6", key: "158jrl" }],
  ["circle", { cx: "5", cy: "18", r: "3", key: "104gr9" }],
  ["path", { d: "M12 3v18", key: "108xh3" }],
  ["circle", { cx: "19", cy: "6", r: "3", key: "108a5v" }],
  ["path", { d: "M16 15.7A9 9 0 0 0 19 9", key: "1e3vqb" }]
]);

const LuGitMerge = createLucideIcon("LuGitMerge", [
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  ["circle", { cx: "6", cy: "6", r: "3", key: "1lh9wr" }],
  ["path", { d: "M6 21V9a9 9 0 0 0 9 9", key: "7kw0sc" }]
]);

const LuGitPullRequestArrow = createLucideIcon("LuGitPullRequestArrow", [
  ["circle", { cx: "5", cy: "6", r: "3", key: "1qnov2" }],
  ["path", { d: "M5 9v12", key: "ih889a" }],
  ["circle", { cx: "19", cy: "18", r: "3", key: "1qljk2" }],
  ["path", { d: "m15 9-3-3 3-3", key: "1lwv8l" }],
  ["path", { d: "M12 6h5a2 2 0 0 1 2 2v7", key: "1yj91y" }]
]);

const LuGitPullRequestClosed = createLucideIcon("LuGitPullRequestClosed", [
  ["circle", { cx: "6", cy: "6", r: "3", key: "1lh9wr" }],
  ["path", { d: "M6 9v12", key: "1sc30k" }],
  ["path", { d: "m21 3-6 6", key: "16nqsk" }],
  ["path", { d: "m21 9-6-6", key: "9j17rh" }],
  ["path", { d: "M18 11.5V15", key: "65xf6f" }],
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }]
]);

const LuGitPullRequestCreateArrow = createLucideIcon("LuGitPullRequestCreateArrow", [
  ["circle", { cx: "5", cy: "6", r: "3", key: "1qnov2" }],
  ["path", { d: "M5 9v12", key: "ih889a" }],
  ["path", { d: "m15 9-3-3 3-3", key: "1lwv8l" }],
  ["path", { d: "M12 6h5a2 2 0 0 1 2 2v3", key: "1rbwk6" }],
  ["path", { d: "M19 15v6", key: "10aioa" }],
  ["path", { d: "M22 18h-6", key: "1d5gi5" }]
]);

const LuGitPullRequestCreate = createLucideIcon("LuGitPullRequestCreate", [
  ["circle", { cx: "6", cy: "6", r: "3", key: "1lh9wr" }],
  ["path", { d: "M6 9v12", key: "1sc30k" }],
  ["path", { d: "M13 6h3a2 2 0 0 1 2 2v3", key: "1jb6z3" }],
  ["path", { d: "M18 15v6", key: "9wciyi" }],
  ["path", { d: "M21 18h-6", key: "139f0c" }]
]);

const LuGitPullRequestDraft = createLucideIcon("LuGitPullRequestDraft", [
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  ["circle", { cx: "6", cy: "6", r: "3", key: "1lh9wr" }],
  ["path", { d: "M18 6V5", key: "1oao2s" }],
  ["path", { d: "M18 11v-1", key: "11c8tz" }],
  ["line", { x1: "6", x2: "6", y1: "9", y2: "21", key: "rroup" }]
]);

const LuGitPullRequest = createLucideIcon("LuGitPullRequest", [
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  ["circle", { cx: "6", cy: "6", r: "3", key: "1lh9wr" }],
  ["path", { d: "M13 6h3a2 2 0 0 1 2 2v7", key: "1yeb86" }],
  ["line", { x1: "6", x2: "6", y1: "9", y2: "21", key: "rroup" }]
]);

const LuGithub = createLucideIcon("LuGithub", [
  [
    "path",
    {
      d: "M15 22v-4a4.8 4.8 0 0 0-1-3.5c3 0 6-2 6-5.5.08-1.25-.27-2.48-1-3.5.28-1.15.28-2.35 0-3.5 0 0-1 0-3 1.5-2.64-.5-5.36-.5-8 0C6 2 5 2 5 2c-.3 1.15-.3 2.35 0 3.5A5.403 5.403 0 0 0 4 9c0 3.5 3 5.5 6 5.5-.39.49-.68 1.05-.85 1.65-.17.6-.22 1.23-.15 1.85v4",
      key: "tonef"
    }
  ],
  ["path", { d: "M9 18c-4.51 2-5-2-7-2", key: "9comsn" }]
]);

const LuGitlab = createLucideIcon("LuGitlab", [
  [
    "path",
    {
      d: "m22 13.29-3.33-10a.42.42 0 0 0-.14-.18.38.38 0 0 0-.22-.11.39.39 0 0 0-.23.07.42.42 0 0 0-.14.18l-2.26 6.67H8.32L6.1 3.26a.42.42 0 0 0-.1-.18.38.38 0 0 0-.26-.08.39.39 0 0 0-.23.07.42.42 0 0 0-.14.18L2 13.29a.74.74 0 0 0 .27.83L12 21l9.69-6.88a.71.71 0 0 0 .31-.83Z",
      key: "148pdi"
    }
  ]
]);

const LuGlassWater = createLucideIcon("LuGlassWater", [
  [
    "path",
    { d: "M15.2 22H8.8a2 2 0 0 1-2-1.79L5 3h14l-1.81 17.21A2 2 0 0 1 15.2 22Z", key: "48rfw3" }
  ],
  ["path", { d: "M6 12a5 5 0 0 1 6 0 5 5 0 0 0 6 0", key: "mjntcy" }]
]);

const LuGlasses = createLucideIcon("LuGlasses", [
  ["circle", { cx: "6", cy: "15", r: "4", key: "vux9w4" }],
  ["circle", { cx: "18", cy: "15", r: "4", key: "18o8ve" }],
  ["path", { d: "M14 15a2 2 0 0 0-2-2 2 2 0 0 0-2 2", key: "1ag4bs" }],
  ["path", { d: "M2.5 13 5 7c.7-1.3 1.4-2 3-2", key: "1hm1gs" }],
  ["path", { d: "M21.5 13 19 7c-.7-1.3-1.5-2-3-2", key: "1r31ai" }]
]);

const LuGlobeLock = createLucideIcon("LuGlobeLock", [
  [
    "path",
    {
      d: "M15.686 15A14.5 14.5 0 0 1 12 22a14.5 14.5 0 0 1 0-20 10 10 0 1 0 9.542 13",
      key: "qkt0x6"
    }
  ],
  ["path", { d: "M2 12h8.5", key: "ovaggd" }],
  ["path", { d: "M20 6V4a2 2 0 1 0-4 0v2", key: "1of5e8" }],
  ["rect", { width: "8", height: "5", x: "14", y: "6", rx: "1", key: "1fmf51" }]
]);

const LuGlobe = createLucideIcon("LuGlobe", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M12 2a14.5 14.5 0 0 0 0 20 14.5 14.5 0 0 0 0-20", key: "13o1zl" }],
  ["path", { d: "M2 12h20", key: "9i4pu4" }]
]);

const LuGoal = createLucideIcon("LuGoal", [
  ["path", { d: "M12 13V2l8 4-8 4", key: "5wlwwj" }],
  ["path", { d: "M20.561 10.222a9 9 0 1 1-12.55-5.29", key: "1c0wjv" }],
  ["path", { d: "M8.002 9.997a5 5 0 1 0 8.9 2.02", key: "gb1g7m" }]
]);

const LuGrab = createLucideIcon("LuGrab", [
  ["path", { d: "M18 11.5V9a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v1.4", key: "n5nng" }],
  ["path", { d: "M14 10V8a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v2", key: "185i9d" }],
  ["path", { d: "M10 9.9V9a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v5", key: "11pz95" }],
  ["path", { d: "M6 14v0a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v0", key: "16yk7l" }],
  [
    "path",
    { d: "M18 11v0a2 2 0 1 1 4 0v3a8 8 0 0 1-8 8h-4a8 8 0 0 1-8-8 2 2 0 1 1 4 0", key: "nzvb1c" }
  ]
]);

const LuGraduationCap = createLucideIcon("LuGraduationCap", [
  [
    "path",
    {
      d: "M21.42 10.922a1 1 0 0 0-.019-1.838L12.83 5.18a2 2 0 0 0-1.66 0L2.6 9.08a1 1 0 0 0 0 1.832l8.57 3.908a2 2 0 0 0 1.66 0z",
      key: "j76jl0"
    }
  ],
  ["path", { d: "M22 10v6", key: "1lu8f3" }],
  ["path", { d: "M6 12.5V16a6 3 0 0 0 12 0v-3.5", key: "1r8lef" }]
]);

const LuGrape = createLucideIcon("LuGrape", [
  ["path", { d: "M22 5V2l-5.89 5.89", key: "1eenpo" }],
  ["circle", { cx: "16.6", cy: "15.89", r: "3", key: "xjtalx" }],
  ["circle", { cx: "8.11", cy: "7.4", r: "3", key: "u2fv6i" }],
  ["circle", { cx: "12.35", cy: "11.65", r: "3", key: "i6i8g7" }],
  ["circle", { cx: "13.91", cy: "5.85", r: "3", key: "6ye0dv" }],
  ["circle", { cx: "18.15", cy: "10.09", r: "3", key: "snx9no" }],
  ["circle", { cx: "6.56", cy: "13.2", r: "3", key: "17x4xg" }],
  ["circle", { cx: "10.8", cy: "17.44", r: "3", key: "1hogw9" }],
  ["circle", { cx: "5", cy: "19", r: "3", key: "1sn6vo" }]
]);

const LuGrid2x2 = createLucideIcon("LuGrid2x2", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 12h18", key: "1i2n21" }],
  ["path", { d: "M12 3v18", key: "108xh3" }]
]);

const LuGrid3x3 = createLucideIcon("LuGrid3x3", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 9h18", key: "1pudct" }],
  ["path", { d: "M3 15h18", key: "5xshup" }],
  ["path", { d: "M9 3v18", key: "fh3hqa" }],
  ["path", { d: "M15 3v18", key: "14nvp0" }]
]);

const LuGripHorizontal = createLucideIcon("LuGripHorizontal", [
  ["circle", { cx: "12", cy: "9", r: "1", key: "124mty" }],
  ["circle", { cx: "19", cy: "9", r: "1", key: "1ruzo2" }],
  ["circle", { cx: "5", cy: "9", r: "1", key: "1a8b28" }],
  ["circle", { cx: "12", cy: "15", r: "1", key: "1e56xg" }],
  ["circle", { cx: "19", cy: "15", r: "1", key: "1a92ep" }],
  ["circle", { cx: "5", cy: "15", r: "1", key: "5r1jwy" }]
]);

const LuGripVertical = createLucideIcon("LuGripVertical", [
  ["circle", { cx: "9", cy: "12", r: "1", key: "1vctgf" }],
  ["circle", { cx: "9", cy: "5", r: "1", key: "hp0tcf" }],
  ["circle", { cx: "9", cy: "19", r: "1", key: "fkjjf6" }],
  ["circle", { cx: "15", cy: "12", r: "1", key: "1tmaij" }],
  ["circle", { cx: "15", cy: "5", r: "1", key: "19l28e" }],
  ["circle", { cx: "15", cy: "19", r: "1", key: "f4zoj3" }]
]);

const LuGrip = createLucideIcon("LuGrip", [
  ["circle", { cx: "12", cy: "5", r: "1", key: "gxeob9" }],
  ["circle", { cx: "19", cy: "5", r: "1", key: "w8mnmm" }],
  ["circle", { cx: "5", cy: "5", r: "1", key: "lttvr7" }],
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }],
  ["circle", { cx: "19", cy: "12", r: "1", key: "1wjl8i" }],
  ["circle", { cx: "5", cy: "12", r: "1", key: "1pcz8c" }],
  ["circle", { cx: "12", cy: "19", r: "1", key: "lyex9k" }],
  ["circle", { cx: "19", cy: "19", r: "1", key: "shf9b7" }],
  ["circle", { cx: "5", cy: "19", r: "1", key: "bfqh0e" }]
]);

const LuGroup = createLucideIcon("LuGroup", [
  ["path", { d: "M3 7V5c0-1.1.9-2 2-2h2", key: "adw53z" }],
  ["path", { d: "M17 3h2c1.1 0 2 .9 2 2v2", key: "an4l38" }],
  ["path", { d: "M21 17v2c0 1.1-.9 2-2 2h-2", key: "144t0e" }],
  ["path", { d: "M7 21H5c-1.1 0-2-.9-2-2v-2", key: "rtnfgi" }],
  ["rect", { width: "7", height: "5", x: "7", y: "7", rx: "1", key: "1eyiv7" }],
  ["rect", { width: "7", height: "5", x: "10", y: "12", rx: "1", key: "1qlmkx" }]
]);

const LuGuitar = createLucideIcon("LuGuitar", [
  ["path", { d: "m20 7 1.7-1.7a1 1 0 0 0 0-1.4l-1.6-1.6a1 1 0 0 0-1.4 0L17 4v3Z", key: "15ixgv" }],
  ["path", { d: "m17 7-5.1 5.1", key: "l9guh7" }],
  ["circle", { cx: "11.5", cy: "12.5", r: ".5", fill: "currentColor", key: "16onso" }],
  [
    "path",
    {
      d: "M6 12a2 2 0 0 0 1.8-1.2l.4-.9C8.7 8.8 9.8 8 11 8c2.8 0 5 2.2 5 5 0 1.2-.8 2.3-1.9 2.8l-.9.4A2 2 0 0 0 12 18a4 4 0 0 1-4 4c-3.3 0-6-2.7-6-6a4 4 0 0 1 4-4",
      key: "x9fguj"
    }
  ],
  ["path", { d: "m6 16 2 2", key: "16qmzd" }]
]);

const LuHam = createLucideIcon("LuHam", [
  ["path", { d: "M13.144 21.144A7.274 10.445 45 1 0 2.856 10.856", key: "1k1t7q" }],
  [
    "path",
    {
      d: "M13.144 21.144A7.274 4.365 45 0 0 2.856 10.856a7.274 4.365 45 0 0 10.288 10.288",
      key: "153t1g"
    }
  ],
  [
    "path",
    {
      d: "M16.565 10.435 18.6 8.4a2.501 2.501 0 1 0 1.65-4.65 2.5 2.5 0 1 0-4.66 1.66l-2.024 2.025",
      key: "gzrt0n"
    }
  ],
  ["path", { d: "m8.5 16.5-1-1", key: "otr954" }]
]);

const LuHammer = createLucideIcon("LuHammer", [
  ["path", { d: "m15 12-8.373 8.373a1 1 0 1 1-3-3L12 9", key: "eefl8a" }],
  ["path", { d: "m18 15 4-4", key: "16gjal" }],
  [
    "path",
    {
      d: "m21.5 11.5-1.914-1.914A2 2 0 0 1 19 8.172V7l-2.26-2.26a6 6 0 0 0-4.202-1.756L9 2.96l.92.82A6.18 6.18 0 0 1 12 8.4V10l2 2h1.172a2 2 0 0 1 1.414.586L18.5 14.5",
      key: "b7pghm"
    }
  ]
]);

const LuHandCoins = createLucideIcon("LuHandCoins", [
  ["path", { d: "M11 15h2a2 2 0 1 0 0-4h-3c-.6 0-1.1.2-1.4.6L3 17", key: "geh8rc" }],
  [
    "path",
    {
      d: "m7 21 1.6-1.4c.3-.4.8-.6 1.4-.6h4c1.1 0 2.1-.4 2.8-1.2l4.6-4.4a2 2 0 0 0-2.75-2.91l-4.2 3.9",
      key: "1fto5m"
    }
  ],
  ["path", { d: "m2 16 6 6", key: "1pfhp9" }],
  ["circle", { cx: "16", cy: "9", r: "2.9", key: "1n0dlu" }],
  ["circle", { cx: "6", cy: "5", r: "3", key: "151irh" }]
]);

const LuHandHeart = createLucideIcon("LuHandHeart", [
  ["path", { d: "M11 14h2a2 2 0 1 0 0-4h-3c-.6 0-1.1.2-1.4.6L3 16", key: "1ifwr1" }],
  [
    "path",
    {
      d: "m7 20 1.6-1.4c.3-.4.8-.6 1.4-.6h4c1.1 0 2.1-.4 2.8-1.2l4.6-4.4a2 2 0 0 0-2.75-2.91l-4.2 3.9",
      key: "17abbs"
    }
  ],
  ["path", { d: "m2 15 6 6", key: "10dquu" }],
  [
    "path",
    {
      d: "M19.5 8.5c.7-.7 1.5-1.6 1.5-2.7A2.73 2.73 0 0 0 16 4a2.78 2.78 0 0 0-5 1.8c0 1.2.8 2 1.5 2.8L16 12Z",
      key: "1h3036"
    }
  ]
]);

const LuHandHelping = createLucideIcon("LuHandHelping", [
  ["path", { d: "M11 12h2a2 2 0 1 0 0-4h-3c-.6 0-1.1.2-1.4.6L3 14", key: "1j4xps" }],
  [
    "path",
    {
      d: "m7 18 1.6-1.4c.3-.4.8-.6 1.4-.6h4c1.1 0 2.1-.4 2.8-1.2l4.6-4.4a2 2 0 0 0-2.75-2.91l-4.2 3.9",
      key: "uospg8"
    }
  ],
  ["path", { d: "m2 13 6 6", key: "16e5sb" }]
]);

const LuHandMetal = createLucideIcon("LuHandMetal", [
  ["path", { d: "M18 12.5V10a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v1.4", key: "7eki13" }],
  ["path", { d: "M14 11V9a2 2 0 1 0-4 0v2", key: "94qvcw" }],
  ["path", { d: "M10 10.5V5a2 2 0 1 0-4 0v9", key: "m1ah89" }],
  [
    "path",
    {
      d: "m7 15-1.76-1.76a2 2 0 0 0-2.83 2.82l3.6 3.6C7.5 21.14 9.2 22 12 22h2a8 8 0 0 0 8-8V7a2 2 0 1 0-4 0v5",
      key: "t1skq1"
    }
  ]
]);

const LuHandPlatter = createLucideIcon("LuHandPlatter", [
  ["path", { d: "M12 3V2", key: "ar7q03" }],
  ["path", { d: "M5 10a7.1 7.1 0 0 1 14 0", key: "1t9y3n" }],
  ["path", { d: "M4 10h16", key: "img6z1" }],
  ["path", { d: "M2 14h12a2 2 0 1 1 0 4h-2", key: "loyjft" }],
  [
    "path",
    {
      d: "m15.4 17.4 3.2-2.8a2 2 0 0 1 2.8 2.9l-3.6 3.3c-.7.8-1.7 1.2-2.8 1.2h-4c-1.1 0-2.1-.4-2.8-1.2L5 18",
      key: "1rixiy"
    }
  ],
  ["path", { d: "M5 14v7H2", key: "3mujks" }]
]);

const LuHand = createLucideIcon("LuHand", [
  ["path", { d: "M18 11V6a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v0", key: "aigmz7" }],
  ["path", { d: "M14 10V4a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v2", key: "1n6bmn" }],
  ["path", { d: "M10 10.5V6a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v8", key: "a9iiix" }],
  [
    "path",
    {
      d: "M18 8a2 2 0 1 1 4 0v6a8 8 0 0 1-8 8h-2c-2.8 0-4.5-.86-5.99-2.34l-3.6-3.6a2 2 0 0 1 2.83-2.82L7 15",
      key: "1s1gnw"
    }
  ]
]);

const LuHandshake = createLucideIcon("LuHandshake", [
  ["path", { d: "m11 17 2 2a1 1 0 1 0 3-3", key: "efffak" }],
  [
    "path",
    {
      d: "m14 14 2.5 2.5a1 1 0 1 0 3-3l-3.88-3.88a3 3 0 0 0-4.24 0l-.88.88a1 1 0 1 1-3-3l2.81-2.81a5.79 5.79 0 0 1 7.06-.87l.47.28a2 2 0 0 0 1.42.25L21 4",
      key: "9pr0kb"
    }
  ],
  ["path", { d: "m21 3 1 11h-2", key: "1tisrp" }],
  ["path", { d: "M3 3 2 14l6.5 6.5a1 1 0 1 0 3-3", key: "1uvwmv" }],
  ["path", { d: "M3 4h8", key: "1ep09j" }]
]);

const LuHardDriveDownload = createLucideIcon("LuHardDriveDownload", [
  ["path", { d: "M12 2v8", key: "1q4o3n" }],
  ["path", { d: "m16 6-4 4-4-4", key: "6wukr" }],
  ["rect", { width: "20", height: "8", x: "2", y: "14", rx: "2", key: "w68u3i" }],
  ["path", { d: "M6 18h.01", key: "uhywen" }],
  ["path", { d: "M10 18h.01", key: "h775k" }]
]);

const LuHardDriveUpload = createLucideIcon("LuHardDriveUpload", [
  ["path", { d: "m16 6-4-4-4 4", key: "13yo43" }],
  ["path", { d: "M12 2v8", key: "1q4o3n" }],
  ["rect", { width: "20", height: "8", x: "2", y: "14", rx: "2", key: "w68u3i" }],
  ["path", { d: "M6 18h.01", key: "uhywen" }],
  ["path", { d: "M10 18h.01", key: "h775k" }]
]);

const LuHardDrive = createLucideIcon("LuHardDrive", [
  ["line", { x1: "22", x2: "2", y1: "12", y2: "12", key: "1y58io" }],
  [
    "path",
    {
      d: "M5.45 5.11 2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z",
      key: "oot6mr"
    }
  ],
  ["line", { x1: "6", x2: "6.01", y1: "16", y2: "16", key: "sgf278" }],
  ["line", { x1: "10", x2: "10.01", y1: "16", y2: "16", key: "1l4acy" }]
]);

const LuHardHat = createLucideIcon("LuHardHat", [
  [
    "path",
    {
      d: "M2 18a1 1 0 0 0 1 1h18a1 1 0 0 0 1-1v-2a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v2z",
      key: "1dej2m"
    }
  ],
  ["path", { d: "M10 10V5a1 1 0 0 1 1-1h2a1 1 0 0 1 1 1v5", key: "1p9q5i" }],
  ["path", { d: "M4 15v-3a6 6 0 0 1 6-6h0", key: "1uc279" }],
  ["path", { d: "M14 6h0a6 6 0 0 1 6 6v3", key: "1j9mnm" }]
]);

const LuHash = createLucideIcon("LuHash", [
  ["line", { x1: "4", x2: "20", y1: "9", y2: "9", key: "4lhtct" }],
  ["line", { x1: "4", x2: "20", y1: "15", y2: "15", key: "vyu0kd" }],
  ["line", { x1: "10", x2: "8", y1: "3", y2: "21", key: "1ggp8o" }],
  ["line", { x1: "16", x2: "14", y1: "3", y2: "21", key: "weycgp" }]
]);

const LuHaze = createLucideIcon("LuHaze", [
  ["path", { d: "m5.2 6.2 1.4 1.4", key: "17imol" }],
  ["path", { d: "M2 13h2", key: "13gyu8" }],
  ["path", { d: "M20 13h2", key: "16rner" }],
  ["path", { d: "m17.4 7.6 1.4-1.4", key: "t4xlah" }],
  ["path", { d: "M22 17H2", key: "1gtaj3" }],
  ["path", { d: "M22 21H2", key: "1gy6en" }],
  ["path", { d: "M16 13a4 4 0 0 0-8 0", key: "1dyczq" }],
  ["path", { d: "M12 5V2.5", key: "1vytko" }]
]);

const LuHdmiPort = createLucideIcon("LuHdmiPort", [
  [
    "path",
    {
      d: "M22 9a1 1 0 0 0-1-1H3a1 1 0 0 0-1 1v4a1 1 0 0 0 1 1h1l2 2h12l2-2h1a1 1 0 0 0 1-1Z",
      key: "2128wb"
    }
  ],
  ["path", { d: "M7.5 12h9", key: "1t0ckc" }]
]);

const LuHeading1 = createLucideIcon("LuHeading1", [
  ["path", { d: "M4 12h8", key: "17cfdx" }],
  ["path", { d: "M4 18V6", key: "1rz3zl" }],
  ["path", { d: "M12 18V6", key: "zqpxq5" }],
  ["path", { d: "m17 12 3-2v8", key: "1hhhft" }]
]);

const LuHeading2 = createLucideIcon("LuHeading2", [
  ["path", { d: "M4 12h8", key: "17cfdx" }],
  ["path", { d: "M4 18V6", key: "1rz3zl" }],
  ["path", { d: "M12 18V6", key: "zqpxq5" }],
  ["path", { d: "M21 18h-4c0-4 4-3 4-6 0-1.5-2-2.5-4-1", key: "9jr5yi" }]
]);

const LuHeading3 = createLucideIcon("LuHeading3", [
  ["path", { d: "M4 12h8", key: "17cfdx" }],
  ["path", { d: "M4 18V6", key: "1rz3zl" }],
  ["path", { d: "M12 18V6", key: "zqpxq5" }],
  ["path", { d: "M17.5 10.5c1.7-1 3.5 0 3.5 1.5a2 2 0 0 1-2 2", key: "68ncm8" }],
  ["path", { d: "M17 17.5c2 1.5 4 .3 4-1.5a2 2 0 0 0-2-2", key: "1ejuhz" }]
]);

const LuHeading4 = createLucideIcon("LuHeading4", [
  ["path", { d: "M4 12h8", key: "17cfdx" }],
  ["path", { d: "M4 18V6", key: "1rz3zl" }],
  ["path", { d: "M12 18V6", key: "zqpxq5" }],
  ["path", { d: "M17 10v4h4", key: "13sv97" }],
  ["path", { d: "M21 10v8", key: "1kdml4" }]
]);

const LuHeading5 = createLucideIcon("LuHeading5", [
  ["path", { d: "M4 12h8", key: "17cfdx" }],
  ["path", { d: "M4 18V6", key: "1rz3zl" }],
  ["path", { d: "M12 18V6", key: "zqpxq5" }],
  ["path", { d: "M17 13v-3h4", key: "1nvgqp" }],
  [
    "path",
    { d: "M17 17.7c.4.2.8.3 1.3.3 1.5 0 2.7-1.1 2.7-2.5S19.8 13 18.3 13H17", key: "2nebdn" }
  ]
]);

const LuHeading6 = createLucideIcon("LuHeading6", [
  ["path", { d: "M4 12h8", key: "17cfdx" }],
  ["path", { d: "M4 18V6", key: "1rz3zl" }],
  ["path", { d: "M12 18V6", key: "zqpxq5" }],
  ["circle", { cx: "19", cy: "16", r: "2", key: "15mx69" }],
  ["path", { d: "M20 10c-2 2-3 3.5-3 6", key: "f35dl0" }]
]);

const LuHeading = createLucideIcon("LuHeading", [
  ["path", { d: "M6 12h12", key: "8npq4p" }],
  ["path", { d: "M6 20V4", key: "1w1bmo" }],
  ["path", { d: "M18 20V4", key: "o2hl4u" }]
]);

const LuHeadphones = createLucideIcon("LuHeadphones", [
  [
    "path",
    {
      d: "M3 14h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-7a9 9 0 0 1 18 0v7a2 2 0 0 1-2 2h-1a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h3",
      key: "1xhozi"
    }
  ]
]);

const LuHeadset = createLucideIcon("LuHeadset", [
  [
    "path",
    {
      d: "M3 11h3a2 2 0 0 1 2 2v3a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-5Zm0 0a9 9 0 1 1 18 0m0 0v5a2 2 0 0 1-2 2h-1a2 2 0 0 1-2-2v-3a2 2 0 0 1 2-2h3Z",
      key: "12oyoe"
    }
  ],
  ["path", { d: "M21 16v2a4 4 0 0 1-4 4h-5", key: "1x7m43" }]
]);

const LuHeartCrack = createLucideIcon("LuHeartCrack", [
  [
    "path",
    {
      d: "M19 14c1.49-1.46 3-3.21 3-5.5A5.5 5.5 0 0 0 16.5 3c-1.76 0-3 .5-4.5 2-1.5-1.5-2.74-2-4.5-2A5.5 5.5 0 0 0 2 8.5c0 2.3 1.5 4.05 3 5.5l7 7Z",
      key: "c3ymky"
    }
  ],
  ["path", { d: "m12 13-1-1 2-2-3-3 2-2", key: "xjdxli" }]
]);

const LuHeartHandshake = createLucideIcon("LuHeartHandshake", [
  [
    "path",
    {
      d: "M19 14c1.49-1.46 3-3.21 3-5.5A5.5 5.5 0 0 0 16.5 3c-1.76 0-3 .5-4.5 2-1.5-1.5-2.74-2-4.5-2A5.5 5.5 0 0 0 2 8.5c0 2.3 1.5 4.05 3 5.5l7 7Z",
      key: "c3ymky"
    }
  ],
  [
    "path",
    {
      d: "M12 5 9.04 7.96a2.17 2.17 0 0 0 0 3.08v0c.82.82 2.13.85 3 .07l2.07-1.9a2.82 2.82 0 0 1 3.79 0l2.96 2.66",
      key: "12sd6o"
    }
  ],
  ["path", { d: "m18 15-2-2", key: "60u0ii" }],
  ["path", { d: "m15 18-2-2", key: "6p76be" }]
]);

const LuHeartOff = createLucideIcon("LuHeartOff", [
  ["line", { x1: "2", y1: "2", x2: "22", y2: "22", key: "1w4vcy" }],
  [
    "path",
    { d: "M16.5 16.5 12 21l-7-7c-1.5-1.45-3-3.2-3-5.5a5.5 5.5 0 0 1 2.14-4.35", key: "3mpagl" }
  ],
  [
    "path",
    {
      d: "M8.76 3.1c1.15.22 2.13.78 3.24 1.9 1.5-1.5 2.74-2 4.5-2A5.5 5.5 0 0 1 22 8.5c0 2.12-1.3 3.78-2.67 5.17",
      key: "1gh3v3"
    }
  ]
]);

const LuHeartPulse = createLucideIcon("LuHeartPulse", [
  [
    "path",
    {
      d: "M19 14c1.49-1.46 3-3.21 3-5.5A5.5 5.5 0 0 0 16.5 3c-1.76 0-3 .5-4.5 2-1.5-1.5-2.74-2-4.5-2A5.5 5.5 0 0 0 2 8.5c0 2.3 1.5 4.05 3 5.5l7 7Z",
      key: "c3ymky"
    }
  ],
  ["path", { d: "M3.22 12H9.5l.5-1 2 4.5 2-7 1.5 3.5h5.27", key: "1uw2ng" }]
]);

const LuHeart = createLucideIcon("LuHeart", [
  [
    "path",
    {
      d: "M19 14c1.49-1.46 3-3.21 3-5.5A5.5 5.5 0 0 0 16.5 3c-1.76 0-3 .5-4.5 2-1.5-1.5-2.74-2-4.5-2A5.5 5.5 0 0 0 2 8.5c0 2.3 1.5 4.05 3 5.5l7 7Z",
      key: "c3ymky"
    }
  ]
]);

const LuHeater = createLucideIcon("LuHeater", [
  ["path", { d: "M11 8c2-3-2-3 0-6", key: "1ldv5m" }],
  ["path", { d: "M15.5 8c2-3-2-3 0-6", key: "1otqoz" }],
  ["path", { d: "M6 10h.01", key: "1lbq93" }],
  ["path", { d: "M6 14h.01", key: "zudwn7" }],
  ["path", { d: "M10 16v-4", key: "1c25yv" }],
  ["path", { d: "M14 16v-4", key: "1dkbt8" }],
  ["path", { d: "M18 16v-4", key: "1yg9me" }],
  [
    "path",
    { d: "M20 6a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h3", key: "1ubg90" }
  ],
  ["path", { d: "M5 20v2", key: "1abpe8" }],
  ["path", { d: "M19 20v2", key: "kqn6ft" }]
]);

const LuHexagon = createLucideIcon("LuHexagon", [
  [
    "path",
    {
      d: "M21 16V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16z",
      key: "yt0hxn"
    }
  ]
]);

const LuHighlighter = createLucideIcon("LuHighlighter", [
  ["path", { d: "m9 11-6 6v3h9l3-3", key: "1a3l36" }],
  ["path", { d: "m22 12-4.6 4.6a2 2 0 0 1-2.8 0l-5.2-5.2a2 2 0 0 1 0-2.8L14 4", key: "14a9rk" }]
]);

const LuHistory = createLucideIcon("LuHistory", [
  ["path", { d: "M3 12a9 9 0 1 0 9-9 9.75 9.75 0 0 0-6.74 2.74L3 8", key: "1357e3" }],
  ["path", { d: "M3 3v5h5", key: "1xhq8a" }],
  ["path", { d: "M12 7v5l4 2", key: "1fdv2h" }]
]);

const LuHome = createLucideIcon("LuHome", [
  ["path", { d: "m3 9 9-7 9 7v11a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2z", key: "y5dka4" }],
  ["polyline", { points: "9 22 9 12 15 12 15 22", key: "e2us08" }]
]);

const LuHopOff = createLucideIcon("LuHopOff", [
  ["path", { d: "M10.82 16.12c1.69.6 3.91.79 5.18.85.28.01.53-.09.7-.27", key: "qyzcap" }],
  [
    "path",
    {
      d: "M11.14 20.57c.52.24 2.44 1.12 4.08 1.37.46.06.86-.25.9-.71.12-1.52-.3-3.43-.5-4.28",
      key: "y078lb"
    }
  ],
  ["path", { d: "M16.13 21.05c1.65.63 3.68.84 4.87.91a.9.9 0 0 0 .7-.26", key: "1utre3" }],
  [
    "path",
    {
      d: "M17.99 5.52a20.83 20.83 0 0 1 3.15 4.5.8.8 0 0 1-.68 1.13c-1.17.1-2.5.02-3.9-.25",
      key: "17o9hm"
    }
  ],
  ["path", { d: "M20.57 11.14c.24.52 1.12 2.44 1.37 4.08.04.3-.08.59-.31.75", key: "1d1n4p" }],
  [
    "path",
    {
      d: "M4.93 4.93a10 10 0 0 0-.67 13.4c.35.43.96.4 1.17-.12.69-1.71 1.07-5.07 1.07-6.71 1.34.45 3.1.9 4.88.62a.85.85 0 0 0 .48-.24",
      key: "9uv3tt"
    }
  ],
  [
    "path",
    {
      d: "M5.52 17.99c1.05.95 2.91 2.42 4.5 3.15a.8.8 0 0 0 1.13-.68c.2-2.34-.33-5.3-1.57-8.28",
      key: "1292wz"
    }
  ],
  [
    "path",
    {
      d: "M8.35 2.68a10 10 0 0 1 9.98 1.58c.43.35.4.96-.12 1.17-1.5.6-4.3.98-6.07 1.05",
      key: "7ozu9p"
    }
  ],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuHop = createLucideIcon("LuHop", [
  [
    "path",
    {
      d: "M10.82 16.12c1.69.6 3.91.79 5.18.85.55.03 1-.42.97-.97-.06-1.27-.26-3.5-.85-5.18",
      key: "18lxf1"
    }
  ],
  [
    "path",
    {
      d: "M11.5 6.5c1.64 0 5-.38 6.71-1.07.52-.2.55-.82.12-1.17A10 10 0 0 0 4.26 18.33c.35.43.96.4 1.17-.12.69-1.71 1.07-5.07 1.07-6.71 1.34.45 3.1.9 4.88.62a.88.88 0 0 0 .73-.74c.3-2.14-.15-3.5-.61-4.88",
      key: "vtfxrw"
    }
  ],
  [
    "path",
    {
      d: "M15.62 16.95c.2.85.62 2.76.5 4.28a.77.77 0 0 1-.9.7 16.64 16.64 0 0 1-4.08-1.36",
      key: "13hl71"
    }
  ],
  [
    "path",
    {
      d: "M16.13 21.05c1.65.63 3.68.84 4.87.91a.9.9 0 0 0 .96-.96 17.68 17.68 0 0 0-.9-4.87",
      key: "1sl8oj"
    }
  ],
  [
    "path",
    {
      d: "M16.94 15.62c.86.2 2.77.62 4.29.5a.77.77 0 0 0 .7-.9 16.64 16.64 0 0 0-1.36-4.08",
      key: "19c6kt"
    }
  ],
  [
    "path",
    {
      d: "M17.99 5.52a20.82 20.82 0 0 1 3.15 4.5.8.8 0 0 1-.68 1.13c-2.33.2-5.3-.32-8.27-1.57",
      key: "85ghs3"
    }
  ],
  ["path", { d: "M4.93 4.93 3 3a.7.7 0 0 1 0-1", key: "x087yj" }],
  [
    "path",
    {
      d: "M9.58 12.18c1.24 2.98 1.77 5.95 1.57 8.28a.8.8 0 0 1-1.13.68 20.82 20.82 0 0 1-4.5-3.15",
      key: "11xdqo"
    }
  ]
]);

const LuHospital = createLucideIcon("LuHospital", [
  ["path", { d: "M12 6v4", key: "16clxf" }],
  ["path", { d: "M14 14h-4", key: "esezmu" }],
  ["path", { d: "M14 18h-4", key: "16mqa2" }],
  ["path", { d: "M14 8h-4", key: "z8ypaz" }],
  [
    "path",
    {
      d: "M18 12h2a2 2 0 0 1 2 2v6a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-9a2 2 0 0 1 2-2h2",
      key: "b1k337"
    }
  ],
  ["path", { d: "M18 22V4a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v18", key: "16g51d" }]
]);

const LuHotel = createLucideIcon("LuHotel", [
  ["path", { d: "M10 22v-6.57", key: "1wmca3" }],
  ["path", { d: "M12 11h.01", key: "z322tv" }],
  ["path", { d: "M12 7h.01", key: "1ivr5q" }],
  ["path", { d: "M14 15.43V22", key: "1q2vjd" }],
  ["path", { d: "M15 16a5 5 0 0 0-6 0", key: "o9wqvi" }],
  ["path", { d: "M16 11h.01", key: "xkw8gn" }],
  ["path", { d: "M16 7h.01", key: "1kdx03" }],
  ["path", { d: "M8 11h.01", key: "1dfujw" }],
  ["path", { d: "M8 7h.01", key: "1vti4s" }],
  ["rect", { x: "4", y: "2", width: "16", height: "20", rx: "2", key: "1uxh74" }]
]);

const LuHourglass = createLucideIcon("LuHourglass", [
  ["path", { d: "M5 22h14", key: "ehvnwv" }],
  ["path", { d: "M5 2h14", key: "pdyrp9" }],
  [
    "path",
    {
      d: "M17 22v-4.172a2 2 0 0 0-.586-1.414L12 12l-4.414 4.414A2 2 0 0 0 7 17.828V22",
      key: "1d314k"
    }
  ],
  [
    "path",
    { d: "M7 2v4.172a2 2 0 0 0 .586 1.414L12 12l4.414-4.414A2 2 0 0 0 17 6.172V2", key: "1vvvr6" }
  ]
]);

const LuIceCreamBowl = createLucideIcon("LuIceCreamBowl", [
  [
    "path",
    {
      d: "M12 17c5 0 8-2.69 8-6H4c0 3.31 3 6 8 6m-4 4h8m-4-3v3M5.14 11a3.5 3.5 0 1 1 6.71 0",
      key: "1uxfcu"
    }
  ],
  ["path", { d: "M12.14 11a3.5 3.5 0 1 1 6.71 0", key: "4k3m1s" }],
  ["path", { d: "M15.5 6.5a3.5 3.5 0 1 0-7 0", key: "zmuahr" }]
]);

const LuIceCreamCone = createLucideIcon("LuIceCreamCone", [
  ["path", { d: "m7 11 4.08 10.35a1 1 0 0 0 1.84 0L17 11", key: "1v6356" }],
  ["path", { d: "M17 7A5 5 0 0 0 7 7", key: "151p3v" }],
  ["path", { d: "M17 7a2 2 0 0 1 0 4H7a2 2 0 0 1 0-4", key: "1sdaij" }]
]);

const LuImageDown = createLucideIcon("LuImageDown", [
  [
    "path",
    {
      d: "M10.3 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v10l-3.1-3.1a2 2 0 0 0-2.814.014L6 21",
      key: "9csbqa"
    }
  ],
  ["path", { d: "m14 19 3 3v-5.5", key: "9ldu5r" }],
  ["path", { d: "m17 22 3-3", key: "1nkfve" }],
  ["circle", { cx: "9", cy: "9", r: "2", key: "af1f0g" }]
]);

const LuImageMinus = createLucideIcon("LuImageMinus", [
  ["path", { d: "M21 9v10a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h7", key: "m87ecr" }],
  ["line", { x1: "16", x2: "22", y1: "5", y2: "5", key: "ez7e4s" }],
  ["circle", { cx: "9", cy: "9", r: "2", key: "af1f0g" }],
  ["path", { d: "m21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21", key: "1xmnt7" }]
]);

const LuImageOff = createLucideIcon("LuImageOff", [
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }],
  ["path", { d: "M10.41 10.41a2 2 0 1 1-2.83-2.83", key: "1bzlo9" }],
  ["line", { x1: "13.5", x2: "6", y1: "13.5", y2: "21", key: "1q0aeu" }],
  ["line", { x1: "18", x2: "21", y1: "12", y2: "15", key: "5mozeu" }],
  [
    "path",
    {
      d: "M3.59 3.59A1.99 1.99 0 0 0 3 5v14a2 2 0 0 0 2 2h14c.55 0 1.052-.22 1.41-.59",
      key: "mmje98"
    }
  ],
  ["path", { d: "M21 15V5a2 2 0 0 0-2-2H9", key: "43el77" }]
]);

const LuImagePlus = createLucideIcon("LuImagePlus", [
  ["path", { d: "M21 12v7a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h7", key: "31hg93" }],
  ["line", { x1: "16", x2: "22", y1: "5", y2: "5", key: "ez7e4s" }],
  ["line", { x1: "19", x2: "19", y1: "2", y2: "8", key: "1gkr8c" }],
  ["circle", { cx: "9", cy: "9", r: "2", key: "af1f0g" }],
  ["path", { d: "m21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21", key: "1xmnt7" }]
]);

const LuImageUp = createLucideIcon("LuImageUp", [
  [
    "path",
    {
      d: "M10.3 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v10l-3.1-3.1a2 2 0 0 0-2.814.014L6 21",
      key: "9csbqa"
    }
  ],
  ["path", { d: "m14 19.5 3-3 3 3", key: "9vmjn0" }],
  ["path", { d: "M17 22v-5.5", key: "1aa6fl" }],
  ["circle", { cx: "9", cy: "9", r: "2", key: "af1f0g" }]
]);

const LuImage = createLucideIcon("LuImage", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["circle", { cx: "9", cy: "9", r: "2", key: "af1f0g" }],
  ["path", { d: "m21 15-3.086-3.086a2 2 0 0 0-2.828 0L6 21", key: "1xmnt7" }]
]);

const LuImages = createLucideIcon("LuImages", [
  ["path", { d: "M18 22H4a2 2 0 0 1-2-2V6", key: "pblm9e" }],
  ["path", { d: "m22 13-1.296-1.296a2.41 2.41 0 0 0-3.408 0L11 18", key: "nf6bnh" }],
  ["circle", { cx: "12", cy: "8", r: "2", key: "1822b1" }],
  ["rect", { width: "16", height: "16", x: "6", y: "2", rx: "2", key: "12espp" }]
]);

const LuImport = createLucideIcon("LuImport", [
  ["path", { d: "M12 3v12", key: "1x0j5s" }],
  ["path", { d: "m8 11 4 4 4-4", key: "1dohi6" }],
  [
    "path",
    {
      d: "M8 5H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-4",
      key: "1ywtjm"
    }
  ]
]);

const LuInbox = createLucideIcon("LuInbox", [
  ["polyline", { points: "22 12 16 12 14 15 10 15 8 12 2 12", key: "o97t9d" }],
  [
    "path",
    {
      d: "M5.45 5.11 2 12v6a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-6l-3.45-6.89A2 2 0 0 0 16.76 4H7.24a2 2 0 0 0-1.79 1.11z",
      key: "oot6mr"
    }
  ]
]);

const LuIndentDecrease = createLucideIcon("LuIndentDecrease", [
  ["polyline", { points: "7 8 3 12 7 16", key: "2j60jr" }],
  ["line", { x1: "21", x2: "11", y1: "12", y2: "12", key: "1fxxak" }],
  ["line", { x1: "21", x2: "11", y1: "6", y2: "6", key: "asgu94" }],
  ["line", { x1: "21", x2: "11", y1: "18", y2: "18", key: "13dsj7" }]
]);

const LuIndentIncrease = createLucideIcon("LuIndentIncrease", [
  ["polyline", { points: "3 8 7 12 3 16", key: "f3rxhf" }],
  ["line", { x1: "21", x2: "11", y1: "12", y2: "12", key: "1fxxak" }],
  ["line", { x1: "21", x2: "11", y1: "6", y2: "6", key: "asgu94" }],
  ["line", { x1: "21", x2: "11", y1: "18", y2: "18", key: "13dsj7" }]
]);

const LuIndianRupee = createLucideIcon("LuIndianRupee", [
  ["path", { d: "M6 3h12", key: "ggurg9" }],
  ["path", { d: "M6 8h12", key: "6g4wlu" }],
  ["path", { d: "m6 13 8.5 8", key: "u1kupk" }],
  ["path", { d: "M6 13h3", key: "wdp6ag" }],
  ["path", { d: "M9 13c6.667 0 6.667-10 0-10", key: "1nkvk2" }]
]);

const LuInfinity = createLucideIcon("LuInfinity", [
  [
    "path",
    {
      d: "M12 12c-2-2.67-4-4-6-4a4 4 0 1 0 0 8c2 0 4-1.33 6-4Zm0 0c2 2.67 4 4 6 4a4 4 0 0 0 0-8c-2 0-4 1.33-6 4Z",
      key: "1z0uae"
    }
  ]
]);

const LuInfo = createLucideIcon("LuInfo", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M12 16v-4", key: "1dtifu" }],
  ["path", { d: "M12 8h.01", key: "e9boi3" }]
]);

const LuInspectionPanel = createLucideIcon("LuInspectionPanel", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M7 7h.01", key: "7u93v4" }],
  ["path", { d: "M17 7h.01", key: "14a9sn" }],
  ["path", { d: "M7 17h.01", key: "19xn7k" }],
  ["path", { d: "M17 17h.01", key: "1sd3ek" }]
]);

const LuInstagram = createLucideIcon("LuInstagram", [
  ["rect", { width: "20", height: "20", x: "2", y: "2", rx: "5", ry: "5", key: "2e1cvw" }],
  ["path", { d: "M16 11.37A4 4 0 1 1 12.63 8 4 4 0 0 1 16 11.37z", key: "9exkf1" }],
  ["line", { x1: "17.5", x2: "17.51", y1: "6.5", y2: "6.5", key: "r4j83e" }]
]);

const LuItalic = createLucideIcon("LuItalic", [
  ["line", { x1: "19", x2: "10", y1: "4", y2: "4", key: "15jd3p" }],
  ["line", { x1: "14", x2: "5", y1: "20", y2: "20", key: "bu0au3" }],
  ["line", { x1: "15", x2: "9", y1: "4", y2: "20", key: "uljnxc" }]
]);

const LuIterationCcw = createLucideIcon("LuIterationCcw", [
  ["path", { d: "M20 10c0-4.4-3.6-8-8-8s-8 3.6-8 8 3.6 8 8 8h8", key: "4znkd0" }],
  ["polyline", { points: "16 14 20 18 16 22", key: "11njsm" }]
]);

const LuIterationCw = createLucideIcon("LuIterationCw", [
  ["path", { d: "M4 10c0-4.4 3.6-8 8-8s8 3.6 8 8-3.6 8-8 8H4", key: "tuf4su" }],
  ["polyline", { points: "8 22 4 18 8 14", key: "evkj9s" }]
]);

const LuJapaneseYen = createLucideIcon("LuJapaneseYen", [
  ["path", { d: "M12 9.5V21m0-11.5L6 3m6 6.5L18 3", key: "2ej80x" }],
  ["path", { d: "M6 15h12", key: "1hwgt5" }],
  ["path", { d: "M6 11h12", key: "wf4gp6" }]
]);

const LuJoystick = createLucideIcon("LuJoystick", [
  [
    "path",
    {
      d: "M21 17a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-2Z",
      key: "jg2n2t"
    }
  ],
  ["path", { d: "M6 15v-2", key: "gd6mvg" }],
  ["path", { d: "M12 15V9", key: "8c7uyn" }],
  ["circle", { cx: "12", cy: "6", r: "3", key: "1gm2ql" }]
]);

const LuKanban = createLucideIcon("LuKanban", [
  ["path", { d: "M6 5v11", key: "mdvv1e" }],
  ["path", { d: "M12 5v6", key: "14ar3b" }],
  ["path", { d: "M18 5v14", key: "7ji314" }]
]);

const LuKeyRound = createLucideIcon("LuKeyRound", [
  ["path", { d: "M2 18v3c0 .6.4 1 1 1h4v-3h3v-3h2l1.4-1.4a6.5 6.5 0 1 0-4-4Z", key: "167ctg" }],
  ["circle", { cx: "16.5", cy: "7.5", r: ".5", fill: "currentColor", key: "w0ekpg" }]
]);

const LuKeySquare = createLucideIcon("LuKeySquare", [
  [
    "path",
    {
      d: "M12.4 2.7c.9-.9 2.5-.9 3.4 0l5.5 5.5c.9.9.9 2.5 0 3.4l-3.7 3.7c-.9.9-2.5.9-3.4 0L8.7 9.8c-.9-.9-.9-2.5 0-3.4Z",
      key: "9li5bk"
    }
  ],
  ["path", { d: "m14 7 3 3", key: "1r5n42" }],
  ["path", { d: "M9.4 10.6 2 18v3c0 .6.4 1 1 1h4v-3h3v-3h2l1.4-1.4", key: "1ym3zm" }]
]);

const LuKey = createLucideIcon("LuKey", [
  ["circle", { cx: "7.5", cy: "15.5", r: "5.5", key: "yqb3hr" }],
  ["path", { d: "m21 2-9.6 9.6", key: "1j0ho8" }],
  ["path", { d: "m15.5 7.5 3 3L22 7l-3-3", key: "1rn1fs" }]
]);

const LuKeyboardMusic = createLucideIcon("LuKeyboardMusic", [
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }],
  ["path", { d: "M6 8h4", key: "utf9t1" }],
  ["path", { d: "M14 8h.01", key: "1primd" }],
  ["path", { d: "M18 8h.01", key: "emo2bl" }],
  ["path", { d: "M2 12h20", key: "9i4pu4" }],
  ["path", { d: "M6 12v4", key: "dy92yo" }],
  ["path", { d: "M10 12v4", key: "1fxnav" }],
  ["path", { d: "M14 12v4", key: "1hft58" }],
  ["path", { d: "M18 12v4", key: "tjjnbz" }]
]);

const LuKeyboard = createLucideIcon("LuKeyboard", [
  ["path", { d: "M10 8h.01", key: "1r9ogq" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }],
  ["path", { d: "M14 8h.01", key: "1primd" }],
  ["path", { d: "M16 12h.01", key: "1l6xoz" }],
  ["path", { d: "M18 8h.01", key: "emo2bl" }],
  ["path", { d: "M6 8h.01", key: "x9i8wu" }],
  ["path", { d: "M7 16h10", key: "wp8him" }],
  ["path", { d: "M8 12h.01", key: "czm47f" }],
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }]
]);

const LuLampCeiling = createLucideIcon("LuLampCeiling", [
  ["path", { d: "M12 2v5", key: "nd4vlx" }],
  ["path", { d: "M6 7h12l4 9H2l4-9Z", key: "123d64" }],
  ["path", { d: "M9.17 16a3 3 0 1 0 5.66 0", key: "1061mw" }]
]);

const LuLampDesk = createLucideIcon("LuLampDesk", [
  ["path", { d: "m14 5-3 3 2 7 8-8-7-2Z", key: "1b0msb" }],
  ["path", { d: "m14 5-3 3-3-3 3-3 3 3Z", key: "1uemms" }],
  ["path", { d: "M9.5 6.5 4 12l3 6", key: "1bx08v" }],
  ["path", { d: "M3 22v-2c0-1.1.9-2 2-2h4a2 2 0 0 1 2 2v2H3Z", key: "wap775" }]
]);

const LuLampFloor = createLucideIcon("LuLampFloor", [
  ["path", { d: "M9 2h6l3 7H6l3-7Z", key: "wcx6mj" }],
  ["path", { d: "M12 9v13", key: "3n1su1" }],
  ["path", { d: "M9 22h6", key: "1rlq3v" }]
]);

const LuLampWallDown = createLucideIcon("LuLampWallDown", [
  ["path", { d: "M11 13h6l3 7H8l3-7Z", key: "9n3qlo" }],
  ["path", { d: "M14 13V8a2 2 0 0 0-2-2H8", key: "1hu4hb" }],
  ["path", { d: "M4 9h2a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2H4v6Z", key: "s053bc" }]
]);

const LuLampWallUp = createLucideIcon("LuLampWallUp", [
  ["path", { d: "M11 4h6l3 7H8l3-7Z", key: "11x1ee" }],
  ["path", { d: "M14 11v5a2 2 0 0 1-2 2H8", key: "eutp5o" }],
  ["path", { d: "M4 15h2a2 2 0 0 1 2 2v2a2 2 0 0 1-2 2H4v-6Z", key: "1iuthr" }]
]);

const LuLamp = createLucideIcon("LuLamp", [
  ["path", { d: "M8 2h8l4 10H4L8 2Z", key: "9dma5w" }],
  ["path", { d: "M12 12v6", key: "3ahymv" }],
  ["path", { d: "M8 22v-2c0-1.1.9-2 2-2h4a2 2 0 0 1 2 2v2H8Z", key: "mwf4oh" }]
]);

const LuLandPlot = createLucideIcon("LuLandPlot", [
  ["path", { d: "m12 8 6-3-6-3v10", key: "mvpnpy" }],
  [
    "path",
    {
      d: "m8 11.99-5.5 3.14a1 1 0 0 0 0 1.74l8.5 4.86a2 2 0 0 0 2 0l8.5-4.86a1 1 0 0 0 0-1.74L16 12",
      key: "ek95tt"
    }
  ],
  ["path", { d: "m6.49 12.85 11.02 6.3", key: "1kt42w" }],
  ["path", { d: "M17.51 12.85 6.5 19.15", key: "v55bdg" }]
]);

const LuLandmark = createLucideIcon("LuLandmark", [
  ["line", { x1: "3", x2: "21", y1: "22", y2: "22", key: "j8o0r" }],
  ["line", { x1: "6", x2: "6", y1: "18", y2: "11", key: "10tf0k" }],
  ["line", { x1: "10", x2: "10", y1: "18", y2: "11", key: "54lgf6" }],
  ["line", { x1: "14", x2: "14", y1: "18", y2: "11", key: "380y" }],
  ["line", { x1: "18", x2: "18", y1: "18", y2: "11", key: "1kevvc" }],
  ["polygon", { points: "12 2 20 7 4 7", key: "jkujk7" }]
]);

const LuLanguages = createLucideIcon("LuLanguages", [
  ["path", { d: "m5 8 6 6", key: "1wu5hv" }],
  ["path", { d: "m4 14 6-6 2-3", key: "1k1g8d" }],
  ["path", { d: "M2 5h12", key: "or177f" }],
  ["path", { d: "M7 2h1", key: "1t2jsx" }],
  ["path", { d: "m22 22-5-10-5 10", key: "don7ne" }],
  ["path", { d: "M14 18h6", key: "1m8k6r" }]
]);

const LuLaptopMinimal = createLucideIcon("LuLaptopMinimal", [
  ["rect", { width: "18", height: "12", x: "3", y: "4", rx: "2", ry: "2", key: "1qhy41" }],
  ["line", { x1: "2", x2: "22", y1: "20", y2: "20", key: "ni3hll" }]
]);

const LuLaptop = createLucideIcon("LuLaptop", [
  [
    "path",
    {
      d: "M20 16V7a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v9m16 0H4m16 0 1.28 2.55a1 1 0 0 1-.9 1.45H3.62a1 1 0 0 1-.9-1.45L4 16",
      key: "tarvll"
    }
  ]
]);

const LuLassoSelect = createLucideIcon("LuLassoSelect", [
  ["path", { d: "M7 22a5 5 0 0 1-2-4", key: "umushi" }],
  ["path", { d: "M7 16.93c.96.43 1.96.74 2.99.91", key: "ybbtv3" }],
  [
    "path",
    {
      d: "M3.34 14A6.8 6.8 0 0 1 2 10c0-4.42 4.48-8 10-8s10 3.58 10 8a7.19 7.19 0 0 1-.33 2",
      key: "gt5e1w"
    }
  ],
  ["path", { d: "M5 18a2 2 0 1 0 0-4 2 2 0 0 0 0 4z", key: "bq3ynw" }],
  [
    "path",
    {
      d: "M14.33 22h-.09a.35.35 0 0 1-.24-.32v-10a.34.34 0 0 1 .33-.34c.08 0 .15.03.21.08l7.34 6a.33.33 0 0 1-.21.59h-4.49l-2.57 3.85a.35.35 0 0 1-.28.14v0z",
      key: "1bawls"
    }
  ]
]);

const LuLasso = createLucideIcon("LuLasso", [
  ["path", { d: "M7 22a5 5 0 0 1-2-4", key: "umushi" }],
  [
    "path",
    {
      d: "M3.3 14A6.8 6.8 0 0 1 2 10c0-4.4 4.5-8 10-8s10 3.6 10 8-4.5 8-10 8a12 12 0 0 1-5-1",
      key: "146dds"
    }
  ],
  ["path", { d: "M5 18a2 2 0 1 0 0-4 2 2 0 0 0 0 4z", key: "bq3ynw" }]
]);

const LuLaugh = createLucideIcon("LuLaugh", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M18 13a6 6 0 0 1-6 5 6 6 0 0 1-6-5h12Z", key: "b2q4dd" }],
  ["line", { x1: "9", x2: "9.01", y1: "9", y2: "9", key: "yxxnd0" }],
  ["line", { x1: "15", x2: "15.01", y1: "9", y2: "9", key: "1p4y9e" }]
]);

const LuLayers2 = createLucideIcon("LuLayers2", [
  [
    "path",
    {
      d: "m16.02 12 5.48 3.13a1 1 0 0 1 0 1.74L13 21.74a2 2 0 0 1-2 0l-8.5-4.87a1 1 0 0 1 0-1.74L7.98 12",
      key: "1cuww1"
    }
  ],
  [
    "path",
    {
      d: "M13 13.74a2 2 0 0 1-2 0L2.5 8.87a1 1 0 0 1 0-1.74L11 2.26a2 2 0 0 1 2 0l8.5 4.87a1 1 0 0 1 0 1.74Z",
      key: "pdlvxu"
    }
  ]
]);

const LuLayers3 = createLucideIcon("LuLayers3", [
  [
    "path",
    {
      d: "m12.83 2.18a2 2 0 0 0-1.66 0L2.6 6.08a1 1 0 0 0 0 1.83l8.58 3.91a2 2 0 0 0 1.66 0l8.58-3.9a1 1 0 0 0 0-1.83Z",
      key: "8b97xw"
    }
  ],
  [
    "path",
    {
      d: "m6.08 9.5-3.5 1.6a1 1 0 0 0 0 1.81l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9a1 1 0 0 0 0-1.83l-3.5-1.59",
      key: "1e5n1m"
    }
  ],
  [
    "path",
    {
      d: "m6.08 14.5-3.5 1.6a1 1 0 0 0 0 1.81l8.6 3.91a2 2 0 0 0 1.65 0l8.58-3.9a1 1 0 0 0 0-1.83l-3.5-1.59",
      key: "1iwflc"
    }
  ]
]);

const LuLayers = createLucideIcon("LuLayers", [
  [
    "path",
    {
      d: "m12.83 2.18a2 2 0 0 0-1.66 0L2.6 6.08a1 1 0 0 0 0 1.83l8.58 3.91a2 2 0 0 0 1.66 0l8.58-3.9a1 1 0 0 0 0-1.83Z",
      key: "8b97xw"
    }
  ],
  ["path", { d: "m22 17.65-9.17 4.16a2 2 0 0 1-1.66 0L2 17.65", key: "dd6zsq" }],
  ["path", { d: "m22 12.65-9.17 4.16a2 2 0 0 1-1.66 0L2 12.65", key: "ep9fru" }]
]);

const LuLayoutDashboard = createLucideIcon("LuLayoutDashboard", [
  ["rect", { width: "7", height: "9", x: "3", y: "3", rx: "1", key: "10lvy0" }],
  ["rect", { width: "7", height: "5", x: "14", y: "3", rx: "1", key: "16une8" }],
  ["rect", { width: "7", height: "9", x: "14", y: "12", rx: "1", key: "1hutg5" }],
  ["rect", { width: "7", height: "5", x: "3", y: "16", rx: "1", key: "ldoo1y" }]
]);

const LuLayoutGrid = createLucideIcon("LuLayoutGrid", [
  ["rect", { width: "7", height: "7", x: "3", y: "3", rx: "1", key: "1g98yp" }],
  ["rect", { width: "7", height: "7", x: "14", y: "3", rx: "1", key: "6d4xhi" }],
  ["rect", { width: "7", height: "7", x: "14", y: "14", rx: "1", key: "nxv5o0" }],
  ["rect", { width: "7", height: "7", x: "3", y: "14", rx: "1", key: "1bb6yr" }]
]);

const LuLayoutList = createLucideIcon("LuLayoutList", [
  ["rect", { width: "7", height: "7", x: "3", y: "3", rx: "1", key: "1g98yp" }],
  ["rect", { width: "7", height: "7", x: "3", y: "14", rx: "1", key: "1bb6yr" }],
  ["path", { d: "M14 4h7", key: "3xa0d5" }],
  ["path", { d: "M14 9h7", key: "1icrd9" }],
  ["path", { d: "M14 15h7", key: "1mj8o2" }],
  ["path", { d: "M14 20h7", key: "11slyb" }]
]);

const LuLayoutPanelLeft = createLucideIcon("LuLayoutPanelLeft", [
  ["rect", { width: "7", height: "18", x: "3", y: "3", rx: "1", key: "2obqm" }],
  ["rect", { width: "7", height: "7", x: "14", y: "3", rx: "1", key: "6d4xhi" }],
  ["rect", { width: "7", height: "7", x: "14", y: "14", rx: "1", key: "nxv5o0" }]
]);

const LuLayoutPanelTop = createLucideIcon("LuLayoutPanelTop", [
  ["rect", { width: "18", height: "7", x: "3", y: "3", rx: "1", key: "f1a2em" }],
  ["rect", { width: "7", height: "7", x: "3", y: "14", rx: "1", key: "1bb6yr" }],
  ["rect", { width: "7", height: "7", x: "14", y: "14", rx: "1", key: "nxv5o0" }]
]);

const LuLayoutTemplate = createLucideIcon("LuLayoutTemplate", [
  ["rect", { width: "18", height: "7", x: "3", y: "3", rx: "1", key: "f1a2em" }],
  ["rect", { width: "9", height: "7", x: "3", y: "14", rx: "1", key: "jqznyg" }],
  ["rect", { width: "5", height: "7", x: "16", y: "14", rx: "1", key: "q5h2i8" }]
]);

const LuLeaf = createLucideIcon("LuLeaf", [
  [
    "path",
    {
      d: "M11 20A7 7 0 0 1 9.8 6.1C15.5 5 17 4.48 19 2c1 2 2 4.18 2 8 0 5.5-4.78 10-10 10Z",
      key: "nnexq3"
    }
  ],
  ["path", { d: "M2 21c0-3 1.85-5.36 5.08-6C9.5 14.52 12 13 13 12", key: "mt58a7" }]
]);

const LuLeafyGreen = createLucideIcon("LuLeafyGreen", [
  [
    "path",
    {
      d: "M2 22c1.25-.987 2.27-1.975 3.9-2.2a5.56 5.56 0 0 1 3.8 1.5 4 4 0 0 0 6.187-2.353 3.5 3.5 0 0 0 3.69-5.116A3.5 3.5 0 0 0 20.95 8 3.5 3.5 0 1 0 16 3.05a3.5 3.5 0 0 0-5.831 1.373 3.5 3.5 0 0 0-5.116 3.69 4 4 0 0 0-2.348 6.155C3.499 15.42 4.409 16.712 4.2 18.1 3.926 19.743 3.014 20.732 2 22",
      key: "1134nt"
    }
  ],
  ["path", { d: "M2 22 17 7", key: "1q7jp2" }]
]);

const LuLibraryBig = createLucideIcon("LuLibraryBig", [
  ["rect", { width: "8", height: "18", x: "3", y: "3", rx: "1", key: "oynpb5" }],
  ["path", { d: "M7 3v18", key: "bbkbws" }],
  [
    "path",
    {
      d: "M20.4 18.9c.2.5-.1 1.1-.6 1.3l-1.9.7c-.5.2-1.1-.1-1.3-.6L11.1 5.1c-.2-.5.1-1.1.6-1.3l1.9-.7c.5-.2 1.1.1 1.3.6Z",
      key: "1qboyk"
    }
  ]
]);

const LuLibrary = createLucideIcon("LuLibrary", [
  ["path", { d: "m16 6 4 14", key: "ji33uf" }],
  ["path", { d: "M12 6v14", key: "1n7gus" }],
  ["path", { d: "M8 8v12", key: "1gg7y9" }],
  ["path", { d: "M4 4v16", key: "6qkkli" }]
]);

const LuLifeBuoy = createLucideIcon("LuLifeBuoy", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "m4.93 4.93 4.24 4.24", key: "1ymg45" }],
  ["path", { d: "m14.83 9.17 4.24-4.24", key: "1cb5xl" }],
  ["path", { d: "m14.83 14.83 4.24 4.24", key: "q42g0n" }],
  ["path", { d: "m9.17 14.83-4.24 4.24", key: "bqpfvv" }],
  ["circle", { cx: "12", cy: "12", r: "4", key: "4exip2" }]
]);

const LuLigature = createLucideIcon("LuLigature", [
  ["path", { d: "M8 20V8c0-2.2 1.8-4 4-4 1.5 0 2.8.8 3.5 2", key: "1rtphz" }],
  ["path", { d: "M6 12h4", key: "a4o3ry" }],
  ["path", { d: "M14 12h2v8", key: "c1fccl" }],
  ["path", { d: "M6 20h4", key: "1i6q5t" }],
  ["path", { d: "M14 20h4", key: "lzx1xo" }]
]);

const LuLightbulbOff = createLucideIcon("LuLightbulbOff", [
  ["path", { d: "M16.8 11.2c.8-.9 1.2-2 1.2-3.2a6 6 0 0 0-9.3-5", key: "1fkcox" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M6.3 6.3a4.67 4.67 0 0 0 1.2 5.2c.7.7 1.3 1.5 1.5 2.5", key: "10m8kw" }],
  ["path", { d: "M9 18h6", key: "x1upvd" }],
  ["path", { d: "M10 22h4", key: "ceow96" }]
]);

const LuLightbulb = createLucideIcon("LuLightbulb", [
  [
    "path",
    {
      d: "M15 14c.2-1 .7-1.7 1.5-2.5 1-.9 1.5-2.2 1.5-3.5A6 6 0 0 0 6 8c0 1 .2 2.2 1.5 3.5.7.7 1.3 1.5 1.5 2.5",
      key: "1gvzjb"
    }
  ],
  ["path", { d: "M9 18h6", key: "x1upvd" }],
  ["path", { d: "M10 22h4", key: "ceow96" }]
]);

const LuLineChart = createLucideIcon("LuLineChart", [
  ["path", { d: "M3 3v18h18", key: "1s2lah" }],
  ["path", { d: "m19 9-5 5-4-4-3 3", key: "2osh9i" }]
]);

const LuLink2Off = createLucideIcon("LuLink2Off", [
  ["path", { d: "M9 17H7A5 5 0 0 1 7 7", key: "10o201" }],
  ["path", { d: "M15 7h2a5 5 0 0 1 4 8", key: "1d3206" }],
  ["line", { x1: "8", x2: "12", y1: "12", y2: "12", key: "rvw6j4" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuLink2 = createLucideIcon("LuLink2", [
  ["path", { d: "M9 17H7A5 5 0 0 1 7 7h2", key: "8i5ue5" }],
  ["path", { d: "M15 7h2a5 5 0 1 1 0 10h-2", key: "1b9ql8" }],
  ["line", { x1: "8", x2: "16", y1: "12", y2: "12", key: "1jonct" }]
]);

const LuLink = createLucideIcon("LuLink", [
  ["path", { d: "M10 13a5 5 0 0 0 7.54.54l3-3a5 5 0 0 0-7.07-7.07l-1.72 1.71", key: "1cjeqo" }],
  ["path", { d: "M14 11a5 5 0 0 0-7.54-.54l-3 3a5 5 0 0 0 7.07 7.07l1.71-1.71", key: "19qd67" }]
]);

const LuLinkedin = createLucideIcon("LuLinkedin", [
  [
    "path",
    {
      d: "M16 8a6 6 0 0 1 6 6v7h-4v-7a2 2 0 0 0-2-2 2 2 0 0 0-2 2v7h-4v-7a6 6 0 0 1 6-6z",
      key: "c2jq9f"
    }
  ],
  ["rect", { width: "4", height: "12", x: "2", y: "9", key: "mk3on5" }],
  ["circle", { cx: "4", cy: "4", r: "2", key: "bt5ra8" }]
]);

const LuListChecks = createLucideIcon("LuListChecks", [
  ["path", { d: "m3 17 2 2 4-4", key: "1jhpwq" }],
  ["path", { d: "m3 7 2 2 4-4", key: "1obspn" }],
  ["path", { d: "M13 6h8", key: "15sg57" }],
  ["path", { d: "M13 12h8", key: "h98zly" }],
  ["path", { d: "M13 18h8", key: "oe0vm4" }]
]);

const LuListCollapse = createLucideIcon("LuListCollapse", [
  ["path", { d: "m3 10 2.5-2.5L3 5", key: "i6eama" }],
  ["path", { d: "m3 19 2.5-2.5L3 14", key: "w2gmor" }],
  ["path", { d: "M10 6h11", key: "c7qv1k" }],
  ["path", { d: "M10 12h11", key: "6m4ad9" }],
  ["path", { d: "M10 18h11", key: "11hvi2" }]
]);

const LuListEnd = createLucideIcon("LuListEnd", [
  ["path", { d: "M16 12H3", key: "1a2rj7" }],
  ["path", { d: "M16 6H3", key: "1wxfjs" }],
  ["path", { d: "M10 18H3", key: "13769t" }],
  ["path", { d: "M21 6v10a2 2 0 0 1-2 2h-5", key: "ilrcs8" }],
  ["path", { d: "m16 16-2 2 2 2", key: "kkc6pm" }]
]);

const LuListFilter = createLucideIcon("LuListFilter", [
  ["path", { d: "M3 6h18", key: "d0wm0j" }],
  ["path", { d: "M7 12h10", key: "b7w52i" }],
  ["path", { d: "M10 18h4", key: "1ulq68" }]
]);

const LuListMinus = createLucideIcon("LuListMinus", [
  ["path", { d: "M11 12H3", key: "51ecnj" }],
  ["path", { d: "M16 6H3", key: "1wxfjs" }],
  ["path", { d: "M16 18H3", key: "12xzn7" }],
  ["path", { d: "M21 12h-6", key: "bt1uis" }]
]);

const LuListMusic = createLucideIcon("LuListMusic", [
  ["path", { d: "M21 15V6", key: "h1cx4g" }],
  ["path", { d: "M18.5 18a2.5 2.5 0 1 0 0-5 2.5 2.5 0 0 0 0 5Z", key: "8saifv" }],
  ["path", { d: "M12 12H3", key: "18klou" }],
  ["path", { d: "M16 6H3", key: "1wxfjs" }],
  ["path", { d: "M12 18H3", key: "11ftsu" }]
]);

const LuListOrdered = createLucideIcon("LuListOrdered", [
  ["line", { x1: "10", x2: "21", y1: "6", y2: "6", key: "76qw6h" }],
  ["line", { x1: "10", x2: "21", y1: "12", y2: "12", key: "16nom4" }],
  ["line", { x1: "10", x2: "21", y1: "18", y2: "18", key: "u3jurt" }],
  ["path", { d: "M4 6h1v4", key: "cnovpq" }],
  ["path", { d: "M4 10h2", key: "16xx2s" }],
  ["path", { d: "M6 18H4c0-1 2-2 2-3s-1-1.5-2-1", key: "m9a95d" }]
]);

const LuListPlus = createLucideIcon("LuListPlus", [
  ["path", { d: "M11 12H3", key: "51ecnj" }],
  ["path", { d: "M16 6H3", key: "1wxfjs" }],
  ["path", { d: "M16 18H3", key: "12xzn7" }],
  ["path", { d: "M18 9v6", key: "1twb98" }],
  ["path", { d: "M21 12h-6", key: "bt1uis" }]
]);

const LuListRestart = createLucideIcon("LuListRestart", [
  ["path", { d: "M21 6H3", key: "1jwq7v" }],
  ["path", { d: "M7 12H3", key: "13ou7f" }],
  ["path", { d: "M7 18H3", key: "1sijw9" }],
  [
    "path",
    {
      d: "M12 18a5 5 0 0 0 9-3 4.5 4.5 0 0 0-4.5-4.5c-1.33 0-2.54.54-3.41 1.41L11 14",
      key: "qth677"
    }
  ],
  ["path", { d: "M11 10v4h4", key: "172dkj" }]
]);

const LuListStart = createLucideIcon("LuListStart", [
  ["path", { d: "M16 12H3", key: "1a2rj7" }],
  ["path", { d: "M16 18H3", key: "12xzn7" }],
  ["path", { d: "M10 6H3", key: "lf8lx7" }],
  ["path", { d: "M21 18V8a2 2 0 0 0-2-2h-5", key: "1hghli" }],
  ["path", { d: "m16 8-2-2 2-2", key: "160uvd" }]
]);

const LuListTodo = createLucideIcon("LuListTodo", [
  ["rect", { x: "3", y: "5", width: "6", height: "6", rx: "1", key: "1defrl" }],
  ["path", { d: "m3 17 2 2 4-4", key: "1jhpwq" }],
  ["path", { d: "M13 6h8", key: "15sg57" }],
  ["path", { d: "M13 12h8", key: "h98zly" }],
  ["path", { d: "M13 18h8", key: "oe0vm4" }]
]);

const LuListTree = createLucideIcon("LuListTree", [
  ["path", { d: "M21 12h-8", key: "1bmf0i" }],
  ["path", { d: "M21 6H8", key: "1pqkrb" }],
  ["path", { d: "M21 18h-8", key: "1tm79t" }],
  ["path", { d: "M3 6v4c0 1.1.9 2 2 2h3", key: "1ywdgy" }],
  ["path", { d: "M3 10v6c0 1.1.9 2 2 2h3", key: "2wc746" }]
]);

const LuListVideo = createLucideIcon("LuListVideo", [
  ["path", { d: "M12 12H3", key: "18klou" }],
  ["path", { d: "M16 6H3", key: "1wxfjs" }],
  ["path", { d: "M12 18H3", key: "11ftsu" }],
  ["path", { d: "m16 12 5 3-5 3v-6Z", key: "zpskkp" }]
]);

const LuListX = createLucideIcon("LuListX", [
  ["path", { d: "M11 12H3", key: "51ecnj" }],
  ["path", { d: "M16 6H3", key: "1wxfjs" }],
  ["path", { d: "M16 18H3", key: "12xzn7" }],
  ["path", { d: "m19 10-4 4", key: "1tz659" }],
  ["path", { d: "m15 10 4 4", key: "1n7nei" }]
]);

const LuList = createLucideIcon("LuList", [
  ["line", { x1: "8", x2: "21", y1: "6", y2: "6", key: "7ey8pc" }],
  ["line", { x1: "8", x2: "21", y1: "12", y2: "12", key: "rjfblc" }],
  ["line", { x1: "8", x2: "21", y1: "18", y2: "18", key: "c3b1m8" }],
  ["line", { x1: "3", x2: "3.01", y1: "6", y2: "6", key: "1g7gq3" }],
  ["line", { x1: "3", x2: "3.01", y1: "12", y2: "12", key: "1pjlvk" }],
  ["line", { x1: "3", x2: "3.01", y1: "18", y2: "18", key: "28t2mc" }]
]);

const LuLoaderCircle = createLucideIcon("LuLoaderCircle", [
  ["path", { d: "M21 12a9 9 0 1 1-6.219-8.56", key: "13zald" }]
]);

const LuLoader = createLucideIcon("LuLoader", [
  ["line", { x1: "12", x2: "12", y1: "2", y2: "6", key: "gza1u7" }],
  ["line", { x1: "12", x2: "12", y1: "18", y2: "22", key: "1qhbu9" }],
  ["line", { x1: "4.93", x2: "7.76", y1: "4.93", y2: "7.76", key: "xae44r" }],
  ["line", { x1: "16.24", x2: "19.07", y1: "16.24", y2: "19.07", key: "bxnmvf" }],
  ["line", { x1: "2", x2: "6", y1: "12", y2: "12", key: "89khin" }],
  ["line", { x1: "18", x2: "22", y1: "12", y2: "12", key: "pb8tfm" }],
  ["line", { x1: "4.93", x2: "7.76", y1: "19.07", y2: "16.24", key: "1uxjnu" }],
  ["line", { x1: "16.24", x2: "19.07", y1: "7.76", y2: "4.93", key: "6duxfx" }]
]);

const LuLocateFixed = createLucideIcon("LuLocateFixed", [
  ["line", { x1: "2", x2: "5", y1: "12", y2: "12", key: "bvdh0s" }],
  ["line", { x1: "19", x2: "22", y1: "12", y2: "12", key: "1tbv5k" }],
  ["line", { x1: "12", x2: "12", y1: "2", y2: "5", key: "11lu5j" }],
  ["line", { x1: "12", x2: "12", y1: "19", y2: "22", key: "x3vr5v" }],
  ["circle", { cx: "12", cy: "12", r: "7", key: "fim9np" }],
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }]
]);

const LuLocateOff = createLucideIcon("LuLocateOff", [
  ["line", { x1: "2", x2: "5", y1: "12", y2: "12", key: "bvdh0s" }],
  ["line", { x1: "19", x2: "22", y1: "12", y2: "12", key: "1tbv5k" }],
  ["line", { x1: "12", x2: "12", y1: "2", y2: "5", key: "11lu5j" }],
  ["line", { x1: "12", x2: "12", y1: "19", y2: "22", key: "x3vr5v" }],
  [
    "path",
    {
      d: "M7.11 7.11C5.83 8.39 5 10.1 5 12c0 3.87 3.13 7 7 7 1.9 0 3.61-.83 4.89-2.11",
      key: "1oh7ia"
    }
  ],
  [
    "path",
    {
      d: "M18.71 13.96c.19-.63.29-1.29.29-1.96 0-3.87-3.13-7-7-7-.67 0-1.33.1-1.96.29",
      key: "3qdecy"
    }
  ],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuLocate = createLucideIcon("LuLocate", [
  ["line", { x1: "2", x2: "5", y1: "12", y2: "12", key: "bvdh0s" }],
  ["line", { x1: "19", x2: "22", y1: "12", y2: "12", key: "1tbv5k" }],
  ["line", { x1: "12", x2: "12", y1: "2", y2: "5", key: "11lu5j" }],
  ["line", { x1: "12", x2: "12", y1: "19", y2: "22", key: "x3vr5v" }],
  ["circle", { cx: "12", cy: "12", r: "7", key: "fim9np" }]
]);

const LuLockKeyholeOpen = createLucideIcon("LuLockKeyholeOpen", [
  ["circle", { cx: "12", cy: "16", r: "1", key: "1au0dj" }],
  ["rect", { width: "18", height: "12", x: "3", y: "10", rx: "2", key: "l0tzu3" }],
  ["path", { d: "M7 10V7a5 5 0 0 1 9.33-2.5", key: "car5b7" }]
]);

const LuLockKeyhole = createLucideIcon("LuLockKeyhole", [
  ["circle", { cx: "12", cy: "16", r: "1", key: "1au0dj" }],
  ["rect", { x: "3", y: "10", width: "18", height: "12", rx: "2", key: "6s8ecr" }],
  ["path", { d: "M7 10V7a5 5 0 0 1 10 0v3", key: "1pqi11" }]
]);

const LuLockOpen = createLucideIcon("LuLockOpen", [
  ["rect", { width: "18", height: "11", x: "3", y: "11", rx: "2", ry: "2", key: "1w4ew1" }],
  ["path", { d: "M7 11V7a5 5 0 0 1 9.9-1", key: "1mm8w8" }]
]);

const LuLock = createLucideIcon("LuLock", [
  ["rect", { width: "18", height: "11", x: "3", y: "11", rx: "2", ry: "2", key: "1w4ew1" }],
  ["path", { d: "M7 11V7a5 5 0 0 1 10 0v4", key: "fwvmzm" }]
]);

const LuLogIn = createLucideIcon("LuLogIn", [
  ["path", { d: "M15 3h4a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2h-4", key: "u53s6r" }],
  ["polyline", { points: "10 17 15 12 10 7", key: "1ail0h" }],
  ["line", { x1: "15", x2: "3", y1: "12", y2: "12", key: "v6grx8" }]
]);

const LuLogOut = createLucideIcon("LuLogOut", [
  ["path", { d: "M9 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h4", key: "1uf3rs" }],
  ["polyline", { points: "16 17 21 12 16 7", key: "1gabdz" }],
  ["line", { x1: "21", x2: "9", y1: "12", y2: "12", key: "1uyos4" }]
]);

const LuLollipop = createLucideIcon("LuLollipop", [
  ["circle", { cx: "11", cy: "11", r: "8", key: "4ej97u" }],
  ["path", { d: "m21 21-4.3-4.3", key: "1qie3q" }],
  ["path", { d: "M11 11a2 2 0 0 0 4 0 4 4 0 0 0-8 0 6 6 0 0 0 12 0", key: "107gwy" }]
]);

const LuLuggage = createLucideIcon("LuLuggage", [
  [
    "path",
    {
      d: "M6 20h0a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h0",
      key: "1h5fkc"
    }
  ],
  ["path", { d: "M8 18V4a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v14", key: "1l99gc" }],
  ["path", { d: "M10 20h4", key: "ni2waw" }],
  ["circle", { cx: "16", cy: "20", r: "2", key: "1vifvg" }],
  ["circle", { cx: "8", cy: "20", r: "2", key: "ckkr5m" }]
]);

const LuMagnet = createLucideIcon("LuMagnet", [
  [
    "path",
    {
      d: "m6 15-4-4 6.75-6.77a7.79 7.79 0 0 1 11 11L13 22l-4-4 6.39-6.36a2.14 2.14 0 0 0-3-3L6 15",
      key: "1i3lhw"
    }
  ],
  ["path", { d: "m5 8 4 4", key: "j6kj7e" }],
  ["path", { d: "m12 15 4 4", key: "lnac28" }]
]);

const LuMailCheck = createLucideIcon("LuMailCheck", [
  ["path", { d: "M22 13V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h8", key: "12jkf8" }],
  ["path", { d: "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7", key: "1ocrg3" }],
  ["path", { d: "m16 19 2 2 4-4", key: "1b14m6" }]
]);

const LuMailMinus = createLucideIcon("LuMailMinus", [
  ["path", { d: "M22 15V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h8", key: "fuxbkv" }],
  ["path", { d: "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7", key: "1ocrg3" }],
  ["path", { d: "M16 19h6", key: "xwg31i" }]
]);

const LuMailOpen = createLucideIcon("LuMailOpen", [
  [
    "path",
    {
      d: "M21.2 8.4c.5.38.8.97.8 1.6v10a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V10a2 2 0 0 1 .8-1.6l8-6a2 2 0 0 1 2.4 0l8 6Z",
      key: "1jhwl8"
    }
  ],
  ["path", { d: "m22 10-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 10", key: "1qfld7" }]
]);

const LuMailPlus = createLucideIcon("LuMailPlus", [
  ["path", { d: "M22 13V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h8", key: "12jkf8" }],
  ["path", { d: "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7", key: "1ocrg3" }],
  ["path", { d: "M19 16v6", key: "tddt3s" }],
  ["path", { d: "M16 19h6", key: "xwg31i" }]
]);

const LuMailQuestion = createLucideIcon("LuMailQuestion", [
  ["path", { d: "M22 10.5V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h12.5", key: "e61zoh" }],
  ["path", { d: "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7", key: "1ocrg3" }],
  [
    "path",
    {
      d: "M18 15.28c.2-.4.5-.8.9-1a2.1 2.1 0 0 1 2.6.4c.3.4.5.8.5 1.3 0 1.3-2 2-2 2",
      key: "7z9rxb"
    }
  ],
  ["path", { d: "M20 22v.01", key: "12bgn6" }]
]);

const LuMailSearch = createLucideIcon("LuMailSearch", [
  ["path", { d: "M22 12.5V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h7.5", key: "w80f2v" }],
  ["path", { d: "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7", key: "1ocrg3" }],
  ["path", { d: "M18 21a3 3 0 1 0 0-6 3 3 0 0 0 0 6v0Z", key: "mgbru4" }],
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  ["path", { d: "m22 22-1.5-1.5", key: "1x83k4" }]
]);

const LuMailWarning = createLucideIcon("LuMailWarning", [
  ["path", { d: "M22 10.5V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h12.5", key: "e61zoh" }],
  ["path", { d: "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7", key: "1ocrg3" }],
  ["path", { d: "M20 14v4", key: "1hm744" }],
  ["path", { d: "M20 22v.01", key: "12bgn6" }]
]);

const LuMailX = createLucideIcon("LuMailX", [
  ["path", { d: "M22 13V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v12c0 1.1.9 2 2 2h9", key: "1j9vog" }],
  ["path", { d: "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7", key: "1ocrg3" }],
  ["path", { d: "m17 17 4 4", key: "1b3523" }],
  ["path", { d: "m21 17-4 4", key: "uinynz" }]
]);

const LuMail = createLucideIcon("LuMail", [
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }],
  ["path", { d: "m22 7-8.97 5.7a1.94 1.94 0 0 1-2.06 0L2 7", key: "1ocrg3" }]
]);

const LuMailbox = createLucideIcon("LuMailbox", [
  [
    "path",
    {
      d: "M22 17a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V9.5C2 7 4 5 6.5 5H18c2.2 0 4 1.8 4 4v8Z",
      key: "1lbycx"
    }
  ],
  ["polyline", { points: "15,9 18,9 18,11", key: "1pm9c0" }],
  ["path", { d: "M6.5 5C9 5 11 7 11 9.5V17a2 2 0 0 1-2 2v0", key: "n6nfvi" }],
  ["line", { x1: "6", x2: "7", y1: "10", y2: "10", key: "1e2scm" }]
]);

const LuMails = createLucideIcon("LuMails", [
  ["rect", { width: "16", height: "13", x: "6", y: "4", rx: "2", key: "1drq3f" }],
  ["path", { d: "m22 7-7.1 3.78c-.57.3-1.23.3-1.8 0L6 7", key: "xn252p" }],
  ["path", { d: "M2 8v11c0 1.1.9 2 2 2h14", key: "n13cji" }]
]);

const LuMapPinOff = createLucideIcon("LuMapPinOff", [
  [
    "path",
    { d: "M5.43 5.43A8.06 8.06 0 0 0 4 10c0 6 8 12 8 12a29.94 29.94 0 0 0 5-5", key: "12a8pk" }
  ],
  [
    "path",
    {
      d: "M19.18 13.52A8.66 8.66 0 0 0 20 10a8 8 0 0 0-8-8 7.88 7.88 0 0 0-3.52.82",
      key: "1r9f6y"
    }
  ],
  [
    "path",
    { d: "M9.13 9.13A2.78 2.78 0 0 0 9 10a3 3 0 0 0 3 3 2.78 2.78 0 0 0 .87-.13", key: "erynq7" }
  ],
  ["path", { d: "M14.9 9.25a3 3 0 0 0-2.15-2.16", key: "1hwwmx" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuMapPin = createLucideIcon("LuMapPin", [
  ["path", { d: "M20 10c0 6-8 12-8 12s-8-6-8-12a8 8 0 0 1 16 0Z", key: "2oe9fu" }],
  ["circle", { cx: "12", cy: "10", r: "3", key: "ilqhr7" }]
]);

const LuMapPinned = createLucideIcon("LuMapPinned", [
  ["path", { d: "M18 8c0 4.5-6 9-6 9s-6-4.5-6-9a6 6 0 0 1 12 0", key: "yrbn30" }],
  ["circle", { cx: "12", cy: "8", r: "2", key: "1822b1" }],
  [
    "path",
    {
      d: "M8.835 14H5a1 1 0 0 0-.9.7l-2 6c-.1.1-.1.2-.1.3 0 .6.4 1 1 1h18c.6 0 1-.4 1-1 0-.1 0-.2-.1-.3l-2-6a1 1 0 0 0-.9-.7h-3.835",
      key: "112zkj"
    }
  ]
]);

const LuMap = createLucideIcon("LuMap", [
  ["polygon", { points: "3 6 9 3 15 6 21 3 21 18 15 21 9 18 3 21", key: "ok2ie8" }],
  ["line", { x1: "9", x2: "9", y1: "3", y2: "18", key: "w34qz5" }],
  ["line", { x1: "15", x2: "15", y1: "6", y2: "21", key: "volv9a" }]
]);

const LuMartini = createLucideIcon("LuMartini", [
  ["path", { d: "M8 22h8", key: "rmew8v" }],
  ["path", { d: "M12 11v11", key: "ur9y6a" }],
  ["path", { d: "m19 3-7 8-7-8Z", key: "1sgpiw" }]
]);

const LuMaximize2 = createLucideIcon("LuMaximize2", [
  ["polyline", { points: "15 3 21 3 21 9", key: "mznyad" }],
  ["polyline", { points: "9 21 3 21 3 15", key: "1avn1i" }],
  ["line", { x1: "21", x2: "14", y1: "3", y2: "10", key: "ota7mn" }],
  ["line", { x1: "3", x2: "10", y1: "21", y2: "14", key: "1atl0r" }]
]);

const LuMaximize = createLucideIcon("LuMaximize", [
  ["path", { d: "M8 3H5a2 2 0 0 0-2 2v3", key: "1dcmit" }],
  ["path", { d: "M21 8V5a2 2 0 0 0-2-2h-3", key: "1e4gt3" }],
  ["path", { d: "M3 16v3a2 2 0 0 0 2 2h3", key: "wsl5sc" }],
  ["path", { d: "M16 21h3a2 2 0 0 0 2-2v-3", key: "18trek" }]
]);

const LuMedal = createLucideIcon("LuMedal", [
  [
    "path",
    {
      d: "M7.21 15 2.66 7.14a2 2 0 0 1 .13-2.2L4.4 2.8A2 2 0 0 1 6 2h12a2 2 0 0 1 1.6.8l1.6 2.14a2 2 0 0 1 .14 2.2L16.79 15",
      key: "143lza"
    }
  ],
  ["path", { d: "M11 12 5.12 2.2", key: "qhuxz6" }],
  ["path", { d: "m13 12 5.88-9.8", key: "hbye0f" }],
  ["path", { d: "M8 7h8", key: "i86dvs" }],
  ["circle", { cx: "12", cy: "17", r: "5", key: "qbz8iq" }],
  ["path", { d: "M12 18v-2h-.5", key: "fawc4q" }]
]);

const LuMegaphoneOff = createLucideIcon("LuMegaphoneOff", [
  ["path", { d: "M9.26 9.26 3 11v3l14.14 3.14", key: "3429n" }],
  ["path", { d: "M21 15.34V6l-7.31 2.03", key: "4o1dh8" }],
  ["path", { d: "M11.6 16.8a3 3 0 1 1-5.8-1.6", key: "1yl0tm" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuMegaphone = createLucideIcon("LuMegaphone", [
  ["path", { d: "m3 11 18-5v12L3 14v-3z", key: "n962bs" }],
  ["path", { d: "M11.6 16.8a3 3 0 1 1-5.8-1.6", key: "1yl0tm" }]
]);

const LuMeh = createLucideIcon("LuMeh", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["line", { x1: "8", x2: "16", y1: "15", y2: "15", key: "1xb1d9" }],
  ["line", { x1: "9", x2: "9.01", y1: "9", y2: "9", key: "yxxnd0" }],
  ["line", { x1: "15", x2: "15.01", y1: "9", y2: "9", key: "1p4y9e" }]
]);

const LuMemoryStick = createLucideIcon("LuMemoryStick", [
  ["path", { d: "M6 19v-3", key: "1nvgqn" }],
  ["path", { d: "M10 19v-3", key: "iu8nkm" }],
  ["path", { d: "M14 19v-3", key: "kcehxu" }],
  ["path", { d: "M18 19v-3", key: "1vh91z" }],
  ["path", { d: "M8 11V9", key: "63erz4" }],
  ["path", { d: "M16 11V9", key: "fru6f3" }],
  ["path", { d: "M12 11V9", key: "ha00sb" }],
  ["path", { d: "M2 15h20", key: "16ne18" }],
  [
    "path",
    {
      d: "M2 7a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v1.1a2 2 0 0 0 0 3.837V17a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-5.1a2 2 0 0 0 0-3.837Z",
      key: "lhddv3"
    }
  ]
]);

const LuMenu = createLucideIcon("LuMenu", [
  ["line", { x1: "4", x2: "20", y1: "12", y2: "12", key: "1e0a9i" }],
  ["line", { x1: "4", x2: "20", y1: "6", y2: "6", key: "1owob3" }],
  ["line", { x1: "4", x2: "20", y1: "18", y2: "18", key: "yk5zj1" }]
]);

const LuMerge = createLucideIcon("LuMerge", [
  ["path", { d: "m8 6 4-4 4 4", key: "ybng9g" }],
  ["path", { d: "M12 2v10.3a4 4 0 0 1-1.172 2.872L4 22", key: "1hyw0i" }],
  ["path", { d: "m20 22-5-5", key: "1m27yz" }]
]);

const LuMessageCircleCode = createLucideIcon("LuMessageCircleCode", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }],
  ["path", { d: "m10 10-2 2 2 2", key: "p6et6i" }],
  ["path", { d: "m14 10 2 2-2 2", key: "1kkmpt" }]
]);

const LuMessageCircleDashed = createLucideIcon("LuMessageCircleDashed", [
  ["path", { d: "M13.5 3.1c-.5 0-1-.1-1.5-.1s-1 .1-1.5.1", key: "16ll65" }],
  ["path", { d: "M19.3 6.8a10.45 10.45 0 0 0-2.1-2.1", key: "1nq77a" }],
  ["path", { d: "M20.9 13.5c.1-.5.1-1 .1-1.5s-.1-1-.1-1.5", key: "1sf7wn" }],
  ["path", { d: "M17.2 19.3a10.45 10.45 0 0 0 2.1-2.1", key: "x1hs5g" }],
  ["path", { d: "M10.5 20.9c.5.1 1 .1 1.5.1s1-.1 1.5-.1", key: "19m18z" }],
  ["path", { d: "M3.5 17.5 2 22l4.5-1.5", key: "1f36qi" }],
  ["path", { d: "M3.1 10.5c0 .5-.1 1-.1 1.5s.1 1 .1 1.5", key: "1vz3ju" }],
  ["path", { d: "M6.8 4.7a10.45 10.45 0 0 0-2.1 2.1", key: "19f9do" }]
]);

const LuMessageCircleHeart = createLucideIcon("LuMessageCircleHeart", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }],
  [
    "path",
    {
      d: "M15.8 9.2a2.5 2.5 0 0 0-3.5 0l-.3.4-.35-.3a2.42 2.42 0 1 0-3.2 3.6l3.6 3.5 3.6-3.5c1.2-1.2 1.1-2.7.2-3.7",
      key: "43lnbm"
    }
  ]
]);

const LuMessageCircleMore = createLucideIcon("LuMessageCircleMore", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }],
  ["path", { d: "M8 12h.01", key: "czm47f" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }],
  ["path", { d: "M16 12h.01", key: "1l6xoz" }]
]);

const LuMessageCircleOff = createLucideIcon("LuMessageCircleOff", [
  ["path", { d: "M20.5 14.9A9 9 0 0 0 9.1 3.5", key: "1iebmn" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M5.6 5.6C3 8.3 2.2 12.5 4 16l-2 6 6-2c3.4 1.8 7.6 1.1 10.3-1.7", key: "1ov8ce" }]
]);

const LuMessageCirclePlus = createLucideIcon("LuMessageCirclePlus", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["path", { d: "M12 8v8", key: "napkw2" }]
]);

const LuMessageCircleQuestion = createLucideIcon("LuMessageCircleQuestion", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }],
  ["path", { d: "M9.09 9a3 3 0 0 1 5.83 1c0 2-3 3-3 3", key: "1u773s" }],
  ["path", { d: "M12 17h.01", key: "p32p05" }]
]);

const LuMessageCircleReply = createLucideIcon("LuMessageCircleReply", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }],
  ["path", { d: "m10 15-3-3 3-3", key: "1pgupc" }],
  ["path", { d: "M7 12h7a2 2 0 0 1 2 2v1", key: "1gheu4" }]
]);

const LuMessageCircleWarning = createLucideIcon("LuMessageCircleWarning", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }],
  ["path", { d: "M12 8v4", key: "1got3b" }],
  ["path", { d: "M12 16h.01", key: "1drbdi" }]
]);

const LuMessageCircleX = createLucideIcon("LuMessageCircleX", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }],
  ["path", { d: "m15 9-6 6", key: "1uzhvr" }],
  ["path", { d: "m9 9 6 6", key: "z0biqf" }]
]);

const LuMessageCircle = createLucideIcon("LuMessageCircle", [
  ["path", { d: "M7.9 20A9 9 0 1 0 4 16.1L2 22Z", key: "vv11sd" }]
]);

const LuMessageSquareCode = createLucideIcon("LuMessageSquareCode", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  ["path", { d: "m10 8-2 2 2 2", key: "19bv1o" }],
  ["path", { d: "m14 8 2 2-2 2", key: "1whylv" }]
]);

const LuMessageSquareDashed = createLucideIcon("LuMessageSquareDashed", [
  ["path", { d: "M3 6V5c0-1.1.9-2 2-2h2", key: "9usibi" }],
  ["path", { d: "M11 3h3", key: "1c3ji7" }],
  ["path", { d: "M18 3h1c1.1 0 2 .9 2 2", key: "19esxn" }],
  ["path", { d: "M21 9v2", key: "p14lih" }],
  ["path", { d: "M21 15c0 1.1-.9 2-2 2h-1", key: "1fo1j8" }],
  ["path", { d: "M14 17h-3", key: "1w4p2m" }],
  ["path", { d: "m7 17-4 4v-5", key: "ph9x1h" }],
  ["path", { d: "M3 12v-2", key: "856n1q" }]
]);

const LuMessageSquareDiff = createLucideIcon("LuMessageSquareDiff", [
  ["path", { d: "m5 19-2 2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2", key: "1xuzuj" }],
  ["path", { d: "M9 10h6", key: "9gxzsh" }],
  ["path", { d: "M12 7v6", key: "lw1j43" }],
  ["path", { d: "M9 17h6", key: "r8uit2" }]
]);

const LuMessageSquareDot = createLucideIcon("LuMessageSquareDot", [
  ["path", { d: "M11.7 3H5a2 2 0 0 0-2 2v16l4-4h12a2 2 0 0 0 2-2v-2.7", key: "uodpkb" }],
  ["circle", { cx: "18", cy: "6", r: "3", key: "1h7g24" }]
]);

const LuMessageSquareHeart = createLucideIcon("LuMessageSquareHeart", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  [
    "path",
    {
      d: "M14.8 7.5a1.84 1.84 0 0 0-2.6 0l-.2.3-.3-.3a1.84 1.84 0 1 0-2.4 2.8L12 13l2.7-2.7c.9-.9.8-2.1.1-2.8",
      key: "1blaws"
    }
  ]
]);

const LuMessageSquareMore = createLucideIcon("LuMessageSquareMore", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  ["path", { d: "M8 10h.01", key: "19clt8" }],
  ["path", { d: "M12 10h.01", key: "1nrarc" }],
  ["path", { d: "M16 10h.01", key: "1m94wz" }]
]);

const LuMessageSquareOff = createLucideIcon("LuMessageSquareOff", [
  ["path", { d: "M21 15V5a2 2 0 0 0-2-2H9", key: "43el77" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M3.6 3.6c-.4.3-.6.8-.6 1.4v16l4-4h10", key: "pwpm4a" }]
]);

const LuMessageSquarePlus = createLucideIcon("LuMessageSquarePlus", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  ["path", { d: "M12 7v6", key: "lw1j43" }],
  ["path", { d: "M9 10h6", key: "9gxzsh" }]
]);

const LuMessageSquareQuote = createLucideIcon("LuMessageSquareQuote", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  ["path", { d: "M8 12a2 2 0 0 0 2-2V8H8", key: "1jfesj" }],
  ["path", { d: "M14 12a2 2 0 0 0 2-2V8h-2", key: "1dq9mh" }]
]);

const LuMessageSquareReply = createLucideIcon("LuMessageSquareReply", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  ["path", { d: "m10 7-3 3 3 3", key: "1eugdv" }],
  ["path", { d: "M17 13v-1a2 2 0 0 0-2-2H7", key: "ernfh3" }]
]);

const LuMessageSquareShare = createLucideIcon("LuMessageSquareShare", [
  ["path", { d: "M21 12v3a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h7", key: "tqtdkg" }],
  ["path", { d: "M16 3h5v5", key: "1806ms" }],
  ["path", { d: "m16 8 5-5", key: "15mbrl" }]
]);

const LuMessageSquareText = createLucideIcon("LuMessageSquareText", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  ["path", { d: "M13 8H7", key: "14i4kc" }],
  ["path", { d: "M17 12H7", key: "16if0g" }]
]);

const LuMessageSquareWarning = createLucideIcon("LuMessageSquareWarning", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  ["path", { d: "M12 7v2", key: "stiyo7" }],
  ["path", { d: "M12 13h.01", key: "y0uutt" }]
]);

const LuMessageSquareX = createLucideIcon("LuMessageSquareX", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }],
  ["path", { d: "m14.5 7.5-5 5", key: "3lb6iw" }],
  ["path", { d: "m9.5 7.5 5 5", key: "ko136h" }]
]);

const LuMessageSquare = createLucideIcon("LuMessageSquare", [
  ["path", { d: "M21 15a2 2 0 0 1-2 2H7l-4 4V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2z", key: "1lielz" }]
]);

const LuMessagesSquare = createLucideIcon("LuMessagesSquare", [
  ["path", { d: "M14 9a2 2 0 0 1-2 2H6l-4 4V4c0-1.1.9-2 2-2h8a2 2 0 0 1 2 2z", key: "jj09z8" }],
  ["path", { d: "M18 9h2a2 2 0 0 1 2 2v11l-4-4h-6a2 2 0 0 1-2-2v-1", key: "1cx29u" }]
]);

const LuMicOff = createLucideIcon("LuMicOff", [
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }],
  ["path", { d: "M18.89 13.23A7.12 7.12 0 0 0 19 12v-2", key: "80xlxr" }],
  ["path", { d: "M5 10v2a7 7 0 0 0 12 5", key: "p2k8kg" }],
  ["path", { d: "M15 9.34V5a3 3 0 0 0-5.68-1.33", key: "1gzdoj" }],
  ["path", { d: "M9 9v3a3 3 0 0 0 5.12 2.12", key: "r2i35w" }],
  ["line", { x1: "12", x2: "12", y1: "19", y2: "22", key: "x3vr5v" }]
]);

const LuMicVocal = createLucideIcon("LuMicVocal", [
  ["path", { d: "m12 8-9.04 9.06a2.82 2.82 0 1 0 3.98 3.98L16 12", key: "zoua8r" }],
  ["circle", { cx: "17", cy: "7", r: "5", key: "1fomce" }]
]);

const LuMic = createLucideIcon("LuMic", [
  ["path", { d: "M12 2a3 3 0 0 0-3 3v7a3 3 0 0 0 6 0V5a3 3 0 0 0-3-3Z", key: "131961" }],
  ["path", { d: "M19 10v2a7 7 0 0 1-14 0v-2", key: "1vc78b" }],
  ["line", { x1: "12", x2: "12", y1: "19", y2: "22", key: "x3vr5v" }]
]);

const LuMicroscope = createLucideIcon("LuMicroscope", [
  ["path", { d: "M6 18h8", key: "1borvv" }],
  ["path", { d: "M3 22h18", key: "8prr45" }],
  ["path", { d: "M14 22a7 7 0 1 0 0-14h-1", key: "1jwaiy" }],
  ["path", { d: "M9 14h2", key: "197e7h" }],
  ["path", { d: "M9 12a2 2 0 0 1-2-2V6h6v4a2 2 0 0 1-2 2Z", key: "1bmzmy" }],
  ["path", { d: "M12 6V3a1 1 0 0 0-1-1H9a1 1 0 0 0-1 1v3", key: "1drr47" }]
]);

const LuMicrowave = createLucideIcon("LuMicrowave", [
  ["rect", { width: "20", height: "15", x: "2", y: "4", rx: "2", key: "2no95f" }],
  ["rect", { width: "8", height: "7", x: "6", y: "8", rx: "1", key: "zh9wx" }],
  ["path", { d: "M18 8v7", key: "o5zi4n" }],
  ["path", { d: "M6 19v2", key: "1loha6" }],
  ["path", { d: "M18 19v2", key: "1dawf0" }]
]);

const LuMilestone = createLucideIcon("LuMilestone", [
  ["path", { d: "M18 6H5a2 2 0 0 0-2 2v3a2 2 0 0 0 2 2h13l4-3.5L18 6Z", key: "1mp5s7" }],
  ["path", { d: "M12 13v8", key: "1l5pq0" }],
  ["path", { d: "M12 3v3", key: "1n5kay" }]
]);

const LuMilkOff = createLucideIcon("LuMilkOff", [
  ["path", { d: "M8 2h8", key: "1ssgc1" }],
  [
    "path",
    {
      d: "M9 2v1.343M15 2v2.789a4 4 0 0 0 .672 2.219l.656.984a4 4 0 0 1 .672 2.22v1.131M7.8 7.8l-.128.192A4 4 0 0 0 7 10.212V20a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-3",
      key: "y0ejgx"
    }
  ],
  ["path", { d: "M7 15a6.47 6.47 0 0 1 5 0 6.472 6.472 0 0 0 3.435.435", key: "iaxqsy" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuMilk = createLucideIcon("LuMilk", [
  ["path", { d: "M8 2h8", key: "1ssgc1" }],
  [
    "path",
    {
      d: "M9 2v2.789a4 4 0 0 1-.672 2.219l-.656.984A4 4 0 0 0 7 10.212V20a2 2 0 0 0 2 2h6a2 2 0 0 0 2-2v-9.789a4 4 0 0 0-.672-2.219l-.656-.984A4 4 0 0 1 15 4.788V2",
      key: "qtp12x"
    }
  ],
  ["path", { d: "M7 15a6.472 6.472 0 0 1 5 0 6.47 6.47 0 0 0 5 0", key: "ygeh44" }]
]);

const LuMinimize2 = createLucideIcon("LuMinimize2", [
  ["polyline", { points: "4 14 10 14 10 20", key: "11kfnr" }],
  ["polyline", { points: "20 10 14 10 14 4", key: "rlmsce" }],
  ["line", { x1: "14", x2: "21", y1: "10", y2: "3", key: "o5lafz" }],
  ["line", { x1: "3", x2: "10", y1: "21", y2: "14", key: "1atl0r" }]
]);

const LuMinimize = createLucideIcon("LuMinimize", [
  ["path", { d: "M8 3v3a2 2 0 0 1-2 2H3", key: "hohbtr" }],
  ["path", { d: "M21 8h-3a2 2 0 0 1-2-2V3", key: "5jw1f3" }],
  ["path", { d: "M3 16h3a2 2 0 0 1 2 2v3", key: "198tvr" }],
  ["path", { d: "M16 21v-3a2 2 0 0 1 2-2h3", key: "ph8mxp" }]
]);

const LuMinus = createLucideIcon("LuMinus", [["path", { d: "M5 12h14", key: "1ays0h" }]]);

const LuMonitorCheck = createLucideIcon("LuMonitorCheck", [
  ["path", { d: "m9 10 2 2 4-4", key: "1gnqz4" }],
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }]
]);

const LuMonitorDot = createLucideIcon("LuMonitorDot", [
  ["circle", { cx: "19", cy: "6", r: "3", key: "108a5v" }],
  ["path", { d: "M22 12v3a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h9", key: "1fet9y" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }]
]);

const LuMonitorDown = createLucideIcon("LuMonitorDown", [
  ["path", { d: "M12 13V7", key: "h0r20n" }],
  ["path", { d: "m15 10-3 3-3-3", key: "lzhmyn" }],
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }]
]);

const LuMonitorOff = createLucideIcon("LuMonitorOff", [
  ["path", { d: "M17 17H4a2 2 0 0 1-2-2V5c0-1.5 1-2 1-2", key: "k0q8oc" }],
  ["path", { d: "M22 15V5a2 2 0 0 0-2-2H9", key: "cp1ac0" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuMonitorPause = createLucideIcon("LuMonitorPause", [
  ["path", { d: "M10 13V7", key: "1u13u9" }],
  ["path", { d: "M14 13V7", key: "1vj9om" }],
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }]
]);

const LuMonitorPlay = createLucideIcon("LuMonitorPlay", [
  ["path", { d: "m10 7 5 3-5 3Z", key: "29ljg6" }],
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }]
]);

const LuMonitorSmartphone = createLucideIcon("LuMonitorSmartphone", [
  ["path", { d: "M18 8V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v7a2 2 0 0 0 2 2h8", key: "10dyio" }],
  ["path", { d: "M10 19v-3.96 3.15", key: "1irgej" }],
  ["path", { d: "M7 19h5", key: "qswx4l" }],
  ["rect", { width: "6", height: "10", x: "16", y: "12", rx: "2", key: "1egngj" }]
]);

const LuMonitorSpeaker = createLucideIcon("LuMonitorSpeaker", [
  ["path", { d: "M5.5 20H8", key: "1k40s5" }],
  ["path", { d: "M17 9h.01", key: "1j24nn" }],
  ["rect", { width: "10", height: "16", x: "12", y: "4", rx: "2", key: "ixliua" }],
  ["path", { d: "M8 6H4a2 2 0 0 0-2 2v6a2 2 0 0 0 2 2h4", key: "1mp6e1" }],
  ["circle", { cx: "17", cy: "15", r: "1", key: "tqvash" }]
]);

const LuMonitorStop = createLucideIcon("LuMonitorStop", [
  ["rect", { x: "9", y: "7", width: "6", height: "6", key: "4xvc6r" }],
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }]
]);

const LuMonitorUp = createLucideIcon("LuMonitorUp", [
  ["path", { d: "m9 10 3-3 3 3", key: "11gsxs" }],
  ["path", { d: "M12 13V7", key: "h0r20n" }],
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }]
]);

const LuMonitorX = createLucideIcon("LuMonitorX", [
  ["path", { d: "m14.5 12.5-5-5", key: "1jahn5" }],
  ["path", { d: "m9.5 12.5 5-5", key: "1k2t7b" }],
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }]
]);

const LuMonitor = createLucideIcon("LuMonitor", [
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }],
  ["line", { x1: "8", x2: "16", y1: "21", y2: "21", key: "1svkeh" }],
  ["line", { x1: "12", x2: "12", y1: "17", y2: "21", key: "vw1qmm" }]
]);

const LuMoonStar = createLucideIcon("LuMoonStar", [
  ["path", { d: "M12 3a6 6 0 0 0 9 9 9 9 0 1 1-9-9Z", key: "a7tn18" }],
  ["path", { d: "M19 3v4", key: "vgv24u" }],
  ["path", { d: "M21 5h-4", key: "1wcg1f" }]
]);

const LuMoon = createLucideIcon("LuMoon", [
  ["path", { d: "M12 3a6 6 0 0 0 9 9 9 9 0 1 1-9-9Z", key: "a7tn18" }]
]);

const LuMountainSnow = createLucideIcon("LuMountainSnow", [
  ["path", { d: "m8 3 4 8 5-5 5 15H2L8 3z", key: "otkl63" }],
  [
    "path",
    { d: "M4.14 15.08c2.62-1.57 5.24-1.43 7.86.42 2.74 1.94 5.49 2 8.23.19", key: "1pvmmp" }
  ]
]);

const LuMountain = createLucideIcon("LuMountain", [
  ["path", { d: "m8 3 4 8 5-5 5 15H2L8 3z", key: "otkl63" }]
]);

const LuMousePointer2 = createLucideIcon("LuMousePointer2", [
  ["path", { d: "m4 4 7.07 17 2.51-7.39L21 11.07z", key: "1vqm48" }]
]);

const LuMousePointerClick = createLucideIcon("LuMousePointerClick", [
  ["path", { d: "m9 9 5 12 1.8-5.2L21 14Z", key: "1b76lo" }],
  ["path", { d: "M7.2 2.2 8 5.1", key: "1cfko1" }],
  ["path", { d: "m5.1 8-2.9-.8", key: "1go3kf" }],
  ["path", { d: "M14 4.1 12 6", key: "ita8i4" }],
  ["path", { d: "m6 12-1.9 2", key: "mnht97" }]
]);

const LuMousePointer = createLucideIcon("LuMousePointer", [
  ["path", { d: "m3 3 7.07 16.97 2.51-7.39 7.39-2.51L3 3z", key: "y2ucgo" }],
  ["path", { d: "m13 13 6 6", key: "1nhxnf" }]
]);

const LuMouse = createLucideIcon("LuMouse", [
  ["rect", { x: "5", y: "2", width: "14", height: "20", rx: "7", key: "11ol66" }],
  ["path", { d: "M12 6v4", key: "16clxf" }]
]);

const LuMove3d = createLucideIcon("LuMove3d", [
  ["path", { d: "M5 3v16h16", key: "1mqmf9" }],
  ["path", { d: "m5 19 6-6", key: "jh6hbb" }],
  ["path", { d: "m2 6 3-3 3 3", key: "tkyvxa" }],
  ["path", { d: "m18 16 3 3-3 3", key: "1d4glt" }]
]);

const LuMoveDiagonal2 = createLucideIcon("LuMoveDiagonal2", [
  ["polyline", { points: "5 11 5 5 11 5", key: "ncfzxk" }],
  ["polyline", { points: "19 13 19 19 13 19", key: "1mk7hk" }],
  ["line", { x1: "5", x2: "19", y1: "5", y2: "19", key: "mcyte3" }]
]);

const LuMoveDiagonal = createLucideIcon("LuMoveDiagonal", [
  ["polyline", { points: "13 5 19 5 19 11", key: "11219e" }],
  ["polyline", { points: "11 19 5 19 5 13", key: "sfq3wq" }],
  ["line", { x1: "19", x2: "5", y1: "5", y2: "19", key: "1x9vlm" }]
]);

const LuMoveDownLeft = createLucideIcon("LuMoveDownLeft", [
  ["path", { d: "M11 19H5V13", key: "1akmht" }],
  ["path", { d: "M19 5L5 19", key: "72u4yj" }]
]);

const LuMoveDownRight = createLucideIcon("LuMoveDownRight", [
  ["path", { d: "M19 13V19H13", key: "10vkzq" }],
  ["path", { d: "M5 5L19 19", key: "5zm2fv" }]
]);

const LuMoveDown = createLucideIcon("LuMoveDown", [
  ["path", { d: "M8 18L12 22L16 18", key: "cskvfv" }],
  ["path", { d: "M12 2V22", key: "r89rzk" }]
]);

const LuMoveHorizontal = createLucideIcon("LuMoveHorizontal", [
  ["polyline", { points: "18 8 22 12 18 16", key: "1hqrds" }],
  ["polyline", { points: "6 8 2 12 6 16", key: "f0ernq" }],
  ["line", { x1: "2", x2: "22", y1: "12", y2: "12", key: "1dnqot" }]
]);

const LuMoveLeft = createLucideIcon("LuMoveLeft", [
  ["path", { d: "M6 8L2 12L6 16", key: "kyvwex" }],
  ["path", { d: "M2 12H22", key: "1m8cig" }]
]);

const LuMoveRight = createLucideIcon("LuMoveRight", [
  ["path", { d: "M18 8L22 12L18 16", key: "1r0oui" }],
  ["path", { d: "M2 12H22", key: "1m8cig" }]
]);

const LuMoveUpLeft = createLucideIcon("LuMoveUpLeft", [
  ["path", { d: "M5 11V5H11", key: "3q78g9" }],
  ["path", { d: "M5 5L19 19", key: "5zm2fv" }]
]);

const LuMoveUpRight = createLucideIcon("LuMoveUpRight", [
  ["path", { d: "M13 5H19V11", key: "1n1gyv" }],
  ["path", { d: "M19 5L5 19", key: "72u4yj" }]
]);

const LuMoveUp = createLucideIcon("LuMoveUp", [
  ["path", { d: "M8 6L12 2L16 6", key: "1yvkyx" }],
  ["path", { d: "M12 2V22", key: "r89rzk" }]
]);

const LuMoveVertical = createLucideIcon("LuMoveVertical", [
  ["polyline", { points: "8 18 12 22 16 18", key: "1uutw3" }],
  ["polyline", { points: "8 6 12 2 16 6", key: "d60sxy" }],
  ["line", { x1: "12", x2: "12", y1: "2", y2: "22", key: "7eqyqh" }]
]);

const LuMove = createLucideIcon("LuMove", [
  ["polyline", { points: "5 9 2 12 5 15", key: "1r5uj5" }],
  ["polyline", { points: "9 5 12 2 15 5", key: "5v383o" }],
  ["polyline", { points: "15 19 12 22 9 19", key: "g7qi8m" }],
  ["polyline", { points: "19 9 22 12 19 15", key: "tpp73q" }],
  ["line", { x1: "2", x2: "22", y1: "12", y2: "12", key: "1dnqot" }],
  ["line", { x1: "12", x2: "12", y1: "2", y2: "22", key: "7eqyqh" }]
]);

const LuMusic2 = createLucideIcon("LuMusic2", [
  ["circle", { cx: "8", cy: "18", r: "4", key: "1fc0mg" }],
  ["path", { d: "M12 18V2l7 4", key: "g04rme" }]
]);

const LuMusic3 = createLucideIcon("LuMusic3", [
  ["circle", { cx: "12", cy: "18", r: "4", key: "m3r9ws" }],
  ["path", { d: "M16 18V2", key: "40x2m5" }]
]);

const LuMusic4 = createLucideIcon("LuMusic4", [
  ["path", { d: "M9 18V5l12-2v13", key: "1jmyc2" }],
  ["path", { d: "m9 9 12-2", key: "1e64n2" }],
  ["circle", { cx: "6", cy: "18", r: "3", key: "fqmcym" }],
  ["circle", { cx: "18", cy: "16", r: "3", key: "1hluhg" }]
]);

const LuMusic = createLucideIcon("LuMusic", [
  ["path", { d: "M9 18V5l12-2v13", key: "1jmyc2" }],
  ["circle", { cx: "6", cy: "18", r: "3", key: "fqmcym" }],
  ["circle", { cx: "18", cy: "16", r: "3", key: "1hluhg" }]
]);

const LuNavigation2Off = createLucideIcon("LuNavigation2Off", [
  ["path", { d: "M9.31 9.31 5 21l7-4 7 4-1.17-3.17", key: "qoq2o2" }],
  ["path", { d: "M14.53 8.88 12 2l-1.17 3.17", key: "k3sjzy" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuNavigation2 = createLucideIcon("LuNavigation2", [
  ["polygon", { points: "12 2 19 21 12 17 5 21 12 2", key: "x8c0qg" }]
]);

const LuNavigationOff = createLucideIcon("LuNavigationOff", [
  ["path", { d: "M8.43 8.43 3 11l8 2 2 8 2.57-5.43", key: "1vdtb7" }],
  ["path", { d: "M17.39 11.73 22 2l-9.73 4.61", key: "tya3r6" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuNavigation = createLucideIcon("LuNavigation", [
  ["polygon", { points: "3 11 22 2 13 21 11 13 3 11", key: "1ltx0t" }]
]);

const LuNetwork = createLucideIcon("LuNetwork", [
  ["rect", { x: "16", y: "16", width: "6", height: "6", rx: "1", key: "4q2zg0" }],
  ["rect", { x: "2", y: "16", width: "6", height: "6", rx: "1", key: "8cvhb9" }],
  ["rect", { x: "9", y: "2", width: "6", height: "6", rx: "1", key: "1egb70" }],
  ["path", { d: "M5 16v-3a1 1 0 0 1 1-1h12a1 1 0 0 1 1 1v3", key: "1jsf9p" }],
  ["path", { d: "M12 12V8", key: "2874zd" }]
]);

const LuNewspaper = createLucideIcon("LuNewspaper", [
  [
    "path",
    {
      d: "M4 22h16a2 2 0 0 0 2-2V4a2 2 0 0 0-2-2H8a2 2 0 0 0-2 2v16a2 2 0 0 1-2 2Zm0 0a2 2 0 0 1-2-2v-9c0-1.1.9-2 2-2h2",
      key: "7pis2x"
    }
  ],
  ["path", { d: "M18 14h-8", key: "sponae" }],
  ["path", { d: "M15 18h-5", key: "95g1m2" }],
  ["path", { d: "M10 6h8v4h-8V6Z", key: "smlsk5" }]
]);

const LuNfc = createLucideIcon("LuNfc", [
  ["path", { d: "M6 8.32a7.43 7.43 0 0 1 0 7.36", key: "9iaqei" }],
  ["path", { d: "M9.46 6.21a11.76 11.76 0 0 1 0 11.58", key: "1yha7l" }],
  ["path", { d: "M12.91 4.1a15.91 15.91 0 0 1 .01 15.8", key: "4iu2gk" }],
  ["path", { d: "M16.37 2a20.16 20.16 0 0 1 0 20", key: "sap9u2" }]
]);

const LuNotebookPen = createLucideIcon("LuNotebookPen", [
  ["path", { d: "M13.4 2H6a2 2 0 0 0-2 2v16a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-7.4", key: "re6nr2" }],
  ["path", { d: "M2 6h4", key: "aawbzj" }],
  ["path", { d: "M2 10h4", key: "l0bgd4" }],
  ["path", { d: "M2 14h4", key: "1gsvsf" }],
  ["path", { d: "M2 18h4", key: "1bu2t1" }],
  ["path", { d: "M18.4 2.6a2.17 2.17 0 0 1 3 3L16 11l-4 1 1-4Z", key: "1dba1m" }]
]);

const LuNotebookTabs = createLucideIcon("LuNotebookTabs", [
  ["path", { d: "M2 6h4", key: "aawbzj" }],
  ["path", { d: "M2 10h4", key: "l0bgd4" }],
  ["path", { d: "M2 14h4", key: "1gsvsf" }],
  ["path", { d: "M2 18h4", key: "1bu2t1" }],
  ["rect", { width: "16", height: "20", x: "4", y: "2", rx: "2", key: "1nb95v" }],
  ["path", { d: "M15 2v20", key: "dcj49h" }],
  ["path", { d: "M15 7h5", key: "1xj5lc" }],
  ["path", { d: "M15 12h5", key: "w5shd9" }],
  ["path", { d: "M15 17h5", key: "1qaofu" }]
]);

const LuNotebookText = createLucideIcon("LuNotebookText", [
  ["path", { d: "M2 6h4", key: "aawbzj" }],
  ["path", { d: "M2 10h4", key: "l0bgd4" }],
  ["path", { d: "M2 14h4", key: "1gsvsf" }],
  ["path", { d: "M2 18h4", key: "1bu2t1" }],
  ["rect", { width: "16", height: "20", x: "4", y: "2", rx: "2", key: "1nb95v" }],
  ["path", { d: "M9.5 8h5", key: "11mslq" }],
  ["path", { d: "M9.5 12H16", key: "ktog6x" }],
  ["path", { d: "M9.5 16H14", key: "p1seyn" }]
]);

const LuNotebook = createLucideIcon("LuNotebook", [
  ["path", { d: "M2 6h4", key: "aawbzj" }],
  ["path", { d: "M2 10h4", key: "l0bgd4" }],
  ["path", { d: "M2 14h4", key: "1gsvsf" }],
  ["path", { d: "M2 18h4", key: "1bu2t1" }],
  ["rect", { width: "16", height: "20", x: "4", y: "2", rx: "2", key: "1nb95v" }],
  ["path", { d: "M16 2v20", key: "rotuqe" }]
]);

const LuNotepadTextDashed = createLucideIcon("LuNotepadTextDashed", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M12 2v4", key: "3427ic" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["path", { d: "M16 4h2a2 2 0 0 1 2 2v2", key: "j91f56" }],
  ["path", { d: "M20 12v2", key: "w8o0tu" }],
  ["path", { d: "M20 18v2a2 2 0 0 1-2 2h-1", key: "1c9ggx" }],
  ["path", { d: "M13 22h-2", key: "191ugt" }],
  ["path", { d: "M7 22H6a2 2 0 0 1-2-2v-2", key: "1rt9px" }],
  ["path", { d: "M4 14v-2", key: "1v0sqh" }],
  ["path", { d: "M4 8V6a2 2 0 0 1 2-2h2", key: "1mwabg" }],
  ["path", { d: "M8 10h6", key: "3oa6kw" }],
  ["path", { d: "M8 14h8", key: "1fgep2" }],
  ["path", { d: "M8 18h5", key: "17enja" }]
]);

const LuNotepadText = createLucideIcon("LuNotepadText", [
  ["path", { d: "M8 2v4", key: "1cmpym" }],
  ["path", { d: "M12 2v4", key: "3427ic" }],
  ["path", { d: "M16 2v4", key: "4m81vk" }],
  ["rect", { width: "16", height: "18", x: "4", y: "4", rx: "2", key: "1u9h20" }],
  ["path", { d: "M8 10h6", key: "3oa6kw" }],
  ["path", { d: "M8 14h8", key: "1fgep2" }],
  ["path", { d: "M8 18h5", key: "17enja" }]
]);

const LuNutOff = createLucideIcon("LuNutOff", [
  ["path", { d: "M12 4V2", key: "1k5q1u" }],
  [
    "path",
    {
      d: "M5 10v4a7.004 7.004 0 0 0 5.277 6.787c.412.104.802.292 1.102.592L12 22l.621-.621c.3-.3.69-.488 1.102-.592a7.01 7.01 0 0 0 4.125-2.939",
      key: "1xcvy9"
    }
  ],
  ["path", { d: "M19 10v3.343", key: "163tfc" }],
  [
    "path",
    {
      d: "M12 12c-1.349-.573-1.905-1.005-2.5-2-.546.902-1.048 1.353-2.5 2-1.018-.644-1.46-1.08-2-2-1.028.71-1.69.918-3 1 1.081-1.048 1.757-2.03 2-3 .194-.776.84-1.551 1.79-2.21m11.654 5.997c.887-.457 1.28-.891 1.556-1.787 1.032.916 1.683 1.157 3 1-1.297-1.036-1.758-2.03-2-3-.5-2-4-4-8-4-.74 0-1.461.068-2.15.192",
      key: "17914v"
    }
  ],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuNut = createLucideIcon("LuNut", [
  ["path", { d: "M12 4V2", key: "1k5q1u" }],
  [
    "path",
    {
      d: "M5 10v4a7.004 7.004 0 0 0 5.277 6.787c.412.104.802.292 1.102.592L12 22l.621-.621c.3-.3.69-.488 1.102-.592A7.003 7.003 0 0 0 19 14v-4",
      key: "1tgyif"
    }
  ],
  [
    "path",
    {
      d: "M12 4C8 4 4.5 6 4 8c-.243.97-.919 1.952-2 3 1.31-.082 1.972-.29 3-1 .54.92.982 1.356 2 2 1.452-.647 1.954-1.098 2.5-2 .595.995 1.151 1.427 2.5 2 1.31-.621 1.862-1.058 2.5-2 .629.977 1.162 1.423 2.5 2 1.209-.548 1.68-.967 2-2 1.032.916 1.683 1.157 3 1-1.297-1.036-1.758-2.03-2-3-.5-2-4-4-8-4Z",
      key: "tnsqj"
    }
  ]
]);

const LuOctagonAlert = createLucideIcon("LuOctagonAlert", [
  [
    "polygon",
    {
      points: "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2",
      key: "h1p8hx"
    }
  ],
  ["line", { x1: "12", x2: "12", y1: "8", y2: "12", key: "1pkeuh" }],
  ["line", { x1: "12", x2: "12.01", y1: "16", y2: "16", key: "4dfq90" }]
]);

const LuOctagonPause = createLucideIcon("LuOctagonPause", [
  ["path", { d: "M10 15V9", key: "1lckn7" }],
  ["path", { d: "M14 15V9", key: "1muqhk" }],
  ["path", { d: "M7.714 2h8.572L22 7.714v8.572L16.286 22H7.714L2 16.286V7.714z", key: "p5imkh" }]
]);

const LuOctagonX = createLucideIcon("LuOctagonX", [
  [
    "polygon",
    {
      points: "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2",
      key: "h1p8hx"
    }
  ],
  ["path", { d: "m15 9-6 6", key: "1uzhvr" }],
  ["path", { d: "m9 9 6 6", key: "z0biqf" }]
]);

const LuOctagon = createLucideIcon("LuOctagon", [
  [
    "polygon",
    {
      points: "7.86 2 16.14 2 22 7.86 22 16.14 16.14 22 7.86 22 2 16.14 2 7.86 7.86 2",
      key: "h1p8hx"
    }
  ]
]);

const LuOption = createLucideIcon("LuOption", [
  ["path", { d: "M3 3h6l6 18h6", key: "ph9rgk" }],
  ["path", { d: "M14 3h7", key: "16f0ms" }]
]);

const LuOrbit = createLucideIcon("LuOrbit", [
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  ["circle", { cx: "19", cy: "5", r: "2", key: "mhkx31" }],
  ["circle", { cx: "5", cy: "19", r: "2", key: "v8kfzx" }],
  ["path", { d: "M10.4 21.9a10 10 0 0 0 9.941-15.416", key: "eohfx2" }],
  ["path", { d: "M13.5 2.1a10 10 0 0 0-9.841 15.416", key: "19pvbm" }]
]);

const LuPackage2 = createLucideIcon("LuPackage2", [
  ["path", { d: "M3 9h18v10a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V9Z", key: "1ront0" }],
  ["path", { d: "m3 9 2.45-4.9A2 2 0 0 1 7.24 3h9.52a2 2 0 0 1 1.8 1.1L21 9", key: "19h2x1" }],
  ["path", { d: "M12 3v6", key: "1holv5" }]
]);

const LuPackageCheck = createLucideIcon("LuPackageCheck", [
  ["path", { d: "m16 16 2 2 4-4", key: "gfu2re" }],
  [
    "path",
    {
      d: "M21 10V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l2-1.14",
      key: "e7tb2h"
    }
  ],
  ["path", { d: "m7.5 4.27 9 5.15", key: "1c824w" }],
  ["polyline", { points: "3.29 7 12 12 20.71 7", key: "ousv84" }],
  ["line", { x1: "12", x2: "12", y1: "22", y2: "12", key: "a4e8g8" }]
]);

const LuPackageMinus = createLucideIcon("LuPackageMinus", [
  ["path", { d: "M16 16h6", key: "100bgy" }],
  [
    "path",
    {
      d: "M21 10V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l2-1.14",
      key: "e7tb2h"
    }
  ],
  ["path", { d: "m7.5 4.27 9 5.15", key: "1c824w" }],
  ["polyline", { points: "3.29 7 12 12 20.71 7", key: "ousv84" }],
  ["line", { x1: "12", x2: "12", y1: "22", y2: "12", key: "a4e8g8" }]
]);

const LuPackageOpen = createLucideIcon("LuPackageOpen", [
  ["path", { d: "M12 22v-9", key: "x3hkom" }],
  [
    "path",
    {
      d: "M15.17 2.21a1.67 1.67 0 0 1 1.63 0L21 4.57a1.93 1.93 0 0 1 0 3.36L8.82 14.79a1.655 1.655 0 0 1-1.64 0L3 12.43a1.93 1.93 0 0 1 0-3.36z",
      key: "2ntwy6"
    }
  ],
  [
    "path",
    {
      d: "M20 13v3.87a2.06 2.06 0 0 1-1.11 1.83l-6 3.08a1.93 1.93 0 0 1-1.78 0l-6-3.08A2.06 2.06 0 0 1 4 16.87V13",
      key: "1pmm1c"
    }
  ],
  [
    "path",
    {
      d: "M21 12.43a1.93 1.93 0 0 0 0-3.36L8.83 2.2a1.64 1.64 0 0 0-1.63 0L3 4.57a1.93 1.93 0 0 0 0 3.36l12.18 6.86a1.636 1.636 0 0 0 1.63 0z",
      key: "12ttoo"
    }
  ]
]);

const LuPackagePlus = createLucideIcon("LuPackagePlus", [
  ["path", { d: "M16 16h6", key: "100bgy" }],
  ["path", { d: "M19 13v6", key: "85cyf1" }],
  [
    "path",
    {
      d: "M21 10V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l2-1.14",
      key: "e7tb2h"
    }
  ],
  ["path", { d: "m7.5 4.27 9 5.15", key: "1c824w" }],
  ["polyline", { points: "3.29 7 12 12 20.71 7", key: "ousv84" }],
  ["line", { x1: "12", x2: "12", y1: "22", y2: "12", key: "a4e8g8" }]
]);

const LuPackageSearch = createLucideIcon("LuPackageSearch", [
  [
    "path",
    {
      d: "M21 10V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l2-1.14",
      key: "e7tb2h"
    }
  ],
  ["path", { d: "m7.5 4.27 9 5.15", key: "1c824w" }],
  ["polyline", { points: "3.29 7 12 12 20.71 7", key: "ousv84" }],
  ["line", { x1: "12", x2: "12", y1: "22", y2: "12", key: "a4e8g8" }],
  ["circle", { cx: "18.5", cy: "15.5", r: "2.5", key: "b5zd12" }],
  ["path", { d: "M20.27 17.27 22 19", key: "1l4muz" }]
]);

const LuPackageX = createLucideIcon("LuPackageX", [
  [
    "path",
    {
      d: "M21 10V8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l2-1.14",
      key: "e7tb2h"
    }
  ],
  ["path", { d: "m7.5 4.27 9 5.15", key: "1c824w" }],
  ["polyline", { points: "3.29 7 12 12 20.71 7", key: "ousv84" }],
  ["line", { x1: "12", x2: "12", y1: "22", y2: "12", key: "a4e8g8" }],
  ["path", { d: "m17 13 5 5m-5 0 5-5", key: "im3w4b" }]
]);

const LuPackage = createLucideIcon("LuPackage", [
  ["path", { d: "m7.5 4.27 9 5.15", key: "1c824w" }],
  [
    "path",
    {
      d: "M21 8a2 2 0 0 0-1-1.73l-7-4a2 2 0 0 0-2 0l-7 4A2 2 0 0 0 3 8v8a2 2 0 0 0 1 1.73l7 4a2 2 0 0 0 2 0l7-4A2 2 0 0 0 21 16Z",
      key: "hh9hay"
    }
  ],
  ["path", { d: "m3.3 7 8.7 5 8.7-5", key: "g66t2b" }],
  ["path", { d: "M12 22V12", key: "d0xqtd" }]
]);

const LuPaintBucket = createLucideIcon("LuPaintBucket", [
  [
    "path",
    { d: "m19 11-8-8-8.6 8.6a2 2 0 0 0 0 2.8l5.2 5.2c.8.8 2 .8 2.8 0L19 11Z", key: "irua1i" }
  ],
  ["path", { d: "m5 2 5 5", key: "1lls2c" }],
  ["path", { d: "M2 13h15", key: "1hkzvu" }],
  ["path", { d: "M22 20a2 2 0 1 1-4 0c0-1.6 1.7-2.4 2-4 .3 1.6 2 2.4 2 4Z", key: "xk76lq" }]
]);

const LuPaintRoller = createLucideIcon("LuPaintRoller", [
  ["rect", { width: "16", height: "6", x: "2", y: "2", rx: "2", key: "jcyz7m" }],
  ["path", { d: "M10 16v-2a2 2 0 0 1 2-2h8a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-2", key: "1b9h7c" }],
  ["rect", { width: "4", height: "6", x: "8", y: "16", rx: "1", key: "d6e7yl" }]
]);

const LuPaintbrush2 = createLucideIcon("LuPaintbrush2", [
  [
    "path",
    { d: "M14 19.9V16h3a2 2 0 0 0 2-2v-2H5v2c0 1.1.9 2 2 2h3v3.9a2 2 0 1 0 4 0Z", key: "1c8kta" }
  ],
  ["path", { d: "M6 12V2h12v10", key: "1esbnf" }],
  ["path", { d: "M14 2v4", key: "qmzblu" }],
  ["path", { d: "M10 2v2", key: "7u0qdc" }]
]);

const LuPaintbrush = createLucideIcon("LuPaintbrush", [
  [
    "path",
    {
      d: "M18.37 2.63 14 7l-1.59-1.59a2 2 0 0 0-2.82 0L8 7l9 9 1.59-1.59a2 2 0 0 0 0-2.82L17 10l4.37-4.37a2.12 2.12 0 1 0-3-3Z",
      key: "m6k5sh"
    }
  ],
  ["path", { d: "M9 8c-2 3-4 3.5-7 4l8 10c2-1 6-5 6-7", key: "arzq70" }],
  ["path", { d: "M14.5 17.5 4.5 15", key: "s7fvrz" }]
]);

const LuPalette = createLucideIcon("LuPalette", [
  ["circle", { cx: "13.5", cy: "6.5", r: ".5", fill: "currentColor", key: "1okk4w" }],
  ["circle", { cx: "17.5", cy: "10.5", r: ".5", fill: "currentColor", key: "f64h9f" }],
  ["circle", { cx: "8.5", cy: "7.5", r: ".5", fill: "currentColor", key: "fotxhn" }],
  ["circle", { cx: "6.5", cy: "12.5", r: ".5", fill: "currentColor", key: "qy21gx" }],
  [
    "path",
    {
      d: "M12 2C6.5 2 2 6.5 2 12s4.5 10 10 10c.926 0 1.648-.746 1.648-1.688 0-.437-.18-.835-.437-1.125-.29-.289-.438-.652-.438-1.125a1.64 1.64 0 0 1 1.668-1.668h1.996c3.051 0 5.555-2.503 5.555-5.554C21.965 6.012 17.461 2 12 2z",
      key: "12rzf8"
    }
  ]
]);

const LuPanelBottomClose = createLucideIcon("LuPanelBottomClose", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 15h18", key: "5xshup" }],
  ["path", { d: "m15 8-3 3-3-3", key: "1oxy1z" }]
]);

const LuPanelBottomDashed = createLucideIcon("LuPanelBottomDashed", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M14 15h1", key: "171nev" }],
  ["path", { d: "M19 15h2", key: "1vnucp" }],
  ["path", { d: "M3 15h2", key: "8bym0q" }],
  ["path", { d: "M9 15h1", key: "1tg3ks" }]
]);

const LuPanelBottomOpen = createLucideIcon("LuPanelBottomOpen", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 15h18", key: "5xshup" }],
  ["path", { d: "m9 10 3-3 3 3", key: "11gsxs" }]
]);

const LuPanelBottom = createLucideIcon("LuPanelBottom", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 15h18", key: "5xshup" }]
]);

const LuPanelLeftClose = createLucideIcon("LuPanelLeftClose", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M9 3v18", key: "fh3hqa" }],
  ["path", { d: "m16 15-3-3 3-3", key: "14y99z" }]
]);

const LuPanelLeftDashed = createLucideIcon("LuPanelLeftDashed", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M9 14v1", key: "askpd8" }],
  ["path", { d: "M9 19v2", key: "16tejx" }],
  ["path", { d: "M9 3v2", key: "1noubl" }],
  ["path", { d: "M9 9v1", key: "19ebxg" }]
]);

const LuPanelLeftOpen = createLucideIcon("LuPanelLeftOpen", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M9 3v18", key: "fh3hqa" }],
  ["path", { d: "m14 9 3 3-3 3", key: "8010ee" }]
]);

const LuPanelLeft = createLucideIcon("LuPanelLeft", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M9 3v18", key: "fh3hqa" }]
]);

const LuPanelRightClose = createLucideIcon("LuPanelRightClose", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M15 3v18", key: "14nvp0" }],
  ["path", { d: "m8 9 3 3-3 3", key: "12hl5m" }]
]);

const LuPanelRightDashed = createLucideIcon("LuPanelRightDashed", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M15 14v1", key: "ilsfch" }],
  ["path", { d: "M15 19v2", key: "1fst2f" }],
  ["path", { d: "M15 3v2", key: "z204g4" }],
  ["path", { d: "M15 9v1", key: "z2a8b1" }]
]);

const LuPanelRightOpen = createLucideIcon("LuPanelRightOpen", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M15 3v18", key: "14nvp0" }],
  ["path", { d: "m10 15-3-3 3-3", key: "1pgupc" }]
]);

const LuPanelRight = createLucideIcon("LuPanelRight", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M15 3v18", key: "14nvp0" }]
]);

const LuPanelTopClose = createLucideIcon("LuPanelTopClose", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 9h18", key: "1pudct" }],
  ["path", { d: "m9 16 3-3 3 3", key: "1idcnm" }]
]);

const LuPanelTopDashed = createLucideIcon("LuPanelTopDashed", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M14 9h1", key: "l0svgy" }],
  ["path", { d: "M19 9h2", key: "te2zfg" }],
  ["path", { d: "M3 9h2", key: "1h4ldw" }],
  ["path", { d: "M9 9h1", key: "15jzuz" }]
]);

const LuPanelTopOpen = createLucideIcon("LuPanelTopOpen", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 9h18", key: "1pudct" }],
  ["path", { d: "m15 14-3 3-3-3", key: "g215vf" }]
]);

const LuPanelTop = createLucideIcon("LuPanelTop", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 9h18", key: "1pudct" }]
]);

const LuPanelsLeftBottom = createLucideIcon("LuPanelsLeftBottom", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M9 3v18", key: "fh3hqa" }],
  ["path", { d: "M9 15h12", key: "5ijen5" }]
]);

const LuPanelsRightBottom = createLucideIcon("LuPanelsRightBottom", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 15h12", key: "1wkqb3" }],
  ["path", { d: "M15 3v18", key: "14nvp0" }]
]);

const LuPanelsTopLeft = createLucideIcon("LuPanelsTopLeft", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 9h18", key: "1pudct" }],
  ["path", { d: "M9 21V9", key: "1oto5p" }]
]);

const LuPaperclip = createLucideIcon("LuPaperclip", [
  [
    "path",
    {
      d: "m21.44 11.05-9.19 9.19a6 6 0 0 1-8.49-8.49l8.57-8.57A4 4 0 1 1 18 8.84l-8.59 8.57a2 2 0 0 1-2.83-2.83l8.49-8.48",
      key: "1u3ebp"
    }
  ]
]);

const LuParentheses = createLucideIcon("LuParentheses", [
  ["path", { d: "M8 21s-4-3-4-9 4-9 4-9", key: "uto9ud" }],
  ["path", { d: "M16 3s4 3 4 9-4 9-4 9", key: "4w2vsq" }]
]);

const LuParkingMeter = createLucideIcon("LuParkingMeter", [
  ["path", { d: "M9 9a3 3 0 1 1 6 0", key: "jdoeu8" }],
  ["path", { d: "M12 12v3", key: "158kv8" }],
  ["path", { d: "M11 15h2", key: "199qp6" }],
  [
    "path",
    {
      d: "M19 9a7 7 0 1 0-13.6 2.3C6.4 14.4 8 19 8 19h8s1.6-4.6 2.6-7.7c.3-.8.4-1.5.4-2.3",
      key: "1l50wn"
    }
  ],
  ["path", { d: "M12 19v3", key: "npa21l" }]
]);

const LuPartyPopper = createLucideIcon("LuPartyPopper", [
  ["path", { d: "M5.8 11.3 2 22l10.7-3.79", key: "gwxi1d" }],
  ["path", { d: "M4 3h.01", key: "1vcuye" }],
  ["path", { d: "M22 8h.01", key: "1mrtc2" }],
  ["path", { d: "M15 2h.01", key: "1cjtqr" }],
  ["path", { d: "M22 20h.01", key: "1mrys2" }],
  [
    "path",
    {
      d: "m22 2-2.24.75a2.9 2.9 0 0 0-1.96 3.12v0c.1.86-.57 1.63-1.45 1.63h-.38c-.86 0-1.6.6-1.76 1.44L14 10",
      key: "bpx1uq"
    }
  ],
  [
    "path",
    { d: "m22 13-.82-.33c-.86-.34-1.82.2-1.98 1.11v0c-.11.7-.72 1.22-1.43 1.22H17", key: "1pd0s7" }
  ],
  [
    "path",
    { d: "m11 2 .33.82c.34.86-.2 1.82-1.11 1.98v0C9.52 4.9 9 5.52 9 6.23V7", key: "zq5xbz" }
  ],
  [
    "path",
    {
      d: "M11 13c1.93 1.93 2.83 4.17 2 5-.83.83-3.07-.07-5-2-1.93-1.93-2.83-4.17-2-5 .83-.83 3.07.07 5 2Z",
      key: "4kbmks"
    }
  ]
]);

const LuPause = createLucideIcon("LuPause", [
  ["rect", { width: "4", height: "16", x: "6", y: "4", key: "iffhe4" }],
  ["rect", { width: "4", height: "16", x: "14", y: "4", key: "sjin7j" }]
]);

const LuPawPrint = createLucideIcon("LuPawPrint", [
  ["circle", { cx: "11", cy: "4", r: "2", key: "vol9p0" }],
  ["circle", { cx: "18", cy: "8", r: "2", key: "17gozi" }],
  ["circle", { cx: "20", cy: "16", r: "2", key: "1v9bxh" }],
  [
    "path",
    {
      d: "M9 10a5 5 0 0 1 5 5v3.5a3.5 3.5 0 0 1-6.84 1.045Q6.52 17.48 4.46 16.84A3.5 3.5 0 0 1 5.5 10Z",
      key: "1ydw1z"
    }
  ]
]);

const LuPcCase = createLucideIcon("LuPcCase", [
  ["rect", { width: "14", height: "20", x: "5", y: "2", rx: "2", key: "1uq1d7" }],
  ["path", { d: "M15 14h.01", key: "1kp3bh" }],
  ["path", { d: "M9 6h6", key: "dgm16u" }],
  ["path", { d: "M9 10h6", key: "9gxzsh" }]
]);

const LuPenLine = createLucideIcon("LuPenLine", [
  ["path", { d: "M12 20h9", key: "t2du7b" }],
  ["path", { d: "M16.5 3.5a2.12 2.12 0 0 1 3 3L7 19l-4 1 1-4Z", key: "ymcmye" }]
]);

const LuPenTool = createLucideIcon("LuPenTool", [
  ["path", { d: "m12 19 7-7 3 3-7 7-3-3z", key: "rklqx2" }],
  ["path", { d: "m18 13-1.5-7.5L2 2l3.5 14.5L13 18l5-5z", key: "1et58u" }],
  ["path", { d: "m2 2 7.586 7.586", key: "etlp93" }],
  ["circle", { cx: "11", cy: "11", r: "2", key: "xmgehs" }]
]);

const LuPen = createLucideIcon("LuPen", [
  ["path", { d: "M17 3a2.85 2.83 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5Z", key: "5qss01" }]
]);

const LuPencilLine = createLucideIcon("LuPencilLine", [
  ["path", { d: "M12 20h9", key: "t2du7b" }],
  ["path", { d: "M16.5 3.5a2.12 2.12 0 0 1 3 3L7 19l-4 1 1-4Z", key: "ymcmye" }],
  ["path", { d: "m15 5 3 3", key: "1w25hb" }]
]);

const LuPencilRuler = createLucideIcon("LuPencilRuler", [
  ["path", { d: "m15 5 4 4", key: "1mk7zo" }],
  [
    "path",
    { d: "M13 7 8.7 2.7a2.41 2.41 0 0 0-3.4 0L2.7 5.3a2.41 2.41 0 0 0 0 3.4L7 13", key: "orapub" }
  ],
  ["path", { d: "m8 6 2-2", key: "115y1s" }],
  ["path", { d: "m2 22 5.5-1.5L21.17 6.83a2.82 2.82 0 0 0-4-4L3.5 16.5Z", key: "hes763" }],
  ["path", { d: "m18 16 2-2", key: "ee94s4" }],
  [
    "path",
    {
      d: "m17 11 4.3 4.3c.94.94.94 2.46 0 3.4l-2.6 2.6c-.94.94-2.46.94-3.4 0L11 17",
      key: "cfq27r"
    }
  ]
]);

const LuPencil = createLucideIcon("LuPencil", [
  ["path", { d: "M17 3a2.85 2.83 0 1 1 4 4L7.5 20.5 2 22l1.5-5.5Z", key: "5qss01" }],
  ["path", { d: "m15 5 4 4", key: "1mk7zo" }]
]);

const LuPentagon = createLucideIcon("LuPentagon", [
  [
    "path",
    {
      d: "M3.5 8.7c-.7.5-1 1.4-.7 2.2l2.8 8.7c.3.8 1 1.4 1.9 1.4h9.1c.9 0 1.6-.6 1.9-1.4l2.8-8.7c.3-.8 0-1.7-.7-2.2l-7.4-5.3a2.1 2.1 0 0 0-2.4 0Z",
      key: "hsj90r"
    }
  ]
]);

const LuPercent = createLucideIcon("LuPercent", [
  ["line", { x1: "19", x2: "5", y1: "5", y2: "19", key: "1x9vlm" }],
  ["circle", { cx: "6.5", cy: "6.5", r: "2.5", key: "4mh3h7" }],
  ["circle", { cx: "17.5", cy: "17.5", r: "2.5", key: "1mdrzq" }]
]);

const LuPersonStanding = createLucideIcon("LuPersonStanding", [
  ["circle", { cx: "12", cy: "5", r: "1", key: "gxeob9" }],
  ["path", { d: "m9 20 3-6 3 6", key: "se2kox" }],
  ["path", { d: "m6 8 6 2 6-2", key: "4o3us4" }],
  ["path", { d: "M12 10v4", key: "1kjpxc" }]
]);

const LuPhoneCall = createLucideIcon("LuPhoneCall", [
  [
    "path",
    {
      d: "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z",
      key: "foiqr5"
    }
  ],
  ["path", { d: "M14.05 2a9 9 0 0 1 8 7.94", key: "vmijpz" }],
  ["path", { d: "M14.05 6A5 5 0 0 1 18 10", key: "13nbpp" }]
]);

const LuPhoneForwarded = createLucideIcon("LuPhoneForwarded", [
  ["polyline", { points: "18 2 22 6 18 10", key: "6vjanh" }],
  ["line", { x1: "14", x2: "22", y1: "6", y2: "6", key: "1jsywh" }],
  [
    "path",
    {
      d: "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z",
      key: "foiqr5"
    }
  ]
]);

const LuPhoneIncoming = createLucideIcon("LuPhoneIncoming", [
  ["polyline", { points: "16 2 16 8 22 8", key: "1ygljm" }],
  ["line", { x1: "22", x2: "16", y1: "2", y2: "8", key: "1xzwqn" }],
  [
    "path",
    {
      d: "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z",
      key: "foiqr5"
    }
  ]
]);

const LuPhoneMissed = createLucideIcon("LuPhoneMissed", [
  ["line", { x1: "22", x2: "16", y1: "2", y2: "8", key: "1xzwqn" }],
  ["line", { x1: "16", x2: "22", y1: "2", y2: "8", key: "13zxdn" }],
  [
    "path",
    {
      d: "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z",
      key: "foiqr5"
    }
  ]
]);

const LuPhoneOff = createLucideIcon("LuPhoneOff", [
  [
    "path",
    {
      d: "M10.68 13.31a16 16 0 0 0 3.41 2.6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7 2 2 0 0 1 1.72 2v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.42 19.42 0 0 1-3.33-2.67m-2.67-3.34a19.79 19.79 0 0 1-3.07-8.63A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91",
      key: "z86iuo"
    }
  ],
  ["line", { x1: "22", x2: "2", y1: "2", y2: "22", key: "11kh81" }]
]);

const LuPhoneOutgoing = createLucideIcon("LuPhoneOutgoing", [
  ["polyline", { points: "22 8 22 2 16 2", key: "1g204g" }],
  ["line", { x1: "16", x2: "22", y1: "8", y2: "2", key: "1ggias" }],
  [
    "path",
    {
      d: "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z",
      key: "foiqr5"
    }
  ]
]);

const LuPhone = createLucideIcon("LuPhone", [
  [
    "path",
    {
      d: "M22 16.92v3a2 2 0 0 1-2.18 2 19.79 19.79 0 0 1-8.63-3.07 19.5 19.5 0 0 1-6-6 19.79 19.79 0 0 1-3.07-8.67A2 2 0 0 1 4.11 2h3a2 2 0 0 1 2 1.72 12.84 12.84 0 0 0 .7 2.81 2 2 0 0 1-.45 2.11L8.09 9.91a16 16 0 0 0 6 6l1.27-1.27a2 2 0 0 1 2.11-.45 12.84 12.84 0 0 0 2.81.7A2 2 0 0 1 22 16.92z",
      key: "foiqr5"
    }
  ]
]);

const LuPi = createLucideIcon("LuPi", [
  ["line", { x1: "9", x2: "9", y1: "4", y2: "20", key: "ovs5a5" }],
  ["path", { d: "M4 7c0-1.7 1.3-3 3-3h13", key: "10pag4" }],
  ["path", { d: "M18 20c-1.7 0-3-1.3-3-3V4", key: "1gaosr" }]
]);

const LuPiano = createLucideIcon("LuPiano", [
  [
    "path",
    {
      d: "M18.5 8c-1.4 0-2.6-.8-3.2-2A6.87 6.87 0 0 0 2 9v11a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-8.5C22 9.6 20.4 8 18.5 8",
      key: "lag0yf"
    }
  ],
  ["path", { d: "M2 14h20", key: "myj16y" }],
  ["path", { d: "M6 14v4", key: "9ng0ue" }],
  ["path", { d: "M10 14v4", key: "1v8uk5" }],
  ["path", { d: "M14 14v4", key: "1tqops" }],
  ["path", { d: "M18 14v4", key: "18uqwm" }]
]);

const LuPickaxe = createLucideIcon("LuPickaxe", [
  ["path", { d: "M14.531 12.469 6.619 20.38a1 1 0 1 1-3-3l7.912-7.912", key: "we99rg" }],
  [
    "path",
    {
      d: "M15.686 4.314A12.5 12.5 0 0 0 5.461 2.958 1 1 0 0 0 5.58 4.71a22 22 0 0 1 6.318 3.393",
      key: "1w6hck"
    }
  ],
  [
    "path",
    {
      d: "M17.7 3.7a1 1 0 0 0-1.4 0l-4.6 4.6a1 1 0 0 0 0 1.4l2.6 2.6a1 1 0 0 0 1.4 0l4.6-4.6a1 1 0 0 0 0-1.4z",
      key: "15hgfx"
    }
  ],
  [
    "path",
    {
      d: "M19.686 8.314a12.501 12.501 0 0 1 1.356 10.225 1 1 0 0 1-1.751-.119 22 22 0 0 0-3.393-6.319",
      key: "452b4h"
    }
  ]
]);

const LuPictureInPicture2 = createLucideIcon("LuPictureInPicture2", [
  ["path", { d: "M21 9V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v10c0 1.1.9 2 2 2h4", key: "daa4of" }],
  ["rect", { width: "10", height: "7", x: "12", y: "13", rx: "2", key: "1nb8gs" }]
]);

const LuPictureInPicture = createLucideIcon("LuPictureInPicture", [
  [
    "path",
    {
      d: "M8 4.5v5H3m-1-6 6 6m13 0v-3c0-1.16-.84-2-2-2h-7m-9 9v2c0 1.05.95 2 2 2h3",
      key: "bcd8fb"
    }
  ],
  ["rect", { width: "10", height: "7", x: "12", y: "13.5", ry: "2", key: "136fx3" }]
]);

const LuPieChart = createLucideIcon("LuPieChart", [
  ["path", { d: "M21.21 15.89A10 10 0 1 1 8 2.83", key: "k2fpak" }],
  ["path", { d: "M22 12A10 10 0 0 0 12 2v10z", key: "1rfc4y" }]
]);

const LuPiggyBank = createLucideIcon("LuPiggyBank", [
  [
    "path",
    {
      d: "M19 5c-1.5 0-2.8 1.4-3 2-3.5-1.5-11-.3-11 5 0 1.8 0 3 2 4.5V20h4v-2h3v2h4v-4c1-.5 1.7-1 2-2h2v-4h-2c0-1-.5-1.5-1-2h0V5z",
      key: "uf6l00"
    }
  ],
  ["path", { d: "M2 9v1c0 1.1.9 2 2 2h1", key: "nm575m" }],
  ["path", { d: "M16 11h0", key: "k2aug8" }]
]);

const LuPilcrow = createLucideIcon("LuPilcrow", [
  ["path", { d: "M13 4v16", key: "8vvj80" }],
  ["path", { d: "M17 4v16", key: "7dpous" }],
  ["path", { d: "M19 4H9.5a4.5 4.5 0 0 0 0 9H13", key: "sh4n9v" }]
]);

const LuPill = createLucideIcon("LuPill", [
  [
    "path",
    { d: "m10.5 20.5 10-10a4.95 4.95 0 1 0-7-7l-10 10a4.95 4.95 0 1 0 7 7Z", key: "wa1lgi" }
  ],
  ["path", { d: "m8.5 8.5 7 7", key: "rvfmvr" }]
]);

const LuPinOff = createLucideIcon("LuPinOff", [
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }],
  ["line", { x1: "12", x2: "12", y1: "17", y2: "22", key: "1jrz49" }],
  ["path", { d: "M9 9v1.76a2 2 0 0 1-1.11 1.79l-1.78.9A2 2 0 0 0 5 15.24V17h12", key: "13x2n8" }],
  ["path", { d: "M15 9.34V6h1a2 2 0 0 0 0-4H7.89", key: "reo3ki" }]
]);

const LuPin = createLucideIcon("LuPin", [
  ["line", { x1: "12", x2: "12", y1: "17", y2: "22", key: "1jrz49" }],
  [
    "path",
    {
      d: "M5 17h14v-1.76a2 2 0 0 0-1.11-1.79l-1.78-.9A2 2 0 0 1 15 10.76V6h1a2 2 0 0 0 0-4H8a2 2 0 0 0 0 4h1v4.76a2 2 0 0 1-1.11 1.79l-1.78.9A2 2 0 0 0 5 15.24Z",
      key: "13yl11"
    }
  ]
]);

const LuPipette = createLucideIcon("LuPipette", [
  ["path", { d: "m2 22 1-1h3l9-9", key: "1sre89" }],
  ["path", { d: "M3 21v-3l9-9", key: "hpe2y6" }],
  [
    "path",
    {
      d: "m15 6 3.4-3.4a2.1 2.1 0 1 1 3 3L18 9l.4.4a2.1 2.1 0 1 1-3 3l-3.8-3.8a2.1 2.1 0 1 1 3-3l.4.4Z",
      key: "196du1"
    }
  ]
]);

const LuPizza = createLucideIcon("LuPizza", [
  ["path", { d: "M15 11h.01", key: "rns66s" }],
  ["path", { d: "M11 15h.01", key: "k85uqc" }],
  ["path", { d: "M16 16h.01", key: "1f9h7w" }],
  ["path", { d: "m2 16 20 6-6-20A20 20 0 0 0 2 16", key: "e4slt2" }],
  ["path", { d: "M5.71 17.11a17.04 17.04 0 0 1 11.4-11.4", key: "rerf8f" }]
]);

const LuPlaneLanding = createLucideIcon("LuPlaneLanding", [
  ["path", { d: "M2 22h20", key: "272qi7" }],
  [
    "path",
    {
      d: "M3.77 10.77 2 9l2-4.5 1.1.55c.55.28.9.84.9 1.45s.35 1.17.9 1.45L8 8.5l3-6 1.05.53a2 2 0 0 1 1.09 1.52l.72 5.4a2 2 0 0 0 1.09 1.52l4.4 2.2c.42.22.78.55 1.01.96l.6 1.03c.49.88-.06 1.98-1.06 2.1l-1.18.15c-.47.06-.95-.02-1.37-.24L4.29 11.15a2 2 0 0 1-.52-.38Z",
      key: "1ma21e"
    }
  ]
]);

const LuPlaneTakeoff = createLucideIcon("LuPlaneTakeoff", [
  ["path", { d: "M2 22h20", key: "272qi7" }],
  [
    "path",
    {
      d: "M6.36 17.4 4 17l-2-4 1.1-.55a2 2 0 0 1 1.8 0l.17.1a2 2 0 0 0 1.8 0L8 12 5 6l.9-.45a2 2 0 0 1 2.09.2l4.02 3a2 2 0 0 0 2.1.2l4.19-2.06a2.41 2.41 0 0 1 1.73-.17L21 7a1.4 1.4 0 0 1 .87 1.99l-.38.76c-.23.46-.6.84-1.07 1.08L7.58 17.2a2 2 0 0 1-1.22.18Z",
      key: "fkigj9"
    }
  ]
]);

const LuPlane = createLucideIcon("LuPlane", [
  [
    "path",
    {
      d: "M17.8 19.2 16 11l3.5-3.5C21 6 21.5 4 21 3c-1-.5-3 0-4.5 1.5L13 8 4.8 6.2c-.5-.1-.9.1-1.1.5l-.3.5c-.2.5-.1 1 .3 1.3L9 12l-2 3H4l-1 1 3 2 2 3 1-1v-3l3-2 3.5 5.3c.3.4.8.5 1.3.3l.5-.2c.4-.3.6-.7.5-1.2z",
      key: "1v9wt8"
    }
  ]
]);

const LuPlay = createLucideIcon("LuPlay", [
  ["polygon", { points: "6 3 20 12 6 21 6 3", key: "1oa8hb" }]
]);

const LuPlug2 = createLucideIcon("LuPlug2", [
  ["path", { d: "M9 2v6", key: "17ngun" }],
  ["path", { d: "M15 2v6", key: "s7yy2p" }],
  ["path", { d: "M12 17v5", key: "bb1du9" }],
  ["path", { d: "M5 8h14", key: "pcz4l3" }],
  ["path", { d: "M6 11V8h12v3a6 6 0 1 1-12 0v0Z", key: "nd4hoy" }]
]);

const LuPlugZap2 = createLucideIcon("LuPlugZap2", [
  ["path", { d: "m13 2-2 2.5h3L12 7", key: "1me98u" }],
  ["path", { d: "M10 14v-3", key: "1mllf3" }],
  ["path", { d: "M14 14v-3", key: "1l3fkq" }],
  ["path", { d: "M11 19c-1.7 0-3-1.3-3-3v-2h8v2c0 1.7-1.3 3-3 3Z", key: "jd5pat" }],
  ["path", { d: "M12 22v-3", key: "kmzjlo" }]
]);

const LuPlugZap = createLucideIcon("LuPlugZap", [
  [
    "path",
    { d: "M6.3 20.3a2.4 2.4 0 0 0 3.4 0L12 18l-6-6-2.3 2.3a2.4 2.4 0 0 0 0 3.4Z", key: "goz73y" }
  ],
  ["path", { d: "m2 22 3-3", key: "19mgm9" }],
  ["path", { d: "M7.5 13.5 10 11", key: "7xgeeb" }],
  ["path", { d: "M10.5 16.5 13 14", key: "10btkg" }],
  ["path", { d: "m18 3-4 4h6l-4 4", key: "16psg9" }]
]);

const LuPlug = createLucideIcon("LuPlug", [
  ["path", { d: "M12 22v-5", key: "1ega77" }],
  ["path", { d: "M9 8V2", key: "14iosj" }],
  ["path", { d: "M15 8V2", key: "18g5xt" }],
  ["path", { d: "M18 8v5a4 4 0 0 1-4 4h-4a4 4 0 0 1-4-4V8Z", key: "osxo6l" }]
]);

const LuPlus = createLucideIcon("LuPlus", [
  ["path", { d: "M5 12h14", key: "1ays0h" }],
  ["path", { d: "M12 5v14", key: "s699le" }]
]);

const LuPocketKnife = createLucideIcon("LuPocketKnife", [
  ["path", { d: "M3 2v1c0 1 2 1 2 2S3 6 3 7s2 1 2 2-2 1-2 2 2 1 2 2", key: "19w3oe" }],
  ["path", { d: "M18 6h.01", key: "1v4wsw" }],
  ["path", { d: "M6 18h.01", key: "uhywen" }],
  ["path", { d: "M20.83 8.83a4 4 0 0 0-5.66-5.66l-12 12a4 4 0 1 0 5.66 5.66Z", key: "6fykxj" }],
  ["path", { d: "M18 11.66V22a4 4 0 0 0 4-4V6", key: "1utzek" }]
]);

const LuPocket = createLucideIcon("LuPocket", [
  [
    "path",
    {
      d: "M4 3h16a2 2 0 0 1 2 2v6a10 10 0 0 1-10 10A10 10 0 0 1 2 11V5a2 2 0 0 1 2-2z",
      key: "1mz881"
    }
  ],
  ["polyline", { points: "8 10 12 14 16 10", key: "w4mbv5" }]
]);

const LuPodcast = createLucideIcon("LuPodcast", [
  ["path", { d: "M16.85 18.58a9 9 0 1 0-9.7 0", key: "d71mpg" }],
  ["path", { d: "M8 14a5 5 0 1 1 8 0", key: "fc81rn" }],
  ["circle", { cx: "12", cy: "11", r: "1", key: "1gvufo" }],
  ["path", { d: "M13 17a1 1 0 1 0-2 0l.5 4.5a.5.5 0 1 0 1 0Z", key: "za5kbj" }]
]);

const LuPointerOff = createLucideIcon("LuPointerOff", [
  ["path", { d: "M10 4.5V4a2 2 0 0 0-2.41-1.957", key: "jsi14n" }],
  ["path", { d: "M13.9 8.4a2 2 0 0 0-1.26-1.295", key: "hirc7f" }],
  [
    "path",
    { d: "M21.7 16.2A8 8 0 0 0 22 14v-3a2 2 0 1 0-4 0v-1a2 2 0 0 0-3.63-1.158", key: "1jxb2e" }
  ],
  [
    "path",
    {
      d: "m7 15-1.8-1.8a2 2 0 0 0-2.79 2.86L6 19.7a7.74 7.74 0 0 0 6 2.3h2a8 8 0 0 0 5.657-2.343",
      key: "10r7hm"
    }
  ],
  ["path", { d: "M6 6v8", key: "tv5xkp" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuPointer = createLucideIcon("LuPointer", [
  ["path", { d: "M22 14a8 8 0 0 1-8 8", key: "56vcr3" }],
  ["path", { d: "M18 11v-1a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v0", key: "1pp0yd" }],
  ["path", { d: "M14 10V9a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v1", key: "u654g" }],
  ["path", { d: "M10 9.5V4a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v10", key: "1e2dtv" }],
  [
    "path",
    {
      d: "M18 11a2 2 0 1 1 4 0v3a8 8 0 0 1-8 8h-2c-2.8 0-4.5-.86-5.99-2.34l-3.6-3.6a2 2 0 0 1 2.83-2.82L7 15",
      key: "g6ys72"
    }
  ]
]);

const LuPopcorn = createLucideIcon("LuPopcorn", [
  [
    "path",
    {
      d: "M18 8a2 2 0 0 0 0-4 2 2 0 0 0-4 0 2 2 0 0 0-4 0 2 2 0 0 0-4 0 2 2 0 0 0 0 4",
      key: "10td1f"
    }
  ],
  ["path", { d: "M10 22 9 8", key: "yjptiv" }],
  ["path", { d: "m14 22 1-14", key: "8jwc8b" }],
  [
    "path",
    {
      d: "M20 8c.5 0 .9.4.8 1l-2.6 12c-.1.5-.7 1-1.2 1H7c-.6 0-1.1-.4-1.2-1L3.2 9c-.1-.6.3-1 .8-1Z",
      key: "1qo33t"
    }
  ]
]);

const LuPopsicle = createLucideIcon("LuPopsicle", [
  [
    "path",
    {
      d: "M18.6 14.4c.8-.8.8-2 0-2.8l-8.1-8.1a4.95 4.95 0 1 0-7.1 7.1l8.1 8.1c.9.7 2.1.7 2.9-.1Z",
      key: "1o68ps"
    }
  ],
  ["path", { d: "m22 22-5.5-5.5", key: "17o70y" }]
]);

const LuPoundSterling = createLucideIcon("LuPoundSterling", [
  ["path", { d: "M18 7c0-5.333-8-5.333-8 0", key: "1prm2n" }],
  ["path", { d: "M10 7v14", key: "18tmcs" }],
  ["path", { d: "M6 21h12", key: "4dkmi1" }],
  ["path", { d: "M6 13h10", key: "ybwr4a" }]
]);

const LuPowerOff = createLucideIcon("LuPowerOff", [
  ["path", { d: "M18.36 6.64A9 9 0 0 1 20.77 15", key: "dxknvb" }],
  ["path", { d: "M6.16 6.16a9 9 0 1 0 12.68 12.68", key: "1x7qb5" }],
  ["path", { d: "M12 2v4", key: "3427ic" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuPower = createLucideIcon("LuPower", [
  ["path", { d: "M12 2v10", key: "mnfbl" }],
  ["path", { d: "M18.4 6.6a9 9 0 1 1-12.77.04", key: "obofu9" }]
]);

const LuPresentation = createLucideIcon("LuPresentation", [
  ["path", { d: "M2 3h20", key: "91anmk" }],
  ["path", { d: "M21 3v11a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V3", key: "2k9sn8" }],
  ["path", { d: "m7 21 5-5 5 5", key: "bip4we" }]
]);

const LuPrinter = createLucideIcon("LuPrinter", [
  ["polyline", { points: "6 9 6 2 18 2 18 9", key: "1306q4" }],
  [
    "path",
    {
      d: "M6 18H4a2 2 0 0 1-2-2v-5a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v5a2 2 0 0 1-2 2h-2",
      key: "143wyd"
    }
  ],
  ["rect", { width: "12", height: "8", x: "6", y: "14", key: "5ipwut" }]
]);

const LuProjector = createLucideIcon("LuProjector", [
  ["path", { d: "M5 7 3 5", key: "1yys58" }],
  ["path", { d: "M9 6V3", key: "1ptz9u" }],
  ["path", { d: "m13 7 2-2", key: "1w3vmq" }],
  ["circle", { cx: "9", cy: "13", r: "3", key: "1mma13" }],
  [
    "path",
    {
      d: "M11.83 12H20a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-4a2 2 0 0 1 2-2h2.17",
      key: "2frwzc"
    }
  ],
  ["path", { d: "M16 16h2", key: "dnq2od" }]
]);

const LuProportions = createLucideIcon("LuProportions", [
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }],
  ["path", { d: "M12 9v11", key: "1fnkrn" }],
  ["path", { d: "M2 9h13a2 2 0 0 1 2 2v9", key: "11z3ex" }]
]);

const LuPuzzle = createLucideIcon("LuPuzzle", [
  [
    "path",
    {
      d: "M19.439 7.85c-.049.322.059.648.289.878l1.568 1.568c.47.47.706 1.087.706 1.704s-.235 1.233-.706 1.704l-1.611 1.611a.98.98 0 0 1-.837.276c-.47-.07-.802-.48-.968-.925a2.501 2.501 0 1 0-3.214 3.214c.446.166.855.497.925.968a.979.979 0 0 1-.276.837l-1.61 1.61a2.404 2.404 0 0 1-1.705.707 2.402 2.402 0 0 1-1.704-.706l-1.568-1.568a1.026 1.026 0 0 0-.877-.29c-.493.074-.84.504-1.02.968a2.5 2.5 0 1 1-3.237-3.237c.464-.18.894-.527.967-1.02a1.026 1.026 0 0 0-.289-.877l-1.568-1.568A2.402 2.402 0 0 1 1.998 12c0-.617.236-1.234.706-1.704L4.23 8.77c.24-.24.581-.353.917-.303.515.077.877.528 1.073 1.01a2.5 2.5 0 1 0 3.259-3.259c-.482-.196-.933-.558-1.01-1.073-.05-.336.062-.676.303-.917l1.525-1.525A2.402 2.402 0 0 1 12 1.998c.617 0 1.234.236 1.704.706l1.568 1.568c.23.23.556.338.877.29.493-.074.84-.504 1.02-.968a2.5 2.5 0 1 1 3.237 3.237c-.464.18-.894.527-.967 1.02Z",
      key: "i0oyt7"
    }
  ]
]);

const LuPyramid = createLucideIcon("LuPyramid", [
  [
    "path",
    {
      d: "M2.5 16.88a1 1 0 0 1-.32-1.43l9-13.02a1 1 0 0 1 1.64 0l9 13.01a1 1 0 0 1-.32 1.44l-8.51 4.86a2 2 0 0 1-1.98 0Z",
      key: "aenxs0"
    }
  ],
  ["path", { d: "M12 2v20", key: "t6zp3m" }]
]);

const LuQrCode = createLucideIcon("LuQrCode", [
  ["rect", { width: "5", height: "5", x: "3", y: "3", rx: "1", key: "1tu5fj" }],
  ["rect", { width: "5", height: "5", x: "16", y: "3", rx: "1", key: "1v8r4q" }],
  ["rect", { width: "5", height: "5", x: "3", y: "16", rx: "1", key: "1x03jg" }],
  ["path", { d: "M21 16h-3a2 2 0 0 0-2 2v3", key: "177gqh" }],
  ["path", { d: "M21 21v.01", key: "ents32" }],
  ["path", { d: "M12 7v3a2 2 0 0 1-2 2H7", key: "8crl2c" }],
  ["path", { d: "M3 12h.01", key: "nlz23k" }],
  ["path", { d: "M12 3h.01", key: "n36tog" }],
  ["path", { d: "M12 16v.01", key: "133mhm" }],
  ["path", { d: "M16 12h1", key: "1slzba" }],
  ["path", { d: "M21 12v.01", key: "1lwtk9" }],
  ["path", { d: "M12 21v-1", key: "1880an" }]
]);

const LuQuote = createLucideIcon("LuQuote", [
  [
    "path",
    {
      d: "M3 21c3 0 7-1 7-8V5c0-1.25-.756-2.017-2-2H4c-1.25 0-2 .75-2 1.972V11c0 1.25.75 2 2 2 1 0 1 0 1 1v1c0 1-1 2-2 2s-1 .008-1 1.031V20c0 1 0 1 1 1z",
      key: "4rm80e"
    }
  ],
  [
    "path",
    {
      d: "M15 21c3 0 7-1 7-8V5c0-1.25-.757-2.017-2-2h-4c-1.25 0-2 .75-2 1.972V11c0 1.25.75 2 2 2h.75c0 2.25.25 4-2.75 4v3c0 1 0 1 1 1z",
      key: "10za9r"
    }
  ]
]);

const LuRabbit = createLucideIcon("LuRabbit", [
  ["path", { d: "M13 16a3 3 0 0 1 2.24 5", key: "1epib5" }],
  ["path", { d: "M18 12h.01", key: "yjnet6" }],
  [
    "path",
    {
      d: "M18 21h-8a4 4 0 0 1-4-4 7 7 0 0 1 7-7h.2L9.6 6.4a1 1 0 1 1 2.8-2.8L15.8 7h.2c3.3 0 6 2.7 6 6v1a2 2 0 0 1-2 2h-1a3 3 0 0 0-3 3",
      key: "ue9ozu"
    }
  ],
  ["path", { d: "M20 8.54V4a2 2 0 1 0-4 0v3", key: "49iql8" }],
  ["path", { d: "M7.612 12.524a3 3 0 1 0-1.6 4.3", key: "1e33i0" }]
]);

const LuRadar = createLucideIcon("LuRadar", [
  ["path", { d: "M19.07 4.93A10 10 0 0 0 6.99 3.34", key: "z3du51" }],
  ["path", { d: "M4 6h.01", key: "oypzma" }],
  ["path", { d: "M2.29 9.62A10 10 0 1 0 21.31 8.35", key: "qzzz0" }],
  ["path", { d: "M16.24 7.76A6 6 0 1 0 8.23 16.67", key: "1yjesh" }],
  ["path", { d: "M12 18h.01", key: "mhygvu" }],
  ["path", { d: "M17.99 11.66A6 6 0 0 1 15.77 16.67", key: "1u2y91" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }],
  ["path", { d: "m13.41 10.59 5.66-5.66", key: "mhq4k0" }]
]);

const LuRadiation = createLucideIcon("LuRadiation", [
  ["path", { d: "M12 12h0.01", key: "6ztbls" }],
  [
    "path",
    {
      d: "M7.5 4.2c-.3-.5-.9-.7-1.3-.4C3.9 5.5 2.3 8.1 2 11c-.1.5.4 1 1 1h5c0-1.5.8-2.8 2-3.4-1.1-1.9-2-3.5-2.5-4.4z",
      key: "wy49g3"
    }
  ],
  [
    "path",
    {
      d: "M21 12c.6 0 1-.4 1-1-.3-2.9-1.8-5.5-4.1-7.1-.4-.3-1.1-.2-1.3.3-.6.9-1.5 2.5-2.6 4.3 1.2.7 2 2 2 3.5h5z",
      key: "vklnvr"
    }
  ],
  [
    "path",
    {
      d: "M7.5 19.8c-.3.5-.1 1.1.4 1.3 2.6 1.2 5.6 1.2 8.2 0 .5-.2.7-.8.4-1.3-.5-.9-1.4-2.5-2.5-4.3-1.2.7-2.8.7-4 0-1.1 1.8-2 3.4-2.5 4.3z",
      key: "wkdf1o"
    }
  ]
]);

const LuRadical = createLucideIcon("LuRadical", [
  ["path", { d: "M3 12h4l3 9 4-17h7", key: "bpxjrx" }]
]);

const LuRadioReceiver = createLucideIcon("LuRadioReceiver", [
  ["path", { d: "M5 16v2", key: "g5qcv5" }],
  ["path", { d: "M19 16v2", key: "1gbaio" }],
  ["rect", { width: "20", height: "8", x: "2", y: "8", rx: "2", key: "vjsjur" }],
  ["path", { d: "M18 12h0", key: "1ucjzd" }]
]);

const LuRadioTower = createLucideIcon("LuRadioTower", [
  ["path", { d: "M4.9 16.1C1 12.2 1 5.8 4.9 1.9", key: "s0qx1y" }],
  ["path", { d: "M7.8 4.7a6.14 6.14 0 0 0-.8 7.5", key: "1idnkw" }],
  ["circle", { cx: "12", cy: "9", r: "2", key: "1092wv" }],
  ["path", { d: "M16.2 4.8c2 2 2.26 5.11.8 7.47", key: "ojru2q" }],
  ["path", { d: "M19.1 1.9a9.96 9.96 0 0 1 0 14.1", key: "rhi7fg" }],
  ["path", { d: "M9.5 18h5", key: "mfy3pd" }],
  ["path", { d: "m8 22 4-11 4 11", key: "25yftu" }]
]);

const LuRadio = createLucideIcon("LuRadio", [
  ["path", { d: "M4.9 19.1C1 15.2 1 8.8 4.9 4.9", key: "1vaf9d" }],
  ["path", { d: "M7.8 16.2c-2.3-2.3-2.3-6.1 0-8.5", key: "u1ii0m" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }],
  ["path", { d: "M16.2 7.8c2.3 2.3 2.3 6.1 0 8.5", key: "1j5fej" }],
  ["path", { d: "M19.1 4.9C23 8.8 23 15.1 19.1 19", key: "10b0cb" }]
]);

const LuRadius = createLucideIcon("LuRadius", [
  ["path", { d: "M20.34 17.52a10 10 0 1 0-2.82 2.82", key: "fydyku" }],
  ["circle", { cx: "19", cy: "19", r: "2", key: "17f5cg" }],
  ["path", { d: "m13.41 13.41 4.18 4.18", key: "1gqbwc" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }]
]);

const LuRailSymbol = createLucideIcon("LuRailSymbol", [
  ["path", { d: "M5 15h14", key: "m0yey3" }],
  ["path", { d: "M5 9h14", key: "7tsvo6" }],
  ["path", { d: "m14 20-5-5 6-6-5-5", key: "1jo42i" }]
]);

const LuRainbow = createLucideIcon("LuRainbow", [
  ["path", { d: "M22 17a10 10 0 0 0-20 0", key: "ozegv" }],
  ["path", { d: "M6 17a6 6 0 0 1 12 0", key: "5giftw" }],
  ["path", { d: "M10 17a2 2 0 0 1 4 0", key: "gnsikk" }]
]);

const LuRat = createLucideIcon("LuRat", [
  [
    "path",
    {
      d: "M17 5c0-1.7-1.3-3-3-3s-3 1.3-3 3c0 .8.3 1.5.8 2H11c-3.9 0-7 3.1-7 7v0c0 2.2 1.8 4 4 4",
      key: "16aj0u"
    }
  ],
  [
    "path",
    {
      d: "M16.8 3.9c.3-.3.6-.5 1-.7 1.5-.6 3.3.1 3.9 1.6.6 1.5-.1 3.3-1.6 3.9l1.6 2.8c.2.3.2.7.2 1-.2.8-.9 1.2-1.7 1.1 0 0-1.6-.3-2.7-.6H17c-1.7 0-3 1.3-3 3",
      key: "1crdmb"
    }
  ],
  ["path", { d: "M13.2 18a3 3 0 0 0-2.2-5", key: "1ol3lk" }],
  ["path", { d: "M13 22H4a2 2 0 0 1 0-4h12", key: "bt3f23" }],
  ["path", { d: "M16 9h.01", key: "1bdo4e" }]
]);

const LuRatio = createLucideIcon("LuRatio", [
  ["rect", { width: "12", height: "20", x: "6", y: "2", rx: "2", key: "1oxtiu" }],
  ["rect", { width: "20", height: "12", x: "2", y: "6", rx: "2", key: "9lu3g6" }]
]);

const LuReceiptCent = createLucideIcon("LuReceiptCent", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "M12 6.5v11", key: "ecfhkf" }],
  ["path", { d: "M15 9.4a4 4 0 1 0 0 5.2", key: "1makmb" }]
]);

const LuReceiptEuro = createLucideIcon("LuReceiptEuro", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "M8 12h5", key: "1g6qi8" }],
  ["path", { d: "M16 9.5a4 4 0 1 0 0 5.2", key: "b2px4r" }]
]);

const LuReceiptIndianRupee = createLucideIcon("LuReceiptIndianRupee", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "M8 7h8", key: "i86dvs" }],
  ["path", { d: "M12 17.5 8 15h1a4 4 0 0 0 0-8", key: "grpkl4" }],
  ["path", { d: "M8 11h8", key: "vwpz6n" }]
]);

const LuReceiptJapaneseYen = createLucideIcon("LuReceiptJapaneseYen", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "m12 10 3-3", key: "1mc12w" }],
  ["path", { d: "m9 7 3 3v7.5", key: "39i0xv" }],
  ["path", { d: "M9 11h6", key: "1fldmi" }],
  ["path", { d: "M9 15h6", key: "cctwl0" }]
]);

const LuReceiptPoundSterling = createLucideIcon("LuReceiptPoundSterling", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "M8 13h5", key: "1k9z8w" }],
  ["path", { d: "M10 17V9.5a2.5 2.5 0 0 1 5 0", key: "1dzgp0" }],
  ["path", { d: "M8 17h7", key: "8mjdqu" }]
]);

const LuReceiptRussianRuble = createLucideIcon("LuReceiptRussianRuble", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "M8 15h5", key: "vxg57a" }],
  ["path", { d: "M8 11h5a2 2 0 1 0 0-4h-3v10", key: "1usi5u" }]
]);

const LuReceiptSwissFranc = createLucideIcon("LuReceiptSwissFranc", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "M10 17V7h5", key: "k7jq18" }],
  ["path", { d: "M10 11h4", key: "1i0mka" }],
  ["path", { d: "M8 15h5", key: "vxg57a" }]
]);

const LuReceiptText = createLucideIcon("LuReceiptText", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "M14 8H8", key: "1l3xfs" }],
  ["path", { d: "M16 12H8", key: "1fr5h0" }],
  ["path", { d: "M13 16H8", key: "wsln4y" }]
]);

const LuReceipt = createLucideIcon("LuReceipt", [
  [
    "path",
    { d: "M4 2v20l2-1 2 1 2-1 2 1 2-1 2 1 2-1 2 1V2l-2 1-2-1-2 1-2-1-2 1-2-1-2 1Z", key: "q3az6g" }
  ],
  ["path", { d: "M16 8h-6a2 2 0 1 0 0 4h4a2 2 0 1 1 0 4H8", key: "1h4pet" }],
  ["path", { d: "M12 17.5v-11", key: "1jc1ny" }]
]);

const LuRectangleEllipsis = createLucideIcon("LuRectangleEllipsis", [
  ["rect", { width: "20", height: "12", x: "2", y: "6", rx: "2", key: "9lu3g6" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }],
  ["path", { d: "M17 12h.01", key: "1m0b6t" }],
  ["path", { d: "M7 12h.01", key: "eqddd0" }]
]);

const LuRectangleHorizontal = createLucideIcon("LuRectangleHorizontal", [
  ["rect", { width: "20", height: "12", x: "2", y: "6", rx: "2", key: "9lu3g6" }]
]);

const LuRectangleVertical = createLucideIcon("LuRectangleVertical", [
  ["rect", { width: "12", height: "20", x: "6", y: "2", rx: "2", key: "1oxtiu" }]
]);

const LuRecycle = createLucideIcon("LuRecycle", [
  [
    "path",
    {
      d: "M7 19H4.815a1.83 1.83 0 0 1-1.57-.881 1.785 1.785 0 0 1-.004-1.784L7.196 9.5",
      key: "x6z5xu"
    }
  ],
  [
    "path",
    {
      d: "M11 19h8.203a1.83 1.83 0 0 0 1.556-.89 1.784 1.784 0 0 0 0-1.775l-1.226-2.12",
      key: "1x4zh5"
    }
  ],
  ["path", { d: "m14 16-3 3 3 3", key: "f6jyew" }],
  ["path", { d: "M8.293 13.596 7.196 9.5 3.1 10.598", key: "wf1obh" }],
  [
    "path",
    {
      d: "m9.344 5.811 1.093-1.892A1.83 1.83 0 0 1 11.985 3a1.784 1.784 0 0 1 1.546.888l3.943 6.843",
      key: "9tzpgr"
    }
  ],
  ["path", { d: "m13.378 9.633 4.096 1.098 1.097-4.096", key: "1oe83g" }]
]);

const LuRedo2 = createLucideIcon("LuRedo2", [
  ["path", { d: "m15 14 5-5-5-5", key: "12vg1m" }],
  ["path", { d: "M20 9H9.5A5.5 5.5 0 0 0 4 14.5v0A5.5 5.5 0 0 0 9.5 20H13", key: "19mnr4" }]
]);

const LuRedoDot = createLucideIcon("LuRedoDot", [
  ["circle", { cx: "12", cy: "17", r: "1", key: "1ixnty" }],
  ["path", { d: "M21 7v6h-6", key: "3ptur4" }],
  ["path", { d: "M3 17a9 9 0 0 1 9-9 9 9 0 0 1 6 2.3l3 2.7", key: "1kgawr" }]
]);

const LuRedo = createLucideIcon("LuRedo", [
  ["path", { d: "M21 7v6h-6", key: "3ptur4" }],
  ["path", { d: "M3 17a9 9 0 0 1 9-9 9 9 0 0 1 6 2.3l3 2.7", key: "1kgawr" }]
]);

const LuRefreshCcwDot = createLucideIcon("LuRefreshCcwDot", [
  ["path", { d: "M3 2v6h6", key: "18ldww" }],
  ["path", { d: "M21 12A9 9 0 0 0 6 5.3L3 8", key: "1pbrqz" }],
  ["path", { d: "M21 22v-6h-6", key: "usdfbe" }],
  ["path", { d: "M3 12a9 9 0 0 0 15 6.7l3-2.7", key: "1hosoe" }],
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }]
]);

const LuRefreshCcw = createLucideIcon("LuRefreshCcw", [
  ["path", { d: "M21 12a9 9 0 0 0-9-9 9.75 9.75 0 0 0-6.74 2.74L3 8", key: "14sxne" }],
  ["path", { d: "M3 3v5h5", key: "1xhq8a" }],
  ["path", { d: "M3 12a9 9 0 0 0 9 9 9.75 9.75 0 0 0 6.74-2.74L21 16", key: "1hlbsb" }],
  ["path", { d: "M16 16h5v5", key: "ccwih5" }]
]);

const LuRefreshCwOff = createLucideIcon("LuRefreshCwOff", [
  ["path", { d: "M21 8L18.74 5.74A9.75 9.75 0 0 0 12 3C11 3 10.03 3.16 9.13 3.47", key: "1krf6h" }],
  ["path", { d: "M8 16H3v5", key: "1cv678" }],
  ["path", { d: "M3 12C3 9.51 4 7.26 5.64 5.64", key: "ruvoct" }],
  ["path", { d: "m3 16 2.26 2.26A9.75 9.75 0 0 0 12 21c2.49 0 4.74-1 6.36-2.64", key: "19q130" }],
  ["path", { d: "M21 12c0 1-.16 1.97-.47 2.87", key: "4w8emr" }],
  ["path", { d: "M21 3v5h-5", key: "1q7to0" }],
  ["path", { d: "M22 22 2 2", key: "1r8tn9" }]
]);

const LuRefreshCw = createLucideIcon("LuRefreshCw", [
  ["path", { d: "M3 12a9 9 0 0 1 9-9 9.75 9.75 0 0 1 6.74 2.74L21 8", key: "v9h5vc" }],
  ["path", { d: "M21 3v5h-5", key: "1q7to0" }],
  ["path", { d: "M21 12a9 9 0 0 1-9 9 9.75 9.75 0 0 1-6.74-2.74L3 16", key: "3uifl3" }],
  ["path", { d: "M8 16H3v5", key: "1cv678" }]
]);

const LuRefrigerator = createLucideIcon("LuRefrigerator", [
  [
    "path",
    { d: "M5 6a4 4 0 0 1 4-4h6a4 4 0 0 1 4 4v14a2 2 0 0 1-2 2H7a2 2 0 0 1-2-2V6Z", key: "fpq118" }
  ],
  ["path", { d: "M5 10h14", key: "elsbfy" }],
  ["path", { d: "M15 7v6", key: "1nx30x" }]
]);

const LuRegex = createLucideIcon("LuRegex", [
  ["path", { d: "M17 3v10", key: "15fgeh" }],
  ["path", { d: "m12.67 5.5 8.66 5", key: "1gpheq" }],
  ["path", { d: "m12.67 10.5 8.66-5", key: "1dkfa6" }],
  [
    "path",
    { d: "M9 17a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v2a2 2 0 0 0 2 2h2a2 2 0 0 0 2-2v-2z", key: "swwfx4" }
  ]
]);

const LuRemoveFormatting = createLucideIcon("LuRemoveFormatting", [
  ["path", { d: "M4 7V4h16v3", key: "9msm58" }],
  ["path", { d: "M5 20h6", key: "1h6pxn" }],
  ["path", { d: "M13 4 8 20", key: "kqq6aj" }],
  ["path", { d: "m15 15 5 5", key: "me55sn" }],
  ["path", { d: "m20 15-5 5", key: "11p7ol" }]
]);

const LuRepeat1 = createLucideIcon("LuRepeat1", [
  ["path", { d: "m17 2 4 4-4 4", key: "nntrym" }],
  ["path", { d: "M3 11v-1a4 4 0 0 1 4-4h14", key: "84bu3i" }],
  ["path", { d: "m7 22-4-4 4-4", key: "1wqhfi" }],
  ["path", { d: "M21 13v1a4 4 0 0 1-4 4H3", key: "1rx37r" }],
  ["path", { d: "M11 10h1v4", key: "70cz1p" }]
]);

const LuRepeat2 = createLucideIcon("LuRepeat2", [
  ["path", { d: "m2 9 3-3 3 3", key: "1ltn5i" }],
  ["path", { d: "M13 18H7a2 2 0 0 1-2-2V6", key: "1r6tfw" }],
  ["path", { d: "m22 15-3 3-3-3", key: "4rnwn2" }],
  ["path", { d: "M11 6h6a2 2 0 0 1 2 2v10", key: "2f72bc" }]
]);

const LuRepeat = createLucideIcon("LuRepeat", [
  ["path", { d: "m17 2 4 4-4 4", key: "nntrym" }],
  ["path", { d: "M3 11v-1a4 4 0 0 1 4-4h14", key: "84bu3i" }],
  ["path", { d: "m7 22-4-4 4-4", key: "1wqhfi" }],
  ["path", { d: "M21 13v1a4 4 0 0 1-4 4H3", key: "1rx37r" }]
]);

const LuReplaceAll = createLucideIcon("LuReplaceAll", [
  ["path", { d: "M14 4c0-1.1.9-2 2-2", key: "1mvvbw" }],
  ["path", { d: "M20 2c1.1 0 2 .9 2 2", key: "1mj6oe" }],
  ["path", { d: "M22 8c0 1.1-.9 2-2 2", key: "v1wql3" }],
  ["path", { d: "M16 10c-1.1 0-2-.9-2-2", key: "821ux0" }],
  ["path", { d: "m3 7 3 3 3-3", key: "x25e72" }],
  ["path", { d: "M6 10V5c0-1.7 1.3-3 3-3h1", key: "13af7h" }],
  ["rect", { width: "8", height: "8", x: "2", y: "14", rx: "2", key: "17ihk4" }],
  ["path", { d: "M14 14c1.1 0 2 .9 2 2v4c0 1.1-.9 2-2 2", key: "1w9p8c" }],
  ["path", { d: "M20 14c1.1 0 2 .9 2 2v4c0 1.1-.9 2-2 2", key: "m45eaa" }]
]);

const LuReplace = createLucideIcon("LuReplace", [
  ["path", { d: "M14 4c0-1.1.9-2 2-2", key: "1mvvbw" }],
  ["path", { d: "M20 2c1.1 0 2 .9 2 2", key: "1mj6oe" }],
  ["path", { d: "M22 8c0 1.1-.9 2-2 2", key: "v1wql3" }],
  ["path", { d: "M16 10c-1.1 0-2-.9-2-2", key: "821ux0" }],
  ["path", { d: "m3 7 3 3 3-3", key: "x25e72" }],
  ["path", { d: "M6 10V5c0-1.7 1.3-3 3-3h1", key: "13af7h" }],
  ["rect", { width: "8", height: "8", x: "2", y: "14", rx: "2", key: "17ihk4" }]
]);

const LuReplyAll = createLucideIcon("LuReplyAll", [
  ["polyline", { points: "7 17 2 12 7 7", key: "t83bqg" }],
  ["polyline", { points: "12 17 7 12 12 7", key: "1g4ajm" }],
  ["path", { d: "M22 18v-2a4 4 0 0 0-4-4H7", key: "1fcyog" }]
]);

const LuReply = createLucideIcon("LuReply", [
  ["polyline", { points: "9 17 4 12 9 7", key: "hvgpf2" }],
  ["path", { d: "M20 18v-2a4 4 0 0 0-4-4H4", key: "5vmcpk" }]
]);

const LuRewind = createLucideIcon("LuRewind", [
  ["polygon", { points: "11 19 2 12 11 5 11 19", key: "14yba5" }],
  ["polygon", { points: "22 19 13 12 22 5 22 19", key: "1pi1cj" }]
]);

const LuRibbon = createLucideIcon("LuRibbon", [
  [
    "path",
    {
      d: "M17.75 9.01c-.52 2.08-1.83 3.64-3.18 5.49l-2.6 3.54-2.97 4-3.5-2.54 3.85-4.97c-1.86-2.61-2.8-3.77-3.16-5.44",
      key: "1njedg"
    }
  ],
  [
    "path",
    {
      d: "M17.75 9.01A7 7 0 0 0 6.2 9.1C6.06 8.5 6 7.82 6 7c0-3.5 2.83-5 5.98-5C15.24 2 18 3.5 18 7c0 .73-.09 1.4-.25 2.01Z",
      key: "10len7"
    }
  ],
  ["path", { d: "m9.35 14.53 2.64-3.31", key: "1wfi09" }],
  ["path", { d: "m11.97 18.04 2.99 4 3.54-2.54-3.93-5", key: "1ezyge" }],
  ["path", { d: "M14 8c0 1-1 2-2.01 3.22C11 10 10 9 10 8a2 2 0 1 1 4 0", key: "aw0zq5" }]
]);

const LuRocket = createLucideIcon("LuRocket", [
  [
    "path",
    {
      d: "M4.5 16.5c-1.5 1.26-2 5-2 5s3.74-.5 5-2c.71-.84.7-2.13-.09-2.91a2.18 2.18 0 0 0-2.91-.09z",
      key: "m3kijz"
    }
  ],
  [
    "path",
    {
      d: "m12 15-3-3a22 22 0 0 1 2-3.95A12.88 12.88 0 0 1 22 2c0 2.72-.78 7.5-6 11a22.35 22.35 0 0 1-4 2z",
      key: "1fmvmk"
    }
  ],
  ["path", { d: "M9 12H4s.55-3.03 2-4c1.62-1.08 5 0 5 0", key: "1f8sc4" }],
  ["path", { d: "M12 15v5s3.03-.55 4-2c1.08-1.62 0-5 0-5", key: "qeys4" }]
]);

const LuRockingChair = createLucideIcon("LuRockingChair", [
  ["polyline", { points: "3.5 2 6.5 12.5 18 12.5", key: "y3iy52" }],
  ["line", { x1: "9.5", x2: "5.5", y1: "12.5", y2: "20", key: "19vg5i" }],
  ["line", { x1: "15", x2: "18.5", y1: "12.5", y2: "20", key: "1inpmv" }],
  ["path", { d: "M2.75 18a13 13 0 0 0 18.5 0", key: "1nquas" }]
]);

const LuRollerCoaster = createLucideIcon("LuRollerCoaster", [
  ["path", { d: "M6 19V5", key: "1r845m" }],
  ["path", { d: "M10 19V6.8", key: "9j2tfs" }],
  ["path", { d: "M14 19v-7.8", key: "10s8qv" }],
  ["path", { d: "M18 5v4", key: "1tajlv" }],
  ["path", { d: "M18 19v-6", key: "ielfq3" }],
  ["path", { d: "M22 19V9", key: "158nzp" }],
  ["path", { d: "M2 19V9a4 4 0 0 1 4-4c2 0 4 1.33 6 4s4 4 6 4a4 4 0 1 0-3-6.65", key: "1930oh" }]
]);

const LuRotate3d = createLucideIcon("LuRotate3d", [
  [
    "path",
    {
      d: "M16.466 7.5C15.643 4.237 13.952 2 12 2 9.239 2 7 6.477 7 12s2.239 10 5 10c.342 0 .677-.069 1-.2",
      key: "10n0gc"
    }
  ],
  ["path", { d: "m15.194 13.707 3.814 1.86-1.86 3.814", key: "16shm9" }],
  [
    "path",
    {
      d: "M19 15.57c-1.804.885-4.274 1.43-7 1.43-5.523 0-10-2.239-10-5s4.477-5 10-5c4.838 0 8.873 1.718 9.8 4",
      key: "1lxi77"
    }
  ]
]);

const LuRotateCcwSquare = createLucideIcon("LuRotateCcwSquare", [
  ["path", { d: "M20 9V7a2 2 0 0 0-2-2h-6", key: "19z8uc" }],
  ["path", { d: "m15 2-3 3 3 3", key: "177bxs" }],
  ["path", { d: "M20 13v5a2 2 0 0 1-2 2H6a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h2", key: "d36hnl" }]
]);

const LuRotateCcw = createLucideIcon("LuRotateCcw", [
  ["path", { d: "M3 12a9 9 0 1 0 9-9 9.75 9.75 0 0 0-6.74 2.74L3 8", key: "1357e3" }],
  ["path", { d: "M3 3v5h5", key: "1xhq8a" }]
]);

const LuRotateCwSquare = createLucideIcon("LuRotateCwSquare", [
  ["path", { d: "M12 5H6a2 2 0 0 0-2 2v3", key: "l96uqu" }],
  ["path", { d: "m9 8 3-3-3-3", key: "1gzgc3" }],
  ["path", { d: "M4 14v4a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2V7a2 2 0 0 0-2-2h-2", key: "1w2k5h" }]
]);

const LuRotateCw = createLucideIcon("LuRotateCw", [
  ["path", { d: "M21 12a9 9 0 1 1-9-9c2.52 0 4.93 1 6.74 2.74L21 8", key: "1p45f6" }],
  ["path", { d: "M21 3v5h-5", key: "1q7to0" }]
]);

const LuRouteOff = createLucideIcon("LuRouteOff", [
  ["circle", { cx: "6", cy: "19", r: "3", key: "1kj8tv" }],
  ["path", { d: "M9 19h8.5c.4 0 .9-.1 1.3-.2", key: "1effex" }],
  ["path", { d: "M5.2 5.2A3.5 3.53 0 0 0 6.5 12H12", key: "k9y2ds" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M21 15.3a3.5 3.5 0 0 0-3.3-3.3", key: "11nlu2" }],
  ["path", { d: "M15 5h-4.3", key: "6537je" }],
  ["circle", { cx: "18", cy: "5", r: "3", key: "gq8acd" }]
]);

const LuRoute = createLucideIcon("LuRoute", [
  ["circle", { cx: "6", cy: "19", r: "3", key: "1kj8tv" }],
  ["path", { d: "M9 19h8.5a3.5 3.5 0 0 0 0-7h-11a3.5 3.5 0 0 1 0-7H15", key: "1d8sl" }],
  ["circle", { cx: "18", cy: "5", r: "3", key: "gq8acd" }]
]);

const LuRouter = createLucideIcon("LuRouter", [
  ["rect", { width: "20", height: "8", x: "2", y: "14", rx: "2", key: "w68u3i" }],
  ["path", { d: "M6.01 18H6", key: "19vcac" }],
  ["path", { d: "M10.01 18H10", key: "uamcmx" }],
  ["path", { d: "M15 10v4", key: "qjz1xs" }],
  ["path", { d: "M17.84 7.17a4 4 0 0 0-5.66 0", key: "1rif40" }],
  ["path", { d: "M20.66 4.34a8 8 0 0 0-11.31 0", key: "6a5xfq" }]
]);

const LuRows2 = createLucideIcon("LuRows2", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 12h18", key: "1i2n21" }]
]);

const LuRows3 = createLucideIcon("LuRows3", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M21 9H3", key: "1338ky" }],
  ["path", { d: "M21 15H3", key: "9uk58r" }]
]);

const LuRows4 = createLucideIcon("LuRows4", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M21 7.5H3", key: "1hm9pq" }],
  ["path", { d: "M21 12H3", key: "2avoz0" }],
  ["path", { d: "M21 16.5H3", key: "n7jzkj" }]
]);

const LuRss = createLucideIcon("LuRss", [
  ["path", { d: "M4 11a9 9 0 0 1 9 9", key: "pv89mb" }],
  ["path", { d: "M4 4a16 16 0 0 1 16 16", key: "k0647b" }],
  ["circle", { cx: "5", cy: "19", r: "1", key: "bfqh0e" }]
]);

const LuRuler = createLucideIcon("LuRuler", [
  [
    "path",
    {
      d: "M21.3 15.3a2.4 2.4 0 0 1 0 3.4l-2.6 2.6a2.4 2.4 0 0 1-3.4 0L2.7 8.7a2.41 2.41 0 0 1 0-3.4l2.6-2.6a2.41 2.41 0 0 1 3.4 0Z",
      key: "icamh8"
    }
  ],
  ["path", { d: "m14.5 12.5 2-2", key: "inckbg" }],
  ["path", { d: "m11.5 9.5 2-2", key: "fmmyf7" }],
  ["path", { d: "m8.5 6.5 2-2", key: "vc6u1g" }],
  ["path", { d: "m17.5 15.5 2-2", key: "wo5hmg" }]
]);

const LuRussianRuble = createLucideIcon("LuRussianRuble", [
  ["path", { d: "M6 11h8a4 4 0 0 0 0-8H9v18", key: "18ai8t" }],
  ["path", { d: "M6 15h8", key: "1y8f6l" }]
]);

const LuSailboat = createLucideIcon("LuSailboat", [
  ["path", { d: "M22 18H2a4 4 0 0 0 4 4h12a4 4 0 0 0 4-4Z", key: "1404fh" }],
  ["path", { d: "M21 14 10 2 3 14h18Z", key: "1nzg7v" }],
  ["path", { d: "M10 2v16", key: "1labyt" }]
]);

const LuSalad = createLucideIcon("LuSalad", [
  ["path", { d: "M7 21h10", key: "1b0cd5" }],
  ["path", { d: "M12 21a9 9 0 0 0 9-9H3a9 9 0 0 0 9 9Z", key: "4rw317" }],
  [
    "path",
    {
      d: "M11.38 12a2.4 2.4 0 0 1-.4-4.77 2.4 2.4 0 0 1 3.2-2.77 2.4 2.4 0 0 1 3.47-.63 2.4 2.4 0 0 1 3.37 3.37 2.4 2.4 0 0 1-1.1 3.7 2.51 2.51 0 0 1 .03 1.1",
      key: "10xrj0"
    }
  ],
  ["path", { d: "m13 12 4-4", key: "1hckqy" }],
  ["path", { d: "M10.9 7.25A3.99 3.99 0 0 0 4 10c0 .73.2 1.41.54 2", key: "1p4srx" }]
]);

const LuSandwich = createLucideIcon("LuSandwich", [
  ["path", { d: "M3 11v3a1 1 0 0 0 1 1h16a1 1 0 0 0 1-1v-3", key: "34v9d7" }],
  [
    "path",
    {
      d: "M12 19H4a1 1 0 0 1-1-1v-2a1 1 0 0 1 1-1h16a1 1 0 0 1 1 1v2a1 1 0 0 1-1 1h-3.83",
      key: "1k5vfb"
    }
  ],
  ["path", { d: "m3 11 7.77-6.04a2 2 0 0 1 2.46 0L21 11H3Z", key: "1oe7l6" }],
  ["path", { d: "M12.97 19.77 7 15h12.5l-3.75 4.5a2 2 0 0 1-2.78.27Z", key: "1ts2ri" }]
]);

const LuSatelliteDish = createLucideIcon("LuSatelliteDish", [
  ["path", { d: "M4 10a7.31 7.31 0 0 0 10 10Z", key: "1fzpp3" }],
  ["path", { d: "m9 15 3-3", key: "88sc13" }],
  ["path", { d: "M17 13a6 6 0 0 0-6-6", key: "15cc6u" }],
  ["path", { d: "M21 13A10 10 0 0 0 11 3", key: "11nf8s" }]
]);

const LuSatellite = createLucideIcon("LuSatellite", [
  ["path", { d: "M13 7 9 3 5 7l4 4", key: "vyckw6" }],
  ["path", { d: "m17 11 4 4-4 4-4-4", key: "rchckc" }],
  ["path", { d: "m8 12 4 4 6-6-4-4Z", key: "1sshf7" }],
  ["path", { d: "m16 8 3-3", key: "x428zp" }],
  ["path", { d: "M9 21a6 6 0 0 0-6-6", key: "1iajcf" }]
]);

const LuSaveAll = createLucideIcon("LuSaveAll", [
  ["path", { d: "M6 4a2 2 0 0 1 2-2h10l4 4v10.2a2 2 0 0 1-2 1.8H8a2 2 0 0 1-2-2Z", key: "1unput" }],
  ["path", { d: "M10 2v4h6", key: "1p5sg6" }],
  ["path", { d: "M18 18v-7h-8v7", key: "1oniuk" }],
  ["path", { d: "M18 22H4a2 2 0 0 1-2-2V6", key: "pblm9e" }]
]);

const LuSave = createLucideIcon("LuSave", [
  ["path", { d: "M19 21H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h11l5 5v11a2 2 0 0 1-2 2z", key: "1owoqh" }],
  ["polyline", { points: "17 21 17 13 7 13 7 21", key: "1md35c" }],
  ["polyline", { points: "7 3 7 8 15 8", key: "8nz8an" }]
]);

const LuScale3d = createLucideIcon("LuScale3d", [
  ["circle", { cx: "19", cy: "19", r: "2", key: "17f5cg" }],
  ["circle", { cx: "5", cy: "5", r: "2", key: "1gwv83" }],
  ["path", { d: "M5 7v12h12", key: "vtaa4r" }],
  ["path", { d: "m5 19 6-6", key: "jh6hbb" }]
]);

const LuScale = createLucideIcon("LuScale", [
  ["path", { d: "m16 16 3-8 3 8c-.87.65-1.92 1-3 1s-2.13-.35-3-1Z", key: "7g6ntu" }],
  ["path", { d: "m2 16 3-8 3 8c-.87.65-1.92 1-3 1s-2.13-.35-3-1Z", key: "ijws7r" }],
  ["path", { d: "M7 21h10", key: "1b0cd5" }],
  ["path", { d: "M12 3v18", key: "108xh3" }],
  ["path", { d: "M3 7h2c2 0 5-1 7-2 2 1 5 2 7 2h2", key: "3gwbw2" }]
]);

const LuScaling = createLucideIcon("LuScaling", [
  ["path", { d: "M12 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7", key: "1m0v6g" }],
  ["path", { d: "M14 15H9v-5", key: "pi4jk9" }],
  ["path", { d: "M16 3h5v5", key: "1806ms" }],
  ["path", { d: "M21 3 9 15", key: "15kdhq" }]
]);

const LuScanBarcode = createLucideIcon("LuScanBarcode", [
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }],
  ["path", { d: "M8 7v10", key: "23sfjj" }],
  ["path", { d: "M12 7v10", key: "jspqdw" }],
  ["path", { d: "M17 7v10", key: "578dap" }]
]);

const LuScanEye = createLucideIcon("LuScanEye", [
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }],
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }],
  ["path", { d: "M5 12s2.5-5 7-5 7 5 7 5-2.5 5-7 5-7-5-7-5", key: "nhuolu" }]
]);

const LuScanFace = createLucideIcon("LuScanFace", [
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }],
  ["path", { d: "M8 14s1.5 2 4 2 4-2 4-2", key: "1y1vjs" }],
  ["path", { d: "M9 9h.01", key: "1q5me6" }],
  ["path", { d: "M15 9h.01", key: "x1ddxp" }]
]);

const LuScanLine = createLucideIcon("LuScanLine", [
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }],
  ["path", { d: "M7 12h10", key: "b7w52i" }]
]);

const LuScanSearch = createLucideIcon("LuScanSearch", [
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }],
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  ["path", { d: "m16 16-1.9-1.9", key: "1dq9hf" }]
]);

const LuScanText = createLucideIcon("LuScanText", [
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }],
  ["path", { d: "M7 8h8", key: "1jbsf9" }],
  ["path", { d: "M7 12h10", key: "b7w52i" }],
  ["path", { d: "M7 16h6", key: "1vyc9m" }]
]);

const LuScan = createLucideIcon("LuScan", [
  ["path", { d: "M3 7V5a2 2 0 0 1 2-2h2", key: "aa7l1z" }],
  ["path", { d: "M17 3h2a2 2 0 0 1 2 2v2", key: "4qcy5o" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2h-2", key: "6vwrx8" }],
  ["path", { d: "M7 21H5a2 2 0 0 1-2-2v-2", key: "ioqczr" }]
]);

const LuScatterChart = createLucideIcon("LuScatterChart", [
  ["circle", { cx: "7.5", cy: "7.5", r: ".5", fill: "currentColor", key: "kqv944" }],
  ["circle", { cx: "18.5", cy: "5.5", r: ".5", fill: "currentColor", key: "lysivs" }],
  ["circle", { cx: "11.5", cy: "11.5", r: ".5", fill: "currentColor", key: "byv1b8" }],
  ["circle", { cx: "7.5", cy: "16.5", r: ".5", fill: "currentColor", key: "nkw3mc" }],
  ["circle", { cx: "17.5", cy: "14.5", r: ".5", fill: "currentColor", key: "1gjh6j" }],
  ["path", { d: "M3 3v18h18", key: "1s2lah" }]
]);

const LuSchool = createLucideIcon("LuSchool", [
  ["path", { d: "M14 22v-4a2 2 0 1 0-4 0v4", key: "hhkicm" }],
  ["path", { d: "m18 10 4 2v8a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2v-8l4-2", key: "1vwozw" }],
  ["path", { d: "M18 5v17", key: "1sw6gf" }],
  ["path", { d: "m4 6 8-4 8 4", key: "1q0ilc" }],
  ["path", { d: "M6 5v17", key: "1xfsm0" }],
  ["circle", { cx: "12", cy: "9", r: "2", key: "1092wv" }]
]);

const LuScissorsLineDashed = createLucideIcon("LuScissorsLineDashed", [
  ["path", { d: "M5.42 9.42 8 12", key: "12pkuq" }],
  ["circle", { cx: "4", cy: "8", r: "2", key: "107mxr" }],
  ["path", { d: "m14 6-8.58 8.58", key: "gvzu5l" }],
  ["circle", { cx: "4", cy: "16", r: "2", key: "1ehqvc" }],
  ["path", { d: "M10.8 14.8 14 18", key: "ax7m9r" }],
  ["path", { d: "M16 12h-2", key: "10asgb" }],
  ["path", { d: "M22 12h-2", key: "14jgyd" }]
]);

const LuScissors = createLucideIcon("LuScissors", [
  ["circle", { cx: "6", cy: "6", r: "3", key: "1lh9wr" }],
  ["path", { d: "M8.12 8.12 12 12", key: "1alkpv" }],
  ["path", { d: "M20 4 8.12 15.88", key: "xgtan2" }],
  ["circle", { cx: "6", cy: "18", r: "3", key: "fqmcym" }],
  ["path", { d: "M14.8 14.8 20 20", key: "ptml3r" }]
]);

const LuScreenShareOff = createLucideIcon("LuScreenShareOff", [
  ["path", { d: "M13 3H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-3", key: "i8wdob" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "m22 3-5 5", key: "12jva0" }],
  ["path", { d: "m17 3 5 5", key: "k36vhe" }]
]);

const LuScreenShare = createLucideIcon("LuScreenShare", [
  ["path", { d: "M13 3H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-3", key: "i8wdob" }],
  ["path", { d: "M8 21h8", key: "1ev6f3" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }],
  ["path", { d: "m17 8 5-5", key: "fqif7o" }],
  ["path", { d: "M17 3h5v5", key: "1o3tu8" }]
]);

const LuScrollText = createLucideIcon("LuScrollText", [
  [
    "path",
    { d: "M8 21h12a2 2 0 0 0 2-2v-2H10v2a2 2 0 1 1-4 0V5a2 2 0 1 0-4 0v3h4", key: "13a6an" }
  ],
  ["path", { d: "M19 17V5a2 2 0 0 0-2-2H4", key: "zz82l3" }],
  ["path", { d: "M15 8h-5", key: "1khuty" }],
  ["path", { d: "M15 12h-5", key: "r7krc0" }]
]);

const LuScroll = createLucideIcon("LuScroll", [
  [
    "path",
    { d: "M8 21h12a2 2 0 0 0 2-2v-2H10v2a2 2 0 1 1-4 0V5a2 2 0 1 0-4 0v3h4", key: "13a6an" }
  ],
  ["path", { d: "M19 17V5a2 2 0 0 0-2-2H4", key: "zz82l3" }]
]);

const LuSearchCheck = createLucideIcon("LuSearchCheck", [
  ["path", { d: "m8 11 2 2 4-4", key: "1sed1v" }],
  ["circle", { cx: "11", cy: "11", r: "8", key: "4ej97u" }],
  ["path", { d: "m21 21-4.3-4.3", key: "1qie3q" }]
]);

const LuSearchCode = createLucideIcon("LuSearchCode", [
  ["path", { d: "m9 9-2 2 2 2", key: "17gsfh" }],
  ["path", { d: "m13 13 2-2-2-2", key: "186z8k" }],
  ["circle", { cx: "11", cy: "11", r: "8", key: "4ej97u" }],
  ["path", { d: "m21 21-4.3-4.3", key: "1qie3q" }]
]);

const LuSearchSlash = createLucideIcon("LuSearchSlash", [
  ["path", { d: "m13.5 8.5-5 5", key: "1cs55j" }],
  ["circle", { cx: "11", cy: "11", r: "8", key: "4ej97u" }],
  ["path", { d: "m21 21-4.3-4.3", key: "1qie3q" }]
]);

const LuSearchX = createLucideIcon("LuSearchX", [
  ["path", { d: "m13.5 8.5-5 5", key: "1cs55j" }],
  ["path", { d: "m8.5 8.5 5 5", key: "a8mexj" }],
  ["circle", { cx: "11", cy: "11", r: "8", key: "4ej97u" }],
  ["path", { d: "m21 21-4.3-4.3", key: "1qie3q" }]
]);

const LuSearch = createLucideIcon("LuSearch", [
  ["circle", { cx: "11", cy: "11", r: "8", key: "4ej97u" }],
  ["path", { d: "m21 21-4.3-4.3", key: "1qie3q" }]
]);

const LuSendHorizontal = createLucideIcon("LuSendHorizontal", [
  ["path", { d: "m3 3 3 9-3 9 19-9Z", key: "1aobqy" }],
  ["path", { d: "M6 12h16", key: "s4cdu5" }]
]);

const LuSendToBack = createLucideIcon("LuSendToBack", [
  ["rect", { x: "14", y: "14", width: "8", height: "8", rx: "2", key: "1b0bso" }],
  ["rect", { x: "2", y: "2", width: "8", height: "8", rx: "2", key: "1x09vl" }],
  ["path", { d: "M7 14v1a2 2 0 0 0 2 2h1", key: "pao6x6" }],
  ["path", { d: "M14 7h1a2 2 0 0 1 2 2v1", key: "19tdru" }]
]);

const LuSend = createLucideIcon("LuSend", [
  ["path", { d: "m22 2-7 20-4-9-9-4Z", key: "1q3vgg" }],
  ["path", { d: "M22 2 11 13", key: "nzbqef" }]
]);

const LuSeparatorHorizontal = createLucideIcon("LuSeparatorHorizontal", [
  ["line", { x1: "3", x2: "21", y1: "12", y2: "12", key: "10d38w" }],
  ["polyline", { points: "8 8 12 4 16 8", key: "zo8t4w" }],
  ["polyline", { points: "16 16 12 20 8 16", key: "1oyrid" }]
]);

const LuSeparatorVertical = createLucideIcon("LuSeparatorVertical", [
  ["line", { x1: "12", x2: "12", y1: "3", y2: "21", key: "1efggb" }],
  ["polyline", { points: "8 8 4 12 8 16", key: "bnfmv4" }],
  ["polyline", { points: "16 16 20 12 16 8", key: "u90052" }]
]);

const LuServerCog = createLucideIcon("LuServerCog", [
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  [
    "path",
    {
      d: "M4.5 10H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2h-.5",
      key: "tn8das"
    }
  ],
  [
    "path",
    {
      d: "M4.5 14H4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-.5",
      key: "1g2pve"
    }
  ],
  ["path", { d: "M6 6h.01", key: "1utrut" }],
  ["path", { d: "M6 18h.01", key: "uhywen" }],
  ["path", { d: "m15.7 13.4-.9-.3", key: "1jwmzr" }],
  ["path", { d: "m9.2 10.9-.9-.3", key: "qapnim" }],
  ["path", { d: "m10.6 15.7.3-.9", key: "quwk0k" }],
  ["path", { d: "m13.6 15.7-.4-1", key: "cb9xp7" }],
  ["path", { d: "m10.8 9.3-.4-1", key: "1uaiz5" }],
  ["path", { d: "m8.3 13.6 1-.4", key: "s6srou" }],
  ["path", { d: "m14.7 10.8 1-.4", key: "4d31cq" }],
  ["path", { d: "m13.4 8.3-.3.9", key: "1bm987" }]
]);

const LuServerCrash = createLucideIcon("LuServerCrash", [
  [
    "path",
    {
      d: "M6 10H4a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2h-2",
      key: "4b9dqc"
    }
  ],
  [
    "path",
    {
      d: "M6 14H4a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-4a2 2 0 0 0-2-2h-2",
      key: "22nnkd"
    }
  ],
  ["path", { d: "M6 6h.01", key: "1utrut" }],
  ["path", { d: "M6 18h.01", key: "uhywen" }],
  ["path", { d: "m13 6-4 6h6l-4 6", key: "14hqih" }]
]);

const LuServerOff = createLucideIcon("LuServerOff", [
  ["path", { d: "M7 2h13a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2h-5", key: "bt2siv" }],
  ["path", { d: "M10 10 2.5 2.5C2 2 2 2.5 2 5v3a2 2 0 0 0 2 2h6z", key: "1hjrv1" }],
  ["path", { d: "M22 17v-1a2 2 0 0 0-2-2h-1", key: "1iynyr" }],
  ["path", { d: "M4 14a2 2 0 0 0-2 2v4a2 2 0 0 0 2 2h16.5l1-.5.5.5-8-8H4z", key: "161ggg" }],
  ["path", { d: "M6 18h.01", key: "uhywen" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuServer = createLucideIcon("LuServer", [
  ["rect", { width: "20", height: "8", x: "2", y: "2", rx: "2", ry: "2", key: "ngkwjq" }],
  ["rect", { width: "20", height: "8", x: "2", y: "14", rx: "2", ry: "2", key: "iecqi9" }],
  ["line", { x1: "6", x2: "6.01", y1: "6", y2: "6", key: "16zg32" }],
  ["line", { x1: "6", x2: "6.01", y1: "18", y2: "18", key: "nzw8ys" }]
]);

const LuSettings2 = createLucideIcon("LuSettings2", [
  ["path", { d: "M20 7h-9", key: "3s1dr2" }],
  ["path", { d: "M14 17H5", key: "gfn3mx" }],
  ["circle", { cx: "17", cy: "17", r: "3", key: "18b49y" }],
  ["circle", { cx: "7", cy: "7", r: "3", key: "dfmy0x" }]
]);

const LuSettings = createLucideIcon("LuSettings", [
  [
    "path",
    {
      d: "M12.22 2h-.44a2 2 0 0 0-2 2v.18a2 2 0 0 1-1 1.73l-.43.25a2 2 0 0 1-2 0l-.15-.08a2 2 0 0 0-2.73.73l-.22.38a2 2 0 0 0 .73 2.73l.15.1a2 2 0 0 1 1 1.72v.51a2 2 0 0 1-1 1.74l-.15.09a2 2 0 0 0-.73 2.73l.22.38a2 2 0 0 0 2.73.73l.15-.08a2 2 0 0 1 2 0l.43.25a2 2 0 0 1 1 1.73V20a2 2 0 0 0 2 2h.44a2 2 0 0 0 2-2v-.18a2 2 0 0 1 1-1.73l.43-.25a2 2 0 0 1 2 0l.15.08a2 2 0 0 0 2.73-.73l.22-.39a2 2 0 0 0-.73-2.73l-.15-.08a2 2 0 0 1-1-1.74v-.5a2 2 0 0 1 1-1.74l.15-.09a2 2 0 0 0 .73-2.73l-.22-.38a2 2 0 0 0-2.73-.73l-.15.08a2 2 0 0 1-2 0l-.43-.25a2 2 0 0 1-1-1.73V4a2 2 0 0 0-2-2z",
      key: "1qme2f"
    }
  ],
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }]
]);

const LuShapes = createLucideIcon("LuShapes", [
  [
    "path",
    {
      d: "M8.3 10a.7.7 0 0 1-.626-1.079L11.4 3a.7.7 0 0 1 1.198-.043L16.3 8.9a.7.7 0 0 1-.572 1.1Z",
      key: "1bo67w"
    }
  ],
  ["rect", { x: "3", y: "14", width: "7", height: "7", rx: "1", key: "1bkyp8" }],
  ["circle", { cx: "17.5", cy: "17.5", r: "3.5", key: "w3z12y" }]
]);

const LuShare2 = createLucideIcon("LuShare2", [
  ["circle", { cx: "18", cy: "5", r: "3", key: "gq8acd" }],
  ["circle", { cx: "6", cy: "12", r: "3", key: "w7nqdw" }],
  ["circle", { cx: "18", cy: "19", r: "3", key: "1xt0gg" }],
  ["line", { x1: "8.59", x2: "15.42", y1: "13.51", y2: "17.49", key: "47mynk" }],
  ["line", { x1: "15.41", x2: "8.59", y1: "6.51", y2: "10.49", key: "1n3mei" }]
]);

const LuShare = createLucideIcon("LuShare", [
  ["path", { d: "M4 12v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-8", key: "1b2hhj" }],
  ["polyline", { points: "16 6 12 2 8 6", key: "m901s6" }],
  ["line", { x1: "12", x2: "12", y1: "2", y2: "15", key: "1p0rca" }]
]);

const LuSheet = createLucideIcon("LuSheet", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["line", { x1: "3", x2: "21", y1: "9", y2: "9", key: "1vqk6q" }],
  ["line", { x1: "3", x2: "21", y1: "15", y2: "15", key: "o2sbyz" }],
  ["line", { x1: "9", x2: "9", y1: "9", y2: "21", key: "1ib60c" }],
  ["line", { x1: "15", x2: "15", y1: "9", y2: "21", key: "1n26ft" }]
]);

const LuShell = createLucideIcon("LuShell", [
  [
    "path",
    {
      d: "M14 11a2 2 0 1 1-4 0 4 4 0 0 1 8 0 6 6 0 0 1-12 0 8 8 0 0 1 16 0 10 10 0 1 1-20 0 11.93 11.93 0 0 1 2.42-7.22 2 2 0 1 1 3.16 2.44",
      key: "1cn552"
    }
  ]
]);

const LuShieldAlert = createLucideIcon("LuShieldAlert", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "M12 8v4", key: "1got3b" }],
  ["path", { d: "M12 16h.01", key: "1drbdi" }]
]);

const LuShieldBan = createLucideIcon("LuShieldBan", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "m4.243 5.21 14.39 12.472", key: "1c9a7c" }]
]);

const LuShieldCheck = createLucideIcon("LuShieldCheck", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "m9 12 2 2 4-4", key: "dzmm74" }]
]);

const LuShieldEllipsis = createLucideIcon("LuShieldEllipsis", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "M8 12h.01", key: "czm47f" }],
  ["path", { d: "M12 12h.01", key: "1mp3jc" }],
  ["path", { d: "M16 12h.01", key: "1l6xoz" }]
]);

const LuShieldHalf = createLucideIcon("LuShieldHalf", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "M12 22V2", key: "zs6s6o" }]
]);

const LuShieldMinus = createLucideIcon("LuShieldMinus", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "M9 12h6", key: "1c52cq" }]
]);

const LuShieldOff = createLucideIcon("LuShieldOff", [
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  [
    "path",
    {
      d: "M5 5a1 1 0 0 0-1 1v7c0 5 3.5 7.5 7.67 8.94a1 1 0 0 0 .67.01c2.35-.82 4.48-1.97 5.9-3.71",
      key: "1jlk70"
    }
  ],
  [
    "path",
    {
      d: "M9.309 3.652A12.252 12.252 0 0 0 11.24 2.28a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1v7a9.784 9.784 0 0 1-.08 1.264",
      key: "18rp1v"
    }
  ]
]);

const LuShieldPlus = createLucideIcon("LuShieldPlus", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "M9 12h6", key: "1c52cq" }],
  ["path", { d: "M12 9v6", key: "199k2o" }]
]);

const LuShieldQuestion = createLucideIcon("LuShieldQuestion", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "M9.1 9a3 3 0 0 1 5.82 1c0 2-3 3-3 3", key: "mhlwft" }],
  ["path", { d: "M12 17h.01", key: "p32p05" }]
]);

const LuShieldX = createLucideIcon("LuShieldX", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ],
  ["path", { d: "m14.5 9.5-5 5", key: "17q4r4" }],
  ["path", { d: "m9.5 9.5 5 5", key: "18nt4w" }]
]);

const LuShield = createLucideIcon("LuShield", [
  [
    "path",
    {
      d: "M20 13c0 5-3.5 7.5-7.66 8.95a1 1 0 0 1-.67-.01C7.5 20.5 4 18 4 13V6a1 1 0 0 1 1-1c2 0 4.5-1.2 6.24-2.72a1.17 1.17 0 0 1 1.52 0C14.51 3.81 17 5 19 5a1 1 0 0 1 1 1z",
      key: "oel41y"
    }
  ]
]);

const LuShipWheel = createLucideIcon("LuShipWheel", [
  ["circle", { cx: "12", cy: "12", r: "8", key: "46899m" }],
  ["path", { d: "M12 2v7.5", key: "1e5rl5" }],
  ["path", { d: "m19 5-5.23 5.23", key: "1ezxxf" }],
  ["path", { d: "M22 12h-7.5", key: "le1719" }],
  ["path", { d: "m19 19-5.23-5.23", key: "p3fmgn" }],
  ["path", { d: "M12 14.5V22", key: "dgcmos" }],
  ["path", { d: "M10.23 13.77 5 19", key: "qwopd4" }],
  ["path", { d: "M9.5 12H2", key: "r7bup8" }],
  ["path", { d: "M10.23 10.23 5 5", key: "k2y7lj" }],
  ["circle", { cx: "12", cy: "12", r: "2.5", key: "ix0uyj" }]
]);

const LuShip = createLucideIcon("LuShip", [
  [
    "path",
    {
      d: "M2 21c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1 .6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1",
      key: "iegodh"
    }
  ],
  [
    "path",
    { d: "M19.38 20A11.6 11.6 0 0 0 21 14l-9-4-9 4c0 2.9.94 5.34 2.81 7.76", key: "fp8vka" }
  ],
  ["path", { d: "M19 13V7a2 2 0 0 0-2-2H7a2 2 0 0 0-2 2v6", key: "qpkstq" }],
  ["path", { d: "M12 10v4", key: "1kjpxc" }],
  ["path", { d: "M12 2v3", key: "qbqxhf" }]
]);

const LuShirt = createLucideIcon("LuShirt", [
  [
    "path",
    {
      d: "M20.38 3.46 16 2a4 4 0 0 1-8 0L3.62 3.46a2 2 0 0 0-1.34 2.23l.58 3.47a1 1 0 0 0 .99.84H6v10c0 1.1.9 2 2 2h8a2 2 0 0 0 2-2V10h2.15a1 1 0 0 0 .99-.84l.58-3.47a2 2 0 0 0-1.34-2.23z",
      key: "1wgbhj"
    }
  ]
]);

const LuShoppingBag = createLucideIcon("LuShoppingBag", [
  ["path", { d: "M6 2 3 6v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V6l-3-4Z", key: "hou9p0" }],
  ["path", { d: "M3 6h18", key: "d0wm0j" }],
  ["path", { d: "M16 10a4 4 0 0 1-8 0", key: "1ltviw" }]
]);

const LuShoppingBasket = createLucideIcon("LuShoppingBasket", [
  ["path", { d: "m15 11-1 9", key: "5wnq3a" }],
  ["path", { d: "m19 11-4-7", key: "cnml18" }],
  ["path", { d: "M2 11h20", key: "3eubbj" }],
  ["path", { d: "m3.5 11 1.6 7.4a2 2 0 0 0 2 1.6h9.8a2 2 0 0 0 2-1.6l1.7-7.4", key: "yiazzp" }],
  ["path", { d: "M4.5 15.5h15", key: "13mye1" }],
  ["path", { d: "m5 11 4-7", key: "116ra9" }],
  ["path", { d: "m9 11 1 9", key: "1ojof7" }]
]);

const LuShoppingCart = createLucideIcon("LuShoppingCart", [
  ["circle", { cx: "8", cy: "21", r: "1", key: "jimo8o" }],
  ["circle", { cx: "19", cy: "21", r: "1", key: "13723u" }],
  [
    "path",
    {
      d: "M2.05 2.05h2l2.66 12.42a2 2 0 0 0 2 1.58h9.78a2 2 0 0 0 1.95-1.57l1.65-7.43H5.12",
      key: "9zh506"
    }
  ]
]);

const LuShovel = createLucideIcon("LuShovel", [
  ["path", { d: "M2 22v-5l5-5 5 5-5 5z", key: "1fh25c" }],
  ["path", { d: "M9.5 14.5 16 8", key: "1smz5x" }],
  [
    "path",
    { d: "m17 2 5 5-.5.5a3.53 3.53 0 0 1-5 0s0 0 0 0a3.53 3.53 0 0 1 0-5L17 2", key: "1q8uv5" }
  ]
]);

const LuShowerHead = createLucideIcon("LuShowerHead", [
  ["path", { d: "m4 4 2.5 2.5", key: "uv2vmf" }],
  ["path", { d: "M13.5 6.5a4.95 4.95 0 0 0-7 7", key: "frdkwv" }],
  ["path", { d: "M15 5 5 15", key: "1ag8rq" }],
  ["path", { d: "M14 17v.01", key: "eokfpp" }],
  ["path", { d: "M10 16v.01", key: "14uyyl" }],
  ["path", { d: "M13 13v.01", key: "1v1k97" }],
  ["path", { d: "M16 10v.01", key: "5169yg" }],
  ["path", { d: "M11 20v.01", key: "cj92p8" }],
  ["path", { d: "M17 14v.01", key: "11cswd" }],
  ["path", { d: "M20 11v.01", key: "19e0od" }]
]);

const LuShrink = createLucideIcon("LuShrink", [
  ["path", { d: "m15 15 6 6m-6-6v4.8m0-4.8h4.8", key: "17vawe" }],
  ["path", { d: "M9 19.8V15m0 0H4.2M9 15l-6 6", key: "chjx8e" }],
  ["path", { d: "M15 4.2V9m0 0h4.8M15 9l6-6", key: "lav6yq" }],
  ["path", { d: "M9 4.2V9m0 0H4.2M9 9 3 3", key: "1pxi2q" }]
]);

const LuShrub = createLucideIcon("LuShrub", [
  ["path", { d: "M12 22v-7l-2-2", key: "eqv9mc" }],
  [
    "path",
    { d: "M17 8v.8A6 6 0 0 1 13.8 20v0H10v0A6.5 6.5 0 0 1 7 8h0a5 5 0 0 1 10 0Z", key: "12jcau" }
  ],
  ["path", { d: "m14 14-2 2", key: "847xa2" }]
]);

const LuShuffle = createLucideIcon("LuShuffle", [
  ["path", { d: "M2 18h1.4c1.3 0 2.5-.6 3.3-1.7l6.1-8.6c.7-1.1 2-1.7 3.3-1.7H22", key: "1wmou1" }],
  ["path", { d: "m18 2 4 4-4 4", key: "pucp1d" }],
  ["path", { d: "M2 6h1.9c1.5 0 2.9.9 3.6 2.2", key: "10bdb2" }],
  ["path", { d: "M22 18h-5.9c-1.3 0-2.6-.7-3.3-1.8l-.5-.8", key: "vgxac0" }],
  ["path", { d: "m18 14 4 4-4 4", key: "10pe0f" }]
]);

const LuSigma = createLucideIcon("LuSigma", [
  ["path", { d: "M18 7V4H6l6 8-6 8h12v-3", key: "zis8ev" }]
]);

const LuSignalHigh = createLucideIcon("LuSignalHigh", [
  ["path", { d: "M2 20h.01", key: "4haj6o" }],
  ["path", { d: "M7 20v-4", key: "j294jx" }],
  ["path", { d: "M12 20v-8", key: "i3yub9" }],
  ["path", { d: "M17 20V8", key: "1tkaf5" }]
]);

const LuSignalLow = createLucideIcon("LuSignalLow", [
  ["path", { d: "M2 20h.01", key: "4haj6o" }],
  ["path", { d: "M7 20v-4", key: "j294jx" }]
]);

const LuSignalMedium = createLucideIcon("LuSignalMedium", [
  ["path", { d: "M2 20h.01", key: "4haj6o" }],
  ["path", { d: "M7 20v-4", key: "j294jx" }],
  ["path", { d: "M12 20v-8", key: "i3yub9" }]
]);

const LuSignalZero = createLucideIcon("LuSignalZero", [
  ["path", { d: "M2 20h.01", key: "4haj6o" }]
]);

const LuSignal = createLucideIcon("LuSignal", [
  ["path", { d: "M2 20h.01", key: "4haj6o" }],
  ["path", { d: "M7 20v-4", key: "j294jx" }],
  ["path", { d: "M12 20v-8", key: "i3yub9" }],
  ["path", { d: "M17 20V8", key: "1tkaf5" }],
  ["path", { d: "M22 4v16", key: "sih9yq" }]
]);

const LuSignpostBig = createLucideIcon("LuSignpostBig", [
  ["path", { d: "M10 9H4L2 7l2-2h6", key: "1hq7x2" }],
  ["path", { d: "M14 5h6l2 2-2 2h-6", key: "bv62ej" }],
  ["path", { d: "M10 22V4a2 2 0 1 1 4 0v18", key: "eqpcf2" }],
  ["path", { d: "M8 22h8", key: "rmew8v" }]
]);

const LuSignpost = createLucideIcon("LuSignpost", [
  ["path", { d: "M12 3v3", key: "1n5kay" }],
  ["path", { d: "M18.5 13h-13L2 9.5 5.5 6h13L22 9.5Z", key: "27os56" }],
  ["path", { d: "M12 13v8", key: "1l5pq0" }]
]);

const LuSiren = createLucideIcon("LuSiren", [
  ["path", { d: "M7 18v-6a5 5 0 1 1 10 0v6", key: "pcx96s" }],
  [
    "path",
    { d: "M5 21a1 1 0 0 0 1 1h12a1 1 0 0 0 1-1v-1a2 2 0 0 0-2-2H7a2 2 0 0 0-2 2z", key: "1b4s83" }
  ],
  ["path", { d: "M21 12h1", key: "jtio3y" }],
  ["path", { d: "M18.5 4.5 18 5", key: "g5sp9y" }],
  ["path", { d: "M2 12h1", key: "1uaihz" }],
  ["path", { d: "M12 2v1", key: "11qlp1" }],
  ["path", { d: "m4.929 4.929.707.707", key: "1i51kw" }],
  ["path", { d: "M12 12v6", key: "3ahymv" }]
]);

const LuSkipBack = createLucideIcon("LuSkipBack", [
  ["polygon", { points: "19 20 9 12 19 4 19 20", key: "o2sva" }],
  ["line", { x1: "5", x2: "5", y1: "19", y2: "5", key: "1ocqjk" }]
]);

const LuSkipForward = createLucideIcon("LuSkipForward", [
  ["polygon", { points: "5 4 15 12 5 20 5 4", key: "16p6eg" }],
  ["line", { x1: "19", x2: "19", y1: "5", y2: "19", key: "futhcm" }]
]);

const LuSkull = createLucideIcon("LuSkull", [
  ["circle", { cx: "9", cy: "12", r: "1", key: "1vctgf" }],
  ["circle", { cx: "15", cy: "12", r: "1", key: "1tmaij" }],
  ["path", { d: "M8 20v2h8v-2", key: "ded4og" }],
  ["path", { d: "m12.5 17-.5-1-.5 1h1z", key: "3me087" }],
  ["path", { d: "M16 20a2 2 0 0 0 1.56-3.25 8 8 0 1 0-11.12 0A2 2 0 0 0 8 20", key: "xq9p5u" }]
]);

const LuSlack = createLucideIcon("LuSlack", [
  ["rect", { width: "3", height: "8", x: "13", y: "2", rx: "1.5", key: "diqz80" }],
  ["path", { d: "M19 8.5V10h1.5A1.5 1.5 0 1 0 19 8.5", key: "183iwg" }],
  ["rect", { width: "3", height: "8", x: "8", y: "14", rx: "1.5", key: "hqg7r1" }],
  ["path", { d: "M5 15.5V14H3.5A1.5 1.5 0 1 0 5 15.5", key: "76g71w" }],
  ["rect", { width: "8", height: "3", x: "14", y: "13", rx: "1.5", key: "1kmz0a" }],
  ["path", { d: "M15.5 19H14v1.5a1.5 1.5 0 1 0 1.5-1.5", key: "jc4sz0" }],
  ["rect", { width: "8", height: "3", x: "2", y: "8", rx: "1.5", key: "1omvl4" }],
  ["path", { d: "M8.5 5H10V3.5A1.5 1.5 0 1 0 8.5 5", key: "16f3cl" }]
]);

const LuSlash = createLucideIcon("LuSlash", [["path", { d: "M22 2 2 22", key: "y4kqgn" }]]);

const LuSlice = createLucideIcon("LuSlice", [
  ["path", { d: "m8 14-6 6h9v-3", key: "zo3j9a" }],
  ["path", { d: "M18.37 3.63 8 14l3 3L21.37 6.63a2.12 2.12 0 1 0-3-3Z", key: "1dzx0j" }]
]);

const LuSlidersHorizontal = createLucideIcon("LuSlidersHorizontal", [
  ["line", { x1: "21", x2: "14", y1: "4", y2: "4", key: "obuewd" }],
  ["line", { x1: "10", x2: "3", y1: "4", y2: "4", key: "1q6298" }],
  ["line", { x1: "21", x2: "12", y1: "12", y2: "12", key: "1iu8h1" }],
  ["line", { x1: "8", x2: "3", y1: "12", y2: "12", key: "ntss68" }],
  ["line", { x1: "21", x2: "16", y1: "20", y2: "20", key: "14d8ph" }],
  ["line", { x1: "12", x2: "3", y1: "20", y2: "20", key: "m0wm8r" }],
  ["line", { x1: "14", x2: "14", y1: "2", y2: "6", key: "14e1ph" }],
  ["line", { x1: "8", x2: "8", y1: "10", y2: "14", key: "1i6ji0" }],
  ["line", { x1: "16", x2: "16", y1: "18", y2: "22", key: "1lctlv" }]
]);

const LuSlidersVertical = createLucideIcon("LuSlidersVertical", [
  ["line", { x1: "4", x2: "4", y1: "21", y2: "14", key: "1p332r" }],
  ["line", { x1: "4", x2: "4", y1: "10", y2: "3", key: "gb41h5" }],
  ["line", { x1: "12", x2: "12", y1: "21", y2: "12", key: "hf2csr" }],
  ["line", { x1: "12", x2: "12", y1: "8", y2: "3", key: "1kfi7u" }],
  ["line", { x1: "20", x2: "20", y1: "21", y2: "16", key: "1lhrwl" }],
  ["line", { x1: "20", x2: "20", y1: "12", y2: "3", key: "16vvfq" }],
  ["line", { x1: "2", x2: "6", y1: "14", y2: "14", key: "1uebub" }],
  ["line", { x1: "10", x2: "14", y1: "8", y2: "8", key: "1yglbp" }],
  ["line", { x1: "18", x2: "22", y1: "16", y2: "16", key: "1jxqpz" }]
]);

const LuSmartphoneCharging = createLucideIcon("LuSmartphoneCharging", [
  ["rect", { width: "14", height: "20", x: "5", y: "2", rx: "2", ry: "2", key: "1yt0o3" }],
  ["path", { d: "M12.667 8 10 12h4l-2.667 4", key: "h9lk2d" }]
]);

const LuSmartphoneNfc = createLucideIcon("LuSmartphoneNfc", [
  ["rect", { width: "7", height: "12", x: "2", y: "6", rx: "1", key: "5nje8w" }],
  ["path", { d: "M13 8.32a7.43 7.43 0 0 1 0 7.36", key: "1g306n" }],
  ["path", { d: "M16.46 6.21a11.76 11.76 0 0 1 0 11.58", key: "uqvjvo" }],
  ["path", { d: "M19.91 4.1a15.91 15.91 0 0 1 .01 15.8", key: "ujntz3" }]
]);

const LuSmartphone = createLucideIcon("LuSmartphone", [
  ["rect", { width: "14", height: "20", x: "5", y: "2", rx: "2", ry: "2", key: "1yt0o3" }],
  ["path", { d: "M12 18h.01", key: "mhygvu" }]
]);

const LuSmilePlus = createLucideIcon("LuSmilePlus", [
  ["path", { d: "M22 11v1a10 10 0 1 1-9-10", key: "ew0xw9" }],
  ["path", { d: "M8 14s1.5 2 4 2 4-2 4-2", key: "1y1vjs" }],
  ["line", { x1: "9", x2: "9.01", y1: "9", y2: "9", key: "yxxnd0" }],
  ["line", { x1: "15", x2: "15.01", y1: "9", y2: "9", key: "1p4y9e" }],
  ["path", { d: "M16 5h6", key: "1vod17" }],
  ["path", { d: "M19 2v6", key: "4bpg5p" }]
]);

const LuSmile = createLucideIcon("LuSmile", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["path", { d: "M8 14s1.5 2 4 2 4-2 4-2", key: "1y1vjs" }],
  ["line", { x1: "9", x2: "9.01", y1: "9", y2: "9", key: "yxxnd0" }],
  ["line", { x1: "15", x2: "15.01", y1: "9", y2: "9", key: "1p4y9e" }]
]);

const LuSnail = createLucideIcon("LuSnail", [
  ["path", { d: "M2 13a6 6 0 1 0 12 0 4 4 0 1 0-8 0 2 2 0 0 0 4 0", key: "hneq2s" }],
  ["circle", { cx: "10", cy: "13", r: "8", key: "194lz3" }],
  ["path", { d: "M2 21h12c4.4 0 8-3.6 8-8V7a2 2 0 1 0-4 0v6", key: "ixqyt7" }],
  ["path", { d: "M18 3 19.1 5.2", key: "9tjm43" }],
  ["path", { d: "M22 3 20.9 5.2", key: "j3odrs" }]
]);

const LuSnowflake = createLucideIcon("LuSnowflake", [
  ["line", { x1: "2", x2: "22", y1: "12", y2: "12", key: "1dnqot" }],
  ["line", { x1: "12", x2: "12", y1: "2", y2: "22", key: "7eqyqh" }],
  ["path", { d: "m20 16-4-4 4-4", key: "rquw4f" }],
  ["path", { d: "m4 8 4 4-4 4", key: "12s3z9" }],
  ["path", { d: "m16 4-4 4-4-4", key: "1tumq1" }],
  ["path", { d: "m8 20 4-4 4 4", key: "9p200w" }]
]);

const LuSofa = createLucideIcon("LuSofa", [
  ["path", { d: "M20 9V6a2 2 0 0 0-2-2H6a2 2 0 0 0-2 2v3", key: "1dgpiv" }],
  [
    "path",
    {
      d: "M2 11v5a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-5a2 2 0 0 0-4 0v2H6v-2a2 2 0 0 0-4 0Z",
      key: "u5qfb7"
    }
  ],
  ["path", { d: "M4 18v2", key: "jwo5n2" }],
  ["path", { d: "M20 18v2", key: "1ar1qi" }],
  ["path", { d: "M12 4v9", key: "oqhhn3" }]
]);

const LuSoup = createLucideIcon("LuSoup", [
  ["path", { d: "M12 21a9 9 0 0 0 9-9H3a9 9 0 0 0 9 9Z", key: "4rw317" }],
  ["path", { d: "M7 21h10", key: "1b0cd5" }],
  ["path", { d: "M19.5 12 22 6", key: "shfsr5" }],
  [
    "path",
    {
      d: "M16.25 3c.27.1.8.53.75 1.36-.06.83-.93 1.2-1 2.02-.05.78.34 1.24.73 1.62",
      key: "rpc6vp"
    }
  ],
  [
    "path",
    {
      d: "M11.25 3c.27.1.8.53.74 1.36-.05.83-.93 1.2-.98 2.02-.06.78.33 1.24.72 1.62",
      key: "1lf63m"
    }
  ],
  [
    "path",
    { d: "M6.25 3c.27.1.8.53.75 1.36-.06.83-.93 1.2-1 2.02-.05.78.34 1.24.74 1.62", key: "97tijn" }
  ]
]);

const LuSpace = createLucideIcon("LuSpace", [
  ["path", { d: "M22 17v1c0 .5-.5 1-1 1H3c-.5 0-1-.5-1-1v-1", key: "lt2kga" }]
]);

const LuSpade = createLucideIcon("LuSpade", [
  [
    "path",
    {
      d: "M5 9c-1.5 1.5-3 3.2-3 5.5A5.5 5.5 0 0 0 7.5 20c1.8 0 3-.5 4.5-2 1.5 1.5 2.7 2 4.5 2a5.5 5.5 0 0 0 5.5-5.5c0-2.3-1.5-4-3-5.5l-7-7-7 7Z",
      key: "40bo9n"
    }
  ],
  ["path", { d: "M12 18v4", key: "jadmvz" }]
]);

const LuSparkle = createLucideIcon("LuSparkle", [
  [
    "path",
    {
      d: "m12 3-1.9 5.8a2 2 0 0 1-1.287 1.288L3 12l5.8 1.9a2 2 0 0 1 1.288 1.287L12 21l1.9-5.8a2 2 0 0 1 1.287-1.288L21 12l-5.8-1.9a2 2 0 0 1-1.288-1.287Z",
      key: "nraa5p"
    }
  ]
]);

const LuSparkles = createLucideIcon("LuSparkles", [
  [
    "path",
    {
      d: "m12 3-1.912 5.813a2 2 0 0 1-1.275 1.275L3 12l5.813 1.912a2 2 0 0 1 1.275 1.275L12 21l1.912-5.813a2 2 0 0 1 1.275-1.275L21 12l-5.813-1.912a2 2 0 0 1-1.275-1.275L12 3Z",
      key: "17u4zn"
    }
  ],
  ["path", { d: "M5 3v4", key: "bklmnn" }],
  ["path", { d: "M19 17v4", key: "iiml17" }],
  ["path", { d: "M3 5h4", key: "nem4j1" }],
  ["path", { d: "M17 19h4", key: "lbex7p" }]
]);

const LuSpeaker = createLucideIcon("LuSpeaker", [
  ["rect", { width: "16", height: "20", x: "4", y: "2", rx: "2", key: "1nb95v" }],
  ["path", { d: "M12 6h.01", key: "1vi96p" }],
  ["circle", { cx: "12", cy: "14", r: "4", key: "1jruaj" }],
  ["path", { d: "M12 14h.01", key: "1etili" }]
]);

const LuSpeech = createLucideIcon("LuSpeech", [
  [
    "path",
    {
      d: "M8.8 20v-4.1l1.9.2a2.3 2.3 0 0 0 2.164-2.1V8.3A5.37 5.37 0 0 0 2 8.25c0 2.8.656 3.054 1 4.55a5.77 5.77 0 0 1 .029 2.758L2 20",
      key: "11atix"
    }
  ],
  ["path", { d: "M19.8 17.8a7.5 7.5 0 0 0 .003-10.603", key: "yol142" }],
  ["path", { d: "M17 15a3.5 3.5 0 0 0-.025-4.975", key: "ssbmkc" }]
]);

const LuSpellCheck2 = createLucideIcon("LuSpellCheck2", [
  ["path", { d: "m6 16 6-12 6 12", key: "1b4byz" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  [
    "path",
    {
      d: "M4 21c1.1 0 1.1-1 2.3-1s1.1 1 2.3 1c1.1 0 1.1-1 2.3-1 1.1 0 1.1 1 2.3 1 1.1 0 1.1-1 2.3-1 1.1 0 1.1 1 2.3 1 1.1 0 1.1-1 2.3-1",
      key: "8mdmtu"
    }
  ]
]);

const LuSpellCheck = createLucideIcon("LuSpellCheck", [
  ["path", { d: "m6 16 6-12 6 12", key: "1b4byz" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["path", { d: "m16 20 2 2 4-4", key: "13tcca" }]
]);

const LuSpline = createLucideIcon("LuSpline", [
  ["circle", { cx: "19", cy: "5", r: "2", key: "mhkx31" }],
  ["circle", { cx: "5", cy: "19", r: "2", key: "v8kfzx" }],
  ["path", { d: "M5 17A12 12 0 0 1 17 5", key: "1okkup" }]
]);

const LuSplit = createLucideIcon("LuSplit", [
  ["path", { d: "M16 3h5v5", key: "1806ms" }],
  ["path", { d: "M8 3H3v5", key: "15dfkv" }],
  ["path", { d: "M12 22v-8.3a4 4 0 0 0-1.172-2.872L3 3", key: "1qrqzj" }],
  ["path", { d: "m15 9 6-6", key: "ko1vev" }]
]);

const LuSprayCan = createLucideIcon("LuSprayCan", [
  ["path", { d: "M3 3h.01", key: "159qn6" }],
  ["path", { d: "M7 5h.01", key: "1hq22a" }],
  ["path", { d: "M11 7h.01", key: "1osv80" }],
  ["path", { d: "M3 7h.01", key: "1xzrh3" }],
  ["path", { d: "M7 9h.01", key: "19b3jx" }],
  ["path", { d: "M3 11h.01", key: "1eifu7" }],
  ["rect", { width: "4", height: "4", x: "15", y: "5", key: "mri9e4" }],
  ["path", { d: "m19 9 2 2v10c0 .6-.4 1-1 1h-6c-.6 0-1-.4-1-1V11l2-2", key: "aib6hk" }],
  ["path", { d: "m13 14 8-2", key: "1d7bmk" }],
  ["path", { d: "m13 19 8-2", key: "1y2vml" }]
]);

const LuSprout = createLucideIcon("LuSprout", [
  ["path", { d: "M7 20h10", key: "e6iznv" }],
  ["path", { d: "M10 20c5.5-2.5.8-6.4 3-10", key: "161w41" }],
  [
    "path",
    {
      d: "M9.5 9.4c1.1.8 1.8 2.2 2.3 3.7-2 .4-3.5.4-4.8-.3-1.2-.6-2.3-1.9-3-4.2 2.8-.5 4.4 0 5.5.8z",
      key: "9gtqwd"
    }
  ],
  [
    "path",
    {
      d: "M14.1 6a7 7 0 0 0-1.1 4c1.9-.1 3.3-.6 4.3-1.4 1-1 1.6-2.3 1.7-4.6-2.7.1-4 1-4.9 2z",
      key: "bkxnd2"
    }
  ]
]);

const LuSquareActivity = createLucideIcon("LuSquareActivity", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M17 12h-2l-2 5-2-10-2 5H7", key: "15hlnc" }]
]);

const LuSquareArrowDownLeft = createLucideIcon("LuSquareArrowDownLeft", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m16 8-8 8", key: "166keh" }],
  ["path", { d: "M16 16H8V8", key: "1w2ppm" }]
]);

const LuSquareArrowDownRight = createLucideIcon("LuSquareArrowDownRight", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m8 8 8 8", key: "1imecy" }],
  ["path", { d: "M16 8v8H8", key: "1lbpgo" }]
]);

const LuSquareArrowDown = createLucideIcon("LuSquareArrowDown", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M12 8v8", key: "napkw2" }],
  ["path", { d: "m8 12 4 4 4-4", key: "k98ssh" }]
]);

const LuSquareArrowLeft = createLucideIcon("LuSquareArrowLeft", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m12 8-4 4 4 4", key: "15vm53" }],
  ["path", { d: "M16 12H8", key: "1fr5h0" }]
]);

const LuSquareArrowOutDownLeft = createLucideIcon("LuSquareArrowOutDownLeft", [
  ["path", { d: "M13 21h6a2 2 0 0 0 2-2V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v6", key: "14qz4y" }],
  ["path", { d: "m3 21 9-9", key: "1jfql5" }],
  ["path", { d: "M9 21H3v-6", key: "wtvkvv" }]
]);

const LuSquareArrowOutDownRight = createLucideIcon("LuSquareArrowOutDownRight", [
  ["path", { d: "M21 11V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h6", key: "14rsvq" }],
  ["path", { d: "m21 21-9-9", key: "1et2py" }],
  ["path", { d: "M21 15v6h-6", key: "1jko0i" }]
]);

const LuSquareArrowOutUpLeft = createLucideIcon("LuSquareArrowOutUpLeft", [
  ["path", { d: "M13 3h6a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-6", key: "14mv1t" }],
  ["path", { d: "m3 3 9 9", key: "rks13r" }],
  ["path", { d: "M3 9V3h6", key: "ira0h2" }]
]);

const LuSquareArrowOutUpRight = createLucideIcon("LuSquareArrowOutUpRight", [
  ["path", { d: "M21 13v6a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h6", key: "y09zxi" }],
  ["path", { d: "m21 3-9 9", key: "mpx6sq" }],
  ["path", { d: "M15 3h6v6", key: "1q9fwt" }]
]);

const LuSquareArrowRight = createLucideIcon("LuSquareArrowRight", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["path", { d: "m12 16 4-4-4-4", key: "1i9zcv" }]
]);

const LuSquareArrowUpLeft = createLucideIcon("LuSquareArrowUpLeft", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M8 16V8h8", key: "19xb1h" }],
  ["path", { d: "M16 16 8 8", key: "1qdy8n" }]
]);

const LuSquareArrowUpRight = createLucideIcon("LuSquareArrowUpRight", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M8 8h8v8", key: "b65dnt" }],
  ["path", { d: "m8 16 8-8", key: "13b9ih" }]
]);

const LuSquareArrowUp = createLucideIcon("LuSquareArrowUp", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m16 12-4-4-4 4", key: "177agl" }],
  ["path", { d: "M12 16V8", key: "1sbj14" }]
]);

const LuSquareAsterisk = createLucideIcon("LuSquareAsterisk", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M12 8v8", key: "napkw2" }],
  ["path", { d: "m8.5 14 7-4", key: "12hpby" }],
  ["path", { d: "m8.5 10 7 4", key: "wwy2dy" }]
]);

const LuSquareBottomDashedScissors = createLucideIcon("LuSquareBottomDashedScissors", [
  [
    "path",
    { d: "M4 22a2 2 0 0 1-2-2V4a2 2 0 0 1 2-2h16a2 2 0 0 1 2 2v16a2 2 0 0 1-2 2", key: "1vzg26" }
  ],
  ["path", { d: "M10 22H8", key: "euku7a" }],
  ["path", { d: "M16 22h-2", key: "18d249" }],
  ["circle", { cx: "8", cy: "8", r: "2", key: "14cg06" }],
  ["path", { d: "M9.414 9.414 12 12", key: "qz4lzr" }],
  ["path", { d: "M14.8 14.8 18 18", key: "11flf1" }],
  ["circle", { cx: "8", cy: "16", r: "2", key: "1acxsx" }],
  ["path", { d: "m18 6-8.586 8.586", key: "11kzk1" }]
]);

const LuSquareCheckBig = createLucideIcon("LuSquareCheckBig", [
  ["path", { d: "m9 11 3 3L22 4", key: "1pflzl" }],
  ["path", { d: "M21 12v7a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h11", key: "1jnkn4" }]
]);

const LuSquareCheck = createLucideIcon("LuSquareCheck", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m9 12 2 2 4-4", key: "dzmm74" }]
]);

const LuSquareChevronDown = createLucideIcon("LuSquareChevronDown", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m16 10-4 4-4-4", key: "894hmk" }]
]);

const LuSquareChevronLeft = createLucideIcon("LuSquareChevronLeft", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m14 16-4-4 4-4", key: "ojs7w8" }]
]);

const LuSquareChevronRight = createLucideIcon("LuSquareChevronRight", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m10 8 4 4-4 4", key: "1wy4r4" }]
]);

const LuSquareChevronUp = createLucideIcon("LuSquareChevronUp", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m8 14 4-4 4 4", key: "fy2ptz" }]
]);

const LuSquareCode = createLucideIcon("LuSquareCode", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m10 10-2 2 2 2", key: "p6et6i" }],
  ["path", { d: "m14 14 2-2-2-2", key: "m075q2" }]
]);

const LuSquareDashedBottomCode = createLucideIcon("LuSquareDashedBottomCode", [
  ["path", { d: "m10 10-2 2 2 2", key: "p6et6i" }],
  ["path", { d: "m14 14 2-2-2-2", key: "m075q2" }],
  [
    "path",
    { d: "M5 21a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2", key: "as5y1o" }
  ],
  ["path", { d: "M9 21h1", key: "15o7lz" }],
  ["path", { d: "M14 21h1", key: "v9vybs" }]
]);

const LuSquareDashedBottom = createLucideIcon("LuSquareDashedBottom", [
  [
    "path",
    { d: "M5 21a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2", key: "as5y1o" }
  ],
  ["path", { d: "M9 21h1", key: "15o7lz" }],
  ["path", { d: "M14 21h1", key: "v9vybs" }]
]);

const LuSquareDashedKanban = createLucideIcon("LuSquareDashedKanban", [
  ["path", { d: "M8 7v7", key: "1x2jlm" }],
  ["path", { d: "M12 7v4", key: "xawao1" }],
  ["path", { d: "M16 7v9", key: "1hp2iy" }],
  ["path", { d: "M5 3a2 2 0 0 0-2 2", key: "y57alp" }],
  ["path", { d: "M9 3h1", key: "1yesri" }],
  ["path", { d: "M14 3h1", key: "1ec4yj" }],
  ["path", { d: "M19 3a2 2 0 0 1 2 2", key: "18rm91" }],
  ["path", { d: "M21 9v1", key: "mxsmne" }],
  ["path", { d: "M21 14v1", key: "169vum" }],
  ["path", { d: "M21 19a2 2 0 0 1-2 2", key: "1j7049" }],
  ["path", { d: "M14 21h1", key: "v9vybs" }],
  ["path", { d: "M9 21h1", key: "15o7lz" }],
  ["path", { d: "M5 21a2 2 0 0 1-2-2", key: "sbafld" }],
  ["path", { d: "M3 14v1", key: "vnatye" }],
  ["path", { d: "M3 9v1", key: "1r0deq" }]
]);

const LuSquareDashedMousePointer = createLucideIcon("LuSquareDashedMousePointer", [
  ["path", { d: "M5 3a2 2 0 0 0-2 2", key: "y57alp" }],
  ["path", { d: "M19 3a2 2 0 0 1 2 2", key: "18rm91" }],
  ["path", { d: "m12 12 4 10 1.7-4.3L22 16Z", key: "64ilsv" }],
  ["path", { d: "M5 21a2 2 0 0 1-2-2", key: "sbafld" }],
  ["path", { d: "M9 3h1", key: "1yesri" }],
  ["path", { d: "M9 21h2", key: "1qve2z" }],
  ["path", { d: "M14 3h1", key: "1ec4yj" }],
  ["path", { d: "M3 9v1", key: "1r0deq" }],
  ["path", { d: "M21 9v2", key: "p14lih" }],
  ["path", { d: "M3 14v1", key: "vnatye" }]
]);

const LuSquareDivide = createLucideIcon("LuSquareDivide", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["line", { x1: "8", x2: "16", y1: "12", y2: "12", key: "1jonct" }],
  ["line", { x1: "12", x2: "12", y1: "16", y2: "16", key: "aqc6ln" }],
  ["line", { x1: "12", x2: "12", y1: "8", y2: "8", key: "1mkcni" }]
]);

const LuSquareDot = createLucideIcon("LuSquareDot", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["circle", { cx: "12", cy: "12", r: "1", key: "41hilf" }]
]);

const LuSquareEqual = createLucideIcon("LuSquareEqual", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M7 10h10", key: "1101jm" }],
  ["path", { d: "M7 14h10", key: "1mhdw3" }]
]);

const LuSquareFunction = createLucideIcon("LuSquareFunction", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["path", { d: "M9 17c2 0 2.8-1 2.8-2.8V10c0-2 1-3.3 3.2-3", key: "m1af9g" }],
  ["path", { d: "M9 11.2h5.7", key: "3zgcl2" }]
]);

const LuSquareGanttChart = createLucideIcon("LuSquareGanttChart", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M9 8h7", key: "kbo1nt" }],
  ["path", { d: "M8 12h6", key: "ikassy" }],
  ["path", { d: "M11 16h5", key: "oq65wt" }]
]);

const LuSquareKanban = createLucideIcon("LuSquareKanban", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M8 7v7", key: "1x2jlm" }],
  ["path", { d: "M12 7v4", key: "xawao1" }],
  ["path", { d: "M16 7v9", key: "1hp2iy" }]
]);

const LuSquareLibrary = createLucideIcon("LuSquareLibrary", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M7 7v10", key: "d5nglc" }],
  ["path", { d: "M11 7v10", key: "pptsnr" }],
  ["path", { d: "m15 7 2 10", key: "1m7qm5" }]
]);

const LuSquareM = createLucideIcon("LuSquareM", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M8 16V8l4 4 4-4v8", key: "141u4e" }]
]);

const LuSquareMenu = createLucideIcon("LuSquareMenu", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M7 8h10", key: "1jw688" }],
  ["path", { d: "M7 12h10", key: "b7w52i" }],
  ["path", { d: "M7 16h10", key: "wp8him" }]
]);

const LuSquareMinus = createLucideIcon("LuSquareMinus", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }]
]);

const LuSquareMousePointer = createLucideIcon("LuSquareMousePointer", [
  ["path", { d: "M21 11V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h6", key: "14rsvq" }],
  ["path", { d: "m12 12 4 10 1.7-4.3L22 16Z", key: "64ilsv" }]
]);

const LuSquareParkingOff = createLucideIcon("LuSquareParkingOff", [
  ["path", { d: "M3.6 3.6A2 2 0 0 1 5 3h14a2 2 0 0 1 2 2v14a2 2 0 0 1-.59 1.41", key: "9l1ft6" }],
  ["path", { d: "M3 8.7V19a2 2 0 0 0 2 2h10.3", key: "17knke" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M13 13a3 3 0 1 0 0-6H9v2", key: "uoagbd" }],
  ["path", { d: "M9 17v-2.3", key: "1jxgo2" }]
]);

const LuSquareParking = createLucideIcon("LuSquareParking", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M9 17V7h4a3 3 0 0 1 0 6H9", key: "1dfk2c" }]
]);

const LuSquarePen = createLucideIcon("LuSquarePen", [
  ["path", { d: "M12 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2v-7", key: "1m0v6g" }],
  ["path", { d: "M18.375 2.625a2.121 2.121 0 1 1 3 3L12 15l-4 1 1-4Z", key: "1lpok0" }]
]);

const LuSquarePercent = createLucideIcon("LuSquarePercent", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m15 9-6 6", key: "1uzhvr" }],
  ["path", { d: "M9 9h.01", key: "1q5me6" }],
  ["path", { d: "M15 15h.01", key: "lqbp3k" }]
]);

const LuSquarePi = createLucideIcon("LuSquarePi", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M7 7h10", key: "udp07y" }],
  ["path", { d: "M10 7v10", key: "i1d9ee" }],
  ["path", { d: "M16 17a2 2 0 0 1-2-2V7", key: "ftwdc7" }]
]);

const LuSquarePilcrow = createLucideIcon("LuSquarePilcrow", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M12 12H9.5a2.5 2.5 0 0 1 0-5H17", key: "1l9586" }],
  ["path", { d: "M12 7v10", key: "jspqdw" }],
  ["path", { d: "M16 7v10", key: "lavkr4" }]
]);

const LuSquarePlay = createLucideIcon("LuSquarePlay", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "m9 8 6 4-6 4Z", key: "f1r3lt" }]
]);

const LuSquarePlus = createLucideIcon("LuSquarePlus", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["path", { d: "M12 8v8", key: "napkw2" }]
]);

const LuSquarePower = createLucideIcon("LuSquarePower", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M12 7v5", key: "ma6bk" }],
  ["path", { d: "M8 9a5.14 5.14 0 0 0 4 8 4.95 4.95 0 0 0 4-8", key: "15eubv" }]
]);

const LuSquareRadical = createLucideIcon("LuSquareRadical", [
  ["path", { d: "M7 12h2l2 5 2-10h4", key: "1fxv6h" }],
  ["rect", { x: "3", y: "3", width: "18", height: "18", rx: "2", key: "h1oib" }]
]);

const LuSquareScissors = createLucideIcon("LuSquareScissors", [
  ["rect", { width: "20", height: "20", x: "2", y: "2", rx: "2", key: "1btzen" }],
  ["circle", { cx: "8", cy: "8", r: "2", key: "14cg06" }],
  ["path", { d: "M9.414 9.414 12 12", key: "qz4lzr" }],
  ["path", { d: "M14.8 14.8 18 18", key: "11flf1" }],
  ["circle", { cx: "8", cy: "16", r: "2", key: "1acxsx" }],
  ["path", { d: "m18 6-8.586 8.586", key: "11kzk1" }]
]);

const LuSquareSigma = createLucideIcon("LuSquareSigma", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M16 8.9V7H8l4 5-4 5h8v-1.9", key: "9nih0i" }]
]);

const LuSquareSlash = createLucideIcon("LuSquareSlash", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["line", { x1: "9", x2: "15", y1: "15", y2: "9", key: "1dfufj" }]
]);

const LuSquareSplitHorizontal = createLucideIcon("LuSquareSplitHorizontal", [
  ["path", { d: "M8 19H5c-1 0-2-1-2-2V7c0-1 1-2 2-2h3", key: "lubmu8" }],
  ["path", { d: "M16 5h3c1 0 2 1 2 2v10c0 1-1 2-2 2h-3", key: "1ag34g" }],
  ["line", { x1: "12", x2: "12", y1: "4", y2: "20", key: "1tx1rr" }]
]);

const LuSquareSplitVertical = createLucideIcon("LuSquareSplitVertical", [
  ["path", { d: "M5 8V5c0-1 1-2 2-2h10c1 0 2 1 2 2v3", key: "1pi83i" }],
  ["path", { d: "M19 16v3c0 1-1 2-2 2H7c-1 0-2-1-2-2v-3", key: "ido5k7" }],
  ["line", { x1: "4", x2: "20", y1: "12", y2: "12", key: "1e0a9i" }]
]);

const LuSquareStack = createLucideIcon("LuSquareStack", [
  ["path", { d: "M4 10c-1.1 0-2-.9-2-2V4c0-1.1.9-2 2-2h4c1.1 0 2 .9 2 2", key: "4i38lg" }],
  ["path", { d: "M10 16c-1.1 0-2-.9-2-2v-4c0-1.1.9-2 2-2h4c1.1 0 2 .9 2 2", key: "mlte4a" }],
  ["rect", { width: "8", height: "8", x: "14", y: "14", rx: "2", key: "1fa9i4" }]
]);

const LuSquareTerminal = createLucideIcon("LuSquareTerminal", [
  ["path", { d: "m7 11 2-2-2-2", key: "1lz0vl" }],
  ["path", { d: "M11 13h4", key: "1p7l4v" }],
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }]
]);

const LuSquareUserRound = createLucideIcon("LuSquareUserRound", [
  ["path", { d: "M18 21a6 6 0 0 0-12 0", key: "kaz2du" }],
  ["circle", { cx: "12", cy: "11", r: "4", key: "1gt34v" }],
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }]
]);

const LuSquareUser = createLucideIcon("LuSquareUser", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["circle", { cx: "12", cy: "10", r: "3", key: "ilqhr7" }],
  ["path", { d: "M7 21v-2a2 2 0 0 1 2-2h6a2 2 0 0 1 2 2v2", key: "1m6ac2" }]
]);

const LuSquareX = createLucideIcon("LuSquareX", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["path", { d: "m15 9-6 6", key: "1uzhvr" }],
  ["path", { d: "m9 9 6 6", key: "z0biqf" }]
]);

const LuSquare = createLucideIcon("LuSquare", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }]
]);

const LuSquircle = createLucideIcon("LuSquircle", [
  ["path", { d: "M12 3c7.2 0 9 1.8 9 9s-1.8 9-9 9-9-1.8-9-9 1.8-9 9-9", key: "garfkc" }]
]);

const LuSquirrel = createLucideIcon("LuSquirrel", [
  ["path", { d: "M15.236 22a3 3 0 0 0-2.2-5", key: "21bitc" }],
  ["path", { d: "M16 20a3 3 0 0 1 3-3h1a2 2 0 0 0 2-2v-2a4 4 0 0 0-4-4V4", key: "oh0fg0" }],
  ["path", { d: "M18 13h.01", key: "9veqaj" }],
  [
    "path",
    {
      d: "M18 6a4 4 0 0 0-4 4 7 7 0 0 0-7 7c0-5 4-5 4-10.5a4.5 4.5 0 1 0-9 0 2.5 2.5 0 0 0 5 0C7 10 3 11 3 17c0 2.8 2.2 5 5 5h10",
      key: "980v8a"
    }
  ]
]);

const LuStamp = createLucideIcon("LuStamp", [
  ["path", { d: "M5 22h14", key: "ehvnwv" }],
  [
    "path",
    {
      d: "M19.27 13.73A2.5 2.5 0 0 0 17.5 13h-11A2.5 2.5 0 0 0 4 15.5V17a1 1 0 0 0 1 1h14a1 1 0 0 0 1-1v-1.5c0-.66-.26-1.3-.73-1.77Z",
      key: "1sy9ra"
    }
  ],
  [
    "path",
    { d: "M14 13V8.5C14 7 15 7 15 5a3 3 0 0 0-3-3c-1.66 0-3 1-3 3s1 2 1 3.5V13", key: "cnxgux" }
  ]
]);

const LuStarHalf = createLucideIcon("LuStarHalf", [
  ["path", { d: "M12 17.8 5.8 21 7 14.1 2 9.3l7-1L12 2", key: "nare05" }]
]);

const LuStarOff = createLucideIcon("LuStarOff", [
  ["path", { d: "M8.34 8.34 2 9.27l5 4.87L5.82 21 12 17.77 18.18 21l-.59-3.43", key: "16m0ql" }],
  ["path", { d: "M18.42 12.76 22 9.27l-6.91-1L12 2l-1.44 2.91", key: "1vt8nq" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuStar = createLucideIcon("LuStar", [
  [
    "polygon",
    {
      points: "12 2 15.09 8.26 22 9.27 17 14.14 18.18 21.02 12 17.77 5.82 21.02 7 14.14 2 9.27 8.91 8.26 12 2",
      key: "8f66p6"
    }
  ]
]);

const LuStepBack = createLucideIcon("LuStepBack", [
  ["line", { x1: "18", x2: "18", y1: "20", y2: "4", key: "cun8e5" }],
  ["polygon", { points: "14,20 4,12 14,4", key: "ypakod" }]
]);

const LuStepForward = createLucideIcon("LuStepForward", [
  ["line", { x1: "6", x2: "6", y1: "4", y2: "20", key: "fy8qot" }],
  ["polygon", { points: "10,4 20,12 10,20", key: "1mc1pf" }]
]);

const LuStethoscope = createLucideIcon("LuStethoscope", [
  [
    "path",
    {
      d: "M4.8 2.3A.3.3 0 1 0 5 2H4a2 2 0 0 0-2 2v5a6 6 0 0 0 6 6v0a6 6 0 0 0 6-6V4a2 2 0 0 0-2-2h-1a.2.2 0 1 0 .3.3",
      key: "1jd90r"
    }
  ],
  ["path", { d: "M8 15v1a6 6 0 0 0 6 6v0a6 6 0 0 0 6-6v-4", key: "126ukv" }],
  ["circle", { cx: "20", cy: "10", r: "2", key: "ts1r5v" }]
]);

const LuSticker = createLucideIcon("LuSticker", [
  [
    "path",
    { d: "M15.5 3H5a2 2 0 0 0-2 2v14c0 1.1.9 2 2 2h14a2 2 0 0 0 2-2V8.5L15.5 3Z", key: "1wis1t" }
  ],
  ["path", { d: "M14 3v4a2 2 0 0 0 2 2h4", key: "36rjfy" }],
  ["path", { d: "M8 13h0", key: "jdup5h" }],
  ["path", { d: "M16 13h0", key: "l4i2ga" }],
  ["path", { d: "M10 16s.8 1 2 1c1.3 0 2-1 2-1", key: "1vvgv3" }]
]);

const LuStickyNote = createLucideIcon("LuStickyNote", [
  ["path", { d: "M16 3H5a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h14a2 2 0 0 0 2-2V8Z", key: "qazsjp" }],
  ["path", { d: "M15 3v4a2 2 0 0 0 2 2h4", key: "40519r" }]
]);

const LuStore = createLucideIcon("LuStore", [
  ["path", { d: "m2 7 4.41-4.41A2 2 0 0 1 7.83 2h8.34a2 2 0 0 1 1.42.59L22 7", key: "ztvudi" }],
  ["path", { d: "M4 12v8a2 2 0 0 0 2 2h12a2 2 0 0 0 2-2v-8", key: "1b2hhj" }],
  ["path", { d: "M15 22v-4a2 2 0 0 0-2-2h-2a2 2 0 0 0-2 2v4", key: "2ebpfo" }],
  ["path", { d: "M2 7h20", key: "1fcdvo" }],
  [
    "path",
    {
      d: "M22 7v3a2 2 0 0 1-2 2v0a2.7 2.7 0 0 1-1.59-.63.7.7 0 0 0-.82 0A2.7 2.7 0 0 1 16 12a2.7 2.7 0 0 1-1.59-.63.7.7 0 0 0-.82 0A2.7 2.7 0 0 1 12 12a2.7 2.7 0 0 1-1.59-.63.7.7 0 0 0-.82 0A2.7 2.7 0 0 1 8 12a2.7 2.7 0 0 1-1.59-.63.7.7 0 0 0-.82 0A2.7 2.7 0 0 1 4 12v0a2 2 0 0 1-2-2V7",
      key: "jon5kx"
    }
  ]
]);

const LuStretchHorizontal = createLucideIcon("LuStretchHorizontal", [
  ["rect", { width: "20", height: "6", x: "2", y: "4", rx: "2", key: "qdearl" }],
  ["rect", { width: "20", height: "6", x: "2", y: "14", rx: "2", key: "1xrn6j" }]
]);

const LuStretchVertical = createLucideIcon("LuStretchVertical", [
  ["rect", { width: "6", height: "20", x: "4", y: "2", rx: "2", key: "19qu7m" }],
  ["rect", { width: "6", height: "20", x: "14", y: "2", rx: "2", key: "24v0nk" }]
]);

const LuStrikethrough = createLucideIcon("LuStrikethrough", [
  ["path", { d: "M16 4H9a3 3 0 0 0-2.83 4", key: "43sutm" }],
  ["path", { d: "M14 12a4 4 0 0 1 0 8H6", key: "nlfj13" }],
  ["line", { x1: "4", x2: "20", y1: "12", y2: "12", key: "1e0a9i" }]
]);

const LuSubscript = createLucideIcon("LuSubscript", [
  ["path", { d: "m4 5 8 8", key: "1eunvl" }],
  ["path", { d: "m12 5-8 8", key: "1ah0jp" }],
  [
    "path",
    {
      d: "M20 19h-4c0-1.5.44-2 1.5-2.5S20 15.33 20 14c0-.47-.17-.93-.48-1.29a2.11 2.11 0 0 0-2.62-.44c-.42.24-.74.62-.9 1.07",
      key: "e8ta8j"
    }
  ]
]);

const LuSunDim = createLucideIcon("LuSunDim", [
  ["circle", { cx: "12", cy: "12", r: "4", key: "4exip2" }],
  ["path", { d: "M12 4h.01", key: "1ujb9j" }],
  ["path", { d: "M20 12h.01", key: "1ykeid" }],
  ["path", { d: "M12 20h.01", key: "zekei9" }],
  ["path", { d: "M4 12h.01", key: "158zrr" }],
  ["path", { d: "M17.657 6.343h.01", key: "31pqzk" }],
  ["path", { d: "M17.657 17.657h.01", key: "jehnf4" }],
  ["path", { d: "M6.343 17.657h.01", key: "gdk6ow" }],
  ["path", { d: "M6.343 6.343h.01", key: "1uurf0" }]
]);

const LuSunMedium = createLucideIcon("LuSunMedium", [
  ["circle", { cx: "12", cy: "12", r: "4", key: "4exip2" }],
  ["path", { d: "M12 3v1", key: "1asbbs" }],
  ["path", { d: "M12 20v1", key: "1wcdkc" }],
  ["path", { d: "M3 12h1", key: "lp3yf2" }],
  ["path", { d: "M20 12h1", key: "1vloll" }],
  ["path", { d: "m18.364 5.636-.707.707", key: "1hakh0" }],
  ["path", { d: "m6.343 17.657-.707.707", key: "18m9nf" }],
  ["path", { d: "m5.636 5.636.707.707", key: "1xv1c5" }],
  ["path", { d: "m17.657 17.657.707.707", key: "vl76zb" }]
]);

const LuSunMoon = createLucideIcon("LuSunMoon", [
  ["path", { d: "M12 8a2.83 2.83 0 0 0 4 4 4 4 0 1 1-4-4", key: "1fu5g2" }],
  ["path", { d: "M12 2v2", key: "tus03m" }],
  ["path", { d: "M12 20v2", key: "1lh1kg" }],
  ["path", { d: "m4.9 4.9 1.4 1.4", key: "b9915j" }],
  ["path", { d: "m17.7 17.7 1.4 1.4", key: "qc3ed3" }],
  ["path", { d: "M2 12h2", key: "1t8f8n" }],
  ["path", { d: "M20 12h2", key: "1q8mjw" }],
  ["path", { d: "m6.3 17.7-1.4 1.4", key: "5gca6" }],
  ["path", { d: "m19.1 4.9-1.4 1.4", key: "wpu9u6" }]
]);

const LuSunSnow = createLucideIcon("LuSunSnow", [
  ["path", { d: "M10 9a3 3 0 1 0 0 6", key: "6zmtdl" }],
  ["path", { d: "M2 12h1", key: "1uaihz" }],
  ["path", { d: "M14 21V3", key: "1llu3z" }],
  ["path", { d: "M10 4V3", key: "pkzwkn" }],
  ["path", { d: "M10 21v-1", key: "1u8rkd" }],
  ["path", { d: "m3.64 18.36.7-.7", key: "105rm9" }],
  ["path", { d: "m4.34 6.34-.7-.7", key: "d3unjp" }],
  ["path", { d: "M14 12h8", key: "4f43i9" }],
  ["path", { d: "m17 4-3 3", key: "15jcng" }],
  ["path", { d: "m14 17 3 3", key: "6tlq38" }],
  ["path", { d: "m21 15-3-3 3-3", key: "1nlnje" }]
]);

const LuSun = createLucideIcon("LuSun", [
  ["circle", { cx: "12", cy: "12", r: "4", key: "4exip2" }],
  ["path", { d: "M12 2v2", key: "tus03m" }],
  ["path", { d: "M12 20v2", key: "1lh1kg" }],
  ["path", { d: "m4.93 4.93 1.41 1.41", key: "149t6j" }],
  ["path", { d: "m17.66 17.66 1.41 1.41", key: "ptbguv" }],
  ["path", { d: "M2 12h2", key: "1t8f8n" }],
  ["path", { d: "M20 12h2", key: "1q8mjw" }],
  ["path", { d: "m6.34 17.66-1.41 1.41", key: "1m8zz5" }],
  ["path", { d: "m19.07 4.93-1.41 1.41", key: "1shlcs" }]
]);

const LuSunrise = createLucideIcon("LuSunrise", [
  ["path", { d: "M12 2v8", key: "1q4o3n" }],
  ["path", { d: "m4.93 10.93 1.41 1.41", key: "2a7f42" }],
  ["path", { d: "M2 18h2", key: "j10viu" }],
  ["path", { d: "M20 18h2", key: "wocana" }],
  ["path", { d: "m19.07 10.93-1.41 1.41", key: "15zs5n" }],
  ["path", { d: "M22 22H2", key: "19qnx5" }],
  ["path", { d: "m8 6 4-4 4 4", key: "ybng9g" }],
  ["path", { d: "M16 18a4 4 0 0 0-8 0", key: "1lzouq" }]
]);

const LuSunset = createLucideIcon("LuSunset", [
  ["path", { d: "M12 10V2", key: "16sf7g" }],
  ["path", { d: "m4.93 10.93 1.41 1.41", key: "2a7f42" }],
  ["path", { d: "M2 18h2", key: "j10viu" }],
  ["path", { d: "M20 18h2", key: "wocana" }],
  ["path", { d: "m19.07 10.93-1.41 1.41", key: "15zs5n" }],
  ["path", { d: "M22 22H2", key: "19qnx5" }],
  ["path", { d: "m16 6-4 4-4-4", key: "6wukr" }],
  ["path", { d: "M16 18a4 4 0 0 0-8 0", key: "1lzouq" }]
]);

const LuSuperscript = createLucideIcon("LuSuperscript", [
  ["path", { d: "m4 19 8-8", key: "hr47gm" }],
  ["path", { d: "m12 19-8-8", key: "1dhhmo" }],
  [
    "path",
    {
      d: "M20 12h-4c0-1.5.442-2 1.5-2.5S20 8.334 20 7.002c0-.472-.17-.93-.484-1.29a2.105 2.105 0 0 0-2.617-.436c-.42.239-.738.614-.899 1.06",
      key: "1dfcux"
    }
  ]
]);

const LuSwatchBook = createLucideIcon("LuSwatchBook", [
  ["path", { d: "M11 17a4 4 0 0 1-8 0V5a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2Z", key: "1ldrpk" }],
  ["path", { d: "M16.7 13H19a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2H7", key: "11i5po" }],
  ["path", { d: "M 7 17h0.01", key: "10821z" }],
  [
    "path",
    {
      d: "m11 8 2.3-2.3a2.4 2.4 0 0 1 3.404.004L18.6 7.6a2.4 2.4 0 0 1 .026 3.434L9.9 19.8",
      key: "o2gii7"
    }
  ]
]);

const LuSwissFranc = createLucideIcon("LuSwissFranc", [
  ["path", { d: "M10 21V3h8", key: "br2l0g" }],
  ["path", { d: "M6 16h9", key: "2py0wn" }],
  ["path", { d: "M10 9.5h7", key: "13dmhz" }]
]);

const LuSwitchCamera = createLucideIcon("LuSwitchCamera", [
  ["path", { d: "M11 19H4a2 2 0 0 1-2-2V7a2 2 0 0 1 2-2h5", key: "mtk2lu" }],
  ["path", { d: "M13 5h7a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2h-5", key: "120jsl" }],
  ["circle", { cx: "12", cy: "12", r: "3", key: "1v7zrd" }],
  ["path", { d: "m18 22-3-3 3-3", key: "kgdoj7" }],
  ["path", { d: "m6 2 3 3-3 3", key: "1fnbkv" }]
]);

const LuSword = createLucideIcon("LuSword", [
  ["polyline", { points: "14.5 17.5 3 6 3 3 6 3 17.5 14.5", key: "1hfsw2" }],
  ["line", { x1: "13", x2: "19", y1: "19", y2: "13", key: "1vrmhu" }],
  ["line", { x1: "16", x2: "20", y1: "16", y2: "20", key: "1bron3" }],
  ["line", { x1: "19", x2: "21", y1: "21", y2: "19", key: "13pww6" }]
]);

const LuSwords = createLucideIcon("LuSwords", [
  ["polyline", { points: "14.5 17.5 3 6 3 3 6 3 17.5 14.5", key: "1hfsw2" }],
  ["line", { x1: "13", x2: "19", y1: "19", y2: "13", key: "1vrmhu" }],
  ["line", { x1: "16", x2: "20", y1: "16", y2: "20", key: "1bron3" }],
  ["line", { x1: "19", x2: "21", y1: "21", y2: "19", key: "13pww6" }],
  ["polyline", { points: "14.5 6.5 18 3 21 3 21 6 17.5 9.5", key: "hbey2j" }],
  ["line", { x1: "5", x2: "9", y1: "14", y2: "18", key: "1hf58s" }],
  ["line", { x1: "7", x2: "4", y1: "17", y2: "20", key: "pidxm4" }],
  ["line", { x1: "3", x2: "5", y1: "19", y2: "21", key: "1pehsh" }]
]);

const LuSyringe = createLucideIcon("LuSyringe", [
  ["path", { d: "m18 2 4 4", key: "22kx64" }],
  ["path", { d: "m17 7 3-3", key: "1w1zoj" }],
  ["path", { d: "M19 9 8.7 19.3c-1 1-2.5 1-3.4 0l-.6-.6c-1-1-1-2.5 0-3.4L15 5", key: "1exhtz" }],
  ["path", { d: "m9 11 4 4", key: "rovt3i" }],
  ["path", { d: "m5 19-3 3", key: "59f2uf" }],
  ["path", { d: "m14 4 6 6", key: "yqp9t2" }]
]);

const LuTable2 = createLucideIcon("LuTable2", [
  [
    "path",
    {
      d: "M9 3H5a2 2 0 0 0-2 2v4m6-6h10a2 2 0 0 1 2 2v4M9 3v18m0 0h10a2 2 0 0 0 2-2V9M9 21H5a2 2 0 0 1-2-2V9m0 0h18",
      key: "gugj83"
    }
  ]
]);

const LuTableCellsMerge = createLucideIcon("LuTableCellsMerge", [
  ["path", { d: "M12 21v-6", key: "lihzve" }],
  ["path", { d: "M12 9V3", key: "da5inc" }],
  ["path", { d: "M3 15h18", key: "5xshup" }],
  ["path", { d: "M3 9h18", key: "1pudct" }],
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }]
]);

const LuTableCellsSplit = createLucideIcon("LuTableCellsSplit", [
  ["path", { d: "M12 15V9", key: "8c7uyn" }],
  ["path", { d: "M3 15h18", key: "5xshup" }],
  ["path", { d: "M3 9h18", key: "1pudct" }],
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }]
]);

const LuTableColumnsSplit = createLucideIcon("LuTableColumnsSplit", [
  ["path", { d: "M14 14v2", key: "w2a1xv" }],
  ["path", { d: "M14 20v2", key: "1lq872" }],
  ["path", { d: "M14 2v2", key: "6buw04" }],
  ["path", { d: "M14 8v2", key: "i67w9a" }],
  ["path", { d: "M2 15h8", key: "82wtch" }],
  ["path", { d: "M2 3h6a2 2 0 0 1 2 2v14a2 2 0 0 1-2 2H2", key: "up0l64" }],
  ["path", { d: "M2 9h8", key: "yelfik" }],
  ["path", { d: "M22 15h-4", key: "1es58f" }],
  ["path", { d: "M22 3h-2a2 2 0 0 0-2 2v14a2 2 0 0 0 2 2h2", key: "pdjoqf" }],
  ["path", { d: "M22 9h-4", key: "1luja7" }],
  ["path", { d: "M5 3v18", key: "14hmio" }]
]);

const LuTableProperties = createLucideIcon("LuTableProperties", [
  ["path", { d: "M15 3v18", key: "14nvp0" }],
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M21 9H3", key: "1338ky" }],
  ["path", { d: "M21 15H3", key: "9uk58r" }]
]);

const LuTableRowsSplit = createLucideIcon("LuTableRowsSplit", [
  ["path", { d: "M14 10h2", key: "1lstlu" }],
  ["path", { d: "M15 22v-8", key: "1fwwgm" }],
  ["path", { d: "M15 2v4", key: "1044rn" }],
  ["path", { d: "M2 10h2", key: "1r8dkt" }],
  ["path", { d: "M20 10h2", key: "1ug425" }],
  ["path", { d: "M3 19h18", key: "awlh7x" }],
  ["path", { d: "M3 22v-6a2 2 135 0 1 2-2h14a2 2 45 0 1 2 2v6", key: "ibqhof" }],
  ["path", { d: "M3 2v2a2 2 45 0 0 2 2h14a2 2 135 0 0 2-2V2", key: "1uenja" }],
  ["path", { d: "M8 10h2", key: "66od0" }],
  ["path", { d: "M9 22v-8", key: "fmnu31" }],
  ["path", { d: "M9 2v4", key: "j1yeou" }]
]);

const LuTable = createLucideIcon("LuTable", [
  ["path", { d: "M12 3v18", key: "108xh3" }],
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 9h18", key: "1pudct" }],
  ["path", { d: "M3 15h18", key: "5xshup" }]
]);

const LuTabletSmartphone = createLucideIcon("LuTabletSmartphone", [
  ["rect", { width: "10", height: "14", x: "3", y: "8", rx: "2", key: "1vrsiq" }],
  ["path", { d: "M5 4a2 2 0 0 1 2-2h12a2 2 0 0 1 2 2v16a2 2 0 0 1-2 2h-2.4", key: "1j4zmg" }],
  ["path", { d: "M8 18h.01", key: "lrp35t" }]
]);

const LuTablet = createLucideIcon("LuTablet", [
  ["rect", { width: "16", height: "20", x: "4", y: "2", rx: "2", ry: "2", key: "76otgf" }],
  ["line", { x1: "12", x2: "12.01", y1: "18", y2: "18", key: "1dp563" }]
]);

const LuTablets = createLucideIcon("LuTablets", [
  ["circle", { cx: "7", cy: "7", r: "5", key: "x29byf" }],
  ["circle", { cx: "17", cy: "17", r: "5", key: "1op1d2" }],
  ["path", { d: "M12 17h10", key: "ls21zv" }],
  ["path", { d: "m3.46 10.54 7.08-7.08", key: "1rehiu" }]
]);

const LuTag = createLucideIcon("LuTag", [
  [
    "path",
    {
      d: "M12.586 2.586A2 2 0 0 0 11.172 2H4a2 2 0 0 0-2 2v7.172a2 2 0 0 0 .586 1.414l8.704 8.704a2.426 2.426 0 0 0 3.42 0l6.58-6.58a2.426 2.426 0 0 0 0-3.42z",
      key: "vktsd0"
    }
  ],
  ["circle", { cx: "7.5", cy: "7.5", r: ".5", fill: "currentColor", key: "kqv944" }]
]);

const LuTags = createLucideIcon("LuTags", [
  ["path", { d: "m15 5 6.3 6.3a2.4 2.4 0 0 1 0 3.4L17 19", key: "1cbfv1" }],
  [
    "path",
    {
      d: "M9.586 5.586A2 2 0 0 0 8.172 5H3a1 1 0 0 0-1 1v5.172a2 2 0 0 0 .586 1.414L8.29 18.29a2.426 2.426 0 0 0 3.42 0l3.58-3.58a2.426 2.426 0 0 0 0-3.42z",
      key: "135mg7"
    }
  ],
  ["circle", { cx: "6.5", cy: "9.5", r: ".5", fill: "currentColor", key: "5pm5xn" }]
]);

const LuTally1 = createLucideIcon("LuTally1", [["path", { d: "M4 4v16", key: "6qkkli" }]]);

const LuTally2 = createLucideIcon("LuTally2", [
  ["path", { d: "M4 4v16", key: "6qkkli" }],
  ["path", { d: "M9 4v16", key: "81ygyz" }]
]);

const LuTally3 = createLucideIcon("LuTally3", [
  ["path", { d: "M4 4v16", key: "6qkkli" }],
  ["path", { d: "M9 4v16", key: "81ygyz" }],
  ["path", { d: "M14 4v16", key: "12vmem" }]
]);

const LuTally4 = createLucideIcon("LuTally4", [
  ["path", { d: "M4 4v16", key: "6qkkli" }],
  ["path", { d: "M9 4v16", key: "81ygyz" }],
  ["path", { d: "M14 4v16", key: "12vmem" }],
  ["path", { d: "M19 4v16", key: "8ij5ei" }]
]);

const LuTally5 = createLucideIcon("LuTally5", [
  ["path", { d: "M4 4v16", key: "6qkkli" }],
  ["path", { d: "M9 4v16", key: "81ygyz" }],
  ["path", { d: "M14 4v16", key: "12vmem" }],
  ["path", { d: "M19 4v16", key: "8ij5ei" }],
  ["path", { d: "M22 6 2 18", key: "h9moai" }]
]);

const LuTangent = createLucideIcon("LuTangent", [
  ["circle", { cx: "17", cy: "4", r: "2", key: "y5j2s2" }],
  ["path", { d: "M15.59 5.41 5.41 15.59", key: "l0vprr" }],
  ["circle", { cx: "4", cy: "17", r: "2", key: "9p4efm" }],
  ["path", { d: "M12 22s-4-9-1.5-11.5S22 12 22 12", key: "1twk4o" }]
]);

const LuTarget = createLucideIcon("LuTarget", [
  ["circle", { cx: "12", cy: "12", r: "10", key: "1mglay" }],
  ["circle", { cx: "12", cy: "12", r: "6", key: "1vlfrh" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }]
]);

const LuTelescope = createLucideIcon("LuTelescope", [
  [
    "path",
    {
      d: "m10.065 12.493-6.18 1.318a.934.934 0 0 1-1.108-.702l-.537-2.15a1.07 1.07 0 0 1 .691-1.265l13.504-4.44",
      key: "k4qptu"
    }
  ],
  ["path", { d: "m13.56 11.747 4.332-.924", key: "19l80z" }],
  ["path", { d: "m16 21-3.105-6.21", key: "7oh9d" }],
  [
    "path",
    {
      d: "M16.485 5.94a2 2 0 0 1 1.455-2.425l1.09-.272a1 1 0 0 1 1.212.727l1.515 6.06a1 1 0 0 1-.727 1.213l-1.09.272a2 2 0 0 1-2.425-1.455z",
      key: "m7xp4m"
    }
  ],
  ["path", { d: "m6.158 8.633 1.114 4.456", key: "74o979" }],
  ["path", { d: "m8 21 3.105-6.21", key: "1fvxut" }],
  ["circle", { cx: "12", cy: "13", r: "2", key: "1c1ljs" }]
]);

const LuTentTree = createLucideIcon("LuTentTree", [
  ["circle", { cx: "4", cy: "4", r: "2", key: "bt5ra8" }],
  ["path", { d: "m14 5 3-3 3 3", key: "1sorif" }],
  ["path", { d: "m14 10 3-3 3 3", key: "1jyi9h" }],
  ["path", { d: "M17 14V2", key: "8ymqnk" }],
  ["path", { d: "M17 14H7l-5 8h20Z", key: "13ar7p" }],
  ["path", { d: "M8 14v8", key: "1ghmqk" }],
  ["path", { d: "m9 14 5 8", key: "13pgi6" }]
]);

const LuTent = createLucideIcon("LuTent", [
  ["path", { d: "M3.5 21 14 3", key: "1szst5" }],
  ["path", { d: "M20.5 21 10 3", key: "1310c3" }],
  ["path", { d: "M15.5 21 12 15l-3.5 6", key: "1ddtfw" }],
  ["path", { d: "M2 21h20", key: "1nyx9w" }]
]);

const LuTerminal = createLucideIcon("LuTerminal", [
  ["polyline", { points: "4 17 10 11 4 5", key: "akl6gq" }],
  ["line", { x1: "12", x2: "20", y1: "19", y2: "19", key: "q2wloq" }]
]);

const LuTestTubeDiagonal = createLucideIcon("LuTestTubeDiagonal", [
  [
    "path",
    { d: "M21 7 6.82 21.18a2.83 2.83 0 0 1-3.99-.01v0a2.83 2.83 0 0 1 0-4L17 3", key: "dg8b2p" }
  ],
  ["path", { d: "m16 2 6 6", key: "1gw87d" }],
  ["path", { d: "M12 16H4", key: "1cjfip" }]
]);

const LuTestTube = createLucideIcon("LuTestTube", [
  ["path", { d: "M14.5 2v17.5c0 1.4-1.1 2.5-2.5 2.5h0c-1.4 0-2.5-1.1-2.5-2.5V2", key: "187lwq" }],
  ["path", { d: "M8.5 2h7", key: "csnxdl" }],
  ["path", { d: "M14.5 16h-5", key: "1ox875" }]
]);

const LuTestTubes = createLucideIcon("LuTestTubes", [
  ["path", { d: "M9 2v17.5A2.5 2.5 0 0 1 6.5 22v0A2.5 2.5 0 0 1 4 19.5V2", key: "12z67u" }],
  ["path", { d: "M20 2v17.5a2.5 2.5 0 0 1-2.5 2.5v0a2.5 2.5 0 0 1-2.5-2.5V2", key: "1q2nfy" }],
  ["path", { d: "M3 2h7", key: "7s29d5" }],
  ["path", { d: "M14 2h7", key: "7sicin" }],
  ["path", { d: "M9 16H4", key: "1bfye3" }],
  ["path", { d: "M20 16h-5", key: "ddnjpe" }]
]);

const LuTextCursorInput = createLucideIcon("LuTextCursorInput", [
  ["path", { d: "M5 4h1a3 3 0 0 1 3 3 3 3 0 0 1 3-3h1", key: "18xjzo" }],
  ["path", { d: "M13 20h-1a3 3 0 0 1-3-3 3 3 0 0 1-3 3H5", key: "fj48gi" }],
  ["path", { d: "M5 16H4a2 2 0 0 1-2-2v-4a2 2 0 0 1 2-2h1", key: "1n9rhb" }],
  ["path", { d: "M13 8h7a2 2 0 0 1 2 2v4a2 2 0 0 1-2 2h-7", key: "13ksps" }],
  ["path", { d: "M9 7v10", key: "1vc8ob" }]
]);

const LuTextCursor = createLucideIcon("LuTextCursor", [
  ["path", { d: "M17 22h-1a4 4 0 0 1-4-4V6a4 4 0 0 1 4-4h1", key: "uvaxm9" }],
  ["path", { d: "M7 22h1a4 4 0 0 0 4-4v-1", key: "11xy8d" }],
  ["path", { d: "M7 2h1a4 4 0 0 1 4 4v1", key: "1uw06m" }]
]);

const LuTextQuote = createLucideIcon("LuTextQuote", [
  ["path", { d: "M17 6H3", key: "16j9eg" }],
  ["path", { d: "M21 12H8", key: "scolzb" }],
  ["path", { d: "M21 18H8", key: "1wfozv" }],
  ["path", { d: "M3 12v6", key: "fv4c87" }]
]);

const LuTextSearch = createLucideIcon("LuTextSearch", [
  ["path", { d: "M21 6H3", key: "1jwq7v" }],
  ["path", { d: "M10 12H3", key: "1ulcyk" }],
  ["path", { d: "M10 18H3", key: "13769t" }],
  ["circle", { cx: "17", cy: "15", r: "3", key: "1upz2a" }],
  ["path", { d: "m21 19-1.9-1.9", key: "dwi7p8" }]
]);

const LuTextSelect = createLucideIcon("LuTextSelect", [
  ["path", { d: "M5 3a2 2 0 0 0-2 2", key: "y57alp" }],
  ["path", { d: "M19 3a2 2 0 0 1 2 2", key: "18rm91" }],
  ["path", { d: "M21 19a2 2 0 0 1-2 2", key: "1j7049" }],
  ["path", { d: "M5 21a2 2 0 0 1-2-2", key: "sbafld" }],
  ["path", { d: "M9 3h1", key: "1yesri" }],
  ["path", { d: "M9 21h1", key: "15o7lz" }],
  ["path", { d: "M14 3h1", key: "1ec4yj" }],
  ["path", { d: "M14 21h1", key: "v9vybs" }],
  ["path", { d: "M3 9v1", key: "1r0deq" }],
  ["path", { d: "M21 9v1", key: "mxsmne" }],
  ["path", { d: "M3 14v1", key: "vnatye" }],
  ["path", { d: "M21 14v1", key: "169vum" }],
  ["line", { x1: "7", x2: "15", y1: "8", y2: "8", key: "1758g8" }],
  ["line", { x1: "7", x2: "17", y1: "12", y2: "12", key: "197423" }],
  ["line", { x1: "7", x2: "13", y1: "16", y2: "16", key: "37cgm6" }]
]);

const LuText = createLucideIcon("LuText", [
  ["path", { d: "M17 6.1H3", key: "wptmhv" }],
  ["path", { d: "M21 12.1H3", key: "1j38uz" }],
  ["path", { d: "M15.1 18H3", key: "1nb16a" }]
]);

const LuTheater = createLucideIcon("LuTheater", [
  ["path", { d: "M2 10s3-3 3-8", key: "3xiif0" }],
  ["path", { d: "M22 10s-3-3-3-8", key: "ioaa5q" }],
  ["path", { d: "M10 2c0 4.4-3.6 8-8 8", key: "16fkpi" }],
  ["path", { d: "M14 2c0 4.4 3.6 8 8 8", key: "b9eulq" }],
  ["path", { d: "M2 10s2 2 2 5", key: "1au1lb" }],
  ["path", { d: "M22 10s-2 2-2 5", key: "qi2y5e" }],
  ["path", { d: "M8 15h8", key: "45n4r" }],
  ["path", { d: "M2 22v-1a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v1", key: "1vsc2m" }],
  ["path", { d: "M14 22v-1a2 2 0 0 1 2-2h4a2 2 0 0 1 2 2v1", key: "hrha4u" }]
]);

const LuThermometerSnowflake = createLucideIcon("LuThermometerSnowflake", [
  ["path", { d: "M2 12h10", key: "19562f" }],
  ["path", { d: "M9 4v16", key: "81ygyz" }],
  ["path", { d: "m3 9 3 3-3 3", key: "1sas0l" }],
  ["path", { d: "M12 6 9 9 6 6", key: "pfrgxu" }],
  ["path", { d: "m6 18 3-3 1.5 1.5", key: "1e277p" }],
  ["path", { d: "M20 4v10.54a4 4 0 1 1-4 0V4a2 2 0 0 1 4 0Z", key: "iof6y5" }]
]);

const LuThermometerSun = createLucideIcon("LuThermometerSun", [
  ["path", { d: "M12 9a4 4 0 0 0-2 7.5", key: "1jvsq6" }],
  ["path", { d: "M12 3v2", key: "1w22ol" }],
  ["path", { d: "m6.6 18.4-1.4 1.4", key: "w2yidj" }],
  ["path", { d: "M20 4v10.54a4 4 0 1 1-4 0V4a2 2 0 0 1 4 0Z", key: "iof6y5" }],
  ["path", { d: "M4 13H2", key: "118le4" }],
  ["path", { d: "M6.34 7.34 4.93 5.93", key: "1brd51" }]
]);

const LuThermometer = createLucideIcon("LuThermometer", [
  ["path", { d: "M14 4v10.54a4 4 0 1 1-4 0V4a2 2 0 0 1 4 0Z", key: "17jzev" }]
]);

const LuThumbsDown = createLucideIcon("LuThumbsDown", [
  ["path", { d: "M17 14V2", key: "8ymqnk" }],
  [
    "path",
    {
      d: "M9 18.12 10 14H4.17a2 2 0 0 1-1.92-2.56l2.33-8A2 2 0 0 1 6.5 2H20a2 2 0 0 1 2 2v8a2 2 0 0 1-2 2h-2.76a2 2 0 0 0-1.79 1.11L12 22h0a3.13 3.13 0 0 1-3-3.88Z",
      key: "s6e0r"
    }
  ]
]);

const LuThumbsUp = createLucideIcon("LuThumbsUp", [
  ["path", { d: "M7 10v12", key: "1qc93n" }],
  [
    "path",
    {
      d: "M15 5.88 14 10h5.83a2 2 0 0 1 1.92 2.56l-2.33 8A2 2 0 0 1 17.5 22H4a2 2 0 0 1-2-2v-8a2 2 0 0 1 2-2h2.76a2 2 0 0 0 1.79-1.11L12 2h0a3.13 3.13 0 0 1 3 3.88Z",
      key: "y3tblf"
    }
  ]
]);

const LuTicketCheck = createLucideIcon("LuTicketCheck", [
  [
    "path",
    {
      d: "M2 9a3 3 0 0 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 0 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z",
      key: "qn84l0"
    }
  ],
  ["path", { d: "m9 12 2 2 4-4", key: "dzmm74" }]
]);

const LuTicketMinus = createLucideIcon("LuTicketMinus", [
  [
    "path",
    {
      d: "M2 9a3 3 0 0 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 0 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z",
      key: "qn84l0"
    }
  ],
  ["path", { d: "M9 12h6", key: "1c52cq" }]
]);

const LuTicketPercent = createLucideIcon("LuTicketPercent", [
  [
    "path",
    {
      d: "M2 9a3 3 0 1 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 1 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z",
      key: "1l48ns"
    }
  ],
  ["path", { d: "M9 9h.01", key: "1q5me6" }],
  ["path", { d: "m15 9-6 6", key: "1uzhvr" }],
  ["path", { d: "M15 15h.01", key: "lqbp3k" }]
]);

const LuTicketPlus = createLucideIcon("LuTicketPlus", [
  [
    "path",
    {
      d: "M2 9a3 3 0 0 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 0 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z",
      key: "qn84l0"
    }
  ],
  ["path", { d: "M9 12h6", key: "1c52cq" }],
  ["path", { d: "M12 9v6", key: "199k2o" }]
]);

const LuTicketSlash = createLucideIcon("LuTicketSlash", [
  [
    "path",
    {
      d: "M2 9a3 3 0 0 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 0 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z",
      key: "qn84l0"
    }
  ],
  ["path", { d: "m9.5 14.5 5-5", key: "qviqfa" }]
]);

const LuTicketX = createLucideIcon("LuTicketX", [
  [
    "path",
    {
      d: "M2 9a3 3 0 0 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 0 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z",
      key: "qn84l0"
    }
  ],
  ["path", { d: "m9.5 14.5 5-5", key: "qviqfa" }],
  ["path", { d: "m9.5 9.5 5 5", key: "18nt4w" }]
]);

const LuTicket = createLucideIcon("LuTicket", [
  [
    "path",
    {
      d: "M2 9a3 3 0 0 1 0 6v2a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2v-2a3 3 0 0 1 0-6V7a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2Z",
      key: "qn84l0"
    }
  ],
  ["path", { d: "M13 5v2", key: "dyzc3o" }],
  ["path", { d: "M13 17v2", key: "1ont0d" }],
  ["path", { d: "M13 11v2", key: "1wjjxi" }]
]);

const LuTimerOff = createLucideIcon("LuTimerOff", [
  ["path", { d: "M10 2h4", key: "n1abiw" }],
  ["path", { d: "M4.6 11a8 8 0 0 0 1.7 8.7 8 8 0 0 0 8.7 1.7", key: "10he05" }],
  ["path", { d: "M7.4 7.4a8 8 0 0 1 10.3 1 8 8 0 0 1 .9 10.2", key: "15f7sh" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M12 12v-2", key: "fwoke6" }]
]);

const LuTimerReset = createLucideIcon("LuTimerReset", [
  ["path", { d: "M10 2h4", key: "n1abiw" }],
  ["path", { d: "M12 14v-4", key: "1evpnu" }],
  ["path", { d: "M4 13a8 8 0 0 1 8-7 8 8 0 1 1-5.3 14L4 17.6", key: "1ts96g" }],
  ["path", { d: "M9 17H4v5", key: "8t5av" }]
]);

const LuTimer = createLucideIcon("LuTimer", [
  ["line", { x1: "10", x2: "14", y1: "2", y2: "2", key: "14vaq8" }],
  ["line", { x1: "12", x2: "15", y1: "14", y2: "11", key: "17fdiu" }],
  ["circle", { cx: "12", cy: "14", r: "8", key: "1e1u0o" }]
]);

const LuToggleLeft = createLucideIcon("LuToggleLeft", [
  ["rect", { width: "20", height: "12", x: "2", y: "6", rx: "6", ry: "6", key: "f2vt7d" }],
  ["circle", { cx: "8", cy: "12", r: "2", key: "1nvbw3" }]
]);

const LuToggleRight = createLucideIcon("LuToggleRight", [
  ["rect", { width: "20", height: "12", x: "2", y: "6", rx: "6", ry: "6", key: "f2vt7d" }],
  ["circle", { cx: "16", cy: "12", r: "2", key: "4ma0v8" }]
]);

const LuTornado = createLucideIcon("LuTornado", [
  ["path", { d: "M21 4H3", key: "1hwok0" }],
  ["path", { d: "M18 8H6", key: "41n648" }],
  ["path", { d: "M19 12H9", key: "1g4lpz" }],
  ["path", { d: "M16 16h-6", key: "1j5d54" }],
  ["path", { d: "M11 20H9", key: "39obr8" }]
]);

const LuTorus = createLucideIcon("LuTorus", [
  ["ellipse", { cx: "12", cy: "11", rx: "3", ry: "2", key: "1b2qxu" }],
  ["ellipse", { cx: "12", cy: "12.5", rx: "10", ry: "8.5", key: "h8emeu" }]
]);

const LuTouchpadOff = createLucideIcon("LuTouchpadOff", [
  ["path", { d: "M4 4a2 2 0 0 0-2 2v12a2 2 0 0 0 2 2h16", key: "lnt0bk" }],
  ["path", { d: "M2 14h12", key: "d8icqz" }],
  ["path", { d: "M22 14h-2", key: "jrx26d" }],
  ["path", { d: "M12 20v-6", key: "1rm09r" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }],
  ["path", { d: "M22 16V6a2 2 0 0 0-2-2H10", key: "11y8e4" }]
]);

const LuTouchpad = createLucideIcon("LuTouchpad", [
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }],
  ["path", { d: "M2 14h20", key: "myj16y" }],
  ["path", { d: "M12 20v-6", key: "1rm09r" }]
]);

const LuTowerControl = createLucideIcon("LuTowerControl", [
  [
    "path",
    { d: "M18.2 12.27 20 6H4l1.8 6.27a1 1 0 0 0 .95.73h10.5a1 1 0 0 0 .96-.73Z", key: "1pledb" }
  ],
  ["path", { d: "M8 13v9", key: "hmv0ci" }],
  ["path", { d: "M16 22v-9", key: "ylnf1u" }],
  ["path", { d: "m9 6 1 7", key: "dpdgam" }],
  ["path", { d: "m15 6-1 7", key: "ls7zgu" }],
  ["path", { d: "M12 6V2", key: "1pj48d" }],
  ["path", { d: "M13 2h-2", key: "mj6ths" }]
]);

const LuToyBrick = createLucideIcon("LuToyBrick", [
  ["rect", { width: "18", height: "12", x: "3", y: "8", rx: "1", key: "158fvp" }],
  ["path", { d: "M10 8V5c0-.6-.4-1-1-1H6a1 1 0 0 0-1 1v3", key: "s0042v" }],
  ["path", { d: "M19 8V5c0-.6-.4-1-1-1h-3a1 1 0 0 0-1 1v3", key: "9wmeh2" }]
]);

const LuTractor = createLucideIcon("LuTractor", [
  ["path", { d: "m10 11 11 .9c.6 0 .9.5.8 1.1l-.8 5h-1", key: "2w242w" }],
  ["path", { d: "M16 18h-5", key: "bq60fd" }],
  ["path", { d: "M18 5a1 1 0 0 0-1 1v5.573", key: "1kv8ia" }],
  ["path", { d: "M3 4h9l1 7.246", key: "d639it" }],
  ["path", { d: "M4 11V4", key: "9ft8pt" }],
  ["path", { d: "M7 15h.01", key: "k5ht0j" }],
  ["path", { d: "M8 10.1V4", key: "1jgyzo" }],
  ["circle", { cx: "18", cy: "18", r: "2", key: "1emm8v" }],
  ["circle", { cx: "7", cy: "15", r: "5", key: "ddtuc" }]
]);

const LuTrafficCone = createLucideIcon("LuTrafficCone", [
  ["path", { d: "M9.3 6.2a4.55 4.55 0 0 0 5.4 0", key: "flyxqv" }],
  ["path", { d: "M7.9 10.7c.9.8 2.4 1.3 4.1 1.3s3.2-.5 4.1-1.3", key: "1nlxxg" }],
  [
    "path",
    {
      d: "M13.9 3.5a1.93 1.93 0 0 0-3.8-.1l-3 10c-.1.2-.1.4-.1.6 0 1.7 2.2 3 5 3s5-1.3 5-3c0-.2 0-.4-.1-.5Z",
      key: "vz7x1l"
    }
  ],
  [
    "path",
    {
      d: "m7.5 12.2-4.7 2.7c-.5.3-.8.7-.8 1.1s.3.8.8 1.1l7.6 4.5c.9.5 2.1.5 3 0l7.6-4.5c.7-.3 1-.7 1-1.1s-.3-.8-.8-1.1l-4.7-2.8",
      key: "1xfzlw"
    }
  ]
]);

const LuTrainFrontTunnel = createLucideIcon("LuTrainFrontTunnel", [
  ["path", { d: "M2 22V12a10 10 0 1 1 20 0v10", key: "o0fyp0" }],
  ["path", { d: "M15 6.8v1.4a3 2.8 0 1 1-6 0V6.8", key: "m8q3n9" }],
  ["path", { d: "M10 15h.01", key: "44in9x" }],
  ["path", { d: "M14 15h.01", key: "5mohn5" }],
  ["path", { d: "M10 19a4 4 0 0 1-4-4v-3a6 6 0 1 1 12 0v3a4 4 0 0 1-4 4Z", key: "hckbmu" }],
  ["path", { d: "m9 19-2 3", key: "iij7hm" }],
  ["path", { d: "m15 19 2 3", key: "npx8sa" }]
]);

const LuTrainFront = createLucideIcon("LuTrainFront", [
  ["path", { d: "M8 3.1V7a4 4 0 0 0 8 0V3.1", key: "1v71zp" }],
  ["path", { d: "m9 15-1-1", key: "1yrq24" }],
  ["path", { d: "m15 15 1-1", key: "1t0d6s" }],
  ["path", { d: "M9 19c-2.8 0-5-2.2-5-5v-4a8 8 0 0 1 16 0v4c0 2.8-2.2 5-5 5Z", key: "1p0hjs" }],
  ["path", { d: "m8 19-2 3", key: "13i0xs" }],
  ["path", { d: "m16 19 2 3", key: "xo31yx" }]
]);

const LuTrainTrack = createLucideIcon("LuTrainTrack", [
  ["path", { d: "M2 17 17 2", key: "18b09t" }],
  ["path", { d: "m2 14 8 8", key: "1gv9hu" }],
  ["path", { d: "m5 11 8 8", key: "189pqp" }],
  ["path", { d: "m8 8 8 8", key: "1imecy" }],
  ["path", { d: "m11 5 8 8", key: "ummqn6" }],
  ["path", { d: "m14 2 8 8", key: "1vk7dn" }],
  ["path", { d: "M7 22 22 7", key: "15mb1i" }]
]);

const LuTramFront = createLucideIcon("LuTramFront", [
  ["rect", { width: "16", height: "16", x: "4", y: "3", rx: "2", key: "1wxw4b" }],
  ["path", { d: "M4 11h16", key: "mpoxn0" }],
  ["path", { d: "M12 3v8", key: "1h2ygw" }],
  ["path", { d: "m8 19-2 3", key: "13i0xs" }],
  ["path", { d: "m18 22-2-3", key: "1p0ohu" }],
  ["path", { d: "M8 15h0", key: "q9eq1f" }],
  ["path", { d: "M16 15h0", key: "pzrbjg" }]
]);

const LuTrash2 = createLucideIcon("LuTrash2", [
  ["path", { d: "M3 6h18", key: "d0wm0j" }],
  ["path", { d: "M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6", key: "4alrt4" }],
  ["path", { d: "M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2", key: "v07s0e" }],
  ["line", { x1: "10", x2: "10", y1: "11", y2: "17", key: "1uufr5" }],
  ["line", { x1: "14", x2: "14", y1: "11", y2: "17", key: "xtxkd" }]
]);

const LuTrash = createLucideIcon("LuTrash", [
  ["path", { d: "M3 6h18", key: "d0wm0j" }],
  ["path", { d: "M19 6v14c0 1-1 2-2 2H7c-1 0-2-1-2-2V6", key: "4alrt4" }],
  ["path", { d: "M8 6V4c0-1 1-2 2-2h4c1 0 2 1 2 2v2", key: "v07s0e" }]
]);

const LuTreeDeciduous = createLucideIcon("LuTreeDeciduous", [
  [
    "path",
    {
      d: "M8 19a4 4 0 0 1-2.24-7.32A3.5 3.5 0 0 1 9 6.03V6a3 3 0 1 1 6 0v.04a3.5 3.5 0 0 1 3.24 5.65A4 4 0 0 1 16 19Z",
      key: "oadzkq"
    }
  ],
  ["path", { d: "M12 19v3", key: "npa21l" }]
]);

const LuTreePalm = createLucideIcon("LuTreePalm", [
  ["path", { d: "M13 8c0-2.76-2.46-5-5.5-5S2 5.24 2 8h2l1-1 1 1h4", key: "foxbe7" }],
  [
    "path",
    { d: "M13 7.14A5.82 5.82 0 0 1 16.5 6c3.04 0 5.5 2.24 5.5 5h-3l-1-1-1 1h-3", key: "18arnh" }
  ],
  [
    "path",
    {
      d: "M5.89 9.71c-2.15 2.15-2.3 5.47-.35 7.43l4.24-4.25.7-.7.71-.71 2.12-2.12c-1.95-1.96-5.27-1.8-7.42.35",
      key: "ywahnh"
    }
  ],
  ["path", { d: "M11 15.5c.5 2.5-.17 4.5-1 6.5h4c2-5.5-.5-12-1-14", key: "ft0feo" }]
]);

const LuTreePine = createLucideIcon("LuTreePine", [
  [
    "path",
    {
      d: "m17 14 3 3.3a1 1 0 0 1-.7 1.7H4.7a1 1 0 0 1-.7-1.7L7 14h-.3a1 1 0 0 1-.7-1.7L9 9h-.2A1 1 0 0 1 8 7.3L12 3l4 4.3a1 1 0 0 1-.8 1.7H15l3 3.3a1 1 0 0 1-.7 1.7H17Z",
      key: "cpyugq"
    }
  ],
  ["path", { d: "M12 22v-3", key: "kmzjlo" }]
]);

const LuTrees = createLucideIcon("LuTrees", [
  [
    "path",
    { d: "M10 10v.2A3 3 0 0 1 8.9 16v0H5v0h0a3 3 0 0 1-1-5.8V10a3 3 0 0 1 6 0Z", key: "yh07w9" }
  ],
  ["path", { d: "M7 16v6", key: "1a82de" }],
  ["path", { d: "M13 19v3", key: "13sx9i" }],
  [
    "path",
    {
      d: "M12 19h8.3a1 1 0 0 0 .7-1.7L18 14h.3a1 1 0 0 0 .7-1.7L16 9h.2a1 1 0 0 0 .8-1.7L13 3l-1.4 1.5",
      key: "1sj9kv"
    }
  ]
]);

const LuTrello = createLucideIcon("LuTrello", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", ry: "2", key: "1m3agn" }],
  ["rect", { width: "3", height: "9", x: "7", y: "7", key: "14n3xi" }],
  ["rect", { width: "3", height: "5", x: "14", y: "7", key: "s4azjd" }]
]);

const LuTrendingDown = createLucideIcon("LuTrendingDown", [
  ["polyline", { points: "22 17 13.5 8.5 8.5 13.5 2 7", key: "1r2t7k" }],
  ["polyline", { points: "16 17 22 17 22 11", key: "11uiuu" }]
]);

const LuTrendingUp = createLucideIcon("LuTrendingUp", [
  ["polyline", { points: "22 7 13.5 15.5 8.5 10.5 2 17", key: "126l90" }],
  ["polyline", { points: "16 7 22 7 22 13", key: "kwv8wd" }]
]);

const LuTriangleAlert = createLucideIcon("LuTriangleAlert", [
  [
    "path",
    {
      d: "m21.73 18-8-14a2 2 0 0 0-3.48 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3",
      key: "wmoenq"
    }
  ],
  ["path", { d: "M12 9v4", key: "juzpu7" }],
  ["path", { d: "M12 17h.01", key: "p32p05" }]
]);

const LuTriangleRight = createLucideIcon("LuTriangleRight", [
  [
    "path",
    {
      d: "M22 18a2 2 0 0 1-2 2H3c-1.1 0-1.3-.6-.4-1.3L20.4 4.3c.9-.7 1.6-.4 1.6.7Z",
      key: "183wce"
    }
  ]
]);

const LuTriangle = createLucideIcon("LuTriangle", [
  [
    "path",
    { d: "M13.73 4a2 2 0 0 0-3.46 0l-8 14A2 2 0 0 0 4 21h16a2 2 0 0 0 1.73-3Z", key: "14u9p9" }
  ]
]);

const LuTrophy = createLucideIcon("LuTrophy", [
  ["path", { d: "M6 9H4.5a2.5 2.5 0 0 1 0-5H6", key: "17hqa7" }],
  ["path", { d: "M18 9h1.5a2.5 2.5 0 0 0 0-5H18", key: "lmptdp" }],
  ["path", { d: "M4 22h16", key: "57wxv0" }],
  ["path", { d: "M10 14.66V17c0 .55-.47.98-.97 1.21C7.85 18.75 7 20.24 7 22", key: "1nw9bq" }],
  ["path", { d: "M14 14.66V17c0 .55.47.98.97 1.21C16.15 18.75 17 20.24 17 22", key: "1np0yb" }],
  ["path", { d: "M18 2H6v7a6 6 0 0 0 12 0V2Z", key: "u46fv3" }]
]);

const LuTruck = createLucideIcon("LuTruck", [
  ["path", { d: "M14 18V6a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v11a1 1 0 0 0 1 1h2", key: "wrbu53" }],
  ["path", { d: "M15 18H9", key: "1lyqi6" }],
  [
    "path",
    {
      d: "M19 18h2a1 1 0 0 0 1-1v-3.65a1 1 0 0 0-.22-.624l-3.48-4.35A1 1 0 0 0 17.52 8H14",
      key: "lysw3i"
    }
  ],
  ["circle", { cx: "17", cy: "18", r: "2", key: "332jqn" }],
  ["circle", { cx: "7", cy: "18", r: "2", key: "19iecd" }]
]);

const LuTurtle = createLucideIcon("LuTurtle", [
  [
    "path",
    {
      d: "m12 10 2 4v3a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-3a8 8 0 1 0-16 0v3a1 1 0 0 0 1 1h2a1 1 0 0 0 1-1v-3l2-4h4Z",
      key: "1lbbv7"
    }
  ],
  ["path", { d: "M4.82 7.9 8 10", key: "m9wose" }],
  ["path", { d: "M15.18 7.9 12 10", key: "p8dp2u" }],
  ["path", { d: "M16.93 10H20a2 2 0 0 1 0 4H2", key: "12nsm7" }]
]);

const LuTv2 = createLucideIcon("LuTv2", [
  ["path", { d: "M7 21h10", key: "1b0cd5" }],
  ["rect", { width: "20", height: "14", x: "2", y: "3", rx: "2", key: "48i651" }]
]);

const LuTv = createLucideIcon("LuTv", [
  ["rect", { width: "20", height: "15", x: "2", y: "7", rx: "2", ry: "2", key: "10ag99" }],
  ["polyline", { points: "17 2 12 7 7 2", key: "11pgbg" }]
]);

const LuTwitch = createLucideIcon("LuTwitch", [
  ["path", { d: "M21 2H3v16h5v4l4-4h5l4-4V2zm-10 9V7m5 4V7", key: "c0yzno" }]
]);

const LuTwitter = createLucideIcon("LuTwitter", [
  [
    "path",
    {
      d: "M22 4s-.7 2.1-2 3.4c1.6 10-9.4 17.3-18 11.6 2.2.1 4.4-.6 6-2C3 15.5.5 9.6 3 5c2.2 2.6 5.6 4.1 9 4-.9-4.2 4-6.6 7-3.8 1.1 0 3-1.2 3-1.2z",
      key: "pff0z6"
    }
  ]
]);

const LuType = createLucideIcon("LuType", [
  ["polyline", { points: "4 7 4 4 20 4 20 7", key: "1nosan" }],
  ["line", { x1: "9", x2: "15", y1: "20", y2: "20", key: "swin9y" }],
  ["line", { x1: "12", x2: "12", y1: "4", y2: "20", key: "1tx1rr" }]
]);

const LuUmbrellaOff = createLucideIcon("LuUmbrellaOff", [
  ["path", { d: "M12 2v1", key: "11qlp1" }],
  ["path", { d: "M15.5 21a1.85 1.85 0 0 1-3.5-1v-8H2a10 10 0 0 1 3.428-6.575", key: "eki10q" }],
  ["path", { d: "M17.5 12H22A10 10 0 0 0 9.004 3.455", key: "n2ayka" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuUmbrella = createLucideIcon("LuUmbrella", [
  ["path", { d: "M22 12a10.06 10.06 1 0 0-20 0Z", key: "1teyop" }],
  ["path", { d: "M12 12v8a2 2 0 0 0 4 0", key: "ulpmoc" }],
  ["path", { d: "M12 2v1", key: "11qlp1" }]
]);

const LuUnderline = createLucideIcon("LuUnderline", [
  ["path", { d: "M6 4v6a6 6 0 0 0 12 0V4", key: "9kb039" }],
  ["line", { x1: "4", x2: "20", y1: "20", y2: "20", key: "nun2al" }]
]);

const LuUndo2 = createLucideIcon("LuUndo2", [
  ["path", { d: "M9 14 4 9l5-5", key: "102s5s" }],
  ["path", { d: "M4 9h10.5a5.5 5.5 0 0 1 5.5 5.5v0a5.5 5.5 0 0 1-5.5 5.5H11", key: "llx8ln" }]
]);

const LuUndoDot = createLucideIcon("LuUndoDot", [
  ["circle", { cx: "12", cy: "17", r: "1", key: "1ixnty" }],
  ["path", { d: "M3 7v6h6", key: "1v2h90" }],
  ["path", { d: "M21 17a9 9 0 0 0-9-9 9 9 0 0 0-6 2.3L3 13", key: "1r6uu6" }]
]);

const LuUndo = createLucideIcon("LuUndo", [
  ["path", { d: "M3 7v6h6", key: "1v2h90" }],
  ["path", { d: "M21 17a9 9 0 0 0-9-9 9 9 0 0 0-6 2.3L3 13", key: "1r6uu6" }]
]);

const LuUnfoldHorizontal = createLucideIcon("LuUnfoldHorizontal", [
  ["path", { d: "M16 12h6", key: "15xry1" }],
  ["path", { d: "M8 12H2", key: "1jqql6" }],
  ["path", { d: "M12 2v2", key: "tus03m" }],
  ["path", { d: "M12 8v2", key: "1woqiv" }],
  ["path", { d: "M12 14v2", key: "8jcxud" }],
  ["path", { d: "M12 20v2", key: "1lh1kg" }],
  ["path", { d: "m19 15 3-3-3-3", key: "wjy7rq" }],
  ["path", { d: "m5 9-3 3 3 3", key: "j64kie" }]
]);

const LuUnfoldVertical = createLucideIcon("LuUnfoldVertical", [
  ["path", { d: "M12 22v-6", key: "6o8u61" }],
  ["path", { d: "M12 8V2", key: "1wkif3" }],
  ["path", { d: "M4 12H2", key: "rhcxmi" }],
  ["path", { d: "M10 12H8", key: "s88cx1" }],
  ["path", { d: "M16 12h-2", key: "10asgb" }],
  ["path", { d: "M22 12h-2", key: "14jgyd" }],
  ["path", { d: "m15 19-3 3-3-3", key: "11eu04" }],
  ["path", { d: "m15 5-3-3-3 3", key: "itvq4r" }]
]);

const LuUngroup = createLucideIcon("LuUngroup", [
  ["rect", { width: "8", height: "6", x: "5", y: "4", rx: "1", key: "nzclkv" }],
  ["rect", { width: "8", height: "6", x: "11", y: "14", rx: "1", key: "4tytwb" }]
]);

const LuUniversity = createLucideIcon("LuUniversity", [
  ["circle", { cx: "12", cy: "10", r: "1", key: "1gnqs8" }],
  ["path", { d: "M22 20V8h-4l-6-4-6 4H2v12a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2", key: "1qj5sn" }],
  ["path", { d: "M6 17v.01", key: "roodi6" }],
  ["path", { d: "M6 13v.01", key: "67c122" }],
  ["path", { d: "M18 17v.01", key: "12ktxm" }],
  ["path", { d: "M18 13v.01", key: "tn1rt1" }],
  ["path", { d: "M14 22v-5a2 2 0 0 0-2-2v0a2 2 0 0 0-2 2v5", key: "jfgdp0" }]
]);

const LuUnlink2 = createLucideIcon("LuUnlink2", [
  ["path", { d: "M15 7h2a5 5 0 0 1 0 10h-2m-6 0H7A5 5 0 0 1 7 7h2", key: "1re2ne" }]
]);

const LuUnlink = createLucideIcon("LuUnlink", [
  [
    "path",
    {
      d: "m18.84 12.25 1.72-1.71h-.02a5.004 5.004 0 0 0-.12-7.07 5.006 5.006 0 0 0-6.95 0l-1.72 1.71",
      key: "yqzxt4"
    }
  ],
  [
    "path",
    {
      d: "m5.17 11.75-1.71 1.71a5.004 5.004 0 0 0 .12 7.07 5.006 5.006 0 0 0 6.95 0l1.71-1.71",
      key: "4qinb0"
    }
  ],
  ["line", { x1: "8", x2: "8", y1: "2", y2: "5", key: "1041cp" }],
  ["line", { x1: "2", x2: "5", y1: "8", y2: "8", key: "14m1p5" }],
  ["line", { x1: "16", x2: "16", y1: "19", y2: "22", key: "rzdirn" }],
  ["line", { x1: "19", x2: "22", y1: "16", y2: "16", key: "ox905f" }]
]);

const LuUnplug = createLucideIcon("LuUnplug", [
  ["path", { d: "m19 5 3-3", key: "yk6iyv" }],
  ["path", { d: "m2 22 3-3", key: "19mgm9" }],
  [
    "path",
    { d: "M6.3 20.3a2.4 2.4 0 0 0 3.4 0L12 18l-6-6-2.3 2.3a2.4 2.4 0 0 0 0 3.4Z", key: "goz73y" }
  ],
  ["path", { d: "M7.5 13.5 10 11", key: "7xgeeb" }],
  ["path", { d: "M10.5 16.5 13 14", key: "10btkg" }],
  [
    "path",
    { d: "m12 6 6 6 2.3-2.3a2.4 2.4 0 0 0 0-3.4l-2.6-2.6a2.4 2.4 0 0 0-3.4 0Z", key: "1snsnr" }
  ]
]);

const LuUpload = createLucideIcon("LuUpload", [
  ["path", { d: "M21 15v4a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-4", key: "ih7n3h" }],
  ["polyline", { points: "17 8 12 3 7 8", key: "t8dd8p" }],
  ["line", { x1: "12", x2: "12", y1: "3", y2: "15", key: "widbto" }]
]);

const LuUsb = createLucideIcon("LuUsb", [
  ["circle", { cx: "10", cy: "7", r: "1", key: "dypaad" }],
  ["circle", { cx: "4", cy: "20", r: "1", key: "22iqad" }],
  ["path", { d: "M4.7 19.3 19 5", key: "1enqfc" }],
  ["path", { d: "m21 3-3 1 2 2Z", key: "d3ov82" }],
  ["path", { d: "M9.26 7.68 5 12l2 5", key: "1esawj" }],
  ["path", { d: "m10 14 5 2 3.5-3.5", key: "v8oal5" }],
  ["path", { d: "m18 12 1-1 1 1-1 1Z", key: "1bh22v" }]
]);

const LuUserCheck = createLucideIcon("LuUserCheck", [
  ["path", { d: "M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2", key: "1yyitq" }],
  ["circle", { cx: "9", cy: "7", r: "4", key: "nufk8" }],
  ["polyline", { points: "16 11 18 13 22 9", key: "1pwet4" }]
]);

const LuUserCog = createLucideIcon("LuUserCog", [
  ["circle", { cx: "18", cy: "15", r: "3", key: "gjjjvw" }],
  ["circle", { cx: "9", cy: "7", r: "4", key: "nufk8" }],
  ["path", { d: "M10 15H6a4 4 0 0 0-4 4v2", key: "1nfge6" }],
  ["path", { d: "m21.7 16.4-.9-.3", key: "12j9ji" }],
  ["path", { d: "m15.2 13.9-.9-.3", key: "1fdjdi" }],
  ["path", { d: "m16.6 18.7.3-.9", key: "heedtr" }],
  ["path", { d: "m19.1 12.2.3-.9", key: "1af3ki" }],
  ["path", { d: "m19.6 18.7-.4-1", key: "1x9vze" }],
  ["path", { d: "m16.8 12.3-.4-1", key: "vqeiwj" }],
  ["path", { d: "m14.3 16.6 1-.4", key: "1qlj63" }],
  ["path", { d: "m20.7 13.8 1-.4", key: "1v5t8k" }]
]);

const LuUserMinus = createLucideIcon("LuUserMinus", [
  ["path", { d: "M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2", key: "1yyitq" }],
  ["circle", { cx: "9", cy: "7", r: "4", key: "nufk8" }],
  ["line", { x1: "22", x2: "16", y1: "11", y2: "11", key: "1shjgl" }]
]);

const LuUserPlus = createLucideIcon("LuUserPlus", [
  ["path", { d: "M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2", key: "1yyitq" }],
  ["circle", { cx: "9", cy: "7", r: "4", key: "nufk8" }],
  ["line", { x1: "19", x2: "19", y1: "8", y2: "14", key: "1bvyxn" }],
  ["line", { x1: "22", x2: "16", y1: "11", y2: "11", key: "1shjgl" }]
]);

const LuUserRoundCheck = createLucideIcon("LuUserRoundCheck", [
  ["path", { d: "M2 21a8 8 0 0 1 13.292-6", key: "bjp14o" }],
  ["circle", { cx: "10", cy: "8", r: "5", key: "o932ke" }],
  ["path", { d: "m16 19 2 2 4-4", key: "1b14m6" }]
]);

const LuUserRoundCog = createLucideIcon("LuUserRoundCog", [
  ["path", { d: "M2 21a8 8 0 0 1 10.434-7.62", key: "1yezr2" }],
  ["circle", { cx: "10", cy: "8", r: "5", key: "o932ke" }],
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  ["path", { d: "m19.5 14.3-.4.9", key: "1eb35c" }],
  ["path", { d: "m16.9 20.8-.4.9", key: "dfjc4z" }],
  ["path", { d: "m21.7 19.5-.9-.4", key: "q4dx6b" }],
  ["path", { d: "m15.2 16.9-.9-.4", key: "1r0w5f" }],
  ["path", { d: "m21.7 16.5-.9.4", key: "1knoei" }],
  ["path", { d: "m15.2 19.1-.9.4", key: "j188fs" }],
  ["path", { d: "m19.5 21.7-.4-.9", key: "1tonu5" }],
  ["path", { d: "m16.9 15.2-.4-.9", key: "699xu" }]
]);

const LuUserRoundMinus = createLucideIcon("LuUserRoundMinus", [
  ["path", { d: "M2 21a8 8 0 0 1 13.292-6", key: "bjp14o" }],
  ["circle", { cx: "10", cy: "8", r: "5", key: "o932ke" }],
  ["path", { d: "M22 19h-6", key: "vcuq98" }]
]);

const LuUserRoundPlus = createLucideIcon("LuUserRoundPlus", [
  ["path", { d: "M2 21a8 8 0 0 1 13.292-6", key: "bjp14o" }],
  ["circle", { cx: "10", cy: "8", r: "5", key: "o932ke" }],
  ["path", { d: "M19 16v6", key: "tddt3s" }],
  ["path", { d: "M22 19h-6", key: "vcuq98" }]
]);

const LuUserRoundSearch = createLucideIcon("LuUserRoundSearch", [
  ["circle", { cx: "10", cy: "8", r: "5", key: "o932ke" }],
  ["path", { d: "M2 21a8 8 0 0 1 10.434-7.62", key: "1yezr2" }],
  ["circle", { cx: "18", cy: "18", r: "3", key: "1xkwt0" }],
  ["path", { d: "m22 22-1.9-1.9", key: "1e5ubv" }]
]);

const LuUserRoundX = createLucideIcon("LuUserRoundX", [
  ["path", { d: "M2 21a8 8 0 0 1 11.873-7", key: "74fkxq" }],
  ["circle", { cx: "10", cy: "8", r: "5", key: "o932ke" }],
  ["path", { d: "m17 17 5 5", key: "p7ous7" }],
  ["path", { d: "m22 17-5 5", key: "gqnmv0" }]
]);

const LuUserRound = createLucideIcon("LuUserRound", [
  ["circle", { cx: "12", cy: "8", r: "5", key: "1hypcn" }],
  ["path", { d: "M20 21a8 8 0 0 0-16 0", key: "rfgkzh" }]
]);

const LuUserSearch = createLucideIcon("LuUserSearch", [
  ["circle", { cx: "10", cy: "7", r: "4", key: "e45bow" }],
  ["path", { d: "M10.3 15H7a4 4 0 0 0-4 4v2", key: "3bnktk" }],
  ["circle", { cx: "17", cy: "17", r: "3", key: "18b49y" }],
  ["path", { d: "m21 21-1.9-1.9", key: "1g2n9r" }]
]);

const LuUserX = createLucideIcon("LuUserX", [
  ["path", { d: "M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2", key: "1yyitq" }],
  ["circle", { cx: "9", cy: "7", r: "4", key: "nufk8" }],
  ["line", { x1: "17", x2: "22", y1: "8", y2: "13", key: "3nzzx3" }],
  ["line", { x1: "22", x2: "17", y1: "8", y2: "13", key: "1swrse" }]
]);

const LuUser = createLucideIcon("LuUser", [
  ["path", { d: "M19 21v-2a4 4 0 0 0-4-4H9a4 4 0 0 0-4 4v2", key: "975kel" }],
  ["circle", { cx: "12", cy: "7", r: "4", key: "17ys0d" }]
]);

const LuUsersRound = createLucideIcon("LuUsersRound", [
  ["path", { d: "M18 21a8 8 0 0 0-16 0", key: "3ypg7q" }],
  ["circle", { cx: "10", cy: "8", r: "5", key: "o932ke" }],
  ["path", { d: "M22 20c0-3.37-2-6.5-4-8a5 5 0 0 0-.45-8.3", key: "10s06x" }]
]);

const LuUsers = createLucideIcon("LuUsers", [
  ["path", { d: "M16 21v-2a4 4 0 0 0-4-4H6a4 4 0 0 0-4 4v2", key: "1yyitq" }],
  ["circle", { cx: "9", cy: "7", r: "4", key: "nufk8" }],
  ["path", { d: "M22 21v-2a4 4 0 0 0-3-3.87", key: "kshegd" }],
  ["path", { d: "M16 3.13a4 4 0 0 1 0 7.75", key: "1da9ce" }]
]);

const LuUtensilsCrossed = createLucideIcon("LuUtensilsCrossed", [
  ["path", { d: "m16 2-2.3 2.3a3 3 0 0 0 0 4.2l1.8 1.8a3 3 0 0 0 4.2 0L22 8", key: "n7qcjb" }],
  [
    "path",
    { d: "M15 15 3.3 3.3a4.2 4.2 0 0 0 0 6l7.3 7.3c.7.7 2 .7 2.8 0L15 15Zm0 0 7 7", key: "d0u48b" }
  ],
  ["path", { d: "m2.1 21.8 6.4-6.3", key: "yn04lh" }],
  ["path", { d: "m19 5-7 7", key: "194lzd" }]
]);

const LuUtensils = createLucideIcon("LuUtensils", [
  ["path", { d: "M3 2v7c0 1.1.9 2 2 2h4a2 2 0 0 0 2-2V2", key: "cjf0a3" }],
  ["path", { d: "M7 2v20", key: "1473qp" }],
  ["path", { d: "M21 15V2v0a5 5 0 0 0-5 5v6c0 1.1.9 2 2 2h3Zm0 0v7", key: "1ogz0v" }]
]);

const LuUtilityPole = createLucideIcon("LuUtilityPole", [
  ["path", { d: "M12 2v20", key: "t6zp3m" }],
  ["path", { d: "M2 5h20", key: "1fs1ex" }],
  ["path", { d: "M3 3v2", key: "9imdir" }],
  ["path", { d: "M7 3v2", key: "n0os7" }],
  ["path", { d: "M17 3v2", key: "1l2re6" }],
  ["path", { d: "M21 3v2", key: "1duuac" }],
  ["path", { d: "m19 5-7 7-7-7", key: "133zxf" }]
]);

const LuVariable = createLucideIcon("LuVariable", [
  ["path", { d: "M8 21s-4-3-4-9 4-9 4-9", key: "uto9ud" }],
  ["path", { d: "M16 3s4 3 4 9-4 9-4 9", key: "4w2vsq" }],
  ["line", { x1: "15", x2: "9", y1: "9", y2: "15", key: "f7djnv" }],
  ["line", { x1: "9", x2: "15", y1: "9", y2: "15", key: "1shsy8" }]
]);

const LuVault = createLucideIcon("LuVault", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["circle", { cx: "7.5", cy: "7.5", r: ".5", fill: "currentColor", key: "kqv944" }],
  ["path", { d: "m7.9 7.9 2.7 2.7", key: "hpeyl3" }],
  ["circle", { cx: "16.5", cy: "7.5", r: ".5", fill: "currentColor", key: "w0ekpg" }],
  ["path", { d: "m13.4 10.6 2.7-2.7", key: "264c1n" }],
  ["circle", { cx: "7.5", cy: "16.5", r: ".5", fill: "currentColor", key: "nkw3mc" }],
  ["path", { d: "m7.9 16.1 2.7-2.7", key: "p81g5e" }],
  ["circle", { cx: "16.5", cy: "16.5", r: ".5", fill: "currentColor", key: "fubopw" }],
  ["path", { d: "m13.4 13.4 2.7 2.7", key: "abhel3" }],
  ["circle", { cx: "12", cy: "12", r: "2", key: "1c9p78" }]
]);

const LuVegan = createLucideIcon("LuVegan", [
  ["path", { d: "M2 2a26.6 26.6 0 0 1 10 20c.9-6.82 1.5-9.5 4-14", key: "qiv7li" }],
  ["path", { d: "M16 8c4 0 6-2 6-6-4 0-6 2-6 6", key: "n7eohy" }],
  ["path", { d: "M17.41 3.6a10 10 0 1 0 3 3", key: "1dion0" }]
]);

const LuVenetianMask = createLucideIcon("LuVenetianMask", [
  [
    "path",
    {
      d: "M2 12a5 5 0 0 0 5 5 8 8 0 0 1 5 2 8 8 0 0 1 5-2 5 5 0 0 0 5-5V7h-5a8 8 0 0 0-5 2 8 8 0 0 0-5-2H2Z",
      key: "1g6z3j"
    }
  ],
  ["path", { d: "M6 11c1.5 0 3 .5 3 2-2 0-3 0-3-2Z", key: "c2lwnf" }],
  ["path", { d: "M18 11c-1.5 0-3 .5-3 2 2 0 3 0 3-2Z", key: "njd9zo" }]
]);

const LuVibrateOff = createLucideIcon("LuVibrateOff", [
  ["path", { d: "m2 8 2 2-2 2 2 2-2 2", key: "sv1b1" }],
  ["path", { d: "m22 8-2 2 2 2-2 2 2 2", key: "101i4y" }],
  ["path", { d: "M8 8v10c0 .55.45 1 1 1h6c.55 0 1-.45 1-1v-2", key: "1hbad5" }],
  ["path", { d: "M16 10.34V6c0-.55-.45-1-1-1h-4.34", key: "1x5tf0" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuVibrate = createLucideIcon("LuVibrate", [
  ["path", { d: "m2 8 2 2-2 2 2 2-2 2", key: "sv1b1" }],
  ["path", { d: "m22 8-2 2 2 2-2 2 2 2", key: "101i4y" }],
  ["rect", { width: "8", height: "14", x: "8", y: "5", rx: "1", key: "1oyrl4" }]
]);

const LuVideoOff = createLucideIcon("LuVideoOff", [
  ["path", { d: "M10.66 6H14a2 2 0 0 1 2 2v2.34l1 1L22 8v8", key: "ubwiq0" }],
  ["path", { d: "M16 16a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V8a2 2 0 0 1 2-2h2l10 10Z", key: "1l10zd" }],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuVideo = createLucideIcon("LuVideo", [
  ["path", { d: "m22 8-6 4 6 4V8Z", key: "50v9me" }],
  ["rect", { width: "14", height: "12", x: "2", y: "6", rx: "2", ry: "2", key: "1rqjg6" }]
]);

const LuVideotape = createLucideIcon("LuVideotape", [
  ["rect", { width: "20", height: "16", x: "2", y: "4", rx: "2", key: "18n3k1" }],
  ["path", { d: "M2 8h20", key: "d11cs7" }],
  ["circle", { cx: "8", cy: "14", r: "2", key: "1k2qr5" }],
  ["path", { d: "M8 12h8", key: "1wcyev" }],
  ["circle", { cx: "16", cy: "14", r: "2", key: "14k7lr" }]
]);

const LuView = createLucideIcon("LuView", [
  [
    "path",
    { d: "M5 12s2.545-5 7-5c4.454 0 7 5 7 5s-2.546 5-7 5c-4.455 0-7-5-7-5z", key: "vptub8" }
  ],
  ["path", { d: "M12 13a1 1 0 1 0 0-2 1 1 0 0 0 0 2z", key: "10lhjs" }],
  ["path", { d: "M21 17v2a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2v-2", key: "mrq65r" }],
  ["path", { d: "M21 7V5a2 2 0 0 0-2-2H5a2 2 0 0 0-2 2v2", key: "be3xqs" }]
]);

const LuVoicemail = createLucideIcon("LuVoicemail", [
  ["circle", { cx: "6", cy: "12", r: "4", key: "1ehtga" }],
  ["circle", { cx: "18", cy: "12", r: "4", key: "4vafl8" }],
  ["line", { x1: "6", x2: "18", y1: "16", y2: "16", key: "pmt8us" }]
]);

const LuVolume1 = createLucideIcon("LuVolume1", [
  ["polygon", { points: "11 5 6 9 2 9 2 15 6 15 11 19 11 5", key: "16drj5" }],
  ["path", { d: "M15.54 8.46a5 5 0 0 1 0 7.07", key: "ltjumu" }]
]);

const LuVolume2 = createLucideIcon("LuVolume2", [
  ["polygon", { points: "11 5 6 9 2 9 2 15 6 15 11 19 11 5", key: "16drj5" }],
  ["path", { d: "M15.54 8.46a5 5 0 0 1 0 7.07", key: "ltjumu" }],
  ["path", { d: "M19.07 4.93a10 10 0 0 1 0 14.14", key: "1kegas" }]
]);

const LuVolumeX = createLucideIcon("LuVolumeX", [
  ["polygon", { points: "11 5 6 9 2 9 2 15 6 15 11 19 11 5", key: "16drj5" }],
  ["line", { x1: "22", x2: "16", y1: "9", y2: "15", key: "1ewh16" }],
  ["line", { x1: "16", x2: "22", y1: "9", y2: "15", key: "5ykzw1" }]
]);

const LuVolume = createLucideIcon("LuVolume", [
  ["polygon", { points: "11 5 6 9 2 9 2 15 6 15 11 19 11 5", key: "16drj5" }]
]);

const LuVote = createLucideIcon("LuVote", [
  ["path", { d: "m9 12 2 2 4-4", key: "dzmm74" }],
  ["path", { d: "M5 7c0-1.1.9-2 2-2h10a2 2 0 0 1 2 2v12H5V7Z", key: "1ezoue" }],
  ["path", { d: "M22 19H2", key: "nuriw5" }]
]);

const LuWalletCards = createLucideIcon("LuWalletCards", [
  ["rect", { width: "18", height: "18", x: "3", y: "3", rx: "2", key: "afitv7" }],
  ["path", { d: "M3 9a2 2 0 0 1 2-2h14a2 2 0 0 1 2 2", key: "4125el" }],
  [
    "path",
    {
      d: "M3 11h3c.8 0 1.6.3 2.1.9l1.1.9c1.6 1.6 4.1 1.6 5.7 0l1.1-.9c.5-.5 1.3-.9 2.1-.9H21",
      key: "1dpki6"
    }
  ]
]);

const LuWalletMinimal = createLucideIcon("LuWalletMinimal", [
  ["path", { d: "M17 14h.01", key: "7oqj8z" }],
  [
    "path",
    {
      d: "M7 7h12a2 2 0 0 1 2 2v10a2 2 0 0 1-2 2H5a2 2 0 0 1-2-2V5a2 2 0 0 1 2-2h14",
      key: "u1rqew"
    }
  ]
]);

const LuWallet = createLucideIcon("LuWallet", [
  ["path", { d: "M21 12V7H5a2 2 0 0 1 0-4h14v4", key: "195gfw" }],
  ["path", { d: "M3 5v14a2 2 0 0 0 2 2h16v-5", key: "195n9w" }],
  ["path", { d: "M18 12a2 2 0 0 0 0 4h4v-4Z", key: "vllfpd" }]
]);

const LuWallpaper = createLucideIcon("LuWallpaper", [
  ["circle", { cx: "8", cy: "9", r: "2", key: "gjzl9d" }],
  [
    "path",
    {
      d: "m9 17 6.1-6.1a2 2 0 0 1 2.81.01L22 15V5a2 2 0 0 0-2-2H4a2 2 0 0 0-2 2v10a2 2 0 0 0 2 2h16a2 2 0 0 0 2-2",
      key: "69xh40"
    }
  ],
  ["path", { d: "M8 21h8", key: "1ev6f3" }],
  ["path", { d: "M12 17v4", key: "1riwvh" }]
]);

const LuWandSparkles = createLucideIcon("LuWandSparkles", [
  [
    "path",
    {
      d: "m21.64 3.64-1.28-1.28a1.21 1.21 0 0 0-1.72 0L2.36 18.64a1.21 1.21 0 0 0 0 1.72l1.28 1.28a1.2 1.2 0 0 0 1.72 0L21.64 5.36a1.2 1.2 0 0 0 0-1.72",
      key: "ul74o6"
    }
  ],
  ["path", { d: "m14 7 3 3", key: "1r5n42" }],
  ["path", { d: "M5 6v4", key: "ilb8ba" }],
  ["path", { d: "M19 14v4", key: "blhpug" }],
  ["path", { d: "M10 2v2", key: "7u0qdc" }],
  ["path", { d: "M7 8H3", key: "zfb6yr" }],
  ["path", { d: "M21 16h-4", key: "1cnmox" }],
  ["path", { d: "M11 3H9", key: "1obp7u" }]
]);

const LuWand = createLucideIcon("LuWand", [
  ["path", { d: "M15 4V2", key: "z1p9b7" }],
  ["path", { d: "M15 16v-2", key: "px0unx" }],
  ["path", { d: "M8 9h2", key: "1g203m" }],
  ["path", { d: "M20 9h2", key: "19tzq7" }],
  ["path", { d: "M17.8 11.8 19 13", key: "yihg8r" }],
  ["path", { d: "M15 9h0", key: "kg5t1u" }],
  ["path", { d: "M17.8 6.2 19 5", key: "fd4us0" }],
  ["path", { d: "m3 21 9-9", key: "1jfql5" }],
  ["path", { d: "M12.2 6.2 11 5", key: "i3da3b" }]
]);

const LuWarehouse = createLucideIcon("LuWarehouse", [
  [
    "path",
    {
      d: "M22 8.35V20a2 2 0 0 1-2 2H4a2 2 0 0 1-2-2V8.35A2 2 0 0 1 3.26 6.5l8-3.2a2 2 0 0 1 1.48 0l8 3.2A2 2 0 0 1 22 8.35Z",
      key: "gksnxg"
    }
  ],
  ["path", { d: "M6 18h12", key: "9pbo8z" }],
  ["path", { d: "M6 14h12", key: "4cwo0f" }],
  ["rect", { width: "12", height: "12", x: "6", y: "10", key: "apd30q" }]
]);

const LuWashingMachine = createLucideIcon("LuWashingMachine", [
  ["path", { d: "M3 6h3", key: "155dbl" }],
  ["path", { d: "M17 6h.01", key: "e2y6kg" }],
  ["rect", { width: "18", height: "20", x: "3", y: "2", rx: "2", key: "od3kk9" }],
  ["circle", { cx: "12", cy: "13", r: "5", key: "nlbqau" }],
  ["path", { d: "M12 18a2.5 2.5 0 0 0 0-5 2.5 2.5 0 0 1 0-5", key: "17lach" }]
]);

const LuWatch = createLucideIcon("LuWatch", [
  ["circle", { cx: "12", cy: "12", r: "6", key: "1vlfrh" }],
  ["polyline", { points: "12 10 12 12 13 13", key: "19dquz" }],
  [
    "path",
    { d: "m16.13 7.66-.81-4.05a2 2 0 0 0-2-1.61h-2.68a2 2 0 0 0-2 1.61l-.78 4.05", key: "18k57s" }
  ],
  ["path", { d: "m7.88 16.36.8 4a2 2 0 0 0 2 1.61h2.72a2 2 0 0 0 2-1.61l.81-4.05", key: "16ny36" }]
]);

const LuWaves = createLucideIcon("LuWaves", [
  [
    "path",
    {
      d: "M2 6c.6.5 1.2 1 2.5 1C7 7 7 5 9.5 5c2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1",
      key: "knzxuh"
    }
  ],
  [
    "path",
    {
      d: "M2 12c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1",
      key: "2jd2cc"
    }
  ],
  [
    "path",
    {
      d: "M2 18c.6.5 1.2 1 2.5 1 2.5 0 2.5-2 5-2 2.6 0 2.4 2 5 2 2.5 0 2.5-2 5-2 1.3 0 1.9.5 2.5 1",
      key: "rd2r6e"
    }
  ]
]);

const LuWaypoints = createLucideIcon("LuWaypoints", [
  ["circle", { cx: "12", cy: "4.5", r: "2.5", key: "r5ysbb" }],
  ["path", { d: "m10.2 6.3-3.9 3.9", key: "1nzqf6" }],
  ["circle", { cx: "4.5", cy: "12", r: "2.5", key: "jydg6v" }],
  ["path", { d: "M7 12h10", key: "b7w52i" }],
  ["circle", { cx: "19.5", cy: "12", r: "2.5", key: "1piiel" }],
  ["path", { d: "m13.8 17.7 3.9-3.9", key: "1wyg1y" }],
  ["circle", { cx: "12", cy: "19.5", r: "2.5", key: "13o1pw" }]
]);

const LuWebcam = createLucideIcon("LuWebcam", [
  ["circle", { cx: "12", cy: "10", r: "8", key: "1gshiw" }],
  ["circle", { cx: "12", cy: "10", r: "3", key: "ilqhr7" }],
  ["path", { d: "M7 22h10", key: "10w4w3" }],
  ["path", { d: "M12 22v-4", key: "1utk9m" }]
]);

const LuWebhookOff = createLucideIcon("LuWebhookOff", [
  ["path", { d: "M17 17h-5c-1.09-.02-1.94.92-2.5 1.9A3 3 0 1 1 2.57 15", key: "1tvl6x" }],
  ["path", { d: "M9 3.4a4 4 0 0 1 6.52.66", key: "q04jfq" }],
  ["path", { d: "m6 17 3.1-5.8a2.5 2.5 0 0 0 .057-2.05", key: "azowf0" }],
  ["path", { d: "M20.3 20.3a4 4 0 0 1-2.3.7", key: "5joiws" }],
  ["path", { d: "M18.6 13a4 4 0 0 1 3.357 3.414", key: "cangb8" }],
  ["path", { d: "m12 6 .6 1", key: "tpjl1n" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuWebhook = createLucideIcon("LuWebhook", [
  [
    "path",
    {
      d: "M18 16.98h-5.99c-1.1 0-1.95.94-2.48 1.9A4 4 0 0 1 2 17c.01-.7.2-1.4.57-2",
      key: "q3hayz"
    }
  ],
  ["path", { d: "m6 17 3.13-5.78c.53-.97.1-2.18-.5-3.1a4 4 0 1 1 6.89-4.06", key: "1go1hn" }],
  ["path", { d: "m12 6 3.13 5.73C15.66 12.7 16.9 13 18 13a4 4 0 0 1 0 8", key: "qlwsc0" }]
]);

const LuWeight = createLucideIcon("LuWeight", [
  ["circle", { cx: "12", cy: "5", r: "3", key: "rqqgnr" }],
  [
    "path",
    {
      d: "M6.5 8a2 2 0 0 0-1.905 1.46L2.1 18.5A2 2 0 0 0 4 21h16a2 2 0 0 0 1.925-2.54L19.4 9.5A2 2 0 0 0 17.48 8Z",
      key: "56o5sh"
    }
  ]
]);

const LuWheatOff = createLucideIcon("LuWheatOff", [
  ["path", { d: "m2 22 10-10", key: "28ilpk" }],
  ["path", { d: "m16 8-1.17 1.17", key: "1qqm82" }],
  [
    "path",
    {
      d: "M3.47 12.53 5 11l1.53 1.53a3.5 3.5 0 0 1 0 4.94L5 19l-1.53-1.53a3.5 3.5 0 0 1 0-4.94Z",
      key: "1rdhi6"
    }
  ],
  [
    "path",
    { d: "m8 8-.53.53a3.5 3.5 0 0 0 0 4.94L9 15l1.53-1.53c.55-.55.88-1.25.98-1.97", key: "4wz8re" }
  ],
  [
    "path",
    { d: "M10.91 5.26c.15-.26.34-.51.56-.73L13 3l1.53 1.53a3.5 3.5 0 0 1 .28 4.62", key: "rves66" }
  ],
  ["path", { d: "M20 2h2v2a4 4 0 0 1-4 4h-2V6a4 4 0 0 1 4-4Z", key: "19rau1" }],
  [
    "path",
    {
      d: "M11.47 17.47 13 19l-1.53 1.53a3.5 3.5 0 0 1-4.94 0L5 19l1.53-1.53a3.5 3.5 0 0 1 4.94 0Z",
      key: "tc8ph9"
    }
  ],
  [
    "path",
    {
      d: "m16 16-.53.53a3.5 3.5 0 0 1-4.94 0L9 15l1.53-1.53a3.49 3.49 0 0 1 1.97-.98",
      key: "ak46r"
    }
  ],
  [
    "path",
    {
      d: "M18.74 13.09c.26-.15.51-.34.73-.56L21 11l-1.53-1.53a3.5 3.5 0 0 0-4.62-.28",
      key: "1tw520"
    }
  ],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuWheat = createLucideIcon("LuWheat", [
  ["path", { d: "M2 22 16 8", key: "60hf96" }],
  [
    "path",
    {
      d: "M3.47 12.53 5 11l1.53 1.53a3.5 3.5 0 0 1 0 4.94L5 19l-1.53-1.53a3.5 3.5 0 0 1 0-4.94Z",
      key: "1rdhi6"
    }
  ],
  [
    "path",
    {
      d: "M7.47 8.53 9 7l1.53 1.53a3.5 3.5 0 0 1 0 4.94L9 15l-1.53-1.53a3.5 3.5 0 0 1 0-4.94Z",
      key: "1sdzmb"
    }
  ],
  [
    "path",
    {
      d: "M11.47 4.53 13 3l1.53 1.53a3.5 3.5 0 0 1 0 4.94L13 11l-1.53-1.53a3.5 3.5 0 0 1 0-4.94Z",
      key: "eoatbi"
    }
  ],
  ["path", { d: "M20 2h2v2a4 4 0 0 1-4 4h-2V6a4 4 0 0 1 4-4Z", key: "19rau1" }],
  [
    "path",
    {
      d: "M11.47 17.47 13 19l-1.53 1.53a3.5 3.5 0 0 1-4.94 0L5 19l1.53-1.53a3.5 3.5 0 0 1 4.94 0Z",
      key: "tc8ph9"
    }
  ],
  [
    "path",
    {
      d: "M15.47 13.47 17 15l-1.53 1.53a3.5 3.5 0 0 1-4.94 0L9 15l1.53-1.53a3.5 3.5 0 0 1 4.94 0Z",
      key: "2m8kc5"
    }
  ],
  [
    "path",
    {
      d: "M19.47 9.47 21 11l-1.53 1.53a3.5 3.5 0 0 1-4.94 0L13 11l1.53-1.53a3.5 3.5 0 0 1 4.94 0Z",
      key: "vex3ng"
    }
  ]
]);

const LuWholeWord = createLucideIcon("LuWholeWord", [
  ["circle", { cx: "7", cy: "12", r: "3", key: "12clwm" }],
  ["path", { d: "M10 9v6", key: "17i7lo" }],
  ["circle", { cx: "17", cy: "12", r: "3", key: "gl7c2s" }],
  ["path", { d: "M14 7v8", key: "dl84cr" }],
  ["path", { d: "M22 17v1c0 .5-.5 1-1 1H3c-.5 0-1-.5-1-1v-1", key: "lt2kga" }]
]);

const LuWifiOff = createLucideIcon("LuWifiOff", [
  ["path", { d: "M12 20h.01", key: "zekei9" }],
  ["path", { d: "M8.5 16.429a5 5 0 0 1 7 0", key: "1bycff" }],
  ["path", { d: "M5 12.859a10 10 0 0 1 5.17-2.69", key: "1dl1wf" }],
  ["path", { d: "M19 12.859a10 10 0 0 0-2.007-1.523", key: "4k23kn" }],
  ["path", { d: "M2 8.82a15 15 0 0 1 4.177-2.643", key: "1grhjp" }],
  ["path", { d: "M22 8.82a15 15 0 0 0-11.288-3.764", key: "z3jwby" }],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuWifi = createLucideIcon("LuWifi", [
  ["path", { d: "M12 20h.01", key: "zekei9" }],
  ["path", { d: "M2 8.82a15 15 0 0 1 20 0", key: "dnpr2z" }],
  ["path", { d: "M5 12.859a10 10 0 0 1 14 0", key: "1x1e6c" }],
  ["path", { d: "M8.5 16.429a5 5 0 0 1 7 0", key: "1bycff" }]
]);

const LuWind = createLucideIcon("LuWind", [
  ["path", { d: "M17.7 7.7a2.5 2.5 0 1 1 1.8 4.3H2", key: "1k4u03" }],
  ["path", { d: "M9.6 4.6A2 2 0 1 1 11 8H2", key: "b7d0fd" }],
  ["path", { d: "M12.6 19.4A2 2 0 1 0 14 16H2", key: "1p5cb3" }]
]);

const LuWineOff = createLucideIcon("LuWineOff", [
  ["path", { d: "M8 22h8", key: "rmew8v" }],
  ["path", { d: "M7 10h3m7 0h-1.343", key: "v48bem" }],
  ["path", { d: "M12 15v7", key: "t2xh3l" }],
  [
    "path",
    {
      d: "M7.307 7.307A12.33 12.33 0 0 0 7 10a5 5 0 0 0 7.391 4.391M8.638 2.981C8.75 2.668 8.872 2.34 9 2h6c1.5 4 2 6 2 8 0 .407-.05.809-.145 1.198",
      key: "1ymjlu"
    }
  ],
  ["line", { x1: "2", x2: "22", y1: "2", y2: "22", key: "a6p6uj" }]
]);

const LuWine = createLucideIcon("LuWine", [
  ["path", { d: "M8 22h8", key: "rmew8v" }],
  ["path", { d: "M7 10h10", key: "1101jm" }],
  ["path", { d: "M12 15v7", key: "t2xh3l" }],
  [
    "path",
    { d: "M12 15a5 5 0 0 0 5-5c0-2-.5-4-2-8H9c-1.5 4-2 6-2 8a5 5 0 0 0 5 5Z", key: "10ffi3" }
  ]
]);

const LuWorkflow = createLucideIcon("LuWorkflow", [
  ["rect", { width: "8", height: "8", x: "3", y: "3", rx: "2", key: "by2w9f" }],
  ["path", { d: "M7 11v4a2 2 0 0 0 2 2h4", key: "xkn7yn" }],
  ["rect", { width: "8", height: "8", x: "13", y: "13", rx: "2", key: "1cgmvn" }]
]);

const LuWrapText = createLucideIcon("LuWrapText", [
  ["line", { x1: "3", x2: "21", y1: "6", y2: "6", key: "4m8b97" }],
  ["path", { d: "M3 12h15a3 3 0 1 1 0 6h-4", key: "1cl7v7" }],
  ["polyline", { points: "16 16 14 18 16 20", key: "1jznyi" }],
  ["line", { x1: "3", x2: "10", y1: "18", y2: "18", key: "1h33wv" }]
]);

const LuWrench = createLucideIcon("LuWrench", [
  [
    "path",
    {
      d: "M14.7 6.3a1 1 0 0 0 0 1.4l1.6 1.6a1 1 0 0 0 1.4 0l3.77-3.77a6 6 0 0 1-7.94 7.94l-6.91 6.91a2.12 2.12 0 0 1-3-3l6.91-6.91a6 6 0 0 1 7.94-7.94l-3.76 3.76z",
      key: "cbrjhi"
    }
  ]
]);

const LuX = createLucideIcon("LuX", [
  ["path", { d: "M18 6 6 18", key: "1bl5f8" }],
  ["path", { d: "m6 6 12 12", key: "d8bk6v" }]
]);

const LuYoutube = createLucideIcon("LuYoutube", [
  [
    "path",
    {
      d: "M2.5 17a24.12 24.12 0 0 1 0-10 2 2 0 0 1 1.4-1.4 49.56 49.56 0 0 1 16.2 0A2 2 0 0 1 21.5 7a24.12 24.12 0 0 1 0 10 2 2 0 0 1-1.4 1.4 49.55 49.55 0 0 1-16.2 0A2 2 0 0 1 2.5 17",
      key: "1q2vi4"
    }
  ],
  ["path", { d: "m10 15 5-3-5-3z", key: "1jp15x" }]
]);

const LuZapOff = createLucideIcon("LuZapOff", [
  ["path", { d: "M10.513 4.856 13.12 2.17a.5.5 0 0 1 .86.46l-1.377 4.317", key: "193nxd" }],
  ["path", { d: "M15.656 10H20a1 1 0 0 1 .78 1.63l-1.72 1.773", key: "27a7lr" }],
  [
    "path",
    {
      d: "M16.273 16.273 10.88 21.83a.5.5 0 0 1-.86-.46l1.92-6.02A1 1 0 0 0 11 14H4a1 1 0 0 1-.78-1.63l4.507-4.643",
      key: "1e0qe9"
    }
  ],
  ["path", { d: "m2 2 20 20", key: "1ooewy" }]
]);

const LuZap = createLucideIcon("LuZap", [
  [
    "path",
    {
      d: "M4 14a1 1 0 0 1-.78-1.63l9.9-10.2a.5.5 0 0 1 .86.46l-1.92 6.02A1 1 0 0 0 13 10h7a1 1 0 0 1 .78 1.63l-9.9 10.2a.5.5 0 0 1-.86-.46l1.92-6.02A1 1 0 0 0 11 14z",
      key: "1xq2db"
    }
  ]
]);

const LuZoomIn = createLucideIcon("LuZoomIn", [
  ["circle", { cx: "11", cy: "11", r: "8", key: "4ej97u" }],
  ["line", { x1: "21", x2: "16.65", y1: "21", y2: "16.65", key: "13gj7c" }],
  ["line", { x1: "11", x2: "11", y1: "8", y2: "14", key: "1vmskp" }],
  ["line", { x1: "8", x2: "14", y1: "11", y2: "11", key: "durymu" }]
]);

const LuZoomOut = createLucideIcon("LuZoomOut", [
  ["circle", { cx: "11", cy: "11", r: "8", key: "4ej97u" }],
  ["line", { x1: "21", x2: "16.65", y1: "21", y2: "16.65", key: "13gj7c" }],
  ["line", { x1: "8", x2: "14", y1: "11", y2: "11", key: "durymu" }]
]);

var index = /*#__PURE__*/Object.freeze({
  __proto__: null,
  LuAArrowDown: LuAArrowDown,
  LuAArrowUp: LuAArrowUp,
  LuALargeSmall: LuALargeSmall,
  LuAccessibility: LuAccessibility,
  LuActivity: LuActivity,
  LuAirVent: LuAirVent,
  LuAirplay: LuAirplay,
  LuAlarmClock: LuAlarmClock,
  LuAlarmClockCheck: LuAlarmClockCheck,
  LuAlarmClockMinus: LuAlarmClockMinus,
  LuAlarmClockOff: LuAlarmClockOff,
  LuAlarmClockPlus: LuAlarmClockPlus,
  LuAlarmSmoke: LuAlarmSmoke,
  LuAlbum: LuAlbum,
  LuAlignCenter: LuAlignCenter,
  LuAlignCenterHorizontal: LuAlignCenterHorizontal,
  LuAlignCenterVertical: LuAlignCenterVertical,
  LuAlignEndHorizontal: LuAlignEndHorizontal,
  LuAlignEndVertical: LuAlignEndVertical,
  LuAlignHorizontalDistributeCenter: LuAlignHorizontalDistributeCenter,
  LuAlignHorizontalDistributeEnd: LuAlignHorizontalDistributeEnd,
  LuAlignHorizontalDistributeStart: LuAlignHorizontalDistributeStart,
  LuAlignHorizontalJustifyCenter: LuAlignHorizontalJustifyCenter,
  LuAlignHorizontalJustifyEnd: LuAlignHorizontalJustifyEnd,
  LuAlignHorizontalJustifyStart: LuAlignHorizontalJustifyStart,
  LuAlignHorizontalSpaceAround: LuAlignHorizontalSpaceAround,
  LuAlignHorizontalSpaceBetween: LuAlignHorizontalSpaceBetween,
  LuAlignJustify: LuAlignJustify,
  LuAlignLeft: LuAlignLeft,
  LuAlignRight: LuAlignRight,
  LuAlignStartHorizontal: LuAlignStartHorizontal,
  LuAlignStartVertical: LuAlignStartVertical,
  LuAlignVerticalDistributeCenter: LuAlignVerticalDistributeCenter,
  LuAlignVerticalDistributeEnd: LuAlignVerticalDistributeEnd,
  LuAlignVerticalDistributeStart: LuAlignVerticalDistributeStart,
  LuAlignVerticalJustifyCenter: LuAlignVerticalJustifyCenter,
  LuAlignVerticalJustifyEnd: LuAlignVerticalJustifyEnd,
  LuAlignVerticalJustifyStart: LuAlignVerticalJustifyStart,
  LuAlignVerticalSpaceAround: LuAlignVerticalSpaceAround,
  LuAlignVerticalSpaceBetween: LuAlignVerticalSpaceBetween,
  LuAmbulance: LuAmbulance,
  LuAmpersand: LuAmpersand,
  LuAmpersands: LuAmpersands,
  LuAnchor: LuAnchor,
  LuAngry: LuAngry,
  LuAnnoyed: LuAnnoyed,
  LuAntenna: LuAntenna,
  LuAnvil: LuAnvil,
  LuAperture: LuAperture,
  LuAppWindow: LuAppWindow,
  LuAppWindowMac: LuAppWindowMac,
  LuApple: LuApple,
  LuArchive: LuArchive,
  LuArchiveRestore: LuArchiveRestore,
  LuArchiveX: LuArchiveX,
  LuAreaChart: LuAreaChart,
  LuArmchair: LuArmchair,
  LuArrowBigDown: LuArrowBigDown,
  LuArrowBigDownDash: LuArrowBigDownDash,
  LuArrowBigLeft: LuArrowBigLeft,
  LuArrowBigLeftDash: LuArrowBigLeftDash,
  LuArrowBigRight: LuArrowBigRight,
  LuArrowBigRightDash: LuArrowBigRightDash,
  LuArrowBigUp: LuArrowBigUp,
  LuArrowBigUpDash: LuArrowBigUpDash,
  LuArrowDown: LuArrowDown,
  LuArrowDown01: LuArrowDown01,
  LuArrowDown10: LuArrowDown10,
  LuArrowDownAZ: LuArrowDownAZ,
  LuArrowDownFromLine: LuArrowDownFromLine,
  LuArrowDownLeft: LuArrowDownLeft,
  LuArrowDownNarrowWide: LuArrowDownNarrowWide,
  LuArrowDownRight: LuArrowDownRight,
  LuArrowDownToDot: LuArrowDownToDot,
  LuArrowDownToLine: LuArrowDownToLine,
  LuArrowDownUp: LuArrowDownUp,
  LuArrowDownWideNarrow: LuArrowDownWideNarrow,
  LuArrowDownZA: LuArrowDownZA,
  LuArrowLeft: LuArrowLeft,
  LuArrowLeftFromLine: LuArrowLeftFromLine,
  LuArrowLeftRight: LuArrowLeftRight,
  LuArrowLeftToLine: LuArrowLeftToLine,
  LuArrowRight: LuArrowRight,
  LuArrowRightFromLine: LuArrowRightFromLine,
  LuArrowRightLeft: LuArrowRightLeft,
  LuArrowRightToLine: LuArrowRightToLine,
  LuArrowUp: LuArrowUp,
  LuArrowUp01: LuArrowUp01,
  LuArrowUp10: LuArrowUp10,
  LuArrowUpAZ: LuArrowUpAZ,
  LuArrowUpDown: LuArrowUpDown,
  LuArrowUpFromDot: LuArrowUpFromDot,
  LuArrowUpFromLine: LuArrowUpFromLine,
  LuArrowUpLeft: LuArrowUpLeft,
  LuArrowUpNarrowWide: LuArrowUpNarrowWide,
  LuArrowUpRight: LuArrowUpRight,
  LuArrowUpToLine: LuArrowUpToLine,
  LuArrowUpWideNarrow: LuArrowUpWideNarrow,
  LuArrowUpZA: LuArrowUpZA,
  LuArrowsUpFromLine: LuArrowsUpFromLine,
  LuAsterisk: LuAsterisk,
  LuAtSign: LuAtSign,
  LuAtom: LuAtom,
  LuAudioLines: LuAudioLines,
  LuAudioWaveform: LuAudioWaveform,
  LuAward: LuAward,
  LuAxe: LuAxe,
  LuAxis3d: LuAxis3d,
  LuBaby: LuBaby,
  LuBackpack: LuBackpack,
  LuBadge: LuBadge,
  LuBadgeAlert: LuBadgeAlert,
  LuBadgeCent: LuBadgeCent,
  LuBadgeCheck: LuBadgeCheck,
  LuBadgeDollarSign: LuBadgeDollarSign,
  LuBadgeEuro: LuBadgeEuro,
  LuBadgeHelp: LuBadgeHelp,
  LuBadgeIndianRupee: LuBadgeIndianRupee,
  LuBadgeInfo: LuBadgeInfo,
  LuBadgeJapaneseYen: LuBadgeJapaneseYen,
  LuBadgeMinus: LuBadgeMinus,
  LuBadgePercent: LuBadgePercent,
  LuBadgePlus: LuBadgePlus,
  LuBadgePoundSterling: LuBadgePoundSterling,
  LuBadgeRussianRuble: LuBadgeRussianRuble,
  LuBadgeSwissFranc: LuBadgeSwissFranc,
  LuBadgeX: LuBadgeX,
  LuBaggageClaim: LuBaggageClaim,
  LuBan: LuBan,
  LuBanana: LuBanana,
  LuBanknote: LuBanknote,
  LuBarChart: LuBarChart,
  LuBarChart2: LuBarChart2,
  LuBarChart3: LuBarChart3,
  LuBarChart4: LuBarChart4,
  LuBarChartBig: LuBarChartBig,
  LuBarChartHorizontal: LuBarChartHorizontal,
  LuBarChartHorizontalBig: LuBarChartHorizontalBig,
  LuBarcode: LuBarcode,
  LuBaseline: LuBaseline,
  LuBath: LuBath,
  LuBattery: LuBattery,
  LuBatteryCharging: LuBatteryCharging,
  LuBatteryFull: LuBatteryFull,
  LuBatteryLow: LuBatteryLow,
  LuBatteryMedium: LuBatteryMedium,
  LuBatteryWarning: LuBatteryWarning,
  LuBeaker: LuBeaker,
  LuBean: LuBean,
  LuBeanOff: LuBeanOff,
  LuBed: LuBed,
  LuBedDouble: LuBedDouble,
  LuBedSingle: LuBedSingle,
  LuBeef: LuBeef,
  LuBeer: LuBeer,
  LuBell: LuBell,
  LuBellDot: LuBellDot,
  LuBellElectric: LuBellElectric,
  LuBellMinus: LuBellMinus,
  LuBellOff: LuBellOff,
  LuBellPlus: LuBellPlus,
  LuBellRing: LuBellRing,
  LuBetweenHorizontalEnd: LuBetweenHorizontalEnd,
  LuBetweenHorizontalStart: LuBetweenHorizontalStart,
  LuBetweenVerticalEnd: LuBetweenVerticalEnd,
  LuBetweenVerticalStart: LuBetweenVerticalStart,
  LuBike: LuBike,
  LuBinary: LuBinary,
  LuBiohazard: LuBiohazard,
  LuBird: LuBird,
  LuBitcoin: LuBitcoin,
  LuBlend: LuBlend,
  LuBlinds: LuBlinds,
  LuBlocks: LuBlocks,
  LuBluetooth: LuBluetooth,
  LuBluetoothConnected: LuBluetoothConnected,
  LuBluetoothOff: LuBluetoothOff,
  LuBluetoothSearching: LuBluetoothSearching,
  LuBold: LuBold,
  LuBolt: LuBolt,
  LuBomb: LuBomb,
  LuBone: LuBone,
  LuBook: LuBook,
  LuBookA: LuBookA,
  LuBookAudio: LuBookAudio,
  LuBookCheck: LuBookCheck,
  LuBookCopy: LuBookCopy,
  LuBookDashed: LuBookDashed,
  LuBookDown: LuBookDown,
  LuBookHeadphones: LuBookHeadphones,
  LuBookHeart: LuBookHeart,
  LuBookImage: LuBookImage,
  LuBookKey: LuBookKey,
  LuBookLock: LuBookLock,
  LuBookMarked: LuBookMarked,
  LuBookMinus: LuBookMinus,
  LuBookOpen: LuBookOpen,
  LuBookOpenCheck: LuBookOpenCheck,
  LuBookOpenText: LuBookOpenText,
  LuBookPlus: LuBookPlus,
  LuBookText: LuBookText,
  LuBookType: LuBookType,
  LuBookUp: LuBookUp,
  LuBookUp2: LuBookUp2,
  LuBookUser: LuBookUser,
  LuBookX: LuBookX,
  LuBookmark: LuBookmark,
  LuBookmarkCheck: LuBookmarkCheck,
  LuBookmarkMinus: LuBookmarkMinus,
  LuBookmarkPlus: LuBookmarkPlus,
  LuBookmarkX: LuBookmarkX,
  LuBoomBox: LuBoomBox,
  LuBot: LuBot,
  LuBotMessageSquare: LuBotMessageSquare,
  LuBox: LuBox,
  LuBoxSelect: LuBoxSelect,
  LuBoxes: LuBoxes,
  LuBraces: LuBraces,
  LuBrackets: LuBrackets,
  LuBrain: LuBrain,
  LuBrainCircuit: LuBrainCircuit,
  LuBrainCog: LuBrainCog,
  LuBrickWall: LuBrickWall,
  LuBriefcase: LuBriefcase,
  LuBriefcaseBusiness: LuBriefcaseBusiness,
  LuBriefcaseMedical: LuBriefcaseMedical,
  LuBringToFront: LuBringToFront,
  LuBrush: LuBrush,
  LuBug: LuBug,
  LuBugOff: LuBugOff,
  LuBugPlay: LuBugPlay,
  LuBuilding: LuBuilding,
  LuBuilding2: LuBuilding2,
  LuBus: LuBus,
  LuBusFront: LuBusFront,
  LuCable: LuCable,
  LuCableCar: LuCableCar,
  LuCake: LuCake,
  LuCakeSlice: LuCakeSlice,
  LuCalculator: LuCalculator,
  LuCalendar: LuCalendar,
  LuCalendarCheck: LuCalendarCheck,
  LuCalendarCheck2: LuCalendarCheck2,
  LuCalendarClock: LuCalendarClock,
  LuCalendarDays: LuCalendarDays,
  LuCalendarFold: LuCalendarFold,
  LuCalendarHeart: LuCalendarHeart,
  LuCalendarMinus: LuCalendarMinus,
  LuCalendarMinus2: LuCalendarMinus2,
  LuCalendarOff: LuCalendarOff,
  LuCalendarPlus: LuCalendarPlus,
  LuCalendarPlus2: LuCalendarPlus2,
  LuCalendarRange: LuCalendarRange,
  LuCalendarSearch: LuCalendarSearch,
  LuCalendarX: LuCalendarX,
  LuCalendarX2: LuCalendarX2,
  LuCamera: LuCamera,
  LuCameraOff: LuCameraOff,
  LuCandlestickChart: LuCandlestickChart,
  LuCandy: LuCandy,
  LuCandyCane: LuCandyCane,
  LuCandyOff: LuCandyOff,
  LuCannabis: LuCannabis,
  LuCaptions: LuCaptions,
  LuCaptionsOff: LuCaptionsOff,
  LuCar: LuCar,
  LuCarFront: LuCarFront,
  LuCarTaxiFront: LuCarTaxiFront,
  LuCaravan: LuCaravan,
  LuCarrot: LuCarrot,
  LuCaseLower: LuCaseLower,
  LuCaseSensitive: LuCaseSensitive,
  LuCaseUpper: LuCaseUpper,
  LuCassetteTape: LuCassetteTape,
  LuCast: LuCast,
  LuCastle: LuCastle,
  LuCat: LuCat,
  LuCctv: LuCctv,
  LuCheck: LuCheck,
  LuCheckCheck: LuCheckCheck,
  LuChefHat: LuChefHat,
  LuCherry: LuCherry,
  LuChevronDown: LuChevronDown,
  LuChevronFirst: LuChevronFirst,
  LuChevronLast: LuChevronLast,
  LuChevronLeft: LuChevronLeft,
  LuChevronRight: LuChevronRight,
  LuChevronUp: LuChevronUp,
  LuChevronsDown: LuChevronsDown,
  LuChevronsDownUp: LuChevronsDownUp,
  LuChevronsLeft: LuChevronsLeft,
  LuChevronsLeftRight: LuChevronsLeftRight,
  LuChevronsRight: LuChevronsRight,
  LuChevronsRightLeft: LuChevronsRightLeft,
  LuChevronsUp: LuChevronsUp,
  LuChevronsUpDown: LuChevronsUpDown,
  LuChrome: LuChrome,
  LuChurch: LuChurch,
  LuCigarette: LuCigarette,
  LuCigaretteOff: LuCigaretteOff,
  LuCircle: LuCircle,
  LuCircleAlert: LuCircleAlert,
  LuCircleArrowDown: LuCircleArrowDown,
  LuCircleArrowLeft: LuCircleArrowLeft,
  LuCircleArrowOutDownLeft: LuCircleArrowOutDownLeft,
  LuCircleArrowOutDownRight: LuCircleArrowOutDownRight,
  LuCircleArrowOutUpLeft: LuCircleArrowOutUpLeft,
  LuCircleArrowOutUpRight: LuCircleArrowOutUpRight,
  LuCircleArrowRight: LuCircleArrowRight,
  LuCircleArrowUp: LuCircleArrowUp,
  LuCircleCheck: LuCircleCheck,
  LuCircleCheckBig: LuCircleCheckBig,
  LuCircleChevronDown: LuCircleChevronDown,
  LuCircleChevronLeft: LuCircleChevronLeft,
  LuCircleChevronRight: LuCircleChevronRight,
  LuCircleChevronUp: LuCircleChevronUp,
  LuCircleDashed: LuCircleDashed,
  LuCircleDivide: LuCircleDivide,
  LuCircleDollarSign: LuCircleDollarSign,
  LuCircleDot: LuCircleDot,
  LuCircleDotDashed: LuCircleDotDashed,
  LuCircleEllipsis: LuCircleEllipsis,
  LuCircleEqual: LuCircleEqual,
  LuCircleFadingPlus: LuCircleFadingPlus,
  LuCircleGauge: LuCircleGauge,
  LuCircleHelp: LuCircleHelp,
  LuCircleMinus: LuCircleMinus,
  LuCircleOff: LuCircleOff,
  LuCircleParking: LuCircleParking,
  LuCircleParkingOff: LuCircleParkingOff,
  LuCirclePause: LuCirclePause,
  LuCirclePercent: LuCirclePercent,
  LuCirclePlay: LuCirclePlay,
  LuCirclePlus: LuCirclePlus,
  LuCirclePower: LuCirclePower,
  LuCircleSlash: LuCircleSlash,
  LuCircleSlash2: LuCircleSlash2,
  LuCircleStop: LuCircleStop,
  LuCircleUser: LuCircleUser,
  LuCircleUserRound: LuCircleUserRound,
  LuCircleX: LuCircleX,
  LuCircuitBoard: LuCircuitBoard,
  LuCitrus: LuCitrus,
  LuClapperboard: LuClapperboard,
  LuClipboard: LuClipboard,
  LuClipboardCheck: LuClipboardCheck,
  LuClipboardCopy: LuClipboardCopy,
  LuClipboardList: LuClipboardList,
  LuClipboardMinus: LuClipboardMinus,
  LuClipboardPaste: LuClipboardPaste,
  LuClipboardPen: LuClipboardPen,
  LuClipboardPenLine: LuClipboardPenLine,
  LuClipboardPlus: LuClipboardPlus,
  LuClipboardType: LuClipboardType,
  LuClipboardX: LuClipboardX,
  LuClock: LuClock,
  LuClock1: LuClock1,
  LuClock10: LuClock10,
  LuClock11: LuClock11,
  LuClock12: LuClock12,
  LuClock2: LuClock2,
  LuClock3: LuClock3,
  LuClock4: LuClock4,
  LuClock5: LuClock5,
  LuClock6: LuClock6,
  LuClock7: LuClock7,
  LuClock8: LuClock8,
  LuClock9: LuClock9,
  LuCloud: LuCloud,
  LuCloudCog: LuCloudCog,
  LuCloudDownload: LuCloudDownload,
  LuCloudDrizzle: LuCloudDrizzle,
  LuCloudFog: LuCloudFog,
  LuCloudHail: LuCloudHail,
  LuCloudLightning: LuCloudLightning,
  LuCloudMoon: LuCloudMoon,
  LuCloudMoonRain: LuCloudMoonRain,
  LuCloudOff: LuCloudOff,
  LuCloudRain: LuCloudRain,
  LuCloudRainWind: LuCloudRainWind,
  LuCloudSnow: LuCloudSnow,
  LuCloudSun: LuCloudSun,
  LuCloudSunRain: LuCloudSunRain,
  LuCloudUpload: LuCloudUpload,
  LuCloudy: LuCloudy,
  LuClover: LuClover,
  LuClub: LuClub,
  LuCode: LuCode,
  LuCodeXml: LuCodeXml,
  LuCodepen: LuCodepen,
  LuCodesandbox: LuCodesandbox,
  LuCoffee: LuCoffee,
  LuCog: LuCog,
  LuCoins: LuCoins,
  LuColumns2: LuColumns2,
  LuColumns3: LuColumns3,
  LuColumns4: LuColumns4,
  LuCombine: LuCombine,
  LuCommand: LuCommand,
  LuCompass: LuCompass,
  LuComponent: LuComponent,
  LuComputer: LuComputer,
  LuConciergeBell: LuConciergeBell,
  LuCone: LuCone,
  LuConstruction: LuConstruction,
  LuContact: LuContact,
  LuContactRound: LuContactRound,
  LuContainer: LuContainer,
  LuContrast: LuContrast,
  LuCookie: LuCookie,
  LuCookingPot: LuCookingPot,
  LuCopy: LuCopy,
  LuCopyCheck: LuCopyCheck,
  LuCopyMinus: LuCopyMinus,
  LuCopyPlus: LuCopyPlus,
  LuCopySlash: LuCopySlash,
  LuCopyX: LuCopyX,
  LuCopyleft: LuCopyleft,
  LuCopyright: LuCopyright,
  LuCornerDownLeft: LuCornerDownLeft,
  LuCornerDownRight: LuCornerDownRight,
  LuCornerLeftDown: LuCornerLeftDown,
  LuCornerLeftUp: LuCornerLeftUp,
  LuCornerRightDown: LuCornerRightDown,
  LuCornerRightUp: LuCornerRightUp,
  LuCornerUpLeft: LuCornerUpLeft,
  LuCornerUpRight: LuCornerUpRight,
  LuCpu: LuCpu,
  LuCreativeCommons: LuCreativeCommons,
  LuCreditCard: LuCreditCard,
  LuCroissant: LuCroissant,
  LuCrop: LuCrop,
  LuCross: LuCross,
  LuCrosshair: LuCrosshair,
  LuCrown: LuCrown,
  LuCuboid: LuCuboid,
  LuCupSoda: LuCupSoda,
  LuCurrency: LuCurrency,
  LuCylinder: LuCylinder,
  LuDatabase: LuDatabase,
  LuDatabaseBackup: LuDatabaseBackup,
  LuDatabaseZap: LuDatabaseZap,
  LuDelete: LuDelete,
  LuDessert: LuDessert,
  LuDiameter: LuDiameter,
  LuDiamond: LuDiamond,
  LuDiamondPercent: LuDiamondPercent,
  LuDice1: LuDice1,
  LuDice2: LuDice2,
  LuDice3: LuDice3,
  LuDice4: LuDice4,
  LuDice5: LuDice5,
  LuDice6: LuDice6,
  LuDices: LuDices,
  LuDiff: LuDiff,
  LuDisc: LuDisc,
  LuDisc2: LuDisc2,
  LuDisc3: LuDisc3,
  LuDiscAlbum: LuDiscAlbum,
  LuDivide: LuDivide,
  LuDna: LuDna,
  LuDnaOff: LuDnaOff,
  LuDock: LuDock,
  LuDog: LuDog,
  LuDollarSign: LuDollarSign,
  LuDonut: LuDonut,
  LuDoorClosed: LuDoorClosed,
  LuDoorOpen: LuDoorOpen,
  LuDot: LuDot,
  LuDownload: LuDownload,
  LuDraftingCompass: LuDraftingCompass,
  LuDrama: LuDrama,
  LuDribbble: LuDribbble,
  LuDrill: LuDrill,
  LuDroplet: LuDroplet,
  LuDroplets: LuDroplets,
  LuDrum: LuDrum,
  LuDrumstick: LuDrumstick,
  LuDumbbell: LuDumbbell,
  LuEar: LuEar,
  LuEarOff: LuEarOff,
  LuEarth: LuEarth,
  LuEarthLock: LuEarthLock,
  LuEclipse: LuEclipse,
  LuEgg: LuEgg,
  LuEggFried: LuEggFried,
  LuEggOff: LuEggOff,
  LuEllipsis: LuEllipsis,
  LuEllipsisVertical: LuEllipsisVertical,
  LuEqual: LuEqual,
  LuEqualNot: LuEqualNot,
  LuEraser: LuEraser,
  LuEuro: LuEuro,
  LuExpand: LuExpand,
  LuExternalLink: LuExternalLink,
  LuEye: LuEye,
  LuEyeOff: LuEyeOff,
  LuFacebook: LuFacebook,
  LuFactory: LuFactory,
  LuFan: LuFan,
  LuFastForward: LuFastForward,
  LuFeather: LuFeather,
  LuFence: LuFence,
  LuFerrisWheel: LuFerrisWheel,
  LuFigma: LuFigma,
  LuFile: LuFile,
  LuFileArchive: LuFileArchive,
  LuFileAudio: LuFileAudio,
  LuFileAudio2: LuFileAudio2,
  LuFileAxis3d: LuFileAxis3d,
  LuFileBadge: LuFileBadge,
  LuFileBadge2: LuFileBadge2,
  LuFileBarChart: LuFileBarChart,
  LuFileBarChart2: LuFileBarChart2,
  LuFileBox: LuFileBox,
  LuFileCheck: LuFileCheck,
  LuFileCheck2: LuFileCheck2,
  LuFileClock: LuFileClock,
  LuFileCode: LuFileCode,
  LuFileCode2: LuFileCode2,
  LuFileCog: LuFileCog,
  LuFileDiff: LuFileDiff,
  LuFileDigit: LuFileDigit,
  LuFileDown: LuFileDown,
  LuFileHeart: LuFileHeart,
  LuFileImage: LuFileImage,
  LuFileInput: LuFileInput,
  LuFileJson: LuFileJson,
  LuFileJson2: LuFileJson2,
  LuFileKey: LuFileKey,
  LuFileKey2: LuFileKey2,
  LuFileLineChart: LuFileLineChart,
  LuFileLock: LuFileLock,
  LuFileLock2: LuFileLock2,
  LuFileMinus: LuFileMinus,
  LuFileMinus2: LuFileMinus2,
  LuFileMusic: LuFileMusic,
  LuFileOutput: LuFileOutput,
  LuFilePen: LuFilePen,
  LuFilePenLine: LuFilePenLine,
  LuFilePieChart: LuFilePieChart,
  LuFilePlus: LuFilePlus,
  LuFilePlus2: LuFilePlus2,
  LuFileQuestion: LuFileQuestion,
  LuFileScan: LuFileScan,
  LuFileSearch: LuFileSearch,
  LuFileSearch2: LuFileSearch2,
  LuFileSliders: LuFileSliders,
  LuFileSpreadsheet: LuFileSpreadsheet,
  LuFileStack: LuFileStack,
  LuFileSymlink: LuFileSymlink,
  LuFileTerminal: LuFileTerminal,
  LuFileText: LuFileText,
  LuFileType: LuFileType,
  LuFileType2: LuFileType2,
  LuFileUp: LuFileUp,
  LuFileVideo: LuFileVideo,
  LuFileVideo2: LuFileVideo2,
  LuFileVolume: LuFileVolume,
  LuFileVolume2: LuFileVolume2,
  LuFileWarning: LuFileWarning,
  LuFileX: LuFileX,
  LuFileX2: LuFileX2,
  LuFiles: LuFiles,
  LuFilm: LuFilm,
  LuFilter: LuFilter,
  LuFilterX: LuFilterX,
  LuFingerprint: LuFingerprint,
  LuFireExtinguisher: LuFireExtinguisher,
  LuFish: LuFish,
  LuFishOff: LuFishOff,
  LuFishSymbol: LuFishSymbol,
  LuFlag: LuFlag,
  LuFlagOff: LuFlagOff,
  LuFlagTriangleLeft: LuFlagTriangleLeft,
  LuFlagTriangleRight: LuFlagTriangleRight,
  LuFlame: LuFlame,
  LuFlameKindling: LuFlameKindling,
  LuFlashlight: LuFlashlight,
  LuFlashlightOff: LuFlashlightOff,
  LuFlaskConical: LuFlaskConical,
  LuFlaskConicalOff: LuFlaskConicalOff,
  LuFlaskRound: LuFlaskRound,
  LuFlipHorizontal: LuFlipHorizontal,
  LuFlipHorizontal2: LuFlipHorizontal2,
  LuFlipVertical: LuFlipVertical,
  LuFlipVertical2: LuFlipVertical2,
  LuFlower: LuFlower,
  LuFlower2: LuFlower2,
  LuFocus: LuFocus,
  LuFoldHorizontal: LuFoldHorizontal,
  LuFoldVertical: LuFoldVertical,
  LuFolder: LuFolder,
  LuFolderArchive: LuFolderArchive,
  LuFolderCheck: LuFolderCheck,
  LuFolderClock: LuFolderClock,
  LuFolderClosed: LuFolderClosed,
  LuFolderCog: LuFolderCog,
  LuFolderDot: LuFolderDot,
  LuFolderDown: LuFolderDown,
  LuFolderGit: LuFolderGit,
  LuFolderGit2: LuFolderGit2,
  LuFolderHeart: LuFolderHeart,
  LuFolderInput: LuFolderInput,
  LuFolderKanban: LuFolderKanban,
  LuFolderKey: LuFolderKey,
  LuFolderLock: LuFolderLock,
  LuFolderMinus: LuFolderMinus,
  LuFolderOpen: LuFolderOpen,
  LuFolderOpenDot: LuFolderOpenDot,
  LuFolderOutput: LuFolderOutput,
  LuFolderPen: LuFolderPen,
  LuFolderPlus: LuFolderPlus,
  LuFolderRoot: LuFolderRoot,
  LuFolderSearch: LuFolderSearch,
  LuFolderSearch2: LuFolderSearch2,
  LuFolderSymlink: LuFolderSymlink,
  LuFolderSync: LuFolderSync,
  LuFolderTree: LuFolderTree,
  LuFolderUp: LuFolderUp,
  LuFolderX: LuFolderX,
  LuFolders: LuFolders,
  LuFootprints: LuFootprints,
  LuForklift: LuForklift,
  LuForward: LuForward,
  LuFrame: LuFrame,
  LuFramer: LuFramer,
  LuFrown: LuFrown,
  LuFuel: LuFuel,
  LuFullscreen: LuFullscreen,
  LuGalleryHorizontal: LuGalleryHorizontal,
  LuGalleryHorizontalEnd: LuGalleryHorizontalEnd,
  LuGalleryThumbnails: LuGalleryThumbnails,
  LuGalleryVertical: LuGalleryVertical,
  LuGalleryVerticalEnd: LuGalleryVerticalEnd,
  LuGamepad: LuGamepad,
  LuGamepad2: LuGamepad2,
  LuGanttChart: LuGanttChart,
  LuGauge: LuGauge,
  LuGavel: LuGavel,
  LuGem: LuGem,
  LuGhost: LuGhost,
  LuGift: LuGift,
  LuGitBranch: LuGitBranch,
  LuGitBranchPlus: LuGitBranchPlus,
  LuGitCommitHorizontal: LuGitCommitHorizontal,
  LuGitCommitVertical: LuGitCommitVertical,
  LuGitCompare: LuGitCompare,
  LuGitCompareArrows: LuGitCompareArrows,
  LuGitFork: LuGitFork,
  LuGitGraph: LuGitGraph,
  LuGitMerge: LuGitMerge,
  LuGitPullRequest: LuGitPullRequest,
  LuGitPullRequestArrow: LuGitPullRequestArrow,
  LuGitPullRequestClosed: LuGitPullRequestClosed,
  LuGitPullRequestCreate: LuGitPullRequestCreate,
  LuGitPullRequestCreateArrow: LuGitPullRequestCreateArrow,
  LuGitPullRequestDraft: LuGitPullRequestDraft,
  LuGithub: LuGithub,
  LuGitlab: LuGitlab,
  LuGlassWater: LuGlassWater,
  LuGlasses: LuGlasses,
  LuGlobe: LuGlobe,
  LuGlobeLock: LuGlobeLock,
  LuGoal: LuGoal,
  LuGrab: LuGrab,
  LuGraduationCap: LuGraduationCap,
  LuGrape: LuGrape,
  LuGrid2x2: LuGrid2x2,
  LuGrid3x3: LuGrid3x3,
  LuGrip: LuGrip,
  LuGripHorizontal: LuGripHorizontal,
  LuGripVertical: LuGripVertical,
  LuGroup: LuGroup,
  LuGuitar: LuGuitar,
  LuHam: LuHam,
  LuHammer: LuHammer,
  LuHand: LuHand,
  LuHandCoins: LuHandCoins,
  LuHandHeart: LuHandHeart,
  LuHandHelping: LuHandHelping,
  LuHandMetal: LuHandMetal,
  LuHandPlatter: LuHandPlatter,
  LuHandshake: LuHandshake,
  LuHardDrive: LuHardDrive,
  LuHardDriveDownload: LuHardDriveDownload,
  LuHardDriveUpload: LuHardDriveUpload,
  LuHardHat: LuHardHat,
  LuHash: LuHash,
  LuHaze: LuHaze,
  LuHdmiPort: LuHdmiPort,
  LuHeading: LuHeading,
  LuHeading1: LuHeading1,
  LuHeading2: LuHeading2,
  LuHeading3: LuHeading3,
  LuHeading4: LuHeading4,
  LuHeading5: LuHeading5,
  LuHeading6: LuHeading6,
  LuHeadphones: LuHeadphones,
  LuHeadset: LuHeadset,
  LuHeart: LuHeart,
  LuHeartCrack: LuHeartCrack,
  LuHeartHandshake: LuHeartHandshake,
  LuHeartOff: LuHeartOff,
  LuHeartPulse: LuHeartPulse,
  LuHeater: LuHeater,
  LuHexagon: LuHexagon,
  LuHighlighter: LuHighlighter,
  LuHistory: LuHistory,
  LuHome: LuHome,
  LuHop: LuHop,
  LuHopOff: LuHopOff,
  LuHospital: LuHospital,
  LuHotel: LuHotel,
  LuHourglass: LuHourglass,
  LuIceCreamBowl: LuIceCreamBowl,
  LuIceCreamCone: LuIceCreamCone,
  LuImage: LuImage,
  LuImageDown: LuImageDown,
  LuImageMinus: LuImageMinus,
  LuImageOff: LuImageOff,
  LuImagePlus: LuImagePlus,
  LuImageUp: LuImageUp,
  LuImages: LuImages,
  LuImport: LuImport,
  LuInbox: LuInbox,
  LuIndentDecrease: LuIndentDecrease,
  LuIndentIncrease: LuIndentIncrease,
  LuIndianRupee: LuIndianRupee,
  LuInfinity: LuInfinity,
  LuInfo: LuInfo,
  LuInspectionPanel: LuInspectionPanel,
  LuInstagram: LuInstagram,
  LuItalic: LuItalic,
  LuIterationCcw: LuIterationCcw,
  LuIterationCw: LuIterationCw,
  LuJapaneseYen: LuJapaneseYen,
  LuJoystick: LuJoystick,
  LuKanban: LuKanban,
  LuKey: LuKey,
  LuKeyRound: LuKeyRound,
  LuKeySquare: LuKeySquare,
  LuKeyboard: LuKeyboard,
  LuKeyboardMusic: LuKeyboardMusic,
  LuLamp: LuLamp,
  LuLampCeiling: LuLampCeiling,
  LuLampDesk: LuLampDesk,
  LuLampFloor: LuLampFloor,
  LuLampWallDown: LuLampWallDown,
  LuLampWallUp: LuLampWallUp,
  LuLandPlot: LuLandPlot,
  LuLandmark: LuLandmark,
  LuLanguages: LuLanguages,
  LuLaptop: LuLaptop,
  LuLaptopMinimal: LuLaptopMinimal,
  LuLasso: LuLasso,
  LuLassoSelect: LuLassoSelect,
  LuLaugh: LuLaugh,
  LuLayers: LuLayers,
  LuLayers2: LuLayers2,
  LuLayers3: LuLayers3,
  LuLayoutDashboard: LuLayoutDashboard,
  LuLayoutGrid: LuLayoutGrid,
  LuLayoutList: LuLayoutList,
  LuLayoutPanelLeft: LuLayoutPanelLeft,
  LuLayoutPanelTop: LuLayoutPanelTop,
  LuLayoutTemplate: LuLayoutTemplate,
  LuLeaf: LuLeaf,
  LuLeafyGreen: LuLeafyGreen,
  LuLibrary: LuLibrary,
  LuLibraryBig: LuLibraryBig,
  LuLifeBuoy: LuLifeBuoy,
  LuLigature: LuLigature,
  LuLightbulb: LuLightbulb,
  LuLightbulbOff: LuLightbulbOff,
  LuLineChart: LuLineChart,
  LuLink: LuLink,
  LuLink2: LuLink2,
  LuLink2Off: LuLink2Off,
  LuLinkedin: LuLinkedin,
  LuList: LuList,
  LuListChecks: LuListChecks,
  LuListCollapse: LuListCollapse,
  LuListEnd: LuListEnd,
  LuListFilter: LuListFilter,
  LuListMinus: LuListMinus,
  LuListMusic: LuListMusic,
  LuListOrdered: LuListOrdered,
  LuListPlus: LuListPlus,
  LuListRestart: LuListRestart,
  LuListStart: LuListStart,
  LuListTodo: LuListTodo,
  LuListTree: LuListTree,
  LuListVideo: LuListVideo,
  LuListX: LuListX,
  LuLoader: LuLoader,
  LuLoaderCircle: LuLoaderCircle,
  LuLocate: LuLocate,
  LuLocateFixed: LuLocateFixed,
  LuLocateOff: LuLocateOff,
  LuLock: LuLock,
  LuLockKeyhole: LuLockKeyhole,
  LuLockKeyholeOpen: LuLockKeyholeOpen,
  LuLockOpen: LuLockOpen,
  LuLogIn: LuLogIn,
  LuLogOut: LuLogOut,
  LuLollipop: LuLollipop,
  LuLuggage: LuLuggage,
  LuMagnet: LuMagnet,
  LuMail: LuMail,
  LuMailCheck: LuMailCheck,
  LuMailMinus: LuMailMinus,
  LuMailOpen: LuMailOpen,
  LuMailPlus: LuMailPlus,
  LuMailQuestion: LuMailQuestion,
  LuMailSearch: LuMailSearch,
  LuMailWarning: LuMailWarning,
  LuMailX: LuMailX,
  LuMailbox: LuMailbox,
  LuMails: LuMails,
  LuMap: LuMap,
  LuMapPin: LuMapPin,
  LuMapPinOff: LuMapPinOff,
  LuMapPinned: LuMapPinned,
  LuMartini: LuMartini,
  LuMaximize: LuMaximize,
  LuMaximize2: LuMaximize2,
  LuMedal: LuMedal,
  LuMegaphone: LuMegaphone,
  LuMegaphoneOff: LuMegaphoneOff,
  LuMeh: LuMeh,
  LuMemoryStick: LuMemoryStick,
  LuMenu: LuMenu,
  LuMerge: LuMerge,
  LuMessageCircle: LuMessageCircle,
  LuMessageCircleCode: LuMessageCircleCode,
  LuMessageCircleDashed: LuMessageCircleDashed,
  LuMessageCircleHeart: LuMessageCircleHeart,
  LuMessageCircleMore: LuMessageCircleMore,
  LuMessageCircleOff: LuMessageCircleOff,
  LuMessageCirclePlus: LuMessageCirclePlus,
  LuMessageCircleQuestion: LuMessageCircleQuestion,
  LuMessageCircleReply: LuMessageCircleReply,
  LuMessageCircleWarning: LuMessageCircleWarning,
  LuMessageCircleX: LuMessageCircleX,
  LuMessageSquare: LuMessageSquare,
  LuMessageSquareCode: LuMessageSquareCode,
  LuMessageSquareDashed: LuMessageSquareDashed,
  LuMessageSquareDiff: LuMessageSquareDiff,
  LuMessageSquareDot: LuMessageSquareDot,
  LuMessageSquareHeart: LuMessageSquareHeart,
  LuMessageSquareMore: LuMessageSquareMore,
  LuMessageSquareOff: LuMessageSquareOff,
  LuMessageSquarePlus: LuMessageSquarePlus,
  LuMessageSquareQuote: LuMessageSquareQuote,
  LuMessageSquareReply: LuMessageSquareReply,
  LuMessageSquareShare: LuMessageSquareShare,
  LuMessageSquareText: LuMessageSquareText,
  LuMessageSquareWarning: LuMessageSquareWarning,
  LuMessageSquareX: LuMessageSquareX,
  LuMessagesSquare: LuMessagesSquare,
  LuMic: LuMic,
  LuMicOff: LuMicOff,
  LuMicVocal: LuMicVocal,
  LuMicroscope: LuMicroscope,
  LuMicrowave: LuMicrowave,
  LuMilestone: LuMilestone,
  LuMilk: LuMilk,
  LuMilkOff: LuMilkOff,
  LuMinimize: LuMinimize,
  LuMinimize2: LuMinimize2,
  LuMinus: LuMinus,
  LuMonitor: LuMonitor,
  LuMonitorCheck: LuMonitorCheck,
  LuMonitorDot: LuMonitorDot,
  LuMonitorDown: LuMonitorDown,
  LuMonitorOff: LuMonitorOff,
  LuMonitorPause: LuMonitorPause,
  LuMonitorPlay: LuMonitorPlay,
  LuMonitorSmartphone: LuMonitorSmartphone,
  LuMonitorSpeaker: LuMonitorSpeaker,
  LuMonitorStop: LuMonitorStop,
  LuMonitorUp: LuMonitorUp,
  LuMonitorX: LuMonitorX,
  LuMoon: LuMoon,
  LuMoonStar: LuMoonStar,
  LuMountain: LuMountain,
  LuMountainSnow: LuMountainSnow,
  LuMouse: LuMouse,
  LuMousePointer: LuMousePointer,
  LuMousePointer2: LuMousePointer2,
  LuMousePointerClick: LuMousePointerClick,
  LuMove: LuMove,
  LuMove3d: LuMove3d,
  LuMoveDiagonal: LuMoveDiagonal,
  LuMoveDiagonal2: LuMoveDiagonal2,
  LuMoveDown: LuMoveDown,
  LuMoveDownLeft: LuMoveDownLeft,
  LuMoveDownRight: LuMoveDownRight,
  LuMoveHorizontal: LuMoveHorizontal,
  LuMoveLeft: LuMoveLeft,
  LuMoveRight: LuMoveRight,
  LuMoveUp: LuMoveUp,
  LuMoveUpLeft: LuMoveUpLeft,
  LuMoveUpRight: LuMoveUpRight,
  LuMoveVertical: LuMoveVertical,
  LuMusic: LuMusic,
  LuMusic2: LuMusic2,
  LuMusic3: LuMusic3,
  LuMusic4: LuMusic4,
  LuNavigation: LuNavigation,
  LuNavigation2: LuNavigation2,
  LuNavigation2Off: LuNavigation2Off,
  LuNavigationOff: LuNavigationOff,
  LuNetwork: LuNetwork,
  LuNewspaper: LuNewspaper,
  LuNfc: LuNfc,
  LuNotebook: LuNotebook,
  LuNotebookPen: LuNotebookPen,
  LuNotebookTabs: LuNotebookTabs,
  LuNotebookText: LuNotebookText,
  LuNotepadText: LuNotepadText,
  LuNotepadTextDashed: LuNotepadTextDashed,
  LuNut: LuNut,
  LuNutOff: LuNutOff,
  LuOctagon: LuOctagon,
  LuOctagonAlert: LuOctagonAlert,
  LuOctagonPause: LuOctagonPause,
  LuOctagonX: LuOctagonX,
  LuOption: LuOption,
  LuOrbit: LuOrbit,
  LuPackage: LuPackage,
  LuPackage2: LuPackage2,
  LuPackageCheck: LuPackageCheck,
  LuPackageMinus: LuPackageMinus,
  LuPackageOpen: LuPackageOpen,
  LuPackagePlus: LuPackagePlus,
  LuPackageSearch: LuPackageSearch,
  LuPackageX: LuPackageX,
  LuPaintBucket: LuPaintBucket,
  LuPaintRoller: LuPaintRoller,
  LuPaintbrush: LuPaintbrush,
  LuPaintbrush2: LuPaintbrush2,
  LuPalette: LuPalette,
  LuPanelBottom: LuPanelBottom,
  LuPanelBottomClose: LuPanelBottomClose,
  LuPanelBottomDashed: LuPanelBottomDashed,
  LuPanelBottomOpen: LuPanelBottomOpen,
  LuPanelLeft: LuPanelLeft,
  LuPanelLeftClose: LuPanelLeftClose,
  LuPanelLeftDashed: LuPanelLeftDashed,
  LuPanelLeftOpen: LuPanelLeftOpen,
  LuPanelRight: LuPanelRight,
  LuPanelRightClose: LuPanelRightClose,
  LuPanelRightDashed: LuPanelRightDashed,
  LuPanelRightOpen: LuPanelRightOpen,
  LuPanelTop: LuPanelTop,
  LuPanelTopClose: LuPanelTopClose,
  LuPanelTopDashed: LuPanelTopDashed,
  LuPanelTopOpen: LuPanelTopOpen,
  LuPanelsLeftBottom: LuPanelsLeftBottom,
  LuPanelsRightBottom: LuPanelsRightBottom,
  LuPanelsTopLeft: LuPanelsTopLeft,
  LuPaperclip: LuPaperclip,
  LuParentheses: LuParentheses,
  LuParkingMeter: LuParkingMeter,
  LuPartyPopper: LuPartyPopper,
  LuPause: LuPause,
  LuPawPrint: LuPawPrint,
  LuPcCase: LuPcCase,
  LuPen: LuPen,
  LuPenLine: LuPenLine,
  LuPenTool: LuPenTool,
  LuPencil: LuPencil,
  LuPencilLine: LuPencilLine,
  LuPencilRuler: LuPencilRuler,
  LuPentagon: LuPentagon,
  LuPercent: LuPercent,
  LuPersonStanding: LuPersonStanding,
  LuPhone: LuPhone,
  LuPhoneCall: LuPhoneCall,
  LuPhoneForwarded: LuPhoneForwarded,
  LuPhoneIncoming: LuPhoneIncoming,
  LuPhoneMissed: LuPhoneMissed,
  LuPhoneOff: LuPhoneOff,
  LuPhoneOutgoing: LuPhoneOutgoing,
  LuPi: LuPi,
  LuPiano: LuPiano,
  LuPickaxe: LuPickaxe,
  LuPictureInPicture: LuPictureInPicture,
  LuPictureInPicture2: LuPictureInPicture2,
  LuPieChart: LuPieChart,
  LuPiggyBank: LuPiggyBank,
  LuPilcrow: LuPilcrow,
  LuPill: LuPill,
  LuPin: LuPin,
  LuPinOff: LuPinOff,
  LuPipette: LuPipette,
  LuPizza: LuPizza,
  LuPlane: LuPlane,
  LuPlaneLanding: LuPlaneLanding,
  LuPlaneTakeoff: LuPlaneTakeoff,
  LuPlay: LuPlay,
  LuPlug: LuPlug,
  LuPlug2: LuPlug2,
  LuPlugZap: LuPlugZap,
  LuPlugZap2: LuPlugZap2,
  LuPlus: LuPlus,
  LuPocket: LuPocket,
  LuPocketKnife: LuPocketKnife,
  LuPodcast: LuPodcast,
  LuPointer: LuPointer,
  LuPointerOff: LuPointerOff,
  LuPopcorn: LuPopcorn,
  LuPopsicle: LuPopsicle,
  LuPoundSterling: LuPoundSterling,
  LuPower: LuPower,
  LuPowerOff: LuPowerOff,
  LuPresentation: LuPresentation,
  LuPrinter: LuPrinter,
  LuProjector: LuProjector,
  LuProportions: LuProportions,
  LuPuzzle: LuPuzzle,
  LuPyramid: LuPyramid,
  LuQrCode: LuQrCode,
  LuQuote: LuQuote,
  LuRabbit: LuRabbit,
  LuRadar: LuRadar,
  LuRadiation: LuRadiation,
  LuRadical: LuRadical,
  LuRadio: LuRadio,
  LuRadioReceiver: LuRadioReceiver,
  LuRadioTower: LuRadioTower,
  LuRadius: LuRadius,
  LuRailSymbol: LuRailSymbol,
  LuRainbow: LuRainbow,
  LuRat: LuRat,
  LuRatio: LuRatio,
  LuReceipt: LuReceipt,
  LuReceiptCent: LuReceiptCent,
  LuReceiptEuro: LuReceiptEuro,
  LuReceiptIndianRupee: LuReceiptIndianRupee,
  LuReceiptJapaneseYen: LuReceiptJapaneseYen,
  LuReceiptPoundSterling: LuReceiptPoundSterling,
  LuReceiptRussianRuble: LuReceiptRussianRuble,
  LuReceiptSwissFranc: LuReceiptSwissFranc,
  LuReceiptText: LuReceiptText,
  LuRectangleEllipsis: LuRectangleEllipsis,
  LuRectangleHorizontal: LuRectangleHorizontal,
  LuRectangleVertical: LuRectangleVertical,
  LuRecycle: LuRecycle,
  LuRedo: LuRedo,
  LuRedo2: LuRedo2,
  LuRedoDot: LuRedoDot,
  LuRefreshCcw: LuRefreshCcw,
  LuRefreshCcwDot: LuRefreshCcwDot,
  LuRefreshCw: LuRefreshCw,
  LuRefreshCwOff: LuRefreshCwOff,
  LuRefrigerator: LuRefrigerator,
  LuRegex: LuRegex,
  LuRemoveFormatting: LuRemoveFormatting,
  LuRepeat: LuRepeat,
  LuRepeat1: LuRepeat1,
  LuRepeat2: LuRepeat2,
  LuReplace: LuReplace,
  LuReplaceAll: LuReplaceAll,
  LuReply: LuReply,
  LuReplyAll: LuReplyAll,
  LuRewind: LuRewind,
  LuRibbon: LuRibbon,
  LuRocket: LuRocket,
  LuRockingChair: LuRockingChair,
  LuRollerCoaster: LuRollerCoaster,
  LuRotate3d: LuRotate3d,
  LuRotateCcw: LuRotateCcw,
  LuRotateCcwSquare: LuRotateCcwSquare,
  LuRotateCw: LuRotateCw,
  LuRotateCwSquare: LuRotateCwSquare,
  LuRoute: LuRoute,
  LuRouteOff: LuRouteOff,
  LuRouter: LuRouter,
  LuRows2: LuRows2,
  LuRows3: LuRows3,
  LuRows4: LuRows4,
  LuRss: LuRss,
  LuRuler: LuRuler,
  LuRussianRuble: LuRussianRuble,
  LuSailboat: LuSailboat,
  LuSalad: LuSalad,
  LuSandwich: LuSandwich,
  LuSatellite: LuSatellite,
  LuSatelliteDish: LuSatelliteDish,
  LuSave: LuSave,
  LuSaveAll: LuSaveAll,
  LuScale: LuScale,
  LuScale3d: LuScale3d,
  LuScaling: LuScaling,
  LuScan: LuScan,
  LuScanBarcode: LuScanBarcode,
  LuScanEye: LuScanEye,
  LuScanFace: LuScanFace,
  LuScanLine: LuScanLine,
  LuScanSearch: LuScanSearch,
  LuScanText: LuScanText,
  LuScatterChart: LuScatterChart,
  LuSchool: LuSchool,
  LuScissors: LuScissors,
  LuScissorsLineDashed: LuScissorsLineDashed,
  LuScreenShare: LuScreenShare,
  LuScreenShareOff: LuScreenShareOff,
  LuScroll: LuScroll,
  LuScrollText: LuScrollText,
  LuSearch: LuSearch,
  LuSearchCheck: LuSearchCheck,
  LuSearchCode: LuSearchCode,
  LuSearchSlash: LuSearchSlash,
  LuSearchX: LuSearchX,
  LuSend: LuSend,
  LuSendHorizontal: LuSendHorizontal,
  LuSendToBack: LuSendToBack,
  LuSeparatorHorizontal: LuSeparatorHorizontal,
  LuSeparatorVertical: LuSeparatorVertical,
  LuServer: LuServer,
  LuServerCog: LuServerCog,
  LuServerCrash: LuServerCrash,
  LuServerOff: LuServerOff,
  LuSettings: LuSettings,
  LuSettings2: LuSettings2,
  LuShapes: LuShapes,
  LuShare: LuShare,
  LuShare2: LuShare2,
  LuSheet: LuSheet,
  LuShell: LuShell,
  LuShield: LuShield,
  LuShieldAlert: LuShieldAlert,
  LuShieldBan: LuShieldBan,
  LuShieldCheck: LuShieldCheck,
  LuShieldEllipsis: LuShieldEllipsis,
  LuShieldHalf: LuShieldHalf,
  LuShieldMinus: LuShieldMinus,
  LuShieldOff: LuShieldOff,
  LuShieldPlus: LuShieldPlus,
  LuShieldQuestion: LuShieldQuestion,
  LuShieldX: LuShieldX,
  LuShip: LuShip,
  LuShipWheel: LuShipWheel,
  LuShirt: LuShirt,
  LuShoppingBag: LuShoppingBag,
  LuShoppingBasket: LuShoppingBasket,
  LuShoppingCart: LuShoppingCart,
  LuShovel: LuShovel,
  LuShowerHead: LuShowerHead,
  LuShrink: LuShrink,
  LuShrub: LuShrub,
  LuShuffle: LuShuffle,
  LuSigma: LuSigma,
  LuSignal: LuSignal,
  LuSignalHigh: LuSignalHigh,
  LuSignalLow: LuSignalLow,
  LuSignalMedium: LuSignalMedium,
  LuSignalZero: LuSignalZero,
  LuSignpost: LuSignpost,
  LuSignpostBig: LuSignpostBig,
  LuSiren: LuSiren,
  LuSkipBack: LuSkipBack,
  LuSkipForward: LuSkipForward,
  LuSkull: LuSkull,
  LuSlack: LuSlack,
  LuSlash: LuSlash,
  LuSlice: LuSlice,
  LuSlidersHorizontal: LuSlidersHorizontal,
  LuSlidersVertical: LuSlidersVertical,
  LuSmartphone: LuSmartphone,
  LuSmartphoneCharging: LuSmartphoneCharging,
  LuSmartphoneNfc: LuSmartphoneNfc,
  LuSmile: LuSmile,
  LuSmilePlus: LuSmilePlus,
  LuSnail: LuSnail,
  LuSnowflake: LuSnowflake,
  LuSofa: LuSofa,
  LuSoup: LuSoup,
  LuSpace: LuSpace,
  LuSpade: LuSpade,
  LuSparkle: LuSparkle,
  LuSparkles: LuSparkles,
  LuSpeaker: LuSpeaker,
  LuSpeech: LuSpeech,
  LuSpellCheck: LuSpellCheck,
  LuSpellCheck2: LuSpellCheck2,
  LuSpline: LuSpline,
  LuSplit: LuSplit,
  LuSprayCan: LuSprayCan,
  LuSprout: LuSprout,
  LuSquare: LuSquare,
  LuSquareActivity: LuSquareActivity,
  LuSquareArrowDown: LuSquareArrowDown,
  LuSquareArrowDownLeft: LuSquareArrowDownLeft,
  LuSquareArrowDownRight: LuSquareArrowDownRight,
  LuSquareArrowLeft: LuSquareArrowLeft,
  LuSquareArrowOutDownLeft: LuSquareArrowOutDownLeft,
  LuSquareArrowOutDownRight: LuSquareArrowOutDownRight,
  LuSquareArrowOutUpLeft: LuSquareArrowOutUpLeft,
  LuSquareArrowOutUpRight: LuSquareArrowOutUpRight,
  LuSquareArrowRight: LuSquareArrowRight,
  LuSquareArrowUp: LuSquareArrowUp,
  LuSquareArrowUpLeft: LuSquareArrowUpLeft,
  LuSquareArrowUpRight: LuSquareArrowUpRight,
  LuSquareAsterisk: LuSquareAsterisk,
  LuSquareBottomDashedScissors: LuSquareBottomDashedScissors,
  LuSquareCheck: LuSquareCheck,
  LuSquareCheckBig: LuSquareCheckBig,
  LuSquareChevronDown: LuSquareChevronDown,
  LuSquareChevronLeft: LuSquareChevronLeft,
  LuSquareChevronRight: LuSquareChevronRight,
  LuSquareChevronUp: LuSquareChevronUp,
  LuSquareCode: LuSquareCode,
  LuSquareDashedBottom: LuSquareDashedBottom,
  LuSquareDashedBottomCode: LuSquareDashedBottomCode,
  LuSquareDashedKanban: LuSquareDashedKanban,
  LuSquareDashedMousePointer: LuSquareDashedMousePointer,
  LuSquareDivide: LuSquareDivide,
  LuSquareDot: LuSquareDot,
  LuSquareEqual: LuSquareEqual,
  LuSquareFunction: LuSquareFunction,
  LuSquareGanttChart: LuSquareGanttChart,
  LuSquareKanban: LuSquareKanban,
  LuSquareLibrary: LuSquareLibrary,
  LuSquareM: LuSquareM,
  LuSquareMenu: LuSquareMenu,
  LuSquareMinus: LuSquareMinus,
  LuSquareMousePointer: LuSquareMousePointer,
  LuSquareParking: LuSquareParking,
  LuSquareParkingOff: LuSquareParkingOff,
  LuSquarePen: LuSquarePen,
  LuSquarePercent: LuSquarePercent,
  LuSquarePi: LuSquarePi,
  LuSquarePilcrow: LuSquarePilcrow,
  LuSquarePlay: LuSquarePlay,
  LuSquarePlus: LuSquarePlus,
  LuSquarePower: LuSquarePower,
  LuSquareRadical: LuSquareRadical,
  LuSquareScissors: LuSquareScissors,
  LuSquareSigma: LuSquareSigma,
  LuSquareSlash: LuSquareSlash,
  LuSquareSplitHorizontal: LuSquareSplitHorizontal,
  LuSquareSplitVertical: LuSquareSplitVertical,
  LuSquareStack: LuSquareStack,
  LuSquareTerminal: LuSquareTerminal,
  LuSquareUser: LuSquareUser,
  LuSquareUserRound: LuSquareUserRound,
  LuSquareX: LuSquareX,
  LuSquircle: LuSquircle,
  LuSquirrel: LuSquirrel,
  LuStamp: LuStamp,
  LuStar: LuStar,
  LuStarHalf: LuStarHalf,
  LuStarOff: LuStarOff,
  LuStepBack: LuStepBack,
  LuStepForward: LuStepForward,
  LuStethoscope: LuStethoscope,
  LuSticker: LuSticker,
  LuStickyNote: LuStickyNote,
  LuStore: LuStore,
  LuStretchHorizontal: LuStretchHorizontal,
  LuStretchVertical: LuStretchVertical,
  LuStrikethrough: LuStrikethrough,
  LuSubscript: LuSubscript,
  LuSun: LuSun,
  LuSunDim: LuSunDim,
  LuSunMedium: LuSunMedium,
  LuSunMoon: LuSunMoon,
  LuSunSnow: LuSunSnow,
  LuSunrise: LuSunrise,
  LuSunset: LuSunset,
  LuSuperscript: LuSuperscript,
  LuSwatchBook: LuSwatchBook,
  LuSwissFranc: LuSwissFranc,
  LuSwitchCamera: LuSwitchCamera,
  LuSword: LuSword,
  LuSwords: LuSwords,
  LuSyringe: LuSyringe,
  LuTable: LuTable,
  LuTable2: LuTable2,
  LuTableCellsMerge: LuTableCellsMerge,
  LuTableCellsSplit: LuTableCellsSplit,
  LuTableColumnsSplit: LuTableColumnsSplit,
  LuTableProperties: LuTableProperties,
  LuTableRowsSplit: LuTableRowsSplit,
  LuTablet: LuTablet,
  LuTabletSmartphone: LuTabletSmartphone,
  LuTablets: LuTablets,
  LuTag: LuTag,
  LuTags: LuTags,
  LuTally1: LuTally1,
  LuTally2: LuTally2,
  LuTally3: LuTally3,
  LuTally4: LuTally4,
  LuTally5: LuTally5,
  LuTangent: LuTangent,
  LuTarget: LuTarget,
  LuTelescope: LuTelescope,
  LuTent: LuTent,
  LuTentTree: LuTentTree,
  LuTerminal: LuTerminal,
  LuTestTube: LuTestTube,
  LuTestTubeDiagonal: LuTestTubeDiagonal,
  LuTestTubes: LuTestTubes,
  LuText: LuText,
  LuTextCursor: LuTextCursor,
  LuTextCursorInput: LuTextCursorInput,
  LuTextQuote: LuTextQuote,
  LuTextSearch: LuTextSearch,
  LuTextSelect: LuTextSelect,
  LuTheater: LuTheater,
  LuThermometer: LuThermometer,
  LuThermometerSnowflake: LuThermometerSnowflake,
  LuThermometerSun: LuThermometerSun,
  LuThumbsDown: LuThumbsDown,
  LuThumbsUp: LuThumbsUp,
  LuTicket: LuTicket,
  LuTicketCheck: LuTicketCheck,
  LuTicketMinus: LuTicketMinus,
  LuTicketPercent: LuTicketPercent,
  LuTicketPlus: LuTicketPlus,
  LuTicketSlash: LuTicketSlash,
  LuTicketX: LuTicketX,
  LuTimer: LuTimer,
  LuTimerOff: LuTimerOff,
  LuTimerReset: LuTimerReset,
  LuToggleLeft: LuToggleLeft,
  LuToggleRight: LuToggleRight,
  LuTornado: LuTornado,
  LuTorus: LuTorus,
  LuTouchpad: LuTouchpad,
  LuTouchpadOff: LuTouchpadOff,
  LuTowerControl: LuTowerControl,
  LuToyBrick: LuToyBrick,
  LuTractor: LuTractor,
  LuTrafficCone: LuTrafficCone,
  LuTrainFront: LuTrainFront,
  LuTrainFrontTunnel: LuTrainFrontTunnel,
  LuTrainTrack: LuTrainTrack,
  LuTramFront: LuTramFront,
  LuTrash: LuTrash,
  LuTrash2: LuTrash2,
  LuTreeDeciduous: LuTreeDeciduous,
  LuTreePalm: LuTreePalm,
  LuTreePine: LuTreePine,
  LuTrees: LuTrees,
  LuTrello: LuTrello,
  LuTrendingDown: LuTrendingDown,
  LuTrendingUp: LuTrendingUp,
  LuTriangle: LuTriangle,
  LuTriangleAlert: LuTriangleAlert,
  LuTriangleRight: LuTriangleRight,
  LuTrophy: LuTrophy,
  LuTruck: LuTruck,
  LuTurtle: LuTurtle,
  LuTv: LuTv,
  LuTv2: LuTv2,
  LuTwitch: LuTwitch,
  LuTwitter: LuTwitter,
  LuType: LuType,
  LuUmbrella: LuUmbrella,
  LuUmbrellaOff: LuUmbrellaOff,
  LuUnderline: LuUnderline,
  LuUndo: LuUndo,
  LuUndo2: LuUndo2,
  LuUndoDot: LuUndoDot,
  LuUnfoldHorizontal: LuUnfoldHorizontal,
  LuUnfoldVertical: LuUnfoldVertical,
  LuUngroup: LuUngroup,
  LuUniversity: LuUniversity,
  LuUnlink: LuUnlink,
  LuUnlink2: LuUnlink2,
  LuUnplug: LuUnplug,
  LuUpload: LuUpload,
  LuUsb: LuUsb,
  LuUser: LuUser,
  LuUserCheck: LuUserCheck,
  LuUserCog: LuUserCog,
  LuUserMinus: LuUserMinus,
  LuUserPlus: LuUserPlus,
  LuUserRound: LuUserRound,
  LuUserRoundCheck: LuUserRoundCheck,
  LuUserRoundCog: LuUserRoundCog,
  LuUserRoundMinus: LuUserRoundMinus,
  LuUserRoundPlus: LuUserRoundPlus,
  LuUserRoundSearch: LuUserRoundSearch,
  LuUserRoundX: LuUserRoundX,
  LuUserSearch: LuUserSearch,
  LuUserX: LuUserX,
  LuUsers: LuUsers,
  LuUsersRound: LuUsersRound,
  LuUtensils: LuUtensils,
  LuUtensilsCrossed: LuUtensilsCrossed,
  LuUtilityPole: LuUtilityPole,
  LuVariable: LuVariable,
  LuVault: LuVault,
  LuVegan: LuVegan,
  LuVenetianMask: LuVenetianMask,
  LuVibrate: LuVibrate,
  LuVibrateOff: LuVibrateOff,
  LuVideo: LuVideo,
  LuVideoOff: LuVideoOff,
  LuVideotape: LuVideotape,
  LuView: LuView,
  LuVoicemail: LuVoicemail,
  LuVolume: LuVolume,
  LuVolume1: LuVolume1,
  LuVolume2: LuVolume2,
  LuVolumeX: LuVolumeX,
  LuVote: LuVote,
  LuWallet: LuWallet,
  LuWalletCards: LuWalletCards,
  LuWalletMinimal: LuWalletMinimal,
  LuWallpaper: LuWallpaper,
  LuWand: LuWand,
  LuWandSparkles: LuWandSparkles,
  LuWarehouse: LuWarehouse,
  LuWashingMachine: LuWashingMachine,
  LuWatch: LuWatch,
  LuWaves: LuWaves,
  LuWaypoints: LuWaypoints,
  LuWebcam: LuWebcam,
  LuWebhook: LuWebhook,
  LuWebhookOff: LuWebhookOff,
  LuWeight: LuWeight,
  LuWheat: LuWheat,
  LuWheatOff: LuWheatOff,
  LuWholeWord: LuWholeWord,
  LuWifi: LuWifi,
  LuWifiOff: LuWifiOff,
  LuWind: LuWind,
  LuWine: LuWine,
  LuWineOff: LuWineOff,
  LuWorkflow: LuWorkflow,
  LuWrapText: LuWrapText,
  LuWrench: LuWrench,
  LuX: LuX,
  LuYoutube: LuYoutube,
  LuZap: LuZap,
  LuZapOff: LuZapOff,
  LuZoomIn: LuZoomIn,
  LuZoomOut: LuZoomOut
});

exports.LuAArrowDown = LuAArrowDown;
exports.LuAArrowDownIcon = LuAArrowDown;
exports.LuAArrowUp = LuAArrowUp;
exports.LuAArrowUpIcon = LuAArrowUp;
exports.LuALargeSmall = LuALargeSmall;
exports.LuALargeSmallIcon = LuALargeSmall;
exports.LuAccessibility = LuAccessibility;
exports.LuAccessibilityIcon = LuAccessibility;
exports.LuActivity = LuActivity;
exports.LuActivityIcon = LuActivity;
exports.LuActivitySquare = LuSquareActivity;
exports.LuActivitySquareIcon = LuSquareActivity;
exports.LuAirVent = LuAirVent;
exports.LuAirVentIcon = LuAirVent;
exports.LuAirplay = LuAirplay;
exports.LuAirplayIcon = LuAirplay;
exports.LuAlarmCheck = LuAlarmClockCheck;
exports.LuAlarmCheckIcon = LuAlarmClockCheck;
exports.LuAlarmClock = LuAlarmClock;
exports.LuAlarmClockCheck = LuAlarmClockCheck;
exports.LuAlarmClockCheckIcon = LuAlarmClockCheck;
exports.LuAlarmClockIcon = LuAlarmClock;
exports.LuAlarmClockMinus = LuAlarmClockMinus;
exports.LuAlarmClockMinusIcon = LuAlarmClockMinus;
exports.LuAlarmClockOff = LuAlarmClockOff;
exports.LuAlarmClockOffIcon = LuAlarmClockOff;
exports.LuAlarmClockPlus = LuAlarmClockPlus;
exports.LuAlarmClockPlusIcon = LuAlarmClockPlus;
exports.LuAlarmMinus = LuAlarmClockMinus;
exports.LuAlarmMinusIcon = LuAlarmClockMinus;
exports.LuAlarmPlus = LuAlarmClockPlus;
exports.LuAlarmPlusIcon = LuAlarmClockPlus;
exports.LuAlarmSmoke = LuAlarmSmoke;
exports.LuAlarmSmokeIcon = LuAlarmSmoke;
exports.LuAlbum = LuAlbum;
exports.LuAlbumIcon = LuAlbum;
exports.LuAlertCircle = LuCircleAlert;
exports.LuAlertCircleIcon = LuCircleAlert;
exports.LuAlertOctagon = LuOctagonAlert;
exports.LuAlertOctagonIcon = LuOctagonAlert;
exports.LuAlertTriangle = LuTriangleAlert;
exports.LuAlertTriangleIcon = LuTriangleAlert;
exports.LuAlignCenter = LuAlignCenter;
exports.LuAlignCenterHorizontal = LuAlignCenterHorizontal;
exports.LuAlignCenterHorizontalIcon = LuAlignCenterHorizontal;
exports.LuAlignCenterIcon = LuAlignCenter;
exports.LuAlignCenterVertical = LuAlignCenterVertical;
exports.LuAlignCenterVerticalIcon = LuAlignCenterVertical;
exports.LuAlignEndHorizontal = LuAlignEndHorizontal;
exports.LuAlignEndHorizontalIcon = LuAlignEndHorizontal;
exports.LuAlignEndVertical = LuAlignEndVertical;
exports.LuAlignEndVerticalIcon = LuAlignEndVertical;
exports.LuAlignHorizontalDistributeCenter = LuAlignHorizontalDistributeCenter;
exports.LuAlignHorizontalDistributeCenterIcon = LuAlignHorizontalDistributeCenter;
exports.LuAlignHorizontalDistributeEnd = LuAlignHorizontalDistributeEnd;
exports.LuAlignHorizontalDistributeEndIcon = LuAlignHorizontalDistributeEnd;
exports.LuAlignHorizontalDistributeStart = LuAlignHorizontalDistributeStart;
exports.LuAlignHorizontalDistributeStartIcon = LuAlignHorizontalDistributeStart;
exports.LuAlignHorizontalJustifyCenter = LuAlignHorizontalJustifyCenter;
exports.LuAlignHorizontalJustifyCenterIcon = LuAlignHorizontalJustifyCenter;
exports.LuAlignHorizontalJustifyEnd = LuAlignHorizontalJustifyEnd;
exports.LuAlignHorizontalJustifyEndIcon = LuAlignHorizontalJustifyEnd;
exports.LuAlignHorizontalJustifyStart = LuAlignHorizontalJustifyStart;
exports.LuAlignHorizontalJustifyStartIcon = LuAlignHorizontalJustifyStart;
exports.LuAlignHorizontalSpaceAround = LuAlignHorizontalSpaceAround;
exports.LuAlignHorizontalSpaceAroundIcon = LuAlignHorizontalSpaceAround;
exports.LuAlignHorizontalSpaceBetween = LuAlignHorizontalSpaceBetween;
exports.LuAlignHorizontalSpaceBetweenIcon = LuAlignHorizontalSpaceBetween;
exports.LuAlignJustify = LuAlignJustify;
exports.LuAlignJustifyIcon = LuAlignJustify;
exports.LuAlignLeft = LuAlignLeft;
exports.LuAlignLeftIcon = LuAlignLeft;
exports.LuAlignRight = LuAlignRight;
exports.LuAlignRightIcon = LuAlignRight;
exports.LuAlignStartHorizontal = LuAlignStartHorizontal;
exports.LuAlignStartHorizontalIcon = LuAlignStartHorizontal;
exports.LuAlignStartVertical = LuAlignStartVertical;
exports.LuAlignStartVerticalIcon = LuAlignStartVertical;
exports.LuAlignVerticalDistributeCenter = LuAlignVerticalDistributeCenter;
exports.LuAlignVerticalDistributeCenterIcon = LuAlignVerticalDistributeCenter;
exports.LuAlignVerticalDistributeEnd = LuAlignVerticalDistributeEnd;
exports.LuAlignVerticalDistributeEndIcon = LuAlignVerticalDistributeEnd;
exports.LuAlignVerticalDistributeStart = LuAlignVerticalDistributeStart;
exports.LuAlignVerticalDistributeStartIcon = LuAlignVerticalDistributeStart;
exports.LuAlignVerticalJustifyCenter = LuAlignVerticalJustifyCenter;
exports.LuAlignVerticalJustifyCenterIcon = LuAlignVerticalJustifyCenter;
exports.LuAlignVerticalJustifyEnd = LuAlignVerticalJustifyEnd;
exports.LuAlignVerticalJustifyEndIcon = LuAlignVerticalJustifyEnd;
exports.LuAlignVerticalJustifyStart = LuAlignVerticalJustifyStart;
exports.LuAlignVerticalJustifyStartIcon = LuAlignVerticalJustifyStart;
exports.LuAlignVerticalSpaceAround = LuAlignVerticalSpaceAround;
exports.LuAlignVerticalSpaceAroundIcon = LuAlignVerticalSpaceAround;
exports.LuAlignVerticalSpaceBetween = LuAlignVerticalSpaceBetween;
exports.LuAlignVerticalSpaceBetweenIcon = LuAlignVerticalSpaceBetween;
exports.LuAmbulance = LuAmbulance;
exports.LuAmbulanceIcon = LuAmbulance;
exports.LuAmpersand = LuAmpersand;
exports.LuAmpersandIcon = LuAmpersand;
exports.LuAmpersands = LuAmpersands;
exports.LuAmpersandsIcon = LuAmpersands;
exports.LuAnchor = LuAnchor;
exports.LuAnchorIcon = LuAnchor;
exports.LuAngry = LuAngry;
exports.LuAngryIcon = LuAngry;
exports.LuAnnoyed = LuAnnoyed;
exports.LuAnnoyedIcon = LuAnnoyed;
exports.LuAntenna = LuAntenna;
exports.LuAntennaIcon = LuAntenna;
exports.LuAnvil = LuAnvil;
exports.LuAnvilIcon = LuAnvil;
exports.LuAperture = LuAperture;
exports.LuApertureIcon = LuAperture;
exports.LuAppWindow = LuAppWindow;
exports.LuAppWindowIcon = LuAppWindow;
exports.LuAppWindowMac = LuAppWindowMac;
exports.LuAppWindowMacIcon = LuAppWindowMac;
exports.LuApple = LuApple;
exports.LuAppleIcon = LuApple;
exports.LuArchive = LuArchive;
exports.LuArchiveIcon = LuArchive;
exports.LuArchiveRestore = LuArchiveRestore;
exports.LuArchiveRestoreIcon = LuArchiveRestore;
exports.LuArchiveX = LuArchiveX;
exports.LuArchiveXIcon = LuArchiveX;
exports.LuAreaChart = LuAreaChart;
exports.LuAreaChartIcon = LuAreaChart;
exports.LuArmchair = LuArmchair;
exports.LuArmchairIcon = LuArmchair;
exports.LuArrowBigDown = LuArrowBigDown;
exports.LuArrowBigDownDash = LuArrowBigDownDash;
exports.LuArrowBigDownDashIcon = LuArrowBigDownDash;
exports.LuArrowBigDownIcon = LuArrowBigDown;
exports.LuArrowBigLeft = LuArrowBigLeft;
exports.LuArrowBigLeftDash = LuArrowBigLeftDash;
exports.LuArrowBigLeftDashIcon = LuArrowBigLeftDash;
exports.LuArrowBigLeftIcon = LuArrowBigLeft;
exports.LuArrowBigRight = LuArrowBigRight;
exports.LuArrowBigRightDash = LuArrowBigRightDash;
exports.LuArrowBigRightDashIcon = LuArrowBigRightDash;
exports.LuArrowBigRightIcon = LuArrowBigRight;
exports.LuArrowBigUp = LuArrowBigUp;
exports.LuArrowBigUpDash = LuArrowBigUpDash;
exports.LuArrowBigUpDashIcon = LuArrowBigUpDash;
exports.LuArrowBigUpIcon = LuArrowBigUp;
exports.LuArrowDown = LuArrowDown;
exports.LuArrowDown01 = LuArrowDown01;
exports.LuArrowDown01Icon = LuArrowDown01;
exports.LuArrowDown10 = LuArrowDown10;
exports.LuArrowDown10Icon = LuArrowDown10;
exports.LuArrowDownAZ = LuArrowDownAZ;
exports.LuArrowDownAZIcon = LuArrowDownAZ;
exports.LuArrowDownAz = LuArrowDownAZ;
exports.LuArrowDownAzIcon = LuArrowDownAZ;
exports.LuArrowDownCircle = LuCircleArrowDown;
exports.LuArrowDownCircleIcon = LuCircleArrowDown;
exports.LuArrowDownFromLine = LuArrowDownFromLine;
exports.LuArrowDownFromLineIcon = LuArrowDownFromLine;
exports.LuArrowDownIcon = LuArrowDown;
exports.LuArrowDownLeft = LuArrowDownLeft;
exports.LuArrowDownLeftFromCircle = LuCircleArrowOutDownLeft;
exports.LuArrowDownLeftFromCircleIcon = LuCircleArrowOutDownLeft;
exports.LuArrowDownLeftFromSquare = LuSquareArrowOutDownLeft;
exports.LuArrowDownLeftFromSquareIcon = LuSquareArrowOutDownLeft;
exports.LuArrowDownLeftIcon = LuArrowDownLeft;
exports.LuArrowDownLeftSquare = LuSquareArrowDownLeft;
exports.LuArrowDownLeftSquareIcon = LuSquareArrowDownLeft;
exports.LuArrowDownNarrowWide = LuArrowDownNarrowWide;
exports.LuArrowDownNarrowWideIcon = LuArrowDownNarrowWide;
exports.LuArrowDownRight = LuArrowDownRight;
exports.LuArrowDownRightFromCircle = LuCircleArrowOutDownRight;
exports.LuArrowDownRightFromCircleIcon = LuCircleArrowOutDownRight;
exports.LuArrowDownRightFromSquare = LuSquareArrowOutDownRight;
exports.LuArrowDownRightFromSquareIcon = LuSquareArrowOutDownRight;
exports.LuArrowDownRightIcon = LuArrowDownRight;
exports.LuArrowDownRightSquare = LuSquareArrowDownRight;
exports.LuArrowDownRightSquareIcon = LuSquareArrowDownRight;
exports.LuArrowDownSquare = LuSquareArrowDown;
exports.LuArrowDownSquareIcon = LuSquareArrowDown;
exports.LuArrowDownToDot = LuArrowDownToDot;
exports.LuArrowDownToDotIcon = LuArrowDownToDot;
exports.LuArrowDownToLine = LuArrowDownToLine;
exports.LuArrowDownToLineIcon = LuArrowDownToLine;
exports.LuArrowDownUp = LuArrowDownUp;
exports.LuArrowDownUpIcon = LuArrowDownUp;
exports.LuArrowDownWideNarrow = LuArrowDownWideNarrow;
exports.LuArrowDownWideNarrowIcon = LuArrowDownWideNarrow;
exports.LuArrowDownZA = LuArrowDownZA;
exports.LuArrowDownZAIcon = LuArrowDownZA;
exports.LuArrowDownZa = LuArrowDownZA;
exports.LuArrowDownZaIcon = LuArrowDownZA;
exports.LuArrowLeft = LuArrowLeft;
exports.LuArrowLeftCircle = LuCircleArrowLeft;
exports.LuArrowLeftCircleIcon = LuCircleArrowLeft;
exports.LuArrowLeftFromLine = LuArrowLeftFromLine;
exports.LuArrowLeftFromLineIcon = LuArrowLeftFromLine;
exports.LuArrowLeftIcon = LuArrowLeft;
exports.LuArrowLeftRight = LuArrowLeftRight;
exports.LuArrowLeftRightIcon = LuArrowLeftRight;
exports.LuArrowLeftSquare = LuSquareArrowLeft;
exports.LuArrowLeftSquareIcon = LuSquareArrowLeft;
exports.LuArrowLeftToLine = LuArrowLeftToLine;
exports.LuArrowLeftToLineIcon = LuArrowLeftToLine;
exports.LuArrowRight = LuArrowRight;
exports.LuArrowRightCircle = LuCircleArrowRight;
exports.LuArrowRightCircleIcon = LuCircleArrowRight;
exports.LuArrowRightFromLine = LuArrowRightFromLine;
exports.LuArrowRightFromLineIcon = LuArrowRightFromLine;
exports.LuArrowRightIcon = LuArrowRight;
exports.LuArrowRightLeft = LuArrowRightLeft;
exports.LuArrowRightLeftIcon = LuArrowRightLeft;
exports.LuArrowRightSquare = LuSquareArrowRight;
exports.LuArrowRightSquareIcon = LuSquareArrowRight;
exports.LuArrowRightToLine = LuArrowRightToLine;
exports.LuArrowRightToLineIcon = LuArrowRightToLine;
exports.LuArrowUp = LuArrowUp;
exports.LuArrowUp01 = LuArrowUp01;
exports.LuArrowUp01Icon = LuArrowUp01;
exports.LuArrowUp10 = LuArrowUp10;
exports.LuArrowUp10Icon = LuArrowUp10;
exports.LuArrowUpAZ = LuArrowUpAZ;
exports.LuArrowUpAZIcon = LuArrowUpAZ;
exports.LuArrowUpAz = LuArrowUpAZ;
exports.LuArrowUpAzIcon = LuArrowUpAZ;
exports.LuArrowUpCircle = LuCircleArrowUp;
exports.LuArrowUpCircleIcon = LuCircleArrowUp;
exports.LuArrowUpDown = LuArrowUpDown;
exports.LuArrowUpDownIcon = LuArrowUpDown;
exports.LuArrowUpFromDot = LuArrowUpFromDot;
exports.LuArrowUpFromDotIcon = LuArrowUpFromDot;
exports.LuArrowUpFromLine = LuArrowUpFromLine;
exports.LuArrowUpFromLineIcon = LuArrowUpFromLine;
exports.LuArrowUpIcon = LuArrowUp;
exports.LuArrowUpLeft = LuArrowUpLeft;
exports.LuArrowUpLeftFromCircle = LuCircleArrowOutUpLeft;
exports.LuArrowUpLeftFromCircleIcon = LuCircleArrowOutUpLeft;
exports.LuArrowUpLeftFromSquare = LuSquareArrowOutUpLeft;
exports.LuArrowUpLeftFromSquareIcon = LuSquareArrowOutUpLeft;
exports.LuArrowUpLeftIcon = LuArrowUpLeft;
exports.LuArrowUpLeftSquare = LuSquareArrowUpLeft;
exports.LuArrowUpLeftSquareIcon = LuSquareArrowUpLeft;
exports.LuArrowUpNarrowWide = LuArrowUpNarrowWide;
exports.LuArrowUpNarrowWideIcon = LuArrowUpNarrowWide;
exports.LuArrowUpRight = LuArrowUpRight;
exports.LuArrowUpRightFromCircle = LuCircleArrowOutUpRight;
exports.LuArrowUpRightFromCircleIcon = LuCircleArrowOutUpRight;
exports.LuArrowUpRightFromSquare = LuSquareArrowOutUpRight;
exports.LuArrowUpRightFromSquareIcon = LuSquareArrowOutUpRight;
exports.LuArrowUpRightIcon = LuArrowUpRight;
exports.LuArrowUpRightSquare = LuSquareArrowUpRight;
exports.LuArrowUpRightSquareIcon = LuSquareArrowUpRight;
exports.LuArrowUpSquare = LuSquareArrowUp;
exports.LuArrowUpSquareIcon = LuSquareArrowUp;
exports.LuArrowUpToLine = LuArrowUpToLine;
exports.LuArrowUpToLineIcon = LuArrowUpToLine;
exports.LuArrowUpWideNarrow = LuArrowUpWideNarrow;
exports.LuArrowUpWideNarrowIcon = LuArrowUpWideNarrow;
exports.LuArrowUpZA = LuArrowUpZA;
exports.LuArrowUpZAIcon = LuArrowUpZA;
exports.LuArrowUpZa = LuArrowUpZA;
exports.LuArrowUpZaIcon = LuArrowUpZA;
exports.LuArrowsUpFromLine = LuArrowsUpFromLine;
exports.LuArrowsUpFromLineIcon = LuArrowsUpFromLine;
exports.LuAsterisk = LuAsterisk;
exports.LuAsteriskIcon = LuAsterisk;
exports.LuAsteriskSquare = LuSquareAsterisk;
exports.LuAsteriskSquareIcon = LuSquareAsterisk;
exports.LuAtSign = LuAtSign;
exports.LuAtSignIcon = LuAtSign;
exports.LuAtom = LuAtom;
exports.LuAtomIcon = LuAtom;
exports.LuAudioLines = LuAudioLines;
exports.LuAudioLinesIcon = LuAudioLines;
exports.LuAudioWaveform = LuAudioWaveform;
exports.LuAudioWaveformIcon = LuAudioWaveform;
exports.LuAward = LuAward;
exports.LuAwardIcon = LuAward;
exports.LuAxe = LuAxe;
exports.LuAxeIcon = LuAxe;
exports.LuAxis3D = LuAxis3d;
exports.LuAxis3DIcon = LuAxis3d;
exports.LuAxis3d = LuAxis3d;
exports.LuAxis3dIcon = LuAxis3d;
exports.LuBaby = LuBaby;
exports.LuBabyIcon = LuBaby;
exports.LuBackpack = LuBackpack;
exports.LuBackpackIcon = LuBackpack;
exports.LuBadge = LuBadge;
exports.LuBadgeAlert = LuBadgeAlert;
exports.LuBadgeAlertIcon = LuBadgeAlert;
exports.LuBadgeCent = LuBadgeCent;
exports.LuBadgeCentIcon = LuBadgeCent;
exports.LuBadgeCheck = LuBadgeCheck;
exports.LuBadgeCheckIcon = LuBadgeCheck;
exports.LuBadgeDollarSign = LuBadgeDollarSign;
exports.LuBadgeDollarSignIcon = LuBadgeDollarSign;
exports.LuBadgeEuro = LuBadgeEuro;
exports.LuBadgeEuroIcon = LuBadgeEuro;
exports.LuBadgeHelp = LuBadgeHelp;
exports.LuBadgeHelpIcon = LuBadgeHelp;
exports.LuBadgeIcon = LuBadge;
exports.LuBadgeIndianRupee = LuBadgeIndianRupee;
exports.LuBadgeIndianRupeeIcon = LuBadgeIndianRupee;
exports.LuBadgeInfo = LuBadgeInfo;
exports.LuBadgeInfoIcon = LuBadgeInfo;
exports.LuBadgeJapaneseYen = LuBadgeJapaneseYen;
exports.LuBadgeJapaneseYenIcon = LuBadgeJapaneseYen;
exports.LuBadgeMinus = LuBadgeMinus;
exports.LuBadgeMinusIcon = LuBadgeMinus;
exports.LuBadgePercent = LuBadgePercent;
exports.LuBadgePercentIcon = LuBadgePercent;
exports.LuBadgePlus = LuBadgePlus;
exports.LuBadgePlusIcon = LuBadgePlus;
exports.LuBadgePoundSterling = LuBadgePoundSterling;
exports.LuBadgePoundSterlingIcon = LuBadgePoundSterling;
exports.LuBadgeRussianRuble = LuBadgeRussianRuble;
exports.LuBadgeRussianRubleIcon = LuBadgeRussianRuble;
exports.LuBadgeSwissFranc = LuBadgeSwissFranc;
exports.LuBadgeSwissFrancIcon = LuBadgeSwissFranc;
exports.LuBadgeX = LuBadgeX;
exports.LuBadgeXIcon = LuBadgeX;
exports.LuBaggageClaim = LuBaggageClaim;
exports.LuBaggageClaimIcon = LuBaggageClaim;
exports.LuBan = LuBan;
exports.LuBanIcon = LuBan;
exports.LuBanana = LuBanana;
exports.LuBananaIcon = LuBanana;
exports.LuBanknote = LuBanknote;
exports.LuBanknoteIcon = LuBanknote;
exports.LuBarChart = LuBarChart;
exports.LuBarChart2 = LuBarChart2;
exports.LuBarChart2Icon = LuBarChart2;
exports.LuBarChart3 = LuBarChart3;
exports.LuBarChart3Icon = LuBarChart3;
exports.LuBarChart4 = LuBarChart4;
exports.LuBarChart4Icon = LuBarChart4;
exports.LuBarChartBig = LuBarChartBig;
exports.LuBarChartBigIcon = LuBarChartBig;
exports.LuBarChartHorizontal = LuBarChartHorizontal;
exports.LuBarChartHorizontalBig = LuBarChartHorizontalBig;
exports.LuBarChartHorizontalBigIcon = LuBarChartHorizontalBig;
exports.LuBarChartHorizontalIcon = LuBarChartHorizontal;
exports.LuBarChartIcon = LuBarChart;
exports.LuBarcode = LuBarcode;
exports.LuBarcodeIcon = LuBarcode;
exports.LuBaseline = LuBaseline;
exports.LuBaselineIcon = LuBaseline;
exports.LuBath = LuBath;
exports.LuBathIcon = LuBath;
exports.LuBattery = LuBattery;
exports.LuBatteryCharging = LuBatteryCharging;
exports.LuBatteryChargingIcon = LuBatteryCharging;
exports.LuBatteryFull = LuBatteryFull;
exports.LuBatteryFullIcon = LuBatteryFull;
exports.LuBatteryIcon = LuBattery;
exports.LuBatteryLow = LuBatteryLow;
exports.LuBatteryLowIcon = LuBatteryLow;
exports.LuBatteryMedium = LuBatteryMedium;
exports.LuBatteryMediumIcon = LuBatteryMedium;
exports.LuBatteryWarning = LuBatteryWarning;
exports.LuBatteryWarningIcon = LuBatteryWarning;
exports.LuBeaker = LuBeaker;
exports.LuBeakerIcon = LuBeaker;
exports.LuBean = LuBean;
exports.LuBeanIcon = LuBean;
exports.LuBeanOff = LuBeanOff;
exports.LuBeanOffIcon = LuBeanOff;
exports.LuBed = LuBed;
exports.LuBedDouble = LuBedDouble;
exports.LuBedDoubleIcon = LuBedDouble;
exports.LuBedIcon = LuBed;
exports.LuBedSingle = LuBedSingle;
exports.LuBedSingleIcon = LuBedSingle;
exports.LuBeef = LuBeef;
exports.LuBeefIcon = LuBeef;
exports.LuBeer = LuBeer;
exports.LuBeerIcon = LuBeer;
exports.LuBell = LuBell;
exports.LuBellDot = LuBellDot;
exports.LuBellDotIcon = LuBellDot;
exports.LuBellElectric = LuBellElectric;
exports.LuBellElectricIcon = LuBellElectric;
exports.LuBellIcon = LuBell;
exports.LuBellMinus = LuBellMinus;
exports.LuBellMinusIcon = LuBellMinus;
exports.LuBellOff = LuBellOff;
exports.LuBellOffIcon = LuBellOff;
exports.LuBellPlus = LuBellPlus;
exports.LuBellPlusIcon = LuBellPlus;
exports.LuBellRing = LuBellRing;
exports.LuBellRingIcon = LuBellRing;
exports.LuBetweenHorizonalEnd = LuBetweenHorizontalEnd;
exports.LuBetweenHorizonalEndIcon = LuBetweenHorizontalEnd;
exports.LuBetweenHorizonalStart = LuBetweenHorizontalStart;
exports.LuBetweenHorizonalStartIcon = LuBetweenHorizontalStart;
exports.LuBetweenHorizontalEnd = LuBetweenHorizontalEnd;
exports.LuBetweenHorizontalEndIcon = LuBetweenHorizontalEnd;
exports.LuBetweenHorizontalStart = LuBetweenHorizontalStart;
exports.LuBetweenHorizontalStartIcon = LuBetweenHorizontalStart;
exports.LuBetweenVerticalEnd = LuBetweenVerticalEnd;
exports.LuBetweenVerticalEndIcon = LuBetweenVerticalEnd;
exports.LuBetweenVerticalStart = LuBetweenVerticalStart;
exports.LuBetweenVerticalStartIcon = LuBetweenVerticalStart;
exports.LuBike = LuBike;
exports.LuBikeIcon = LuBike;
exports.LuBinary = LuBinary;
exports.LuBinaryIcon = LuBinary;
exports.LuBiohazard = LuBiohazard;
exports.LuBiohazardIcon = LuBiohazard;
exports.LuBird = LuBird;
exports.LuBirdIcon = LuBird;
exports.LuBitcoin = LuBitcoin;
exports.LuBitcoinIcon = LuBitcoin;
exports.LuBlend = LuBlend;
exports.LuBlendIcon = LuBlend;
exports.LuBlinds = LuBlinds;
exports.LuBlindsIcon = LuBlinds;
exports.LuBlocks = LuBlocks;
exports.LuBlocksIcon = LuBlocks;
exports.LuBluetooth = LuBluetooth;
exports.LuBluetoothConnected = LuBluetoothConnected;
exports.LuBluetoothConnectedIcon = LuBluetoothConnected;
exports.LuBluetoothIcon = LuBluetooth;
exports.LuBluetoothOff = LuBluetoothOff;
exports.LuBluetoothOffIcon = LuBluetoothOff;
exports.LuBluetoothSearching = LuBluetoothSearching;
exports.LuBluetoothSearchingIcon = LuBluetoothSearching;
exports.LuBold = LuBold;
exports.LuBoldIcon = LuBold;
exports.LuBolt = LuBolt;
exports.LuBoltIcon = LuBolt;
exports.LuBomb = LuBomb;
exports.LuBombIcon = LuBomb;
exports.LuBone = LuBone;
exports.LuBoneIcon = LuBone;
exports.LuBook = LuBook;
exports.LuBookA = LuBookA;
exports.LuBookAIcon = LuBookA;
exports.LuBookAudio = LuBookAudio;
exports.LuBookAudioIcon = LuBookAudio;
exports.LuBookCheck = LuBookCheck;
exports.LuBookCheckIcon = LuBookCheck;
exports.LuBookCopy = LuBookCopy;
exports.LuBookCopyIcon = LuBookCopy;
exports.LuBookDashed = LuBookDashed;
exports.LuBookDashedIcon = LuBookDashed;
exports.LuBookDown = LuBookDown;
exports.LuBookDownIcon = LuBookDown;
exports.LuBookHeadphones = LuBookHeadphones;
exports.LuBookHeadphonesIcon = LuBookHeadphones;
exports.LuBookHeart = LuBookHeart;
exports.LuBookHeartIcon = LuBookHeart;
exports.LuBookIcon = LuBook;
exports.LuBookImage = LuBookImage;
exports.LuBookImageIcon = LuBookImage;
exports.LuBookKey = LuBookKey;
exports.LuBookKeyIcon = LuBookKey;
exports.LuBookLock = LuBookLock;
exports.LuBookLockIcon = LuBookLock;
exports.LuBookMarked = LuBookMarked;
exports.LuBookMarkedIcon = LuBookMarked;
exports.LuBookMinus = LuBookMinus;
exports.LuBookMinusIcon = LuBookMinus;
exports.LuBookOpen = LuBookOpen;
exports.LuBookOpenCheck = LuBookOpenCheck;
exports.LuBookOpenCheckIcon = LuBookOpenCheck;
exports.LuBookOpenIcon = LuBookOpen;
exports.LuBookOpenText = LuBookOpenText;
exports.LuBookOpenTextIcon = LuBookOpenText;
exports.LuBookPlus = LuBookPlus;
exports.LuBookPlusIcon = LuBookPlus;
exports.LuBookTemplate = LuBookDashed;
exports.LuBookTemplateIcon = LuBookDashed;
exports.LuBookText = LuBookText;
exports.LuBookTextIcon = LuBookText;
exports.LuBookType = LuBookType;
exports.LuBookTypeIcon = LuBookType;
exports.LuBookUp = LuBookUp;
exports.LuBookUp2 = LuBookUp2;
exports.LuBookUp2Icon = LuBookUp2;
exports.LuBookUpIcon = LuBookUp;
exports.LuBookUser = LuBookUser;
exports.LuBookUserIcon = LuBookUser;
exports.LuBookX = LuBookX;
exports.LuBookXIcon = LuBookX;
exports.LuBookmark = LuBookmark;
exports.LuBookmarkCheck = LuBookmarkCheck;
exports.LuBookmarkCheckIcon = LuBookmarkCheck;
exports.LuBookmarkIcon = LuBookmark;
exports.LuBookmarkMinus = LuBookmarkMinus;
exports.LuBookmarkMinusIcon = LuBookmarkMinus;
exports.LuBookmarkPlus = LuBookmarkPlus;
exports.LuBookmarkPlusIcon = LuBookmarkPlus;
exports.LuBookmarkX = LuBookmarkX;
exports.LuBookmarkXIcon = LuBookmarkX;
exports.LuBoomBox = LuBoomBox;
exports.LuBoomBoxIcon = LuBoomBox;
exports.LuBot = LuBot;
exports.LuBotIcon = LuBot;
exports.LuBotMessageSquare = LuBotMessageSquare;
exports.LuBotMessageSquareIcon = LuBotMessageSquare;
exports.LuBox = LuBox;
exports.LuBoxIcon = LuBox;
exports.LuBoxSelect = LuBoxSelect;
exports.LuBoxSelectIcon = LuBoxSelect;
exports.LuBoxes = LuBoxes;
exports.LuBoxesIcon = LuBoxes;
exports.LuBraces = LuBraces;
exports.LuBracesIcon = LuBraces;
exports.LuBrackets = LuBrackets;
exports.LuBracketsIcon = LuBrackets;
exports.LuBrain = LuBrain;
exports.LuBrainCircuit = LuBrainCircuit;
exports.LuBrainCircuitIcon = LuBrainCircuit;
exports.LuBrainCog = LuBrainCog;
exports.LuBrainCogIcon = LuBrainCog;
exports.LuBrainIcon = LuBrain;
exports.LuBrickWall = LuBrickWall;
exports.LuBrickWallIcon = LuBrickWall;
exports.LuBriefcase = LuBriefcase;
exports.LuBriefcaseBusiness = LuBriefcaseBusiness;
exports.LuBriefcaseBusinessIcon = LuBriefcaseBusiness;
exports.LuBriefcaseIcon = LuBriefcase;
exports.LuBriefcaseMedical = LuBriefcaseMedical;
exports.LuBriefcaseMedicalIcon = LuBriefcaseMedical;
exports.LuBringToFront = LuBringToFront;
exports.LuBringToFrontIcon = LuBringToFront;
exports.LuBrush = LuBrush;
exports.LuBrushIcon = LuBrush;
exports.LuBug = LuBug;
exports.LuBugIcon = LuBug;
exports.LuBugOff = LuBugOff;
exports.LuBugOffIcon = LuBugOff;
exports.LuBugPlay = LuBugPlay;
exports.LuBugPlayIcon = LuBugPlay;
exports.LuBuilding = LuBuilding;
exports.LuBuilding2 = LuBuilding2;
exports.LuBuilding2Icon = LuBuilding2;
exports.LuBuildingIcon = LuBuilding;
exports.LuBus = LuBus;
exports.LuBusFront = LuBusFront;
exports.LuBusFrontIcon = LuBusFront;
exports.LuBusIcon = LuBus;
exports.LuCable = LuCable;
exports.LuCableCar = LuCableCar;
exports.LuCableCarIcon = LuCableCar;
exports.LuCableIcon = LuCable;
exports.LuCake = LuCake;
exports.LuCakeIcon = LuCake;
exports.LuCakeSlice = LuCakeSlice;
exports.LuCakeSliceIcon = LuCakeSlice;
exports.LuCalculator = LuCalculator;
exports.LuCalculatorIcon = LuCalculator;
exports.LuCalendar = LuCalendar;
exports.LuCalendarCheck = LuCalendarCheck;
exports.LuCalendarCheck2 = LuCalendarCheck2;
exports.LuCalendarCheck2Icon = LuCalendarCheck2;
exports.LuCalendarCheckIcon = LuCalendarCheck;
exports.LuCalendarClock = LuCalendarClock;
exports.LuCalendarClockIcon = LuCalendarClock;
exports.LuCalendarDays = LuCalendarDays;
exports.LuCalendarDaysIcon = LuCalendarDays;
exports.LuCalendarFold = LuCalendarFold;
exports.LuCalendarFoldIcon = LuCalendarFold;
exports.LuCalendarHeart = LuCalendarHeart;
exports.LuCalendarHeartIcon = LuCalendarHeart;
exports.LuCalendarIcon = LuCalendar;
exports.LuCalendarMinus = LuCalendarMinus;
exports.LuCalendarMinus2 = LuCalendarMinus2;
exports.LuCalendarMinus2Icon = LuCalendarMinus2;
exports.LuCalendarMinusIcon = LuCalendarMinus;
exports.LuCalendarOff = LuCalendarOff;
exports.LuCalendarOffIcon = LuCalendarOff;
exports.LuCalendarPlus = LuCalendarPlus;
exports.LuCalendarPlus2 = LuCalendarPlus2;
exports.LuCalendarPlus2Icon = LuCalendarPlus2;
exports.LuCalendarPlusIcon = LuCalendarPlus;
exports.LuCalendarRange = LuCalendarRange;
exports.LuCalendarRangeIcon = LuCalendarRange;
exports.LuCalendarSearch = LuCalendarSearch;
exports.LuCalendarSearchIcon = LuCalendarSearch;
exports.LuCalendarX = LuCalendarX;
exports.LuCalendarX2 = LuCalendarX2;
exports.LuCalendarX2Icon = LuCalendarX2;
exports.LuCalendarXIcon = LuCalendarX;
exports.LuCamera = LuCamera;
exports.LuCameraIcon = LuCamera;
exports.LuCameraOff = LuCameraOff;
exports.LuCameraOffIcon = LuCameraOff;
exports.LuCandlestickChart = LuCandlestickChart;
exports.LuCandlestickChartIcon = LuCandlestickChart;
exports.LuCandy = LuCandy;
exports.LuCandyCane = LuCandyCane;
exports.LuCandyCaneIcon = LuCandyCane;
exports.LuCandyIcon = LuCandy;
exports.LuCandyOff = LuCandyOff;
exports.LuCandyOffIcon = LuCandyOff;
exports.LuCannabis = LuCannabis;
exports.LuCannabisIcon = LuCannabis;
exports.LuCaptions = LuCaptions;
exports.LuCaptionsIcon = LuCaptions;
exports.LuCaptionsOff = LuCaptionsOff;
exports.LuCaptionsOffIcon = LuCaptionsOff;
exports.LuCar = LuCar;
exports.LuCarFront = LuCarFront;
exports.LuCarFrontIcon = LuCarFront;
exports.LuCarIcon = LuCar;
exports.LuCarTaxiFront = LuCarTaxiFront;
exports.LuCarTaxiFrontIcon = LuCarTaxiFront;
exports.LuCaravan = LuCaravan;
exports.LuCaravanIcon = LuCaravan;
exports.LuCarrot = LuCarrot;
exports.LuCarrotIcon = LuCarrot;
exports.LuCaseLower = LuCaseLower;
exports.LuCaseLowerIcon = LuCaseLower;
exports.LuCaseSensitive = LuCaseSensitive;
exports.LuCaseSensitiveIcon = LuCaseSensitive;
exports.LuCaseUpper = LuCaseUpper;
exports.LuCaseUpperIcon = LuCaseUpper;
exports.LuCassetteTape = LuCassetteTape;
exports.LuCassetteTapeIcon = LuCassetteTape;
exports.LuCast = LuCast;
exports.LuCastIcon = LuCast;
exports.LuCastle = LuCastle;
exports.LuCastleIcon = LuCastle;
exports.LuCat = LuCat;
exports.LuCatIcon = LuCat;
exports.LuCctv = LuCctv;
exports.LuCctvIcon = LuCctv;
exports.LuCheck = LuCheck;
exports.LuCheckCheck = LuCheckCheck;
exports.LuCheckCheckIcon = LuCheckCheck;
exports.LuCheckCircle = LuCircleCheckBig;
exports.LuCheckCircle2 = LuCircleCheck;
exports.LuCheckCircle2Icon = LuCircleCheck;
exports.LuCheckCircleIcon = LuCircleCheckBig;
exports.LuCheckIcon = LuCheck;
exports.LuCheckSquare = LuSquareCheckBig;
exports.LuCheckSquare2 = LuSquareCheck;
exports.LuCheckSquare2Icon = LuSquareCheck;
exports.LuCheckSquareIcon = LuSquareCheckBig;
exports.LuChefHat = LuChefHat;
exports.LuChefHatIcon = LuChefHat;
exports.LuCherry = LuCherry;
exports.LuCherryIcon = LuCherry;
exports.LuChevronDown = LuChevronDown;
exports.LuChevronDownCircle = LuCircleChevronDown;
exports.LuChevronDownCircleIcon = LuCircleChevronDown;
exports.LuChevronDownIcon = LuChevronDown;
exports.LuChevronDownSquare = LuSquareChevronDown;
exports.LuChevronDownSquareIcon = LuSquareChevronDown;
exports.LuChevronFirst = LuChevronFirst;
exports.LuChevronFirstIcon = LuChevronFirst;
exports.LuChevronLast = LuChevronLast;
exports.LuChevronLastIcon = LuChevronLast;
exports.LuChevronLeft = LuChevronLeft;
exports.LuChevronLeftCircle = LuCircleChevronLeft;
exports.LuChevronLeftCircleIcon = LuCircleChevronLeft;
exports.LuChevronLeftIcon = LuChevronLeft;
exports.LuChevronLeftSquare = LuSquareChevronLeft;
exports.LuChevronLeftSquareIcon = LuSquareChevronLeft;
exports.LuChevronRight = LuChevronRight;
exports.LuChevronRightCircle = LuCircleChevronRight;
exports.LuChevronRightCircleIcon = LuCircleChevronRight;
exports.LuChevronRightIcon = LuChevronRight;
exports.LuChevronRightSquare = LuSquareChevronRight;
exports.LuChevronRightSquareIcon = LuSquareChevronRight;
exports.LuChevronUp = LuChevronUp;
exports.LuChevronUpCircle = LuCircleChevronUp;
exports.LuChevronUpCircleIcon = LuCircleChevronUp;
exports.LuChevronUpIcon = LuChevronUp;
exports.LuChevronUpSquare = LuSquareChevronUp;
exports.LuChevronUpSquareIcon = LuSquareChevronUp;
exports.LuChevronsDown = LuChevronsDown;
exports.LuChevronsDownIcon = LuChevronsDown;
exports.LuChevronsDownUp = LuChevronsDownUp;
exports.LuChevronsDownUpIcon = LuChevronsDownUp;
exports.LuChevronsLeft = LuChevronsLeft;
exports.LuChevronsLeftIcon = LuChevronsLeft;
exports.LuChevronsLeftRight = LuChevronsLeftRight;
exports.LuChevronsLeftRightIcon = LuChevronsLeftRight;
exports.LuChevronsRight = LuChevronsRight;
exports.LuChevronsRightIcon = LuChevronsRight;
exports.LuChevronsRightLeft = LuChevronsRightLeft;
exports.LuChevronsRightLeftIcon = LuChevronsRightLeft;
exports.LuChevronsUp = LuChevronsUp;
exports.LuChevronsUpDown = LuChevronsUpDown;
exports.LuChevronsUpDownIcon = LuChevronsUpDown;
exports.LuChevronsUpIcon = LuChevronsUp;
exports.LuChrome = LuChrome;
exports.LuChromeIcon = LuChrome;
exports.LuChurch = LuChurch;
exports.LuChurchIcon = LuChurch;
exports.LuCigarette = LuCigarette;
exports.LuCigaretteIcon = LuCigarette;
exports.LuCigaretteOff = LuCigaretteOff;
exports.LuCigaretteOffIcon = LuCigaretteOff;
exports.LuCircle = LuCircle;
exports.LuCircleAlert = LuCircleAlert;
exports.LuCircleAlertIcon = LuCircleAlert;
exports.LuCircleArrowDown = LuCircleArrowDown;
exports.LuCircleArrowDownIcon = LuCircleArrowDown;
exports.LuCircleArrowLeft = LuCircleArrowLeft;
exports.LuCircleArrowLeftIcon = LuCircleArrowLeft;
exports.LuCircleArrowOutDownLeft = LuCircleArrowOutDownLeft;
exports.LuCircleArrowOutDownLeftIcon = LuCircleArrowOutDownLeft;
exports.LuCircleArrowOutDownRight = LuCircleArrowOutDownRight;
exports.LuCircleArrowOutDownRightIcon = LuCircleArrowOutDownRight;
exports.LuCircleArrowOutUpLeft = LuCircleArrowOutUpLeft;
exports.LuCircleArrowOutUpLeftIcon = LuCircleArrowOutUpLeft;
exports.LuCircleArrowOutUpRight = LuCircleArrowOutUpRight;
exports.LuCircleArrowOutUpRightIcon = LuCircleArrowOutUpRight;
exports.LuCircleArrowRight = LuCircleArrowRight;
exports.LuCircleArrowRightIcon = LuCircleArrowRight;
exports.LuCircleArrowUp = LuCircleArrowUp;
exports.LuCircleArrowUpIcon = LuCircleArrowUp;
exports.LuCircleCheck = LuCircleCheck;
exports.LuCircleCheckBig = LuCircleCheckBig;
exports.LuCircleCheckBigIcon = LuCircleCheckBig;
exports.LuCircleCheckIcon = LuCircleCheck;
exports.LuCircleChevronDown = LuCircleChevronDown;
exports.LuCircleChevronDownIcon = LuCircleChevronDown;
exports.LuCircleChevronLeft = LuCircleChevronLeft;
exports.LuCircleChevronLeftIcon = LuCircleChevronLeft;
exports.LuCircleChevronRight = LuCircleChevronRight;
exports.LuCircleChevronRightIcon = LuCircleChevronRight;
exports.LuCircleChevronUp = LuCircleChevronUp;
exports.LuCircleChevronUpIcon = LuCircleChevronUp;
exports.LuCircleDashed = LuCircleDashed;
exports.LuCircleDashedIcon = LuCircleDashed;
exports.LuCircleDivide = LuCircleDivide;
exports.LuCircleDivideIcon = LuCircleDivide;
exports.LuCircleDollarSign = LuCircleDollarSign;
exports.LuCircleDollarSignIcon = LuCircleDollarSign;
exports.LuCircleDot = LuCircleDot;
exports.LuCircleDotDashed = LuCircleDotDashed;
exports.LuCircleDotDashedIcon = LuCircleDotDashed;
exports.LuCircleDotIcon = LuCircleDot;
exports.LuCircleEllipsis = LuCircleEllipsis;
exports.LuCircleEllipsisIcon = LuCircleEllipsis;
exports.LuCircleEqual = LuCircleEqual;
exports.LuCircleEqualIcon = LuCircleEqual;
exports.LuCircleFadingPlus = LuCircleFadingPlus;
exports.LuCircleFadingPlusIcon = LuCircleFadingPlus;
exports.LuCircleGauge = LuCircleGauge;
exports.LuCircleGaugeIcon = LuCircleGauge;
exports.LuCircleHelp = LuCircleHelp;
exports.LuCircleHelpIcon = LuCircleHelp;
exports.LuCircleIcon = LuCircle;
exports.LuCircleMinus = LuCircleMinus;
exports.LuCircleMinusIcon = LuCircleMinus;
exports.LuCircleOff = LuCircleOff;
exports.LuCircleOffIcon = LuCircleOff;
exports.LuCircleParking = LuCircleParking;
exports.LuCircleParkingIcon = LuCircleParking;
exports.LuCircleParkingOff = LuCircleParkingOff;
exports.LuCircleParkingOffIcon = LuCircleParkingOff;
exports.LuCirclePause = LuCirclePause;
exports.LuCirclePauseIcon = LuCirclePause;
exports.LuCirclePercent = LuCirclePercent;
exports.LuCirclePercentIcon = LuCirclePercent;
exports.LuCirclePlay = LuCirclePlay;
exports.LuCirclePlayIcon = LuCirclePlay;
exports.LuCirclePlus = LuCirclePlus;
exports.LuCirclePlusIcon = LuCirclePlus;
exports.LuCirclePower = LuCirclePower;
exports.LuCirclePowerIcon = LuCirclePower;
exports.LuCircleSlash = LuCircleSlash;
exports.LuCircleSlash2 = LuCircleSlash2;
exports.LuCircleSlash2Icon = LuCircleSlash2;
exports.LuCircleSlashIcon = LuCircleSlash;
exports.LuCircleSlashed = LuCircleSlash2;
exports.LuCircleSlashedIcon = LuCircleSlash2;
exports.LuCircleStop = LuCircleStop;
exports.LuCircleStopIcon = LuCircleStop;
exports.LuCircleUser = LuCircleUser;
exports.LuCircleUserIcon = LuCircleUser;
exports.LuCircleUserRound = LuCircleUserRound;
exports.LuCircleUserRoundIcon = LuCircleUserRound;
exports.LuCircleX = LuCircleX;
exports.LuCircleXIcon = LuCircleX;
exports.LuCircuitBoard = LuCircuitBoard;
exports.LuCircuitBoardIcon = LuCircuitBoard;
exports.LuCitrus = LuCitrus;
exports.LuCitrusIcon = LuCitrus;
exports.LuClapperboard = LuClapperboard;
exports.LuClapperboardIcon = LuClapperboard;
exports.LuClipboard = LuClipboard;
exports.LuClipboardCheck = LuClipboardCheck;
exports.LuClipboardCheckIcon = LuClipboardCheck;
exports.LuClipboardCopy = LuClipboardCopy;
exports.LuClipboardCopyIcon = LuClipboardCopy;
exports.LuClipboardEdit = LuClipboardPen;
exports.LuClipboardEditIcon = LuClipboardPen;
exports.LuClipboardIcon = LuClipboard;
exports.LuClipboardList = LuClipboardList;
exports.LuClipboardListIcon = LuClipboardList;
exports.LuClipboardMinus = LuClipboardMinus;
exports.LuClipboardMinusIcon = LuClipboardMinus;
exports.LuClipboardPaste = LuClipboardPaste;
exports.LuClipboardPasteIcon = LuClipboardPaste;
exports.LuClipboardPen = LuClipboardPen;
exports.LuClipboardPenIcon = LuClipboardPen;
exports.LuClipboardPenLine = LuClipboardPenLine;
exports.LuClipboardPenLineIcon = LuClipboardPenLine;
exports.LuClipboardPlus = LuClipboardPlus;
exports.LuClipboardPlusIcon = LuClipboardPlus;
exports.LuClipboardSignature = LuClipboardPenLine;
exports.LuClipboardSignatureIcon = LuClipboardPenLine;
exports.LuClipboardType = LuClipboardType;
exports.LuClipboardTypeIcon = LuClipboardType;
exports.LuClipboardX = LuClipboardX;
exports.LuClipboardXIcon = LuClipboardX;
exports.LuClock = LuClock;
exports.LuClock1 = LuClock1;
exports.LuClock10 = LuClock10;
exports.LuClock10Icon = LuClock10;
exports.LuClock11 = LuClock11;
exports.LuClock11Icon = LuClock11;
exports.LuClock12 = LuClock12;
exports.LuClock12Icon = LuClock12;
exports.LuClock1Icon = LuClock1;
exports.LuClock2 = LuClock2;
exports.LuClock2Icon = LuClock2;
exports.LuClock3 = LuClock3;
exports.LuClock3Icon = LuClock3;
exports.LuClock4 = LuClock4;
exports.LuClock4Icon = LuClock4;
exports.LuClock5 = LuClock5;
exports.LuClock5Icon = LuClock5;
exports.LuClock6 = LuClock6;
exports.LuClock6Icon = LuClock6;
exports.LuClock7 = LuClock7;
exports.LuClock7Icon = LuClock7;
exports.LuClock8 = LuClock8;
exports.LuClock8Icon = LuClock8;
exports.LuClock9 = LuClock9;
exports.LuClock9Icon = LuClock9;
exports.LuClockIcon = LuClock;
exports.LuCloud = LuCloud;
exports.LuCloudCog = LuCloudCog;
exports.LuCloudCogIcon = LuCloudCog;
exports.LuCloudDownload = LuCloudDownload;
exports.LuCloudDownloadIcon = LuCloudDownload;
exports.LuCloudDrizzle = LuCloudDrizzle;
exports.LuCloudDrizzleIcon = LuCloudDrizzle;
exports.LuCloudFog = LuCloudFog;
exports.LuCloudFogIcon = LuCloudFog;
exports.LuCloudHail = LuCloudHail;
exports.LuCloudHailIcon = LuCloudHail;
exports.LuCloudIcon = LuCloud;
exports.LuCloudLightning = LuCloudLightning;
exports.LuCloudLightningIcon = LuCloudLightning;
exports.LuCloudMoon = LuCloudMoon;
exports.LuCloudMoonIcon = LuCloudMoon;
exports.LuCloudMoonRain = LuCloudMoonRain;
exports.LuCloudMoonRainIcon = LuCloudMoonRain;
exports.LuCloudOff = LuCloudOff;
exports.LuCloudOffIcon = LuCloudOff;
exports.LuCloudRain = LuCloudRain;
exports.LuCloudRainIcon = LuCloudRain;
exports.LuCloudRainWind = LuCloudRainWind;
exports.LuCloudRainWindIcon = LuCloudRainWind;
exports.LuCloudSnow = LuCloudSnow;
exports.LuCloudSnowIcon = LuCloudSnow;
exports.LuCloudSun = LuCloudSun;
exports.LuCloudSunIcon = LuCloudSun;
exports.LuCloudSunRain = LuCloudSunRain;
exports.LuCloudSunRainIcon = LuCloudSunRain;
exports.LuCloudUpload = LuCloudUpload;
exports.LuCloudUploadIcon = LuCloudUpload;
exports.LuCloudy = LuCloudy;
exports.LuCloudyIcon = LuCloudy;
exports.LuClover = LuClover;
exports.LuCloverIcon = LuClover;
exports.LuClub = LuClub;
exports.LuClubIcon = LuClub;
exports.LuCode = LuCode;
exports.LuCode2 = LuCodeXml;
exports.LuCode2Icon = LuCodeXml;
exports.LuCodeIcon = LuCode;
exports.LuCodeSquare = LuSquareCode;
exports.LuCodeSquareIcon = LuSquareCode;
exports.LuCodeXml = LuCodeXml;
exports.LuCodeXmlIcon = LuCodeXml;
exports.LuCodepen = LuCodepen;
exports.LuCodepenIcon = LuCodepen;
exports.LuCodesandbox = LuCodesandbox;
exports.LuCodesandboxIcon = LuCodesandbox;
exports.LuCoffee = LuCoffee;
exports.LuCoffeeIcon = LuCoffee;
exports.LuCog = LuCog;
exports.LuCogIcon = LuCog;
exports.LuCoins = LuCoins;
exports.LuCoinsIcon = LuCoins;
exports.LuColumns = LuColumns2;
exports.LuColumns2 = LuColumns2;
exports.LuColumns2Icon = LuColumns2;
exports.LuColumns3 = LuColumns3;
exports.LuColumns3Icon = LuColumns3;
exports.LuColumns4 = LuColumns4;
exports.LuColumns4Icon = LuColumns4;
exports.LuColumnsIcon = LuColumns2;
exports.LuCombine = LuCombine;
exports.LuCombineIcon = LuCombine;
exports.LuCommand = LuCommand;
exports.LuCommandIcon = LuCommand;
exports.LuCompass = LuCompass;
exports.LuCompassIcon = LuCompass;
exports.LuComponent = LuComponent;
exports.LuComponentIcon = LuComponent;
exports.LuComputer = LuComputer;
exports.LuComputerIcon = LuComputer;
exports.LuConciergeBell = LuConciergeBell;
exports.LuConciergeBellIcon = LuConciergeBell;
exports.LuCone = LuCone;
exports.LuConeIcon = LuCone;
exports.LuConstruction = LuConstruction;
exports.LuConstructionIcon = LuConstruction;
exports.LuContact = LuContact;
exports.LuContact2 = LuContactRound;
exports.LuContact2Icon = LuContactRound;
exports.LuContactIcon = LuContact;
exports.LuContactRound = LuContactRound;
exports.LuContactRoundIcon = LuContactRound;
exports.LuContainer = LuContainer;
exports.LuContainerIcon = LuContainer;
exports.LuContrast = LuContrast;
exports.LuContrastIcon = LuContrast;
exports.LuCookie = LuCookie;
exports.LuCookieIcon = LuCookie;
exports.LuCookingPot = LuCookingPot;
exports.LuCookingPotIcon = LuCookingPot;
exports.LuCopy = LuCopy;
exports.LuCopyCheck = LuCopyCheck;
exports.LuCopyCheckIcon = LuCopyCheck;
exports.LuCopyIcon = LuCopy;
exports.LuCopyMinus = LuCopyMinus;
exports.LuCopyMinusIcon = LuCopyMinus;
exports.LuCopyPlus = LuCopyPlus;
exports.LuCopyPlusIcon = LuCopyPlus;
exports.LuCopySlash = LuCopySlash;
exports.LuCopySlashIcon = LuCopySlash;
exports.LuCopyX = LuCopyX;
exports.LuCopyXIcon = LuCopyX;
exports.LuCopyleft = LuCopyleft;
exports.LuCopyleftIcon = LuCopyleft;
exports.LuCopyright = LuCopyright;
exports.LuCopyrightIcon = LuCopyright;
exports.LuCornerDownLeft = LuCornerDownLeft;
exports.LuCornerDownLeftIcon = LuCornerDownLeft;
exports.LuCornerDownRight = LuCornerDownRight;
exports.LuCornerDownRightIcon = LuCornerDownRight;
exports.LuCornerLeftDown = LuCornerLeftDown;
exports.LuCornerLeftDownIcon = LuCornerLeftDown;
exports.LuCornerLeftUp = LuCornerLeftUp;
exports.LuCornerLeftUpIcon = LuCornerLeftUp;
exports.LuCornerRightDown = LuCornerRightDown;
exports.LuCornerRightDownIcon = LuCornerRightDown;
exports.LuCornerRightUp = LuCornerRightUp;
exports.LuCornerRightUpIcon = LuCornerRightUp;
exports.LuCornerUpLeft = LuCornerUpLeft;
exports.LuCornerUpLeftIcon = LuCornerUpLeft;
exports.LuCornerUpRight = LuCornerUpRight;
exports.LuCornerUpRightIcon = LuCornerUpRight;
exports.LuCpu = LuCpu;
exports.LuCpuIcon = LuCpu;
exports.LuCreativeCommons = LuCreativeCommons;
exports.LuCreativeCommonsIcon = LuCreativeCommons;
exports.LuCreditCard = LuCreditCard;
exports.LuCreditCardIcon = LuCreditCard;
exports.LuCroissant = LuCroissant;
exports.LuCroissantIcon = LuCroissant;
exports.LuCrop = LuCrop;
exports.LuCropIcon = LuCrop;
exports.LuCross = LuCross;
exports.LuCrossIcon = LuCross;
exports.LuCrosshair = LuCrosshair;
exports.LuCrosshairIcon = LuCrosshair;
exports.LuCrown = LuCrown;
exports.LuCrownIcon = LuCrown;
exports.LuCuboid = LuCuboid;
exports.LuCuboidIcon = LuCuboid;
exports.LuCupSoda = LuCupSoda;
exports.LuCupSodaIcon = LuCupSoda;
exports.LuCurlyBraces = LuBraces;
exports.LuCurlyBracesIcon = LuBraces;
exports.LuCurrency = LuCurrency;
exports.LuCurrencyIcon = LuCurrency;
exports.LuCylinder = LuCylinder;
exports.LuCylinderIcon = LuCylinder;
exports.LuDatabase = LuDatabase;
exports.LuDatabaseBackup = LuDatabaseBackup;
exports.LuDatabaseBackupIcon = LuDatabaseBackup;
exports.LuDatabaseIcon = LuDatabase;
exports.LuDatabaseZap = LuDatabaseZap;
exports.LuDatabaseZapIcon = LuDatabaseZap;
exports.LuDelete = LuDelete;
exports.LuDeleteIcon = LuDelete;
exports.LuDessert = LuDessert;
exports.LuDessertIcon = LuDessert;
exports.LuDiameter = LuDiameter;
exports.LuDiameterIcon = LuDiameter;
exports.LuDiamond = LuDiamond;
exports.LuDiamondIcon = LuDiamond;
exports.LuDiamondPercent = LuDiamondPercent;
exports.LuDiamondPercentIcon = LuDiamondPercent;
exports.LuDice1 = LuDice1;
exports.LuDice1Icon = LuDice1;
exports.LuDice2 = LuDice2;
exports.LuDice2Icon = LuDice2;
exports.LuDice3 = LuDice3;
exports.LuDice3Icon = LuDice3;
exports.LuDice4 = LuDice4;
exports.LuDice4Icon = LuDice4;
exports.LuDice5 = LuDice5;
exports.LuDice5Icon = LuDice5;
exports.LuDice6 = LuDice6;
exports.LuDice6Icon = LuDice6;
exports.LuDices = LuDices;
exports.LuDicesIcon = LuDices;
exports.LuDiff = LuDiff;
exports.LuDiffIcon = LuDiff;
exports.LuDisc = LuDisc;
exports.LuDisc2 = LuDisc2;
exports.LuDisc2Icon = LuDisc2;
exports.LuDisc3 = LuDisc3;
exports.LuDisc3Icon = LuDisc3;
exports.LuDiscAlbum = LuDiscAlbum;
exports.LuDiscAlbumIcon = LuDiscAlbum;
exports.LuDiscIcon = LuDisc;
exports.LuDivide = LuDivide;
exports.LuDivideCircle = LuCircleDivide;
exports.LuDivideCircleIcon = LuCircleDivide;
exports.LuDivideIcon = LuDivide;
exports.LuDivideSquare = LuSquareDivide;
exports.LuDivideSquareIcon = LuSquareDivide;
exports.LuDna = LuDna;
exports.LuDnaIcon = LuDna;
exports.LuDnaOff = LuDnaOff;
exports.LuDnaOffIcon = LuDnaOff;
exports.LuDock = LuDock;
exports.LuDockIcon = LuDock;
exports.LuDog = LuDog;
exports.LuDogIcon = LuDog;
exports.LuDollarSign = LuDollarSign;
exports.LuDollarSignIcon = LuDollarSign;
exports.LuDonut = LuDonut;
exports.LuDonutIcon = LuDonut;
exports.LuDoorClosed = LuDoorClosed;
exports.LuDoorClosedIcon = LuDoorClosed;
exports.LuDoorOpen = LuDoorOpen;
exports.LuDoorOpenIcon = LuDoorOpen;
exports.LuDot = LuDot;
exports.LuDotIcon = LuDot;
exports.LuDotSquare = LuSquareDot;
exports.LuDotSquareIcon = LuSquareDot;
exports.LuDownload = LuDownload;
exports.LuDownloadCloud = LuCloudDownload;
exports.LuDownloadCloudIcon = LuCloudDownload;
exports.LuDownloadIcon = LuDownload;
exports.LuDraftingCompass = LuDraftingCompass;
exports.LuDraftingCompassIcon = LuDraftingCompass;
exports.LuDrama = LuDrama;
exports.LuDramaIcon = LuDrama;
exports.LuDribbble = LuDribbble;
exports.LuDribbbleIcon = LuDribbble;
exports.LuDrill = LuDrill;
exports.LuDrillIcon = LuDrill;
exports.LuDroplet = LuDroplet;
exports.LuDropletIcon = LuDroplet;
exports.LuDroplets = LuDroplets;
exports.LuDropletsIcon = LuDroplets;
exports.LuDrum = LuDrum;
exports.LuDrumIcon = LuDrum;
exports.LuDrumstick = LuDrumstick;
exports.LuDrumstickIcon = LuDrumstick;
exports.LuDumbbell = LuDumbbell;
exports.LuDumbbellIcon = LuDumbbell;
exports.LuEar = LuEar;
exports.LuEarIcon = LuEar;
exports.LuEarOff = LuEarOff;
exports.LuEarOffIcon = LuEarOff;
exports.LuEarth = LuEarth;
exports.LuEarthIcon = LuEarth;
exports.LuEarthLock = LuEarthLock;
exports.LuEarthLockIcon = LuEarthLock;
exports.LuEclipse = LuEclipse;
exports.LuEclipseIcon = LuEclipse;
exports.LuEdit = LuSquarePen;
exports.LuEdit2 = LuPen;
exports.LuEdit2Icon = LuPen;
exports.LuEdit3 = LuPenLine;
exports.LuEdit3Icon = LuPenLine;
exports.LuEditIcon = LuSquarePen;
exports.LuEgg = LuEgg;
exports.LuEggFried = LuEggFried;
exports.LuEggFriedIcon = LuEggFried;
exports.LuEggIcon = LuEgg;
exports.LuEggOff = LuEggOff;
exports.LuEggOffIcon = LuEggOff;
exports.LuEllipsis = LuEllipsis;
exports.LuEllipsisIcon = LuEllipsis;
exports.LuEllipsisVertical = LuEllipsisVertical;
exports.LuEllipsisVerticalIcon = LuEllipsisVertical;
exports.LuEqual = LuEqual;
exports.LuEqualIcon = LuEqual;
exports.LuEqualNot = LuEqualNot;
exports.LuEqualNotIcon = LuEqualNot;
exports.LuEqualSquare = LuSquareEqual;
exports.LuEqualSquareIcon = LuSquareEqual;
exports.LuEraser = LuEraser;
exports.LuEraserIcon = LuEraser;
exports.LuEuro = LuEuro;
exports.LuEuroIcon = LuEuro;
exports.LuExpand = LuExpand;
exports.LuExpandIcon = LuExpand;
exports.LuExternalLink = LuExternalLink;
exports.LuExternalLinkIcon = LuExternalLink;
exports.LuEye = LuEye;
exports.LuEyeIcon = LuEye;
exports.LuEyeOff = LuEyeOff;
exports.LuEyeOffIcon = LuEyeOff;
exports.LuFacebook = LuFacebook;
exports.LuFacebookIcon = LuFacebook;
exports.LuFactory = LuFactory;
exports.LuFactoryIcon = LuFactory;
exports.LuFan = LuFan;
exports.LuFanIcon = LuFan;
exports.LuFastForward = LuFastForward;
exports.LuFastForwardIcon = LuFastForward;
exports.LuFeather = LuFeather;
exports.LuFeatherIcon = LuFeather;
exports.LuFence = LuFence;
exports.LuFenceIcon = LuFence;
exports.LuFerrisWheel = LuFerrisWheel;
exports.LuFerrisWheelIcon = LuFerrisWheel;
exports.LuFigma = LuFigma;
exports.LuFigmaIcon = LuFigma;
exports.LuFile = LuFile;
exports.LuFileArchive = LuFileArchive;
exports.LuFileArchiveIcon = LuFileArchive;
exports.LuFileAudio = LuFileAudio;
exports.LuFileAudio2 = LuFileAudio2;
exports.LuFileAudio2Icon = LuFileAudio2;
exports.LuFileAudioIcon = LuFileAudio;
exports.LuFileAxis3D = LuFileAxis3d;
exports.LuFileAxis3DIcon = LuFileAxis3d;
exports.LuFileAxis3d = LuFileAxis3d;
exports.LuFileAxis3dIcon = LuFileAxis3d;
exports.LuFileBadge = LuFileBadge;
exports.LuFileBadge2 = LuFileBadge2;
exports.LuFileBadge2Icon = LuFileBadge2;
exports.LuFileBadgeIcon = LuFileBadge;
exports.LuFileBarChart = LuFileBarChart;
exports.LuFileBarChart2 = LuFileBarChart2;
exports.LuFileBarChart2Icon = LuFileBarChart2;
exports.LuFileBarChartIcon = LuFileBarChart;
exports.LuFileBox = LuFileBox;
exports.LuFileBoxIcon = LuFileBox;
exports.LuFileCheck = LuFileCheck;
exports.LuFileCheck2 = LuFileCheck2;
exports.LuFileCheck2Icon = LuFileCheck2;
exports.LuFileCheckIcon = LuFileCheck;
exports.LuFileClock = LuFileClock;
exports.LuFileClockIcon = LuFileClock;
exports.LuFileCode = LuFileCode;
exports.LuFileCode2 = LuFileCode2;
exports.LuFileCode2Icon = LuFileCode2;
exports.LuFileCodeIcon = LuFileCode;
exports.LuFileCog = LuFileCog;
exports.LuFileCog2 = LuFileCog;
exports.LuFileCog2Icon = LuFileCog;
exports.LuFileCogIcon = LuFileCog;
exports.LuFileDiff = LuFileDiff;
exports.LuFileDiffIcon = LuFileDiff;
exports.LuFileDigit = LuFileDigit;
exports.LuFileDigitIcon = LuFileDigit;
exports.LuFileDown = LuFileDown;
exports.LuFileDownIcon = LuFileDown;
exports.LuFileEdit = LuFilePen;
exports.LuFileEditIcon = LuFilePen;
exports.LuFileHeart = LuFileHeart;
exports.LuFileHeartIcon = LuFileHeart;
exports.LuFileIcon = LuFile;
exports.LuFileImage = LuFileImage;
exports.LuFileImageIcon = LuFileImage;
exports.LuFileInput = LuFileInput;
exports.LuFileInputIcon = LuFileInput;
exports.LuFileJson = LuFileJson;
exports.LuFileJson2 = LuFileJson2;
exports.LuFileJson2Icon = LuFileJson2;
exports.LuFileJsonIcon = LuFileJson;
exports.LuFileKey = LuFileKey;
exports.LuFileKey2 = LuFileKey2;
exports.LuFileKey2Icon = LuFileKey2;
exports.LuFileKeyIcon = LuFileKey;
exports.LuFileLineChart = LuFileLineChart;
exports.LuFileLineChartIcon = LuFileLineChart;
exports.LuFileLock = LuFileLock;
exports.LuFileLock2 = LuFileLock2;
exports.LuFileLock2Icon = LuFileLock2;
exports.LuFileLockIcon = LuFileLock;
exports.LuFileMinus = LuFileMinus;
exports.LuFileMinus2 = LuFileMinus2;
exports.LuFileMinus2Icon = LuFileMinus2;
exports.LuFileMinusIcon = LuFileMinus;
exports.LuFileMusic = LuFileMusic;
exports.LuFileMusicIcon = LuFileMusic;
exports.LuFileOutput = LuFileOutput;
exports.LuFileOutputIcon = LuFileOutput;
exports.LuFilePen = LuFilePen;
exports.LuFilePenIcon = LuFilePen;
exports.LuFilePenLine = LuFilePenLine;
exports.LuFilePenLineIcon = LuFilePenLine;
exports.LuFilePieChart = LuFilePieChart;
exports.LuFilePieChartIcon = LuFilePieChart;
exports.LuFilePlus = LuFilePlus;
exports.LuFilePlus2 = LuFilePlus2;
exports.LuFilePlus2Icon = LuFilePlus2;
exports.LuFilePlusIcon = LuFilePlus;
exports.LuFileQuestion = LuFileQuestion;
exports.LuFileQuestionIcon = LuFileQuestion;
exports.LuFileScan = LuFileScan;
exports.LuFileScanIcon = LuFileScan;
exports.LuFileSearch = LuFileSearch;
exports.LuFileSearch2 = LuFileSearch2;
exports.LuFileSearch2Icon = LuFileSearch2;
exports.LuFileSearchIcon = LuFileSearch;
exports.LuFileSignature = LuFilePenLine;
exports.LuFileSignatureIcon = LuFilePenLine;
exports.LuFileSliders = LuFileSliders;
exports.LuFileSlidersIcon = LuFileSliders;
exports.LuFileSpreadsheet = LuFileSpreadsheet;
exports.LuFileSpreadsheetIcon = LuFileSpreadsheet;
exports.LuFileStack = LuFileStack;
exports.LuFileStackIcon = LuFileStack;
exports.LuFileSymlink = LuFileSymlink;
exports.LuFileSymlinkIcon = LuFileSymlink;
exports.LuFileTerminal = LuFileTerminal;
exports.LuFileTerminalIcon = LuFileTerminal;
exports.LuFileText = LuFileText;
exports.LuFileTextIcon = LuFileText;
exports.LuFileType = LuFileType;
exports.LuFileType2 = LuFileType2;
exports.LuFileType2Icon = LuFileType2;
exports.LuFileTypeIcon = LuFileType;
exports.LuFileUp = LuFileUp;
exports.LuFileUpIcon = LuFileUp;
exports.LuFileVideo = LuFileVideo;
exports.LuFileVideo2 = LuFileVideo2;
exports.LuFileVideo2Icon = LuFileVideo2;
exports.LuFileVideoIcon = LuFileVideo;
exports.LuFileVolume = LuFileVolume;
exports.LuFileVolume2 = LuFileVolume2;
exports.LuFileVolume2Icon = LuFileVolume2;
exports.LuFileVolumeIcon = LuFileVolume;
exports.LuFileWarning = LuFileWarning;
exports.LuFileWarningIcon = LuFileWarning;
exports.LuFileX = LuFileX;
exports.LuFileX2 = LuFileX2;
exports.LuFileX2Icon = LuFileX2;
exports.LuFileXIcon = LuFileX;
exports.LuFiles = LuFiles;
exports.LuFilesIcon = LuFiles;
exports.LuFilm = LuFilm;
exports.LuFilmIcon = LuFilm;
exports.LuFilter = LuFilter;
exports.LuFilterIcon = LuFilter;
exports.LuFilterX = LuFilterX;
exports.LuFilterXIcon = LuFilterX;
exports.LuFingerprint = LuFingerprint;
exports.LuFingerprintIcon = LuFingerprint;
exports.LuFireExtinguisher = LuFireExtinguisher;
exports.LuFireExtinguisherIcon = LuFireExtinguisher;
exports.LuFish = LuFish;
exports.LuFishIcon = LuFish;
exports.LuFishOff = LuFishOff;
exports.LuFishOffIcon = LuFishOff;
exports.LuFishSymbol = LuFishSymbol;
exports.LuFishSymbolIcon = LuFishSymbol;
exports.LuFlag = LuFlag;
exports.LuFlagIcon = LuFlag;
exports.LuFlagOff = LuFlagOff;
exports.LuFlagOffIcon = LuFlagOff;
exports.LuFlagTriangleLeft = LuFlagTriangleLeft;
exports.LuFlagTriangleLeftIcon = LuFlagTriangleLeft;
exports.LuFlagTriangleRight = LuFlagTriangleRight;
exports.LuFlagTriangleRightIcon = LuFlagTriangleRight;
exports.LuFlame = LuFlame;
exports.LuFlameIcon = LuFlame;
exports.LuFlameKindling = LuFlameKindling;
exports.LuFlameKindlingIcon = LuFlameKindling;
exports.LuFlashlight = LuFlashlight;
exports.LuFlashlightIcon = LuFlashlight;
exports.LuFlashlightOff = LuFlashlightOff;
exports.LuFlashlightOffIcon = LuFlashlightOff;
exports.LuFlaskConical = LuFlaskConical;
exports.LuFlaskConicalIcon = LuFlaskConical;
exports.LuFlaskConicalOff = LuFlaskConicalOff;
exports.LuFlaskConicalOffIcon = LuFlaskConicalOff;
exports.LuFlaskRound = LuFlaskRound;
exports.LuFlaskRoundIcon = LuFlaskRound;
exports.LuFlipHorizontal = LuFlipHorizontal;
exports.LuFlipHorizontal2 = LuFlipHorizontal2;
exports.LuFlipHorizontal2Icon = LuFlipHorizontal2;
exports.LuFlipHorizontalIcon = LuFlipHorizontal;
exports.LuFlipVertical = LuFlipVertical;
exports.LuFlipVertical2 = LuFlipVertical2;
exports.LuFlipVertical2Icon = LuFlipVertical2;
exports.LuFlipVerticalIcon = LuFlipVertical;
exports.LuFlower = LuFlower;
exports.LuFlower2 = LuFlower2;
exports.LuFlower2Icon = LuFlower2;
exports.LuFlowerIcon = LuFlower;
exports.LuFocus = LuFocus;
exports.LuFocusIcon = LuFocus;
exports.LuFoldHorizontal = LuFoldHorizontal;
exports.LuFoldHorizontalIcon = LuFoldHorizontal;
exports.LuFoldVertical = LuFoldVertical;
exports.LuFoldVerticalIcon = LuFoldVertical;
exports.LuFolder = LuFolder;
exports.LuFolderArchive = LuFolderArchive;
exports.LuFolderArchiveIcon = LuFolderArchive;
exports.LuFolderCheck = LuFolderCheck;
exports.LuFolderCheckIcon = LuFolderCheck;
exports.LuFolderClock = LuFolderClock;
exports.LuFolderClockIcon = LuFolderClock;
exports.LuFolderClosed = LuFolderClosed;
exports.LuFolderClosedIcon = LuFolderClosed;
exports.LuFolderCog = LuFolderCog;
exports.LuFolderCog2 = LuFolderCog;
exports.LuFolderCog2Icon = LuFolderCog;
exports.LuFolderCogIcon = LuFolderCog;
exports.LuFolderDot = LuFolderDot;
exports.LuFolderDotIcon = LuFolderDot;
exports.LuFolderDown = LuFolderDown;
exports.LuFolderDownIcon = LuFolderDown;
exports.LuFolderEdit = LuFolderPen;
exports.LuFolderEditIcon = LuFolderPen;
exports.LuFolderGit = LuFolderGit;
exports.LuFolderGit2 = LuFolderGit2;
exports.LuFolderGit2Icon = LuFolderGit2;
exports.LuFolderGitIcon = LuFolderGit;
exports.LuFolderHeart = LuFolderHeart;
exports.LuFolderHeartIcon = LuFolderHeart;
exports.LuFolderIcon = LuFolder;
exports.LuFolderInput = LuFolderInput;
exports.LuFolderInputIcon = LuFolderInput;
exports.LuFolderKanban = LuFolderKanban;
exports.LuFolderKanbanIcon = LuFolderKanban;
exports.LuFolderKey = LuFolderKey;
exports.LuFolderKeyIcon = LuFolderKey;
exports.LuFolderLock = LuFolderLock;
exports.LuFolderLockIcon = LuFolderLock;
exports.LuFolderMinus = LuFolderMinus;
exports.LuFolderMinusIcon = LuFolderMinus;
exports.LuFolderOpen = LuFolderOpen;
exports.LuFolderOpenDot = LuFolderOpenDot;
exports.LuFolderOpenDotIcon = LuFolderOpenDot;
exports.LuFolderOpenIcon = LuFolderOpen;
exports.LuFolderOutput = LuFolderOutput;
exports.LuFolderOutputIcon = LuFolderOutput;
exports.LuFolderPen = LuFolderPen;
exports.LuFolderPenIcon = LuFolderPen;
exports.LuFolderPlus = LuFolderPlus;
exports.LuFolderPlusIcon = LuFolderPlus;
exports.LuFolderRoot = LuFolderRoot;
exports.LuFolderRootIcon = LuFolderRoot;
exports.LuFolderSearch = LuFolderSearch;
exports.LuFolderSearch2 = LuFolderSearch2;
exports.LuFolderSearch2Icon = LuFolderSearch2;
exports.LuFolderSearchIcon = LuFolderSearch;
exports.LuFolderSymlink = LuFolderSymlink;
exports.LuFolderSymlinkIcon = LuFolderSymlink;
exports.LuFolderSync = LuFolderSync;
exports.LuFolderSyncIcon = LuFolderSync;
exports.LuFolderTree = LuFolderTree;
exports.LuFolderTreeIcon = LuFolderTree;
exports.LuFolderUp = LuFolderUp;
exports.LuFolderUpIcon = LuFolderUp;
exports.LuFolderX = LuFolderX;
exports.LuFolderXIcon = LuFolderX;
exports.LuFolders = LuFolders;
exports.LuFoldersIcon = LuFolders;
exports.LuFootprints = LuFootprints;
exports.LuFootprintsIcon = LuFootprints;
exports.LuForklift = LuForklift;
exports.LuForkliftIcon = LuForklift;
exports.LuFormInput = LuRectangleEllipsis;
exports.LuFormInputIcon = LuRectangleEllipsis;
exports.LuForward = LuForward;
exports.LuForwardIcon = LuForward;
exports.LuFrame = LuFrame;
exports.LuFrameIcon = LuFrame;
exports.LuFramer = LuFramer;
exports.LuFramerIcon = LuFramer;
exports.LuFrown = LuFrown;
exports.LuFrownIcon = LuFrown;
exports.LuFuel = LuFuel;
exports.LuFuelIcon = LuFuel;
exports.LuFullscreen = LuFullscreen;
exports.LuFullscreenIcon = LuFullscreen;
exports.LuFunctionSquare = LuSquareFunction;
exports.LuFunctionSquareIcon = LuSquareFunction;
exports.LuGalleryHorizontal = LuGalleryHorizontal;
exports.LuGalleryHorizontalEnd = LuGalleryHorizontalEnd;
exports.LuGalleryHorizontalEndIcon = LuGalleryHorizontalEnd;
exports.LuGalleryHorizontalIcon = LuGalleryHorizontal;
exports.LuGalleryThumbnails = LuGalleryThumbnails;
exports.LuGalleryThumbnailsIcon = LuGalleryThumbnails;
exports.LuGalleryVertical = LuGalleryVertical;
exports.LuGalleryVerticalEnd = LuGalleryVerticalEnd;
exports.LuGalleryVerticalEndIcon = LuGalleryVerticalEnd;
exports.LuGalleryVerticalIcon = LuGalleryVertical;
exports.LuGamepad = LuGamepad;
exports.LuGamepad2 = LuGamepad2;
exports.LuGamepad2Icon = LuGamepad2;
exports.LuGamepadIcon = LuGamepad;
exports.LuGanttChart = LuGanttChart;
exports.LuGanttChartIcon = LuGanttChart;
exports.LuGanttChartSquare = LuSquareGanttChart;
exports.LuGanttChartSquareIcon = LuSquareGanttChart;
exports.LuGauge = LuGauge;
exports.LuGaugeCircle = LuCircleGauge;
exports.LuGaugeCircleIcon = LuCircleGauge;
exports.LuGaugeIcon = LuGauge;
exports.LuGavel = LuGavel;
exports.LuGavelIcon = LuGavel;
exports.LuGem = LuGem;
exports.LuGemIcon = LuGem;
exports.LuGhost = LuGhost;
exports.LuGhostIcon = LuGhost;
exports.LuGift = LuGift;
exports.LuGiftIcon = LuGift;
exports.LuGitBranch = LuGitBranch;
exports.LuGitBranchIcon = LuGitBranch;
exports.LuGitBranchPlus = LuGitBranchPlus;
exports.LuGitBranchPlusIcon = LuGitBranchPlus;
exports.LuGitCommit = LuGitCommitHorizontal;
exports.LuGitCommitHorizontal = LuGitCommitHorizontal;
exports.LuGitCommitHorizontalIcon = LuGitCommitHorizontal;
exports.LuGitCommitIcon = LuGitCommitHorizontal;
exports.LuGitCommitVertical = LuGitCommitVertical;
exports.LuGitCommitVerticalIcon = LuGitCommitVertical;
exports.LuGitCompare = LuGitCompare;
exports.LuGitCompareArrows = LuGitCompareArrows;
exports.LuGitCompareArrowsIcon = LuGitCompareArrows;
exports.LuGitCompareIcon = LuGitCompare;
exports.LuGitFork = LuGitFork;
exports.LuGitForkIcon = LuGitFork;
exports.LuGitGraph = LuGitGraph;
exports.LuGitGraphIcon = LuGitGraph;
exports.LuGitMerge = LuGitMerge;
exports.LuGitMergeIcon = LuGitMerge;
exports.LuGitPullRequest = LuGitPullRequest;
exports.LuGitPullRequestArrow = LuGitPullRequestArrow;
exports.LuGitPullRequestArrowIcon = LuGitPullRequestArrow;
exports.LuGitPullRequestClosed = LuGitPullRequestClosed;
exports.LuGitPullRequestClosedIcon = LuGitPullRequestClosed;
exports.LuGitPullRequestCreate = LuGitPullRequestCreate;
exports.LuGitPullRequestCreateArrow = LuGitPullRequestCreateArrow;
exports.LuGitPullRequestCreateArrowIcon = LuGitPullRequestCreateArrow;
exports.LuGitPullRequestCreateIcon = LuGitPullRequestCreate;
exports.LuGitPullRequestDraft = LuGitPullRequestDraft;
exports.LuGitPullRequestDraftIcon = LuGitPullRequestDraft;
exports.LuGitPullRequestIcon = LuGitPullRequest;
exports.LuGithub = LuGithub;
exports.LuGithubIcon = LuGithub;
exports.LuGitlab = LuGitlab;
exports.LuGitlabIcon = LuGitlab;
exports.LuGlassWater = LuGlassWater;
exports.LuGlassWaterIcon = LuGlassWater;
exports.LuGlasses = LuGlasses;
exports.LuGlassesIcon = LuGlasses;
exports.LuGlobe = LuGlobe;
exports.LuGlobe2 = LuEarth;
exports.LuGlobe2Icon = LuEarth;
exports.LuGlobeIcon = LuGlobe;
exports.LuGlobeLock = LuGlobeLock;
exports.LuGlobeLockIcon = LuGlobeLock;
exports.LuGoal = LuGoal;
exports.LuGoalIcon = LuGoal;
exports.LuGrab = LuGrab;
exports.LuGrabIcon = LuGrab;
exports.LuGraduationCap = LuGraduationCap;
exports.LuGraduationCapIcon = LuGraduationCap;
exports.LuGrape = LuGrape;
exports.LuGrapeIcon = LuGrape;
exports.LuGrid = LuGrid3x3;
exports.LuGrid2X2 = LuGrid2x2;
exports.LuGrid2X2Icon = LuGrid2x2;
exports.LuGrid2x2 = LuGrid2x2;
exports.LuGrid2x2Icon = LuGrid2x2;
exports.LuGrid3X3 = LuGrid3x3;
exports.LuGrid3X3Icon = LuGrid3x3;
exports.LuGrid3x3 = LuGrid3x3;
exports.LuGrid3x3Icon = LuGrid3x3;
exports.LuGridIcon = LuGrid3x3;
exports.LuGrip = LuGrip;
exports.LuGripHorizontal = LuGripHorizontal;
exports.LuGripHorizontalIcon = LuGripHorizontal;
exports.LuGripIcon = LuGrip;
exports.LuGripVertical = LuGripVertical;
exports.LuGripVerticalIcon = LuGripVertical;
exports.LuGroup = LuGroup;
exports.LuGroupIcon = LuGroup;
exports.LuGuitar = LuGuitar;
exports.LuGuitarIcon = LuGuitar;
exports.LuHam = LuHam;
exports.LuHamIcon = LuHam;
exports.LuHammer = LuHammer;
exports.LuHammerIcon = LuHammer;
exports.LuHand = LuHand;
exports.LuHandCoins = LuHandCoins;
exports.LuHandCoinsIcon = LuHandCoins;
exports.LuHandHeart = LuHandHeart;
exports.LuHandHeartIcon = LuHandHeart;
exports.LuHandHelping = LuHandHelping;
exports.LuHandHelpingIcon = LuHandHelping;
exports.LuHandIcon = LuHand;
exports.LuHandMetal = LuHandMetal;
exports.LuHandMetalIcon = LuHandMetal;
exports.LuHandPlatter = LuHandPlatter;
exports.LuHandPlatterIcon = LuHandPlatter;
exports.LuHandshake = LuHandshake;
exports.LuHandshakeIcon = LuHandshake;
exports.LuHardDrive = LuHardDrive;
exports.LuHardDriveDownload = LuHardDriveDownload;
exports.LuHardDriveDownloadIcon = LuHardDriveDownload;
exports.LuHardDriveIcon = LuHardDrive;
exports.LuHardDriveUpload = LuHardDriveUpload;
exports.LuHardDriveUploadIcon = LuHardDriveUpload;
exports.LuHardHat = LuHardHat;
exports.LuHardHatIcon = LuHardHat;
exports.LuHash = LuHash;
exports.LuHashIcon = LuHash;
exports.LuHaze = LuHaze;
exports.LuHazeIcon = LuHaze;
exports.LuHdmiPort = LuHdmiPort;
exports.LuHdmiPortIcon = LuHdmiPort;
exports.LuHeading = LuHeading;
exports.LuHeading1 = LuHeading1;
exports.LuHeading1Icon = LuHeading1;
exports.LuHeading2 = LuHeading2;
exports.LuHeading2Icon = LuHeading2;
exports.LuHeading3 = LuHeading3;
exports.LuHeading3Icon = LuHeading3;
exports.LuHeading4 = LuHeading4;
exports.LuHeading4Icon = LuHeading4;
exports.LuHeading5 = LuHeading5;
exports.LuHeading5Icon = LuHeading5;
exports.LuHeading6 = LuHeading6;
exports.LuHeading6Icon = LuHeading6;
exports.LuHeadingIcon = LuHeading;
exports.LuHeadphones = LuHeadphones;
exports.LuHeadphonesIcon = LuHeadphones;
exports.LuHeadset = LuHeadset;
exports.LuHeadsetIcon = LuHeadset;
exports.LuHeart = LuHeart;
exports.LuHeartCrack = LuHeartCrack;
exports.LuHeartCrackIcon = LuHeartCrack;
exports.LuHeartHandshake = LuHeartHandshake;
exports.LuHeartHandshakeIcon = LuHeartHandshake;
exports.LuHeartIcon = LuHeart;
exports.LuHeartOff = LuHeartOff;
exports.LuHeartOffIcon = LuHeartOff;
exports.LuHeartPulse = LuHeartPulse;
exports.LuHeartPulseIcon = LuHeartPulse;
exports.LuHeater = LuHeater;
exports.LuHeaterIcon = LuHeater;
exports.LuHelpCircle = LuCircleHelp;
exports.LuHelpCircleIcon = LuCircleHelp;
exports.LuHelpingHand = LuHandHelping;
exports.LuHelpingHandIcon = LuHandHelping;
exports.LuHexagon = LuHexagon;
exports.LuHexagonIcon = LuHexagon;
exports.LuHighlighter = LuHighlighter;
exports.LuHighlighterIcon = LuHighlighter;
exports.LuHistory = LuHistory;
exports.LuHistoryIcon = LuHistory;
exports.LuHome = LuHome;
exports.LuHomeIcon = LuHome;
exports.LuHop = LuHop;
exports.LuHopIcon = LuHop;
exports.LuHopOff = LuHopOff;
exports.LuHopOffIcon = LuHopOff;
exports.LuHospital = LuHospital;
exports.LuHospitalIcon = LuHospital;
exports.LuHotel = LuHotel;
exports.LuHotelIcon = LuHotel;
exports.LuHourglass = LuHourglass;
exports.LuHourglassIcon = LuHourglass;
exports.LuIceCream = LuIceCreamCone;
exports.LuIceCream2 = LuIceCreamBowl;
exports.LuIceCream2Icon = LuIceCreamBowl;
exports.LuIceCreamBowl = LuIceCreamBowl;
exports.LuIceCreamBowlIcon = LuIceCreamBowl;
exports.LuIceCreamCone = LuIceCreamCone;
exports.LuIceCreamConeIcon = LuIceCreamCone;
exports.LuIceCreamIcon = LuIceCreamCone;
exports.LuImage = LuImage;
exports.LuImageDown = LuImageDown;
exports.LuImageDownIcon = LuImageDown;
exports.LuImageIcon = LuImage;
exports.LuImageMinus = LuImageMinus;
exports.LuImageMinusIcon = LuImageMinus;
exports.LuImageOff = LuImageOff;
exports.LuImageOffIcon = LuImageOff;
exports.LuImagePlus = LuImagePlus;
exports.LuImagePlusIcon = LuImagePlus;
exports.LuImageUp = LuImageUp;
exports.LuImageUpIcon = LuImageUp;
exports.LuImages = LuImages;
exports.LuImagesIcon = LuImages;
exports.LuImport = LuImport;
exports.LuImportIcon = LuImport;
exports.LuInbox = LuInbox;
exports.LuInboxIcon = LuInbox;
exports.LuIndent = LuIndentIncrease;
exports.LuIndentDecrease = LuIndentDecrease;
exports.LuIndentDecreaseIcon = LuIndentDecrease;
exports.LuIndentIcon = LuIndentIncrease;
exports.LuIndentIncrease = LuIndentIncrease;
exports.LuIndentIncreaseIcon = LuIndentIncrease;
exports.LuIndianRupee = LuIndianRupee;
exports.LuIndianRupeeIcon = LuIndianRupee;
exports.LuInfinity = LuInfinity;
exports.LuInfinityIcon = LuInfinity;
exports.LuInfo = LuInfo;
exports.LuInfoIcon = LuInfo;
exports.LuInspect = LuSquareMousePointer;
exports.LuInspectIcon = LuSquareMousePointer;
exports.LuInspectionPanel = LuInspectionPanel;
exports.LuInspectionPanelIcon = LuInspectionPanel;
exports.LuInstagram = LuInstagram;
exports.LuInstagramIcon = LuInstagram;
exports.LuItalic = LuItalic;
exports.LuItalicIcon = LuItalic;
exports.LuIterationCcw = LuIterationCcw;
exports.LuIterationCcwIcon = LuIterationCcw;
exports.LuIterationCw = LuIterationCw;
exports.LuIterationCwIcon = LuIterationCw;
exports.LuJapaneseYen = LuJapaneseYen;
exports.LuJapaneseYenIcon = LuJapaneseYen;
exports.LuJoystick = LuJoystick;
exports.LuJoystickIcon = LuJoystick;
exports.LuKanban = LuKanban;
exports.LuKanbanIcon = LuKanban;
exports.LuKanbanSquare = LuSquareKanban;
exports.LuKanbanSquareDashed = LuSquareDashedKanban;
exports.LuKanbanSquareDashedIcon = LuSquareDashedKanban;
exports.LuKanbanSquareIcon = LuSquareKanban;
exports.LuKey = LuKey;
exports.LuKeyIcon = LuKey;
exports.LuKeyRound = LuKeyRound;
exports.LuKeyRoundIcon = LuKeyRound;
exports.LuKeySquare = LuKeySquare;
exports.LuKeySquareIcon = LuKeySquare;
exports.LuKeyboard = LuKeyboard;
exports.LuKeyboardIcon = LuKeyboard;
exports.LuKeyboardMusic = LuKeyboardMusic;
exports.LuKeyboardMusicIcon = LuKeyboardMusic;
exports.LuLamp = LuLamp;
exports.LuLampCeiling = LuLampCeiling;
exports.LuLampCeilingIcon = LuLampCeiling;
exports.LuLampDesk = LuLampDesk;
exports.LuLampDeskIcon = LuLampDesk;
exports.LuLampFloor = LuLampFloor;
exports.LuLampFloorIcon = LuLampFloor;
exports.LuLampIcon = LuLamp;
exports.LuLampWallDown = LuLampWallDown;
exports.LuLampWallDownIcon = LuLampWallDown;
exports.LuLampWallUp = LuLampWallUp;
exports.LuLampWallUpIcon = LuLampWallUp;
exports.LuLandPlot = LuLandPlot;
exports.LuLandPlotIcon = LuLandPlot;
exports.LuLandmark = LuLandmark;
exports.LuLandmarkIcon = LuLandmark;
exports.LuLanguages = LuLanguages;
exports.LuLanguagesIcon = LuLanguages;
exports.LuLaptop = LuLaptop;
exports.LuLaptop2 = LuLaptopMinimal;
exports.LuLaptop2Icon = LuLaptopMinimal;
exports.LuLaptopIcon = LuLaptop;
exports.LuLaptopMinimal = LuLaptopMinimal;
exports.LuLaptopMinimalIcon = LuLaptopMinimal;
exports.LuLasso = LuLasso;
exports.LuLassoIcon = LuLasso;
exports.LuLassoSelect = LuLassoSelect;
exports.LuLassoSelectIcon = LuLassoSelect;
exports.LuLaugh = LuLaugh;
exports.LuLaughIcon = LuLaugh;
exports.LuLayers = LuLayers;
exports.LuLayers2 = LuLayers2;
exports.LuLayers2Icon = LuLayers2;
exports.LuLayers3 = LuLayers3;
exports.LuLayers3Icon = LuLayers3;
exports.LuLayersIcon = LuLayers;
exports.LuLayout = LuPanelsTopLeft;
exports.LuLayoutDashboard = LuLayoutDashboard;
exports.LuLayoutDashboardIcon = LuLayoutDashboard;
exports.LuLayoutGrid = LuLayoutGrid;
exports.LuLayoutGridIcon = LuLayoutGrid;
exports.LuLayoutIcon = LuPanelsTopLeft;
exports.LuLayoutList = LuLayoutList;
exports.LuLayoutListIcon = LuLayoutList;
exports.LuLayoutPanelLeft = LuLayoutPanelLeft;
exports.LuLayoutPanelLeftIcon = LuLayoutPanelLeft;
exports.LuLayoutPanelTop = LuLayoutPanelTop;
exports.LuLayoutPanelTopIcon = LuLayoutPanelTop;
exports.LuLayoutTemplate = LuLayoutTemplate;
exports.LuLayoutTemplateIcon = LuLayoutTemplate;
exports.LuLeaf = LuLeaf;
exports.LuLeafIcon = LuLeaf;
exports.LuLeafyGreen = LuLeafyGreen;
exports.LuLeafyGreenIcon = LuLeafyGreen;
exports.LuLibrary = LuLibrary;
exports.LuLibraryBig = LuLibraryBig;
exports.LuLibraryBigIcon = LuLibraryBig;
exports.LuLibraryIcon = LuLibrary;
exports.LuLibrarySquare = LuSquareLibrary;
exports.LuLibrarySquareIcon = LuSquareLibrary;
exports.LuLifeBuoy = LuLifeBuoy;
exports.LuLifeBuoyIcon = LuLifeBuoy;
exports.LuLigature = LuLigature;
exports.LuLigatureIcon = LuLigature;
exports.LuLightbulb = LuLightbulb;
exports.LuLightbulbIcon = LuLightbulb;
exports.LuLightbulbOff = LuLightbulbOff;
exports.LuLightbulbOffIcon = LuLightbulbOff;
exports.LuLineChart = LuLineChart;
exports.LuLineChartIcon = LuLineChart;
exports.LuLink = LuLink;
exports.LuLink2 = LuLink2;
exports.LuLink2Icon = LuLink2;
exports.LuLink2Off = LuLink2Off;
exports.LuLink2OffIcon = LuLink2Off;
exports.LuLinkIcon = LuLink;
exports.LuLinkedin = LuLinkedin;
exports.LuLinkedinIcon = LuLinkedin;
exports.LuList = LuList;
exports.LuListChecks = LuListChecks;
exports.LuListChecksIcon = LuListChecks;
exports.LuListCollapse = LuListCollapse;
exports.LuListCollapseIcon = LuListCollapse;
exports.LuListEnd = LuListEnd;
exports.LuListEndIcon = LuListEnd;
exports.LuListFilter = LuListFilter;
exports.LuListFilterIcon = LuListFilter;
exports.LuListIcon = LuList;
exports.LuListMinus = LuListMinus;
exports.LuListMinusIcon = LuListMinus;
exports.LuListMusic = LuListMusic;
exports.LuListMusicIcon = LuListMusic;
exports.LuListOrdered = LuListOrdered;
exports.LuListOrderedIcon = LuListOrdered;
exports.LuListPlus = LuListPlus;
exports.LuListPlusIcon = LuListPlus;
exports.LuListRestart = LuListRestart;
exports.LuListRestartIcon = LuListRestart;
exports.LuListStart = LuListStart;
exports.LuListStartIcon = LuListStart;
exports.LuListTodo = LuListTodo;
exports.LuListTodoIcon = LuListTodo;
exports.LuListTree = LuListTree;
exports.LuListTreeIcon = LuListTree;
exports.LuListVideo = LuListVideo;
exports.LuListVideoIcon = LuListVideo;
exports.LuListX = LuListX;
exports.LuListXIcon = LuListX;
exports.LuLoader = LuLoader;
exports.LuLoader2 = LuLoaderCircle;
exports.LuLoader2Icon = LuLoaderCircle;
exports.LuLoaderCircle = LuLoaderCircle;
exports.LuLoaderCircleIcon = LuLoaderCircle;
exports.LuLoaderIcon = LuLoader;
exports.LuLocate = LuLocate;
exports.LuLocateFixed = LuLocateFixed;
exports.LuLocateFixedIcon = LuLocateFixed;
exports.LuLocateIcon = LuLocate;
exports.LuLocateOff = LuLocateOff;
exports.LuLocateOffIcon = LuLocateOff;
exports.LuLock = LuLock;
exports.LuLockIcon = LuLock;
exports.LuLockKeyhole = LuLockKeyhole;
exports.LuLockKeyholeIcon = LuLockKeyhole;
exports.LuLockKeyholeOpen = LuLockKeyholeOpen;
exports.LuLockKeyholeOpenIcon = LuLockKeyholeOpen;
exports.LuLockOpen = LuLockOpen;
exports.LuLockOpenIcon = LuLockOpen;
exports.LuLogIn = LuLogIn;
exports.LuLogInIcon = LuLogIn;
exports.LuLogOut = LuLogOut;
exports.LuLogOutIcon = LuLogOut;
exports.LuLollipop = LuLollipop;
exports.LuLollipopIcon = LuLollipop;
exports.LuLuggage = LuLuggage;
exports.LuLuggageIcon = LuLuggage;
exports.LuMSquare = LuSquareM;
exports.LuMSquareIcon = LuSquareM;
exports.LuMagnet = LuMagnet;
exports.LuMagnetIcon = LuMagnet;
exports.LuMail = LuMail;
exports.LuMailCheck = LuMailCheck;
exports.LuMailCheckIcon = LuMailCheck;
exports.LuMailIcon = LuMail;
exports.LuMailMinus = LuMailMinus;
exports.LuMailMinusIcon = LuMailMinus;
exports.LuMailOpen = LuMailOpen;
exports.LuMailOpenIcon = LuMailOpen;
exports.LuMailPlus = LuMailPlus;
exports.LuMailPlusIcon = LuMailPlus;
exports.LuMailQuestion = LuMailQuestion;
exports.LuMailQuestionIcon = LuMailQuestion;
exports.LuMailSearch = LuMailSearch;
exports.LuMailSearchIcon = LuMailSearch;
exports.LuMailWarning = LuMailWarning;
exports.LuMailWarningIcon = LuMailWarning;
exports.LuMailX = LuMailX;
exports.LuMailXIcon = LuMailX;
exports.LuMailbox = LuMailbox;
exports.LuMailboxIcon = LuMailbox;
exports.LuMails = LuMails;
exports.LuMailsIcon = LuMails;
exports.LuMap = LuMap;
exports.LuMapIcon = LuMap;
exports.LuMapPin = LuMapPin;
exports.LuMapPinIcon = LuMapPin;
exports.LuMapPinOff = LuMapPinOff;
exports.LuMapPinOffIcon = LuMapPinOff;
exports.LuMapPinned = LuMapPinned;
exports.LuMapPinnedIcon = LuMapPinned;
exports.LuMartini = LuMartini;
exports.LuMartiniIcon = LuMartini;
exports.LuMaximize = LuMaximize;
exports.LuMaximize2 = LuMaximize2;
exports.LuMaximize2Icon = LuMaximize2;
exports.LuMaximizeIcon = LuMaximize;
exports.LuMedal = LuMedal;
exports.LuMedalIcon = LuMedal;
exports.LuMegaphone = LuMegaphone;
exports.LuMegaphoneIcon = LuMegaphone;
exports.LuMegaphoneOff = LuMegaphoneOff;
exports.LuMegaphoneOffIcon = LuMegaphoneOff;
exports.LuMeh = LuMeh;
exports.LuMehIcon = LuMeh;
exports.LuMemoryStick = LuMemoryStick;
exports.LuMemoryStickIcon = LuMemoryStick;
exports.LuMenu = LuMenu;
exports.LuMenuIcon = LuMenu;
exports.LuMenuSquare = LuSquareMenu;
exports.LuMenuSquareIcon = LuSquareMenu;
exports.LuMerge = LuMerge;
exports.LuMergeIcon = LuMerge;
exports.LuMessageCircle = LuMessageCircle;
exports.LuMessageCircleCode = LuMessageCircleCode;
exports.LuMessageCircleCodeIcon = LuMessageCircleCode;
exports.LuMessageCircleDashed = LuMessageCircleDashed;
exports.LuMessageCircleDashedIcon = LuMessageCircleDashed;
exports.LuMessageCircleHeart = LuMessageCircleHeart;
exports.LuMessageCircleHeartIcon = LuMessageCircleHeart;
exports.LuMessageCircleIcon = LuMessageCircle;
exports.LuMessageCircleMore = LuMessageCircleMore;
exports.LuMessageCircleMoreIcon = LuMessageCircleMore;
exports.LuMessageCircleOff = LuMessageCircleOff;
exports.LuMessageCircleOffIcon = LuMessageCircleOff;
exports.LuMessageCirclePlus = LuMessageCirclePlus;
exports.LuMessageCirclePlusIcon = LuMessageCirclePlus;
exports.LuMessageCircleQuestion = LuMessageCircleQuestion;
exports.LuMessageCircleQuestionIcon = LuMessageCircleQuestion;
exports.LuMessageCircleReply = LuMessageCircleReply;
exports.LuMessageCircleReplyIcon = LuMessageCircleReply;
exports.LuMessageCircleWarning = LuMessageCircleWarning;
exports.LuMessageCircleWarningIcon = LuMessageCircleWarning;
exports.LuMessageCircleX = LuMessageCircleX;
exports.LuMessageCircleXIcon = LuMessageCircleX;
exports.LuMessageSquare = LuMessageSquare;
exports.LuMessageSquareCode = LuMessageSquareCode;
exports.LuMessageSquareCodeIcon = LuMessageSquareCode;
exports.LuMessageSquareDashed = LuMessageSquareDashed;
exports.LuMessageSquareDashedIcon = LuMessageSquareDashed;
exports.LuMessageSquareDiff = LuMessageSquareDiff;
exports.LuMessageSquareDiffIcon = LuMessageSquareDiff;
exports.LuMessageSquareDot = LuMessageSquareDot;
exports.LuMessageSquareDotIcon = LuMessageSquareDot;
exports.LuMessageSquareHeart = LuMessageSquareHeart;
exports.LuMessageSquareHeartIcon = LuMessageSquareHeart;
exports.LuMessageSquareIcon = LuMessageSquare;
exports.LuMessageSquareMore = LuMessageSquareMore;
exports.LuMessageSquareMoreIcon = LuMessageSquareMore;
exports.LuMessageSquareOff = LuMessageSquareOff;
exports.LuMessageSquareOffIcon = LuMessageSquareOff;
exports.LuMessageSquarePlus = LuMessageSquarePlus;
exports.LuMessageSquarePlusIcon = LuMessageSquarePlus;
exports.LuMessageSquareQuote = LuMessageSquareQuote;
exports.LuMessageSquareQuoteIcon = LuMessageSquareQuote;
exports.LuMessageSquareReply = LuMessageSquareReply;
exports.LuMessageSquareReplyIcon = LuMessageSquareReply;
exports.LuMessageSquareShare = LuMessageSquareShare;
exports.LuMessageSquareShareIcon = LuMessageSquareShare;
exports.LuMessageSquareText = LuMessageSquareText;
exports.LuMessageSquareTextIcon = LuMessageSquareText;
exports.LuMessageSquareWarning = LuMessageSquareWarning;
exports.LuMessageSquareWarningIcon = LuMessageSquareWarning;
exports.LuMessageSquareX = LuMessageSquareX;
exports.LuMessageSquareXIcon = LuMessageSquareX;
exports.LuMessagesSquare = LuMessagesSquare;
exports.LuMessagesSquareIcon = LuMessagesSquare;
exports.LuMic = LuMic;
exports.LuMic2 = LuMicVocal;
exports.LuMic2Icon = LuMicVocal;
exports.LuMicIcon = LuMic;
exports.LuMicOff = LuMicOff;
exports.LuMicOffIcon = LuMicOff;
exports.LuMicVocal = LuMicVocal;
exports.LuMicVocalIcon = LuMicVocal;
exports.LuMicroscope = LuMicroscope;
exports.LuMicroscopeIcon = LuMicroscope;
exports.LuMicrowave = LuMicrowave;
exports.LuMicrowaveIcon = LuMicrowave;
exports.LuMilestone = LuMilestone;
exports.LuMilestoneIcon = LuMilestone;
exports.LuMilk = LuMilk;
exports.LuMilkIcon = LuMilk;
exports.LuMilkOff = LuMilkOff;
exports.LuMilkOffIcon = LuMilkOff;
exports.LuMinimize = LuMinimize;
exports.LuMinimize2 = LuMinimize2;
exports.LuMinimize2Icon = LuMinimize2;
exports.LuMinimizeIcon = LuMinimize;
exports.LuMinus = LuMinus;
exports.LuMinusCircle = LuCircleMinus;
exports.LuMinusCircleIcon = LuCircleMinus;
exports.LuMinusIcon = LuMinus;
exports.LuMinusSquare = LuSquareMinus;
exports.LuMinusSquareIcon = LuSquareMinus;
exports.LuMonitor = LuMonitor;
exports.LuMonitorCheck = LuMonitorCheck;
exports.LuMonitorCheckIcon = LuMonitorCheck;
exports.LuMonitorDot = LuMonitorDot;
exports.LuMonitorDotIcon = LuMonitorDot;
exports.LuMonitorDown = LuMonitorDown;
exports.LuMonitorDownIcon = LuMonitorDown;
exports.LuMonitorIcon = LuMonitor;
exports.LuMonitorOff = LuMonitorOff;
exports.LuMonitorOffIcon = LuMonitorOff;
exports.LuMonitorPause = LuMonitorPause;
exports.LuMonitorPauseIcon = LuMonitorPause;
exports.LuMonitorPlay = LuMonitorPlay;
exports.LuMonitorPlayIcon = LuMonitorPlay;
exports.LuMonitorSmartphone = LuMonitorSmartphone;
exports.LuMonitorSmartphoneIcon = LuMonitorSmartphone;
exports.LuMonitorSpeaker = LuMonitorSpeaker;
exports.LuMonitorSpeakerIcon = LuMonitorSpeaker;
exports.LuMonitorStop = LuMonitorStop;
exports.LuMonitorStopIcon = LuMonitorStop;
exports.LuMonitorUp = LuMonitorUp;
exports.LuMonitorUpIcon = LuMonitorUp;
exports.LuMonitorX = LuMonitorX;
exports.LuMonitorXIcon = LuMonitorX;
exports.LuMoon = LuMoon;
exports.LuMoonIcon = LuMoon;
exports.LuMoonStar = LuMoonStar;
exports.LuMoonStarIcon = LuMoonStar;
exports.LuMoreHorizontal = LuEllipsis;
exports.LuMoreHorizontalIcon = LuEllipsis;
exports.LuMoreVertical = LuEllipsisVertical;
exports.LuMoreVerticalIcon = LuEllipsisVertical;
exports.LuMountain = LuMountain;
exports.LuMountainIcon = LuMountain;
exports.LuMountainSnow = LuMountainSnow;
exports.LuMountainSnowIcon = LuMountainSnow;
exports.LuMouse = LuMouse;
exports.LuMouseIcon = LuMouse;
exports.LuMousePointer = LuMousePointer;
exports.LuMousePointer2 = LuMousePointer2;
exports.LuMousePointer2Icon = LuMousePointer2;
exports.LuMousePointerClick = LuMousePointerClick;
exports.LuMousePointerClickIcon = LuMousePointerClick;
exports.LuMousePointerIcon = LuMousePointer;
exports.LuMousePointerSquareDashed = LuSquareDashedMousePointer;
exports.LuMousePointerSquareDashedIcon = LuSquareDashedMousePointer;
exports.LuMove = LuMove;
exports.LuMove3D = LuMove3d;
exports.LuMove3DIcon = LuMove3d;
exports.LuMove3d = LuMove3d;
exports.LuMove3dIcon = LuMove3d;
exports.LuMoveDiagonal = LuMoveDiagonal;
exports.LuMoveDiagonal2 = LuMoveDiagonal2;
exports.LuMoveDiagonal2Icon = LuMoveDiagonal2;
exports.LuMoveDiagonalIcon = LuMoveDiagonal;
exports.LuMoveDown = LuMoveDown;
exports.LuMoveDownIcon = LuMoveDown;
exports.LuMoveDownLeft = LuMoveDownLeft;
exports.LuMoveDownLeftIcon = LuMoveDownLeft;
exports.LuMoveDownRight = LuMoveDownRight;
exports.LuMoveDownRightIcon = LuMoveDownRight;
exports.LuMoveHorizontal = LuMoveHorizontal;
exports.LuMoveHorizontalIcon = LuMoveHorizontal;
exports.LuMoveIcon = LuMove;
exports.LuMoveLeft = LuMoveLeft;
exports.LuMoveLeftIcon = LuMoveLeft;
exports.LuMoveRight = LuMoveRight;
exports.LuMoveRightIcon = LuMoveRight;
exports.LuMoveUp = LuMoveUp;
exports.LuMoveUpIcon = LuMoveUp;
exports.LuMoveUpLeft = LuMoveUpLeft;
exports.LuMoveUpLeftIcon = LuMoveUpLeft;
exports.LuMoveUpRight = LuMoveUpRight;
exports.LuMoveUpRightIcon = LuMoveUpRight;
exports.LuMoveVertical = LuMoveVertical;
exports.LuMoveVerticalIcon = LuMoveVertical;
exports.LuMusic = LuMusic;
exports.LuMusic2 = LuMusic2;
exports.LuMusic2Icon = LuMusic2;
exports.LuMusic3 = LuMusic3;
exports.LuMusic3Icon = LuMusic3;
exports.LuMusic4 = LuMusic4;
exports.LuMusic4Icon = LuMusic4;
exports.LuMusicIcon = LuMusic;
exports.LuNavigation = LuNavigation;
exports.LuNavigation2 = LuNavigation2;
exports.LuNavigation2Icon = LuNavigation2;
exports.LuNavigation2Off = LuNavigation2Off;
exports.LuNavigation2OffIcon = LuNavigation2Off;
exports.LuNavigationIcon = LuNavigation;
exports.LuNavigationOff = LuNavigationOff;
exports.LuNavigationOffIcon = LuNavigationOff;
exports.LuNetwork = LuNetwork;
exports.LuNetworkIcon = LuNetwork;
exports.LuNewspaper = LuNewspaper;
exports.LuNewspaperIcon = LuNewspaper;
exports.LuNfc = LuNfc;
exports.LuNfcIcon = LuNfc;
exports.LuNotebook = LuNotebook;
exports.LuNotebookIcon = LuNotebook;
exports.LuNotebookPen = LuNotebookPen;
exports.LuNotebookPenIcon = LuNotebookPen;
exports.LuNotebookTabs = LuNotebookTabs;
exports.LuNotebookTabsIcon = LuNotebookTabs;
exports.LuNotebookText = LuNotebookText;
exports.LuNotebookTextIcon = LuNotebookText;
exports.LuNotepadText = LuNotepadText;
exports.LuNotepadTextDashed = LuNotepadTextDashed;
exports.LuNotepadTextDashedIcon = LuNotepadTextDashed;
exports.LuNotepadTextIcon = LuNotepadText;
exports.LuNut = LuNut;
exports.LuNutIcon = LuNut;
exports.LuNutOff = LuNutOff;
exports.LuNutOffIcon = LuNutOff;
exports.LuOctagon = LuOctagon;
exports.LuOctagonAlert = LuOctagonAlert;
exports.LuOctagonAlertIcon = LuOctagonAlert;
exports.LuOctagonIcon = LuOctagon;
exports.LuOctagonPause = LuOctagonPause;
exports.LuOctagonPauseIcon = LuOctagonPause;
exports.LuOctagonX = LuOctagonX;
exports.LuOctagonXIcon = LuOctagonX;
exports.LuOption = LuOption;
exports.LuOptionIcon = LuOption;
exports.LuOrbit = LuOrbit;
exports.LuOrbitIcon = LuOrbit;
exports.LuOutdent = LuIndentDecrease;
exports.LuOutdentIcon = LuIndentDecrease;
exports.LuPackage = LuPackage;
exports.LuPackage2 = LuPackage2;
exports.LuPackage2Icon = LuPackage2;
exports.LuPackageCheck = LuPackageCheck;
exports.LuPackageCheckIcon = LuPackageCheck;
exports.LuPackageIcon = LuPackage;
exports.LuPackageMinus = LuPackageMinus;
exports.LuPackageMinusIcon = LuPackageMinus;
exports.LuPackageOpen = LuPackageOpen;
exports.LuPackageOpenIcon = LuPackageOpen;
exports.LuPackagePlus = LuPackagePlus;
exports.LuPackagePlusIcon = LuPackagePlus;
exports.LuPackageSearch = LuPackageSearch;
exports.LuPackageSearchIcon = LuPackageSearch;
exports.LuPackageX = LuPackageX;
exports.LuPackageXIcon = LuPackageX;
exports.LuPaintBucket = LuPaintBucket;
exports.LuPaintBucketIcon = LuPaintBucket;
exports.LuPaintRoller = LuPaintRoller;
exports.LuPaintRollerIcon = LuPaintRoller;
exports.LuPaintbrush = LuPaintbrush;
exports.LuPaintbrush2 = LuPaintbrush2;
exports.LuPaintbrush2Icon = LuPaintbrush2;
exports.LuPaintbrushIcon = LuPaintbrush;
exports.LuPalette = LuPalette;
exports.LuPaletteIcon = LuPalette;
exports.LuPalmtree = LuTreePalm;
exports.LuPalmtreeIcon = LuTreePalm;
exports.LuPanelBottom = LuPanelBottom;
exports.LuPanelBottomClose = LuPanelBottomClose;
exports.LuPanelBottomCloseIcon = LuPanelBottomClose;
exports.LuPanelBottomDashed = LuPanelBottomDashed;
exports.LuPanelBottomDashedIcon = LuPanelBottomDashed;
exports.LuPanelBottomIcon = LuPanelBottom;
exports.LuPanelBottomInactive = LuPanelBottomDashed;
exports.LuPanelBottomInactiveIcon = LuPanelBottomDashed;
exports.LuPanelBottomOpen = LuPanelBottomOpen;
exports.LuPanelBottomOpenIcon = LuPanelBottomOpen;
exports.LuPanelLeft = LuPanelLeft;
exports.LuPanelLeftClose = LuPanelLeftClose;
exports.LuPanelLeftCloseIcon = LuPanelLeftClose;
exports.LuPanelLeftDashed = LuPanelLeftDashed;
exports.LuPanelLeftDashedIcon = LuPanelLeftDashed;
exports.LuPanelLeftIcon = LuPanelLeft;
exports.LuPanelLeftInactive = LuPanelLeftDashed;
exports.LuPanelLeftInactiveIcon = LuPanelLeftDashed;
exports.LuPanelLeftOpen = LuPanelLeftOpen;
exports.LuPanelLeftOpenIcon = LuPanelLeftOpen;
exports.LuPanelRight = LuPanelRight;
exports.LuPanelRightClose = LuPanelRightClose;
exports.LuPanelRightCloseIcon = LuPanelRightClose;
exports.LuPanelRightDashed = LuPanelRightDashed;
exports.LuPanelRightDashedIcon = LuPanelRightDashed;
exports.LuPanelRightIcon = LuPanelRight;
exports.LuPanelRightInactive = LuPanelRightDashed;
exports.LuPanelRightInactiveIcon = LuPanelRightDashed;
exports.LuPanelRightOpen = LuPanelRightOpen;
exports.LuPanelRightOpenIcon = LuPanelRightOpen;
exports.LuPanelTop = LuPanelTop;
exports.LuPanelTopClose = LuPanelTopClose;
exports.LuPanelTopCloseIcon = LuPanelTopClose;
exports.LuPanelTopDashed = LuPanelTopDashed;
exports.LuPanelTopDashedIcon = LuPanelTopDashed;
exports.LuPanelTopIcon = LuPanelTop;
exports.LuPanelTopInactive = LuPanelTopDashed;
exports.LuPanelTopInactiveIcon = LuPanelTopDashed;
exports.LuPanelTopOpen = LuPanelTopOpen;
exports.LuPanelTopOpenIcon = LuPanelTopOpen;
exports.LuPanelsLeftBottom = LuPanelsLeftBottom;
exports.LuPanelsLeftBottomIcon = LuPanelsLeftBottom;
exports.LuPanelsLeftRight = LuColumns3;
exports.LuPanelsLeftRightIcon = LuColumns3;
exports.LuPanelsRightBottom = LuPanelsRightBottom;
exports.LuPanelsRightBottomIcon = LuPanelsRightBottom;
exports.LuPanelsTopBottom = LuRows3;
exports.LuPanelsTopBottomIcon = LuRows3;
exports.LuPanelsTopLeft = LuPanelsTopLeft;
exports.LuPanelsTopLeftIcon = LuPanelsTopLeft;
exports.LuPaperclip = LuPaperclip;
exports.LuPaperclipIcon = LuPaperclip;
exports.LuParentheses = LuParentheses;
exports.LuParenthesesIcon = LuParentheses;
exports.LuParkingCircle = LuCircleParking;
exports.LuParkingCircleIcon = LuCircleParking;
exports.LuParkingCircleOff = LuCircleParkingOff;
exports.LuParkingCircleOffIcon = LuCircleParkingOff;
exports.LuParkingMeter = LuParkingMeter;
exports.LuParkingMeterIcon = LuParkingMeter;
exports.LuParkingSquare = LuSquareParking;
exports.LuParkingSquareIcon = LuSquareParking;
exports.LuParkingSquareOff = LuSquareParkingOff;
exports.LuParkingSquareOffIcon = LuSquareParkingOff;
exports.LuPartyPopper = LuPartyPopper;
exports.LuPartyPopperIcon = LuPartyPopper;
exports.LuPause = LuPause;
exports.LuPauseCircle = LuCirclePause;
exports.LuPauseCircleIcon = LuCirclePause;
exports.LuPauseIcon = LuPause;
exports.LuPauseOctagon = LuOctagonPause;
exports.LuPauseOctagonIcon = LuOctagonPause;
exports.LuPawPrint = LuPawPrint;
exports.LuPawPrintIcon = LuPawPrint;
exports.LuPcCase = LuPcCase;
exports.LuPcCaseIcon = LuPcCase;
exports.LuPen = LuPen;
exports.LuPenBox = LuSquarePen;
exports.LuPenBoxIcon = LuSquarePen;
exports.LuPenIcon = LuPen;
exports.LuPenLine = LuPenLine;
exports.LuPenLineIcon = LuPenLine;
exports.LuPenSquare = LuSquarePen;
exports.LuPenSquareIcon = LuSquarePen;
exports.LuPenTool = LuPenTool;
exports.LuPenToolIcon = LuPenTool;
exports.LuPencil = LuPencil;
exports.LuPencilIcon = LuPencil;
exports.LuPencilLine = LuPencilLine;
exports.LuPencilLineIcon = LuPencilLine;
exports.LuPencilRuler = LuPencilRuler;
exports.LuPencilRulerIcon = LuPencilRuler;
exports.LuPentagon = LuPentagon;
exports.LuPentagonIcon = LuPentagon;
exports.LuPercent = LuPercent;
exports.LuPercentCircle = LuCirclePercent;
exports.LuPercentCircleIcon = LuCirclePercent;
exports.LuPercentDiamond = LuDiamondPercent;
exports.LuPercentDiamondIcon = LuDiamondPercent;
exports.LuPercentIcon = LuPercent;
exports.LuPercentSquare = LuSquarePercent;
exports.LuPercentSquareIcon = LuSquarePercent;
exports.LuPersonStanding = LuPersonStanding;
exports.LuPersonStandingIcon = LuPersonStanding;
exports.LuPhone = LuPhone;
exports.LuPhoneCall = LuPhoneCall;
exports.LuPhoneCallIcon = LuPhoneCall;
exports.LuPhoneForwarded = LuPhoneForwarded;
exports.LuPhoneForwardedIcon = LuPhoneForwarded;
exports.LuPhoneIcon = LuPhone;
exports.LuPhoneIncoming = LuPhoneIncoming;
exports.LuPhoneIncomingIcon = LuPhoneIncoming;
exports.LuPhoneMissed = LuPhoneMissed;
exports.LuPhoneMissedIcon = LuPhoneMissed;
exports.LuPhoneOff = LuPhoneOff;
exports.LuPhoneOffIcon = LuPhoneOff;
exports.LuPhoneOutgoing = LuPhoneOutgoing;
exports.LuPhoneOutgoingIcon = LuPhoneOutgoing;
exports.LuPi = LuPi;
exports.LuPiIcon = LuPi;
exports.LuPiSquare = LuSquarePi;
exports.LuPiSquareIcon = LuSquarePi;
exports.LuPiano = LuPiano;
exports.LuPianoIcon = LuPiano;
exports.LuPickaxe = LuPickaxe;
exports.LuPickaxeIcon = LuPickaxe;
exports.LuPictureInPicture = LuPictureInPicture;
exports.LuPictureInPicture2 = LuPictureInPicture2;
exports.LuPictureInPicture2Icon = LuPictureInPicture2;
exports.LuPictureInPictureIcon = LuPictureInPicture;
exports.LuPieChart = LuPieChart;
exports.LuPieChartIcon = LuPieChart;
exports.LuPiggyBank = LuPiggyBank;
exports.LuPiggyBankIcon = LuPiggyBank;
exports.LuPilcrow = LuPilcrow;
exports.LuPilcrowIcon = LuPilcrow;
exports.LuPilcrowSquare = LuSquarePilcrow;
exports.LuPilcrowSquareIcon = LuSquarePilcrow;
exports.LuPill = LuPill;
exports.LuPillIcon = LuPill;
exports.LuPin = LuPin;
exports.LuPinIcon = LuPin;
exports.LuPinOff = LuPinOff;
exports.LuPinOffIcon = LuPinOff;
exports.LuPipette = LuPipette;
exports.LuPipetteIcon = LuPipette;
exports.LuPizza = LuPizza;
exports.LuPizzaIcon = LuPizza;
exports.LuPlane = LuPlane;
exports.LuPlaneIcon = LuPlane;
exports.LuPlaneLanding = LuPlaneLanding;
exports.LuPlaneLandingIcon = LuPlaneLanding;
exports.LuPlaneTakeoff = LuPlaneTakeoff;
exports.LuPlaneTakeoffIcon = LuPlaneTakeoff;
exports.LuPlay = LuPlay;
exports.LuPlayCircle = LuCirclePlay;
exports.LuPlayCircleIcon = LuCirclePlay;
exports.LuPlayIcon = LuPlay;
exports.LuPlaySquare = LuSquarePlay;
exports.LuPlaySquareIcon = LuSquarePlay;
exports.LuPlug = LuPlug;
exports.LuPlug2 = LuPlug2;
exports.LuPlug2Icon = LuPlug2;
exports.LuPlugIcon = LuPlug;
exports.LuPlugZap = LuPlugZap;
exports.LuPlugZap2 = LuPlugZap2;
exports.LuPlugZap2Icon = LuPlugZap2;
exports.LuPlugZapIcon = LuPlugZap;
exports.LuPlus = LuPlus;
exports.LuPlusCircle = LuCirclePlus;
exports.LuPlusCircleIcon = LuCirclePlus;
exports.LuPlusIcon = LuPlus;
exports.LuPlusSquare = LuSquarePlus;
exports.LuPlusSquareIcon = LuSquarePlus;
exports.LuPocket = LuPocket;
exports.LuPocketIcon = LuPocket;
exports.LuPocketKnife = LuPocketKnife;
exports.LuPocketKnifeIcon = LuPocketKnife;
exports.LuPodcast = LuPodcast;
exports.LuPodcastIcon = LuPodcast;
exports.LuPointer = LuPointer;
exports.LuPointerIcon = LuPointer;
exports.LuPointerOff = LuPointerOff;
exports.LuPointerOffIcon = LuPointerOff;
exports.LuPopcorn = LuPopcorn;
exports.LuPopcornIcon = LuPopcorn;
exports.LuPopsicle = LuPopsicle;
exports.LuPopsicleIcon = LuPopsicle;
exports.LuPoundSterling = LuPoundSterling;
exports.LuPoundSterlingIcon = LuPoundSterling;
exports.LuPower = LuPower;
exports.LuPowerCircle = LuCirclePower;
exports.LuPowerCircleIcon = LuCirclePower;
exports.LuPowerIcon = LuPower;
exports.LuPowerOff = LuPowerOff;
exports.LuPowerOffIcon = LuPowerOff;
exports.LuPowerSquare = LuSquarePower;
exports.LuPowerSquareIcon = LuSquarePower;
exports.LuPresentation = LuPresentation;
exports.LuPresentationIcon = LuPresentation;
exports.LuPrinter = LuPrinter;
exports.LuPrinterIcon = LuPrinter;
exports.LuProjector = LuProjector;
exports.LuProjectorIcon = LuProjector;
exports.LuProportions = LuProportions;
exports.LuProportionsIcon = LuProportions;
exports.LuPuzzle = LuPuzzle;
exports.LuPuzzleIcon = LuPuzzle;
exports.LuPyramid = LuPyramid;
exports.LuPyramidIcon = LuPyramid;
exports.LuQrCode = LuQrCode;
exports.LuQrCodeIcon = LuQrCode;
exports.LuQuote = LuQuote;
exports.LuQuoteIcon = LuQuote;
exports.LuRabbit = LuRabbit;
exports.LuRabbitIcon = LuRabbit;
exports.LuRadar = LuRadar;
exports.LuRadarIcon = LuRadar;
exports.LuRadiation = LuRadiation;
exports.LuRadiationIcon = LuRadiation;
exports.LuRadical = LuRadical;
exports.LuRadicalIcon = LuRadical;
exports.LuRadio = LuRadio;
exports.LuRadioIcon = LuRadio;
exports.LuRadioReceiver = LuRadioReceiver;
exports.LuRadioReceiverIcon = LuRadioReceiver;
exports.LuRadioTower = LuRadioTower;
exports.LuRadioTowerIcon = LuRadioTower;
exports.LuRadius = LuRadius;
exports.LuRadiusIcon = LuRadius;
exports.LuRailSymbol = LuRailSymbol;
exports.LuRailSymbolIcon = LuRailSymbol;
exports.LuRainbow = LuRainbow;
exports.LuRainbowIcon = LuRainbow;
exports.LuRat = LuRat;
exports.LuRatIcon = LuRat;
exports.LuRatio = LuRatio;
exports.LuRatioIcon = LuRatio;
exports.LuReceipt = LuReceipt;
exports.LuReceiptCent = LuReceiptCent;
exports.LuReceiptCentIcon = LuReceiptCent;
exports.LuReceiptEuro = LuReceiptEuro;
exports.LuReceiptEuroIcon = LuReceiptEuro;
exports.LuReceiptIcon = LuReceipt;
exports.LuReceiptIndianRupee = LuReceiptIndianRupee;
exports.LuReceiptIndianRupeeIcon = LuReceiptIndianRupee;
exports.LuReceiptJapaneseYen = LuReceiptJapaneseYen;
exports.LuReceiptJapaneseYenIcon = LuReceiptJapaneseYen;
exports.LuReceiptPoundSterling = LuReceiptPoundSterling;
exports.LuReceiptPoundSterlingIcon = LuReceiptPoundSterling;
exports.LuReceiptRussianRuble = LuReceiptRussianRuble;
exports.LuReceiptRussianRubleIcon = LuReceiptRussianRuble;
exports.LuReceiptSwissFranc = LuReceiptSwissFranc;
exports.LuReceiptSwissFrancIcon = LuReceiptSwissFranc;
exports.LuReceiptText = LuReceiptText;
exports.LuReceiptTextIcon = LuReceiptText;
exports.LuRectangleEllipsis = LuRectangleEllipsis;
exports.LuRectangleEllipsisIcon = LuRectangleEllipsis;
exports.LuRectangleHorizontal = LuRectangleHorizontal;
exports.LuRectangleHorizontalIcon = LuRectangleHorizontal;
exports.LuRectangleVertical = LuRectangleVertical;
exports.LuRectangleVerticalIcon = LuRectangleVertical;
exports.LuRecycle = LuRecycle;
exports.LuRecycleIcon = LuRecycle;
exports.LuRedo = LuRedo;
exports.LuRedo2 = LuRedo2;
exports.LuRedo2Icon = LuRedo2;
exports.LuRedoDot = LuRedoDot;
exports.LuRedoDotIcon = LuRedoDot;
exports.LuRedoIcon = LuRedo;
exports.LuRefreshCcw = LuRefreshCcw;
exports.LuRefreshCcwDot = LuRefreshCcwDot;
exports.LuRefreshCcwDotIcon = LuRefreshCcwDot;
exports.LuRefreshCcwIcon = LuRefreshCcw;
exports.LuRefreshCw = LuRefreshCw;
exports.LuRefreshCwIcon = LuRefreshCw;
exports.LuRefreshCwOff = LuRefreshCwOff;
exports.LuRefreshCwOffIcon = LuRefreshCwOff;
exports.LuRefrigerator = LuRefrigerator;
exports.LuRefrigeratorIcon = LuRefrigerator;
exports.LuRegex = LuRegex;
exports.LuRegexIcon = LuRegex;
exports.LuRemoveFormatting = LuRemoveFormatting;
exports.LuRemoveFormattingIcon = LuRemoveFormatting;
exports.LuRepeat = LuRepeat;
exports.LuRepeat1 = LuRepeat1;
exports.LuRepeat1Icon = LuRepeat1;
exports.LuRepeat2 = LuRepeat2;
exports.LuRepeat2Icon = LuRepeat2;
exports.LuRepeatIcon = LuRepeat;
exports.LuReplace = LuReplace;
exports.LuReplaceAll = LuReplaceAll;
exports.LuReplaceAllIcon = LuReplaceAll;
exports.LuReplaceIcon = LuReplace;
exports.LuReply = LuReply;
exports.LuReplyAll = LuReplyAll;
exports.LuReplyAllIcon = LuReplyAll;
exports.LuReplyIcon = LuReply;
exports.LuRewind = LuRewind;
exports.LuRewindIcon = LuRewind;
exports.LuRibbon = LuRibbon;
exports.LuRibbonIcon = LuRibbon;
exports.LuRocket = LuRocket;
exports.LuRocketIcon = LuRocket;
exports.LuRockingChair = LuRockingChair;
exports.LuRockingChairIcon = LuRockingChair;
exports.LuRollerCoaster = LuRollerCoaster;
exports.LuRollerCoasterIcon = LuRollerCoaster;
exports.LuRotate3D = LuRotate3d;
exports.LuRotate3DIcon = LuRotate3d;
exports.LuRotate3d = LuRotate3d;
exports.LuRotate3dIcon = LuRotate3d;
exports.LuRotateCcw = LuRotateCcw;
exports.LuRotateCcwIcon = LuRotateCcw;
exports.LuRotateCcwSquare = LuRotateCcwSquare;
exports.LuRotateCcwSquareIcon = LuRotateCcwSquare;
exports.LuRotateCw = LuRotateCw;
exports.LuRotateCwIcon = LuRotateCw;
exports.LuRotateCwSquare = LuRotateCwSquare;
exports.LuRotateCwSquareIcon = LuRotateCwSquare;
exports.LuRoute = LuRoute;
exports.LuRouteIcon = LuRoute;
exports.LuRouteOff = LuRouteOff;
exports.LuRouteOffIcon = LuRouteOff;
exports.LuRouter = LuRouter;
exports.LuRouterIcon = LuRouter;
exports.LuRows = LuRows2;
exports.LuRows2 = LuRows2;
exports.LuRows2Icon = LuRows2;
exports.LuRows3 = LuRows3;
exports.LuRows3Icon = LuRows3;
exports.LuRows4 = LuRows4;
exports.LuRows4Icon = LuRows4;
exports.LuRowsIcon = LuRows2;
exports.LuRss = LuRss;
exports.LuRssIcon = LuRss;
exports.LuRuler = LuRuler;
exports.LuRulerIcon = LuRuler;
exports.LuRussianRuble = LuRussianRuble;
exports.LuRussianRubleIcon = LuRussianRuble;
exports.LuSailboat = LuSailboat;
exports.LuSailboatIcon = LuSailboat;
exports.LuSalad = LuSalad;
exports.LuSaladIcon = LuSalad;
exports.LuSandwich = LuSandwich;
exports.LuSandwichIcon = LuSandwich;
exports.LuSatellite = LuSatellite;
exports.LuSatelliteDish = LuSatelliteDish;
exports.LuSatelliteDishIcon = LuSatelliteDish;
exports.LuSatelliteIcon = LuSatellite;
exports.LuSave = LuSave;
exports.LuSaveAll = LuSaveAll;
exports.LuSaveAllIcon = LuSaveAll;
exports.LuSaveIcon = LuSave;
exports.LuScale = LuScale;
exports.LuScale3D = LuScale3d;
exports.LuScale3DIcon = LuScale3d;
exports.LuScale3d = LuScale3d;
exports.LuScale3dIcon = LuScale3d;
exports.LuScaleIcon = LuScale;
exports.LuScaling = LuScaling;
exports.LuScalingIcon = LuScaling;
exports.LuScan = LuScan;
exports.LuScanBarcode = LuScanBarcode;
exports.LuScanBarcodeIcon = LuScanBarcode;
exports.LuScanEye = LuScanEye;
exports.LuScanEyeIcon = LuScanEye;
exports.LuScanFace = LuScanFace;
exports.LuScanFaceIcon = LuScanFace;
exports.LuScanIcon = LuScan;
exports.LuScanLine = LuScanLine;
exports.LuScanLineIcon = LuScanLine;
exports.LuScanSearch = LuScanSearch;
exports.LuScanSearchIcon = LuScanSearch;
exports.LuScanText = LuScanText;
exports.LuScanTextIcon = LuScanText;
exports.LuScatterChart = LuScatterChart;
exports.LuScatterChartIcon = LuScatterChart;
exports.LuSchool = LuSchool;
exports.LuSchool2 = LuUniversity;
exports.LuSchool2Icon = LuUniversity;
exports.LuSchoolIcon = LuSchool;
exports.LuScissors = LuScissors;
exports.LuScissorsIcon = LuScissors;
exports.LuScissorsLineDashed = LuScissorsLineDashed;
exports.LuScissorsLineDashedIcon = LuScissorsLineDashed;
exports.LuScissorsSquare = LuSquareScissors;
exports.LuScissorsSquareDashedBottom = LuSquareBottomDashedScissors;
exports.LuScissorsSquareDashedBottomIcon = LuSquareBottomDashedScissors;
exports.LuScissorsSquareIcon = LuSquareScissors;
exports.LuScreenShare = LuScreenShare;
exports.LuScreenShareIcon = LuScreenShare;
exports.LuScreenShareOff = LuScreenShareOff;
exports.LuScreenShareOffIcon = LuScreenShareOff;
exports.LuScroll = LuScroll;
exports.LuScrollIcon = LuScroll;
exports.LuScrollText = LuScrollText;
exports.LuScrollTextIcon = LuScrollText;
exports.LuSearch = LuSearch;
exports.LuSearchCheck = LuSearchCheck;
exports.LuSearchCheckIcon = LuSearchCheck;
exports.LuSearchCode = LuSearchCode;
exports.LuSearchCodeIcon = LuSearchCode;
exports.LuSearchIcon = LuSearch;
exports.LuSearchSlash = LuSearchSlash;
exports.LuSearchSlashIcon = LuSearchSlash;
exports.LuSearchX = LuSearchX;
exports.LuSearchXIcon = LuSearchX;
exports.LuSend = LuSend;
exports.LuSendHorizonal = LuSendHorizontal;
exports.LuSendHorizonalIcon = LuSendHorizontal;
exports.LuSendHorizontal = LuSendHorizontal;
exports.LuSendHorizontalIcon = LuSendHorizontal;
exports.LuSendIcon = LuSend;
exports.LuSendToBack = LuSendToBack;
exports.LuSendToBackIcon = LuSendToBack;
exports.LuSeparatorHorizontal = LuSeparatorHorizontal;
exports.LuSeparatorHorizontalIcon = LuSeparatorHorizontal;
exports.LuSeparatorVertical = LuSeparatorVertical;
exports.LuSeparatorVerticalIcon = LuSeparatorVertical;
exports.LuServer = LuServer;
exports.LuServerCog = LuServerCog;
exports.LuServerCogIcon = LuServerCog;
exports.LuServerCrash = LuServerCrash;
exports.LuServerCrashIcon = LuServerCrash;
exports.LuServerIcon = LuServer;
exports.LuServerOff = LuServerOff;
exports.LuServerOffIcon = LuServerOff;
exports.LuSettings = LuSettings;
exports.LuSettings2 = LuSettings2;
exports.LuSettings2Icon = LuSettings2;
exports.LuSettingsIcon = LuSettings;
exports.LuShapes = LuShapes;
exports.LuShapesIcon = LuShapes;
exports.LuShare = LuShare;
exports.LuShare2 = LuShare2;
exports.LuShare2Icon = LuShare2;
exports.LuShareIcon = LuShare;
exports.LuSheet = LuSheet;
exports.LuSheetIcon = LuSheet;
exports.LuShell = LuShell;
exports.LuShellIcon = LuShell;
exports.LuShield = LuShield;
exports.LuShieldAlert = LuShieldAlert;
exports.LuShieldAlertIcon = LuShieldAlert;
exports.LuShieldBan = LuShieldBan;
exports.LuShieldBanIcon = LuShieldBan;
exports.LuShieldCheck = LuShieldCheck;
exports.LuShieldCheckIcon = LuShieldCheck;
exports.LuShieldClose = LuShieldX;
exports.LuShieldCloseIcon = LuShieldX;
exports.LuShieldEllipsis = LuShieldEllipsis;
exports.LuShieldEllipsisIcon = LuShieldEllipsis;
exports.LuShieldHalf = LuShieldHalf;
exports.LuShieldHalfIcon = LuShieldHalf;
exports.LuShieldIcon = LuShield;
exports.LuShieldMinus = LuShieldMinus;
exports.LuShieldMinusIcon = LuShieldMinus;
exports.LuShieldOff = LuShieldOff;
exports.LuShieldOffIcon = LuShieldOff;
exports.LuShieldPlus = LuShieldPlus;
exports.LuShieldPlusIcon = LuShieldPlus;
exports.LuShieldQuestion = LuShieldQuestion;
exports.LuShieldQuestionIcon = LuShieldQuestion;
exports.LuShieldX = LuShieldX;
exports.LuShieldXIcon = LuShieldX;
exports.LuShip = LuShip;
exports.LuShipIcon = LuShip;
exports.LuShipWheel = LuShipWheel;
exports.LuShipWheelIcon = LuShipWheel;
exports.LuShirt = LuShirt;
exports.LuShirtIcon = LuShirt;
exports.LuShoppingBag = LuShoppingBag;
exports.LuShoppingBagIcon = LuShoppingBag;
exports.LuShoppingBasket = LuShoppingBasket;
exports.LuShoppingBasketIcon = LuShoppingBasket;
exports.LuShoppingCart = LuShoppingCart;
exports.LuShoppingCartIcon = LuShoppingCart;
exports.LuShovel = LuShovel;
exports.LuShovelIcon = LuShovel;
exports.LuShowerHead = LuShowerHead;
exports.LuShowerHeadIcon = LuShowerHead;
exports.LuShrink = LuShrink;
exports.LuShrinkIcon = LuShrink;
exports.LuShrub = LuShrub;
exports.LuShrubIcon = LuShrub;
exports.LuShuffle = LuShuffle;
exports.LuShuffleIcon = LuShuffle;
exports.LuSidebar = LuPanelLeft;
exports.LuSidebarClose = LuPanelLeftClose;
exports.LuSidebarCloseIcon = LuPanelLeftClose;
exports.LuSidebarIcon = LuPanelLeft;
exports.LuSidebarOpen = LuPanelLeftOpen;
exports.LuSidebarOpenIcon = LuPanelLeftOpen;
exports.LuSigma = LuSigma;
exports.LuSigmaIcon = LuSigma;
exports.LuSigmaSquare = LuSquareSigma;
exports.LuSigmaSquareIcon = LuSquareSigma;
exports.LuSignal = LuSignal;
exports.LuSignalHigh = LuSignalHigh;
exports.LuSignalHighIcon = LuSignalHigh;
exports.LuSignalIcon = LuSignal;
exports.LuSignalLow = LuSignalLow;
exports.LuSignalLowIcon = LuSignalLow;
exports.LuSignalMedium = LuSignalMedium;
exports.LuSignalMediumIcon = LuSignalMedium;
exports.LuSignalZero = LuSignalZero;
exports.LuSignalZeroIcon = LuSignalZero;
exports.LuSignpost = LuSignpost;
exports.LuSignpostBig = LuSignpostBig;
exports.LuSignpostBigIcon = LuSignpostBig;
exports.LuSignpostIcon = LuSignpost;
exports.LuSiren = LuSiren;
exports.LuSirenIcon = LuSiren;
exports.LuSkipBack = LuSkipBack;
exports.LuSkipBackIcon = LuSkipBack;
exports.LuSkipForward = LuSkipForward;
exports.LuSkipForwardIcon = LuSkipForward;
exports.LuSkull = LuSkull;
exports.LuSkullIcon = LuSkull;
exports.LuSlack = LuSlack;
exports.LuSlackIcon = LuSlack;
exports.LuSlash = LuSlash;
exports.LuSlashIcon = LuSlash;
exports.LuSlashSquare = LuSquareSlash;
exports.LuSlashSquareIcon = LuSquareSlash;
exports.LuSlice = LuSlice;
exports.LuSliceIcon = LuSlice;
exports.LuSliders = LuSlidersVertical;
exports.LuSlidersHorizontal = LuSlidersHorizontal;
exports.LuSlidersHorizontalIcon = LuSlidersHorizontal;
exports.LuSlidersIcon = LuSlidersVertical;
exports.LuSlidersVertical = LuSlidersVertical;
exports.LuSlidersVerticalIcon = LuSlidersVertical;
exports.LuSmartphone = LuSmartphone;
exports.LuSmartphoneCharging = LuSmartphoneCharging;
exports.LuSmartphoneChargingIcon = LuSmartphoneCharging;
exports.LuSmartphoneIcon = LuSmartphone;
exports.LuSmartphoneNfc = LuSmartphoneNfc;
exports.LuSmartphoneNfcIcon = LuSmartphoneNfc;
exports.LuSmile = LuSmile;
exports.LuSmileIcon = LuSmile;
exports.LuSmilePlus = LuSmilePlus;
exports.LuSmilePlusIcon = LuSmilePlus;
exports.LuSnail = LuSnail;
exports.LuSnailIcon = LuSnail;
exports.LuSnowflake = LuSnowflake;
exports.LuSnowflakeIcon = LuSnowflake;
exports.LuSofa = LuSofa;
exports.LuSofaIcon = LuSofa;
exports.LuSortAsc = LuArrowUpNarrowWide;
exports.LuSortAscIcon = LuArrowUpNarrowWide;
exports.LuSortDesc = LuArrowDownWideNarrow;
exports.LuSortDescIcon = LuArrowDownWideNarrow;
exports.LuSoup = LuSoup;
exports.LuSoupIcon = LuSoup;
exports.LuSpace = LuSpace;
exports.LuSpaceIcon = LuSpace;
exports.LuSpade = LuSpade;
exports.LuSpadeIcon = LuSpade;
exports.LuSparkle = LuSparkle;
exports.LuSparkleIcon = LuSparkle;
exports.LuSparkles = LuSparkles;
exports.LuSparklesIcon = LuSparkles;
exports.LuSpeaker = LuSpeaker;
exports.LuSpeakerIcon = LuSpeaker;
exports.LuSpeech = LuSpeech;
exports.LuSpeechIcon = LuSpeech;
exports.LuSpellCheck = LuSpellCheck;
exports.LuSpellCheck2 = LuSpellCheck2;
exports.LuSpellCheck2Icon = LuSpellCheck2;
exports.LuSpellCheckIcon = LuSpellCheck;
exports.LuSpline = LuSpline;
exports.LuSplineIcon = LuSpline;
exports.LuSplit = LuSplit;
exports.LuSplitIcon = LuSplit;
exports.LuSplitSquareHorizontal = LuSquareSplitHorizontal;
exports.LuSplitSquareHorizontalIcon = LuSquareSplitHorizontal;
exports.LuSplitSquareVertical = LuSquareSplitVertical;
exports.LuSplitSquareVerticalIcon = LuSquareSplitVertical;
exports.LuSprayCan = LuSprayCan;
exports.LuSprayCanIcon = LuSprayCan;
exports.LuSprout = LuSprout;
exports.LuSproutIcon = LuSprout;
exports.LuSquare = LuSquare;
exports.LuSquareActivity = LuSquareActivity;
exports.LuSquareActivityIcon = LuSquareActivity;
exports.LuSquareArrowDown = LuSquareArrowDown;
exports.LuSquareArrowDownIcon = LuSquareArrowDown;
exports.LuSquareArrowDownLeft = LuSquareArrowDownLeft;
exports.LuSquareArrowDownLeftIcon = LuSquareArrowDownLeft;
exports.LuSquareArrowDownRight = LuSquareArrowDownRight;
exports.LuSquareArrowDownRightIcon = LuSquareArrowDownRight;
exports.LuSquareArrowLeft = LuSquareArrowLeft;
exports.LuSquareArrowLeftIcon = LuSquareArrowLeft;
exports.LuSquareArrowOutDownLeft = LuSquareArrowOutDownLeft;
exports.LuSquareArrowOutDownLeftIcon = LuSquareArrowOutDownLeft;
exports.LuSquareArrowOutDownRight = LuSquareArrowOutDownRight;
exports.LuSquareArrowOutDownRightIcon = LuSquareArrowOutDownRight;
exports.LuSquareArrowOutUpLeft = LuSquareArrowOutUpLeft;
exports.LuSquareArrowOutUpLeftIcon = LuSquareArrowOutUpLeft;
exports.LuSquareArrowOutUpRight = LuSquareArrowOutUpRight;
exports.LuSquareArrowOutUpRightIcon = LuSquareArrowOutUpRight;
exports.LuSquareArrowRight = LuSquareArrowRight;
exports.LuSquareArrowRightIcon = LuSquareArrowRight;
exports.LuSquareArrowUp = LuSquareArrowUp;
exports.LuSquareArrowUpIcon = LuSquareArrowUp;
exports.LuSquareArrowUpLeft = LuSquareArrowUpLeft;
exports.LuSquareArrowUpLeftIcon = LuSquareArrowUpLeft;
exports.LuSquareArrowUpRight = LuSquareArrowUpRight;
exports.LuSquareArrowUpRightIcon = LuSquareArrowUpRight;
exports.LuSquareAsterisk = LuSquareAsterisk;
exports.LuSquareAsteriskIcon = LuSquareAsterisk;
exports.LuSquareBottomDashedScissors = LuSquareBottomDashedScissors;
exports.LuSquareBottomDashedScissorsIcon = LuSquareBottomDashedScissors;
exports.LuSquareCheck = LuSquareCheck;
exports.LuSquareCheckBig = LuSquareCheckBig;
exports.LuSquareCheckBigIcon = LuSquareCheckBig;
exports.LuSquareCheckIcon = LuSquareCheck;
exports.LuSquareChevronDown = LuSquareChevronDown;
exports.LuSquareChevronDownIcon = LuSquareChevronDown;
exports.LuSquareChevronLeft = LuSquareChevronLeft;
exports.LuSquareChevronLeftIcon = LuSquareChevronLeft;
exports.LuSquareChevronRight = LuSquareChevronRight;
exports.LuSquareChevronRightIcon = LuSquareChevronRight;
exports.LuSquareChevronUp = LuSquareChevronUp;
exports.LuSquareChevronUpIcon = LuSquareChevronUp;
exports.LuSquareCode = LuSquareCode;
exports.LuSquareCodeIcon = LuSquareCode;
exports.LuSquareDashedBottom = LuSquareDashedBottom;
exports.LuSquareDashedBottomCode = LuSquareDashedBottomCode;
exports.LuSquareDashedBottomCodeIcon = LuSquareDashedBottomCode;
exports.LuSquareDashedBottomIcon = LuSquareDashedBottom;
exports.LuSquareDashedKanban = LuSquareDashedKanban;
exports.LuSquareDashedKanbanIcon = LuSquareDashedKanban;
exports.LuSquareDashedMousePointer = LuSquareDashedMousePointer;
exports.LuSquareDashedMousePointerIcon = LuSquareDashedMousePointer;
exports.LuSquareDivide = LuSquareDivide;
exports.LuSquareDivideIcon = LuSquareDivide;
exports.LuSquareDot = LuSquareDot;
exports.LuSquareDotIcon = LuSquareDot;
exports.LuSquareEqual = LuSquareEqual;
exports.LuSquareEqualIcon = LuSquareEqual;
exports.LuSquareFunction = LuSquareFunction;
exports.LuSquareFunctionIcon = LuSquareFunction;
exports.LuSquareGanttChart = LuSquareGanttChart;
exports.LuSquareGanttChartIcon = LuSquareGanttChart;
exports.LuSquareIcon = LuSquare;
exports.LuSquareKanban = LuSquareKanban;
exports.LuSquareKanbanIcon = LuSquareKanban;
exports.LuSquareLibrary = LuSquareLibrary;
exports.LuSquareLibraryIcon = LuSquareLibrary;
exports.LuSquareM = LuSquareM;
exports.LuSquareMIcon = LuSquareM;
exports.LuSquareMenu = LuSquareMenu;
exports.LuSquareMenuIcon = LuSquareMenu;
exports.LuSquareMinus = LuSquareMinus;
exports.LuSquareMinusIcon = LuSquareMinus;
exports.LuSquareMousePointer = LuSquareMousePointer;
exports.LuSquareMousePointerIcon = LuSquareMousePointer;
exports.LuSquareParking = LuSquareParking;
exports.LuSquareParkingIcon = LuSquareParking;
exports.LuSquareParkingOff = LuSquareParkingOff;
exports.LuSquareParkingOffIcon = LuSquareParkingOff;
exports.LuSquarePen = LuSquarePen;
exports.LuSquarePenIcon = LuSquarePen;
exports.LuSquarePercent = LuSquarePercent;
exports.LuSquarePercentIcon = LuSquarePercent;
exports.LuSquarePi = LuSquarePi;
exports.LuSquarePiIcon = LuSquarePi;
exports.LuSquarePilcrow = LuSquarePilcrow;
exports.LuSquarePilcrowIcon = LuSquarePilcrow;
exports.LuSquarePlay = LuSquarePlay;
exports.LuSquarePlayIcon = LuSquarePlay;
exports.LuSquarePlus = LuSquarePlus;
exports.LuSquarePlusIcon = LuSquarePlus;
exports.LuSquarePower = LuSquarePower;
exports.LuSquarePowerIcon = LuSquarePower;
exports.LuSquareRadical = LuSquareRadical;
exports.LuSquareRadicalIcon = LuSquareRadical;
exports.LuSquareScissors = LuSquareScissors;
exports.LuSquareScissorsIcon = LuSquareScissors;
exports.LuSquareSigma = LuSquareSigma;
exports.LuSquareSigmaIcon = LuSquareSigma;
exports.LuSquareSlash = LuSquareSlash;
exports.LuSquareSlashIcon = LuSquareSlash;
exports.LuSquareSplitHorizontal = LuSquareSplitHorizontal;
exports.LuSquareSplitHorizontalIcon = LuSquareSplitHorizontal;
exports.LuSquareSplitVertical = LuSquareSplitVertical;
exports.LuSquareSplitVerticalIcon = LuSquareSplitVertical;
exports.LuSquareStack = LuSquareStack;
exports.LuSquareStackIcon = LuSquareStack;
exports.LuSquareTerminal = LuSquareTerminal;
exports.LuSquareTerminalIcon = LuSquareTerminal;
exports.LuSquareUser = LuSquareUser;
exports.LuSquareUserIcon = LuSquareUser;
exports.LuSquareUserRound = LuSquareUserRound;
exports.LuSquareUserRoundIcon = LuSquareUserRound;
exports.LuSquareX = LuSquareX;
exports.LuSquareXIcon = LuSquareX;
exports.LuSquircle = LuSquircle;
exports.LuSquircleIcon = LuSquircle;
exports.LuSquirrel = LuSquirrel;
exports.LuSquirrelIcon = LuSquirrel;
exports.LuStamp = LuStamp;
exports.LuStampIcon = LuStamp;
exports.LuStar = LuStar;
exports.LuStarHalf = LuStarHalf;
exports.LuStarHalfIcon = LuStarHalf;
exports.LuStarIcon = LuStar;
exports.LuStarOff = LuStarOff;
exports.LuStarOffIcon = LuStarOff;
exports.LuStars = LuSparkles;
exports.LuStarsIcon = LuSparkles;
exports.LuStepBack = LuStepBack;
exports.LuStepBackIcon = LuStepBack;
exports.LuStepForward = LuStepForward;
exports.LuStepForwardIcon = LuStepForward;
exports.LuStethoscope = LuStethoscope;
exports.LuStethoscopeIcon = LuStethoscope;
exports.LuSticker = LuSticker;
exports.LuStickerIcon = LuSticker;
exports.LuStickyNote = LuStickyNote;
exports.LuStickyNoteIcon = LuStickyNote;
exports.LuStopCircle = LuCircleStop;
exports.LuStopCircleIcon = LuCircleStop;
exports.LuStore = LuStore;
exports.LuStoreIcon = LuStore;
exports.LuStretchHorizontal = LuStretchHorizontal;
exports.LuStretchHorizontalIcon = LuStretchHorizontal;
exports.LuStretchVertical = LuStretchVertical;
exports.LuStretchVerticalIcon = LuStretchVertical;
exports.LuStrikethrough = LuStrikethrough;
exports.LuStrikethroughIcon = LuStrikethrough;
exports.LuSubscript = LuSubscript;
exports.LuSubscriptIcon = LuSubscript;
exports.LuSubtitles = LuCaptions;
exports.LuSubtitlesIcon = LuCaptions;
exports.LuSun = LuSun;
exports.LuSunDim = LuSunDim;
exports.LuSunDimIcon = LuSunDim;
exports.LuSunIcon = LuSun;
exports.LuSunMedium = LuSunMedium;
exports.LuSunMediumIcon = LuSunMedium;
exports.LuSunMoon = LuSunMoon;
exports.LuSunMoonIcon = LuSunMoon;
exports.LuSunSnow = LuSunSnow;
exports.LuSunSnowIcon = LuSunSnow;
exports.LuSunrise = LuSunrise;
exports.LuSunriseIcon = LuSunrise;
exports.LuSunset = LuSunset;
exports.LuSunsetIcon = LuSunset;
exports.LuSuperscript = LuSuperscript;
exports.LuSuperscriptIcon = LuSuperscript;
exports.LuSwatchBook = LuSwatchBook;
exports.LuSwatchBookIcon = LuSwatchBook;
exports.LuSwissFranc = LuSwissFranc;
exports.LuSwissFrancIcon = LuSwissFranc;
exports.LuSwitchCamera = LuSwitchCamera;
exports.LuSwitchCameraIcon = LuSwitchCamera;
exports.LuSword = LuSword;
exports.LuSwordIcon = LuSword;
exports.LuSwords = LuSwords;
exports.LuSwordsIcon = LuSwords;
exports.LuSyringe = LuSyringe;
exports.LuSyringeIcon = LuSyringe;
exports.LuTable = LuTable;
exports.LuTable2 = LuTable2;
exports.LuTable2Icon = LuTable2;
exports.LuTableCellsMerge = LuTableCellsMerge;
exports.LuTableCellsMergeIcon = LuTableCellsMerge;
exports.LuTableCellsSplit = LuTableCellsSplit;
exports.LuTableCellsSplitIcon = LuTableCellsSplit;
exports.LuTableColumnsSplit = LuTableColumnsSplit;
exports.LuTableColumnsSplitIcon = LuTableColumnsSplit;
exports.LuTableIcon = LuTable;
exports.LuTableProperties = LuTableProperties;
exports.LuTablePropertiesIcon = LuTableProperties;
exports.LuTableRowsSplit = LuTableRowsSplit;
exports.LuTableRowsSplitIcon = LuTableRowsSplit;
exports.LuTablet = LuTablet;
exports.LuTabletIcon = LuTablet;
exports.LuTabletSmartphone = LuTabletSmartphone;
exports.LuTabletSmartphoneIcon = LuTabletSmartphone;
exports.LuTablets = LuTablets;
exports.LuTabletsIcon = LuTablets;
exports.LuTag = LuTag;
exports.LuTagIcon = LuTag;
exports.LuTags = LuTags;
exports.LuTagsIcon = LuTags;
exports.LuTally1 = LuTally1;
exports.LuTally1Icon = LuTally1;
exports.LuTally2 = LuTally2;
exports.LuTally2Icon = LuTally2;
exports.LuTally3 = LuTally3;
exports.LuTally3Icon = LuTally3;
exports.LuTally4 = LuTally4;
exports.LuTally4Icon = LuTally4;
exports.LuTally5 = LuTally5;
exports.LuTally5Icon = LuTally5;
exports.LuTangent = LuTangent;
exports.LuTangentIcon = LuTangent;
exports.LuTarget = LuTarget;
exports.LuTargetIcon = LuTarget;
exports.LuTelescope = LuTelescope;
exports.LuTelescopeIcon = LuTelescope;
exports.LuTent = LuTent;
exports.LuTentIcon = LuTent;
exports.LuTentTree = LuTentTree;
exports.LuTentTreeIcon = LuTentTree;
exports.LuTerminal = LuTerminal;
exports.LuTerminalIcon = LuTerminal;
exports.LuTerminalSquare = LuSquareTerminal;
exports.LuTerminalSquareIcon = LuSquareTerminal;
exports.LuTestTube = LuTestTube;
exports.LuTestTube2 = LuTestTubeDiagonal;
exports.LuTestTube2Icon = LuTestTubeDiagonal;
exports.LuTestTubeDiagonal = LuTestTubeDiagonal;
exports.LuTestTubeDiagonalIcon = LuTestTubeDiagonal;
exports.LuTestTubeIcon = LuTestTube;
exports.LuTestTubes = LuTestTubes;
exports.LuTestTubesIcon = LuTestTubes;
exports.LuText = LuText;
exports.LuTextCursor = LuTextCursor;
exports.LuTextCursorIcon = LuTextCursor;
exports.LuTextCursorInput = LuTextCursorInput;
exports.LuTextCursorInputIcon = LuTextCursorInput;
exports.LuTextIcon = LuText;
exports.LuTextQuote = LuTextQuote;
exports.LuTextQuoteIcon = LuTextQuote;
exports.LuTextSearch = LuTextSearch;
exports.LuTextSearchIcon = LuTextSearch;
exports.LuTextSelect = LuTextSelect;
exports.LuTextSelectIcon = LuTextSelect;
exports.LuTextSelection = LuTextSelect;
exports.LuTextSelectionIcon = LuTextSelect;
exports.LuTheater = LuTheater;
exports.LuTheaterIcon = LuTheater;
exports.LuThermometer = LuThermometer;
exports.LuThermometerIcon = LuThermometer;
exports.LuThermometerSnowflake = LuThermometerSnowflake;
exports.LuThermometerSnowflakeIcon = LuThermometerSnowflake;
exports.LuThermometerSun = LuThermometerSun;
exports.LuThermometerSunIcon = LuThermometerSun;
exports.LuThumbsDown = LuThumbsDown;
exports.LuThumbsDownIcon = LuThumbsDown;
exports.LuThumbsUp = LuThumbsUp;
exports.LuThumbsUpIcon = LuThumbsUp;
exports.LuTicket = LuTicket;
exports.LuTicketCheck = LuTicketCheck;
exports.LuTicketCheckIcon = LuTicketCheck;
exports.LuTicketIcon = LuTicket;
exports.LuTicketMinus = LuTicketMinus;
exports.LuTicketMinusIcon = LuTicketMinus;
exports.LuTicketPercent = LuTicketPercent;
exports.LuTicketPercentIcon = LuTicketPercent;
exports.LuTicketPlus = LuTicketPlus;
exports.LuTicketPlusIcon = LuTicketPlus;
exports.LuTicketSlash = LuTicketSlash;
exports.LuTicketSlashIcon = LuTicketSlash;
exports.LuTicketX = LuTicketX;
exports.LuTicketXIcon = LuTicketX;
exports.LuTimer = LuTimer;
exports.LuTimerIcon = LuTimer;
exports.LuTimerOff = LuTimerOff;
exports.LuTimerOffIcon = LuTimerOff;
exports.LuTimerReset = LuTimerReset;
exports.LuTimerResetIcon = LuTimerReset;
exports.LuToggleLeft = LuToggleLeft;
exports.LuToggleLeftIcon = LuToggleLeft;
exports.LuToggleRight = LuToggleRight;
exports.LuToggleRightIcon = LuToggleRight;
exports.LuTornado = LuTornado;
exports.LuTornadoIcon = LuTornado;
exports.LuTorus = LuTorus;
exports.LuTorusIcon = LuTorus;
exports.LuTouchpad = LuTouchpad;
exports.LuTouchpadIcon = LuTouchpad;
exports.LuTouchpadOff = LuTouchpadOff;
exports.LuTouchpadOffIcon = LuTouchpadOff;
exports.LuTowerControl = LuTowerControl;
exports.LuTowerControlIcon = LuTowerControl;
exports.LuToyBrick = LuToyBrick;
exports.LuToyBrickIcon = LuToyBrick;
exports.LuTractor = LuTractor;
exports.LuTractorIcon = LuTractor;
exports.LuTrafficCone = LuTrafficCone;
exports.LuTrafficConeIcon = LuTrafficCone;
exports.LuTrain = LuTramFront;
exports.LuTrainFront = LuTrainFront;
exports.LuTrainFrontIcon = LuTrainFront;
exports.LuTrainFrontTunnel = LuTrainFrontTunnel;
exports.LuTrainFrontTunnelIcon = LuTrainFrontTunnel;
exports.LuTrainIcon = LuTramFront;
exports.LuTrainTrack = LuTrainTrack;
exports.LuTrainTrackIcon = LuTrainTrack;
exports.LuTramFront = LuTramFront;
exports.LuTramFrontIcon = LuTramFront;
exports.LuTrash = LuTrash;
exports.LuTrash2 = LuTrash2;
exports.LuTrash2Icon = LuTrash2;
exports.LuTrashIcon = LuTrash;
exports.LuTreeDeciduous = LuTreeDeciduous;
exports.LuTreeDeciduousIcon = LuTreeDeciduous;
exports.LuTreePalm = LuTreePalm;
exports.LuTreePalmIcon = LuTreePalm;
exports.LuTreePine = LuTreePine;
exports.LuTreePineIcon = LuTreePine;
exports.LuTrees = LuTrees;
exports.LuTreesIcon = LuTrees;
exports.LuTrello = LuTrello;
exports.LuTrelloIcon = LuTrello;
exports.LuTrendingDown = LuTrendingDown;
exports.LuTrendingDownIcon = LuTrendingDown;
exports.LuTrendingUp = LuTrendingUp;
exports.LuTrendingUpIcon = LuTrendingUp;
exports.LuTriangle = LuTriangle;
exports.LuTriangleAlert = LuTriangleAlert;
exports.LuTriangleAlertIcon = LuTriangleAlert;
exports.LuTriangleIcon = LuTriangle;
exports.LuTriangleRight = LuTriangleRight;
exports.LuTriangleRightIcon = LuTriangleRight;
exports.LuTrophy = LuTrophy;
exports.LuTrophyIcon = LuTrophy;
exports.LuTruck = LuTruck;
exports.LuTruckIcon = LuTruck;
exports.LuTurtle = LuTurtle;
exports.LuTurtleIcon = LuTurtle;
exports.LuTv = LuTv;
exports.LuTv2 = LuTv2;
exports.LuTv2Icon = LuTv2;
exports.LuTvIcon = LuTv;
exports.LuTwitch = LuTwitch;
exports.LuTwitchIcon = LuTwitch;
exports.LuTwitter = LuTwitter;
exports.LuTwitterIcon = LuTwitter;
exports.LuType = LuType;
exports.LuTypeIcon = LuType;
exports.LuUmbrella = LuUmbrella;
exports.LuUmbrellaIcon = LuUmbrella;
exports.LuUmbrellaOff = LuUmbrellaOff;
exports.LuUmbrellaOffIcon = LuUmbrellaOff;
exports.LuUnderline = LuUnderline;
exports.LuUnderlineIcon = LuUnderline;
exports.LuUndo = LuUndo;
exports.LuUndo2 = LuUndo2;
exports.LuUndo2Icon = LuUndo2;
exports.LuUndoDot = LuUndoDot;
exports.LuUndoDotIcon = LuUndoDot;
exports.LuUndoIcon = LuUndo;
exports.LuUnfoldHorizontal = LuUnfoldHorizontal;
exports.LuUnfoldHorizontalIcon = LuUnfoldHorizontal;
exports.LuUnfoldVertical = LuUnfoldVertical;
exports.LuUnfoldVerticalIcon = LuUnfoldVertical;
exports.LuUngroup = LuUngroup;
exports.LuUngroupIcon = LuUngroup;
exports.LuUniversity = LuUniversity;
exports.LuUniversityIcon = LuUniversity;
exports.LuUnlink = LuUnlink;
exports.LuUnlink2 = LuUnlink2;
exports.LuUnlink2Icon = LuUnlink2;
exports.LuUnlinkIcon = LuUnlink;
exports.LuUnlock = LuLockOpen;
exports.LuUnlockIcon = LuLockOpen;
exports.LuUnlockKeyhole = LuLockKeyholeOpen;
exports.LuUnlockKeyholeIcon = LuLockKeyholeOpen;
exports.LuUnplug = LuUnplug;
exports.LuUnplugIcon = LuUnplug;
exports.LuUpload = LuUpload;
exports.LuUploadCloud = LuCloudUpload;
exports.LuUploadCloudIcon = LuCloudUpload;
exports.LuUploadIcon = LuUpload;
exports.LuUsb = LuUsb;
exports.LuUsbIcon = LuUsb;
exports.LuUser = LuUser;
exports.LuUser2 = LuUserRound;
exports.LuUser2Icon = LuUserRound;
exports.LuUserCheck = LuUserCheck;
exports.LuUserCheck2 = LuUserRoundCheck;
exports.LuUserCheck2Icon = LuUserRoundCheck;
exports.LuUserCheckIcon = LuUserCheck;
exports.LuUserCircle = LuCircleUser;
exports.LuUserCircle2 = LuCircleUserRound;
exports.LuUserCircle2Icon = LuCircleUserRound;
exports.LuUserCircleIcon = LuCircleUser;
exports.LuUserCog = LuUserCog;
exports.LuUserCog2 = LuUserRoundCog;
exports.LuUserCog2Icon = LuUserRoundCog;
exports.LuUserCogIcon = LuUserCog;
exports.LuUserIcon = LuUser;
exports.LuUserMinus = LuUserMinus;
exports.LuUserMinus2 = LuUserRoundMinus;
exports.LuUserMinus2Icon = LuUserRoundMinus;
exports.LuUserMinusIcon = LuUserMinus;
exports.LuUserPlus = LuUserPlus;
exports.LuUserPlus2 = LuUserRoundPlus;
exports.LuUserPlus2Icon = LuUserRoundPlus;
exports.LuUserPlusIcon = LuUserPlus;
exports.LuUserRound = LuUserRound;
exports.LuUserRoundCheck = LuUserRoundCheck;
exports.LuUserRoundCheckIcon = LuUserRoundCheck;
exports.LuUserRoundCog = LuUserRoundCog;
exports.LuUserRoundCogIcon = LuUserRoundCog;
exports.LuUserRoundIcon = LuUserRound;
exports.LuUserRoundMinus = LuUserRoundMinus;
exports.LuUserRoundMinusIcon = LuUserRoundMinus;
exports.LuUserRoundPlus = LuUserRoundPlus;
exports.LuUserRoundPlusIcon = LuUserRoundPlus;
exports.LuUserRoundSearch = LuUserRoundSearch;
exports.LuUserRoundSearchIcon = LuUserRoundSearch;
exports.LuUserRoundX = LuUserRoundX;
exports.LuUserRoundXIcon = LuUserRoundX;
exports.LuUserSearch = LuUserSearch;
exports.LuUserSearchIcon = LuUserSearch;
exports.LuUserSquare = LuSquareUser;
exports.LuUserSquare2 = LuSquareUserRound;
exports.LuUserSquare2Icon = LuSquareUserRound;
exports.LuUserSquareIcon = LuSquareUser;
exports.LuUserX = LuUserX;
exports.LuUserX2 = LuUserRoundX;
exports.LuUserX2Icon = LuUserRoundX;
exports.LuUserXIcon = LuUserX;
exports.LuUsers = LuUsers;
exports.LuUsers2 = LuUsersRound;
exports.LuUsers2Icon = LuUsersRound;
exports.LuUsersIcon = LuUsers;
exports.LuUsersRound = LuUsersRound;
exports.LuUsersRoundIcon = LuUsersRound;
exports.LuUtensils = LuUtensils;
exports.LuUtensilsCrossed = LuUtensilsCrossed;
exports.LuUtensilsCrossedIcon = LuUtensilsCrossed;
exports.LuUtensilsIcon = LuUtensils;
exports.LuUtilityPole = LuUtilityPole;
exports.LuUtilityPoleIcon = LuUtilityPole;
exports.LuVariable = LuVariable;
exports.LuVariableIcon = LuVariable;
exports.LuVault = LuVault;
exports.LuVaultIcon = LuVault;
exports.LuVegan = LuVegan;
exports.LuVeganIcon = LuVegan;
exports.LuVenetianMask = LuVenetianMask;
exports.LuVenetianMaskIcon = LuVenetianMask;
exports.LuVerified = LuBadgeCheck;
exports.LuVerifiedIcon = LuBadgeCheck;
exports.LuVibrate = LuVibrate;
exports.LuVibrateIcon = LuVibrate;
exports.LuVibrateOff = LuVibrateOff;
exports.LuVibrateOffIcon = LuVibrateOff;
exports.LuVideo = LuVideo;
exports.LuVideoIcon = LuVideo;
exports.LuVideoOff = LuVideoOff;
exports.LuVideoOffIcon = LuVideoOff;
exports.LuVideotape = LuVideotape;
exports.LuVideotapeIcon = LuVideotape;
exports.LuView = LuView;
exports.LuViewIcon = LuView;
exports.LuVoicemail = LuVoicemail;
exports.LuVoicemailIcon = LuVoicemail;
exports.LuVolume = LuVolume;
exports.LuVolume1 = LuVolume1;
exports.LuVolume1Icon = LuVolume1;
exports.LuVolume2 = LuVolume2;
exports.LuVolume2Icon = LuVolume2;
exports.LuVolumeIcon = LuVolume;
exports.LuVolumeX = LuVolumeX;
exports.LuVolumeXIcon = LuVolumeX;
exports.LuVote = LuVote;
exports.LuVoteIcon = LuVote;
exports.LuWallet = LuWallet;
exports.LuWallet2 = LuWalletMinimal;
exports.LuWallet2Icon = LuWalletMinimal;
exports.LuWalletCards = LuWalletCards;
exports.LuWalletCardsIcon = LuWalletCards;
exports.LuWalletIcon = LuWallet;
exports.LuWalletMinimal = LuWalletMinimal;
exports.LuWalletMinimalIcon = LuWalletMinimal;
exports.LuWallpaper = LuWallpaper;
exports.LuWallpaperIcon = LuWallpaper;
exports.LuWand = LuWand;
exports.LuWand2 = LuWandSparkles;
exports.LuWand2Icon = LuWandSparkles;
exports.LuWandIcon = LuWand;
exports.LuWandSparkles = LuWandSparkles;
exports.LuWandSparklesIcon = LuWandSparkles;
exports.LuWarehouse = LuWarehouse;
exports.LuWarehouseIcon = LuWarehouse;
exports.LuWashingMachine = LuWashingMachine;
exports.LuWashingMachineIcon = LuWashingMachine;
exports.LuWatch = LuWatch;
exports.LuWatchIcon = LuWatch;
exports.LuWaves = LuWaves;
exports.LuWavesIcon = LuWaves;
exports.LuWaypoints = LuWaypoints;
exports.LuWaypointsIcon = LuWaypoints;
exports.LuWebcam = LuWebcam;
exports.LuWebcamIcon = LuWebcam;
exports.LuWebhook = LuWebhook;
exports.LuWebhookIcon = LuWebhook;
exports.LuWebhookOff = LuWebhookOff;
exports.LuWebhookOffIcon = LuWebhookOff;
exports.LuWeight = LuWeight;
exports.LuWeightIcon = LuWeight;
exports.LuWheat = LuWheat;
exports.LuWheatIcon = LuWheat;
exports.LuWheatOff = LuWheatOff;
exports.LuWheatOffIcon = LuWheatOff;
exports.LuWholeWord = LuWholeWord;
exports.LuWholeWordIcon = LuWholeWord;
exports.LuWifi = LuWifi;
exports.LuWifiIcon = LuWifi;
exports.LuWifiOff = LuWifiOff;
exports.LuWifiOffIcon = LuWifiOff;
exports.LuWind = LuWind;
exports.LuWindIcon = LuWind;
exports.LuWine = LuWine;
exports.LuWineIcon = LuWine;
exports.LuWineOff = LuWineOff;
exports.LuWineOffIcon = LuWineOff;
exports.LuWorkflow = LuWorkflow;
exports.LuWorkflowIcon = LuWorkflow;
exports.LuWrapText = LuWrapText;
exports.LuWrapTextIcon = LuWrapText;
exports.LuWrench = LuWrench;
exports.LuWrenchIcon = LuWrench;
exports.LuX = LuX;
exports.LuXCircle = LuCircleX;
exports.LuXCircleIcon = LuCircleX;
exports.LuXIcon = LuX;
exports.LuXOctagon = LuOctagonX;
exports.LuXOctagonIcon = LuOctagonX;
exports.LuXSquare = LuSquareX;
exports.LuXSquareIcon = LuSquareX;
exports.LuYoutube = LuYoutube;
exports.LuYoutubeIcon = LuYoutube;
exports.LuZap = LuZap;
exports.LuZapIcon = LuZap;
exports.LuZapOff = LuZapOff;
exports.LuZapOffIcon = LuZapOff;
exports.LuZoomIn = LuZoomIn;
exports.LuZoomInIcon = LuZoomIn;
exports.LuZoomOut = LuZoomOut;
exports.LuZoomOutIcon = LuZoomOut;
exports.LucideLuAArrowDown = LuAArrowDown;
exports.LucideLuAArrowUp = LuAArrowUp;
exports.LucideLuALargeSmall = LuALargeSmall;
exports.LucideLuAccessibility = LuAccessibility;
exports.LucideLuActivity = LuActivity;
exports.LucideLuActivitySquare = LuSquareActivity;
exports.LucideLuAirVent = LuAirVent;
exports.LucideLuAirplay = LuAirplay;
exports.LucideLuAlarmCheck = LuAlarmClockCheck;
exports.LucideLuAlarmClock = LuAlarmClock;
exports.LucideLuAlarmClockCheck = LuAlarmClockCheck;
exports.LucideLuAlarmClockMinus = LuAlarmClockMinus;
exports.LucideLuAlarmClockOff = LuAlarmClockOff;
exports.LucideLuAlarmClockPlus = LuAlarmClockPlus;
exports.LucideLuAlarmMinus = LuAlarmClockMinus;
exports.LucideLuAlarmPlus = LuAlarmClockPlus;
exports.LucideLuAlarmSmoke = LuAlarmSmoke;
exports.LucideLuAlbum = LuAlbum;
exports.LucideLuAlertCircle = LuCircleAlert;
exports.LucideLuAlertOctagon = LuOctagonAlert;
exports.LucideLuAlertTriangle = LuTriangleAlert;
exports.LucideLuAlignCenter = LuAlignCenter;
exports.LucideLuAlignCenterHorizontal = LuAlignCenterHorizontal;
exports.LucideLuAlignCenterVertical = LuAlignCenterVertical;
exports.LucideLuAlignEndHorizontal = LuAlignEndHorizontal;
exports.LucideLuAlignEndVertical = LuAlignEndVertical;
exports.LucideLuAlignHorizontalDistributeCenter = LuAlignHorizontalDistributeCenter;
exports.LucideLuAlignHorizontalDistributeEnd = LuAlignHorizontalDistributeEnd;
exports.LucideLuAlignHorizontalDistributeStart = LuAlignHorizontalDistributeStart;
exports.LucideLuAlignHorizontalJustifyCenter = LuAlignHorizontalJustifyCenter;
exports.LucideLuAlignHorizontalJustifyEnd = LuAlignHorizontalJustifyEnd;
exports.LucideLuAlignHorizontalJustifyStart = LuAlignHorizontalJustifyStart;
exports.LucideLuAlignHorizontalSpaceAround = LuAlignHorizontalSpaceAround;
exports.LucideLuAlignHorizontalSpaceBetween = LuAlignHorizontalSpaceBetween;
exports.LucideLuAlignJustify = LuAlignJustify;
exports.LucideLuAlignLeft = LuAlignLeft;
exports.LucideLuAlignRight = LuAlignRight;
exports.LucideLuAlignStartHorizontal = LuAlignStartHorizontal;
exports.LucideLuAlignStartVertical = LuAlignStartVertical;
exports.LucideLuAlignVerticalDistributeCenter = LuAlignVerticalDistributeCenter;
exports.LucideLuAlignVerticalDistributeEnd = LuAlignVerticalDistributeEnd;
exports.LucideLuAlignVerticalDistributeStart = LuAlignVerticalDistributeStart;
exports.LucideLuAlignVerticalJustifyCenter = LuAlignVerticalJustifyCenter;
exports.LucideLuAlignVerticalJustifyEnd = LuAlignVerticalJustifyEnd;
exports.LucideLuAlignVerticalJustifyStart = LuAlignVerticalJustifyStart;
exports.LucideLuAlignVerticalSpaceAround = LuAlignVerticalSpaceAround;
exports.LucideLuAlignVerticalSpaceBetween = LuAlignVerticalSpaceBetween;
exports.LucideLuAmbulance = LuAmbulance;
exports.LucideLuAmpersand = LuAmpersand;
exports.LucideLuAmpersands = LuAmpersands;
exports.LucideLuAnchor = LuAnchor;
exports.LucideLuAngry = LuAngry;
exports.LucideLuAnnoyed = LuAnnoyed;
exports.LucideLuAntenna = LuAntenna;
exports.LucideLuAnvil = LuAnvil;
exports.LucideLuAperture = LuAperture;
exports.LucideLuAppWindow = LuAppWindow;
exports.LucideLuAppWindowMac = LuAppWindowMac;
exports.LucideLuApple = LuApple;
exports.LucideLuArchive = LuArchive;
exports.LucideLuArchiveRestore = LuArchiveRestore;
exports.LucideLuArchiveX = LuArchiveX;
exports.LucideLuAreaChart = LuAreaChart;
exports.LucideLuArmchair = LuArmchair;
exports.LucideLuArrowBigDown = LuArrowBigDown;
exports.LucideLuArrowBigDownDash = LuArrowBigDownDash;
exports.LucideLuArrowBigLeft = LuArrowBigLeft;
exports.LucideLuArrowBigLeftDash = LuArrowBigLeftDash;
exports.LucideLuArrowBigRight = LuArrowBigRight;
exports.LucideLuArrowBigRightDash = LuArrowBigRightDash;
exports.LucideLuArrowBigUp = LuArrowBigUp;
exports.LucideLuArrowBigUpDash = LuArrowBigUpDash;
exports.LucideLuArrowDown = LuArrowDown;
exports.LucideLuArrowDown01 = LuArrowDown01;
exports.LucideLuArrowDown10 = LuArrowDown10;
exports.LucideLuArrowDownAZ = LuArrowDownAZ;
exports.LucideLuArrowDownAz = LuArrowDownAZ;
exports.LucideLuArrowDownCircle = LuCircleArrowDown;
exports.LucideLuArrowDownFromLine = LuArrowDownFromLine;
exports.LucideLuArrowDownLeft = LuArrowDownLeft;
exports.LucideLuArrowDownLeftFromCircle = LuCircleArrowOutDownLeft;
exports.LucideLuArrowDownLeftFromSquare = LuSquareArrowOutDownLeft;
exports.LucideLuArrowDownLeftSquare = LuSquareArrowDownLeft;
exports.LucideLuArrowDownNarrowWide = LuArrowDownNarrowWide;
exports.LucideLuArrowDownRight = LuArrowDownRight;
exports.LucideLuArrowDownRightFromCircle = LuCircleArrowOutDownRight;
exports.LucideLuArrowDownRightFromSquare = LuSquareArrowOutDownRight;
exports.LucideLuArrowDownRightSquare = LuSquareArrowDownRight;
exports.LucideLuArrowDownSquare = LuSquareArrowDown;
exports.LucideLuArrowDownToDot = LuArrowDownToDot;
exports.LucideLuArrowDownToLine = LuArrowDownToLine;
exports.LucideLuArrowDownUp = LuArrowDownUp;
exports.LucideLuArrowDownWideNarrow = LuArrowDownWideNarrow;
exports.LucideLuArrowDownZA = LuArrowDownZA;
exports.LucideLuArrowDownZa = LuArrowDownZA;
exports.LucideLuArrowLeft = LuArrowLeft;
exports.LucideLuArrowLeftCircle = LuCircleArrowLeft;
exports.LucideLuArrowLeftFromLine = LuArrowLeftFromLine;
exports.LucideLuArrowLeftRight = LuArrowLeftRight;
exports.LucideLuArrowLeftSquare = LuSquareArrowLeft;
exports.LucideLuArrowLeftToLine = LuArrowLeftToLine;
exports.LucideLuArrowRight = LuArrowRight;
exports.LucideLuArrowRightCircle = LuCircleArrowRight;
exports.LucideLuArrowRightFromLine = LuArrowRightFromLine;
exports.LucideLuArrowRightLeft = LuArrowRightLeft;
exports.LucideLuArrowRightSquare = LuSquareArrowRight;
exports.LucideLuArrowRightToLine = LuArrowRightToLine;
exports.LucideLuArrowUp = LuArrowUp;
exports.LucideLuArrowUp01 = LuArrowUp01;
exports.LucideLuArrowUp10 = LuArrowUp10;
exports.LucideLuArrowUpAZ = LuArrowUpAZ;
exports.LucideLuArrowUpAz = LuArrowUpAZ;
exports.LucideLuArrowUpCircle = LuCircleArrowUp;
exports.LucideLuArrowUpDown = LuArrowUpDown;
exports.LucideLuArrowUpFromDot = LuArrowUpFromDot;
exports.LucideLuArrowUpFromLine = LuArrowUpFromLine;
exports.LucideLuArrowUpLeft = LuArrowUpLeft;
exports.LucideLuArrowUpLeftFromCircle = LuCircleArrowOutUpLeft;
exports.LucideLuArrowUpLeftFromSquare = LuSquareArrowOutUpLeft;
exports.LucideLuArrowUpLeftSquare = LuSquareArrowUpLeft;
exports.LucideLuArrowUpNarrowWide = LuArrowUpNarrowWide;
exports.LucideLuArrowUpRight = LuArrowUpRight;
exports.LucideLuArrowUpRightFromCircle = LuCircleArrowOutUpRight;
exports.LucideLuArrowUpRightFromSquare = LuSquareArrowOutUpRight;
exports.LucideLuArrowUpRightSquare = LuSquareArrowUpRight;
exports.LucideLuArrowUpSquare = LuSquareArrowUp;
exports.LucideLuArrowUpToLine = LuArrowUpToLine;
exports.LucideLuArrowUpWideNarrow = LuArrowUpWideNarrow;
exports.LucideLuArrowUpZA = LuArrowUpZA;
exports.LucideLuArrowUpZa = LuArrowUpZA;
exports.LucideLuArrowsUpFromLine = LuArrowsUpFromLine;
exports.LucideLuAsterisk = LuAsterisk;
exports.LucideLuAsteriskSquare = LuSquareAsterisk;
exports.LucideLuAtSign = LuAtSign;
exports.LucideLuAtom = LuAtom;
exports.LucideLuAudioLines = LuAudioLines;
exports.LucideLuAudioWaveform = LuAudioWaveform;
exports.LucideLuAward = LuAward;
exports.LucideLuAxe = LuAxe;
exports.LucideLuAxis3D = LuAxis3d;
exports.LucideLuAxis3d = LuAxis3d;
exports.LucideLuBaby = LuBaby;
exports.LucideLuBackpack = LuBackpack;
exports.LucideLuBadge = LuBadge;
exports.LucideLuBadgeAlert = LuBadgeAlert;
exports.LucideLuBadgeCent = LuBadgeCent;
exports.LucideLuBadgeCheck = LuBadgeCheck;
exports.LucideLuBadgeDollarSign = LuBadgeDollarSign;
exports.LucideLuBadgeEuro = LuBadgeEuro;
exports.LucideLuBadgeHelp = LuBadgeHelp;
exports.LucideLuBadgeIndianRupee = LuBadgeIndianRupee;
exports.LucideLuBadgeInfo = LuBadgeInfo;
exports.LucideLuBadgeJapaneseYen = LuBadgeJapaneseYen;
exports.LucideLuBadgeMinus = LuBadgeMinus;
exports.LucideLuBadgePercent = LuBadgePercent;
exports.LucideLuBadgePlus = LuBadgePlus;
exports.LucideLuBadgePoundSterling = LuBadgePoundSterling;
exports.LucideLuBadgeRussianRuble = LuBadgeRussianRuble;
exports.LucideLuBadgeSwissFranc = LuBadgeSwissFranc;
exports.LucideLuBadgeX = LuBadgeX;
exports.LucideLuBaggageClaim = LuBaggageClaim;
exports.LucideLuBan = LuBan;
exports.LucideLuBanana = LuBanana;
exports.LucideLuBanknote = LuBanknote;
exports.LucideLuBarChart = LuBarChart;
exports.LucideLuBarChart2 = LuBarChart2;
exports.LucideLuBarChart3 = LuBarChart3;
exports.LucideLuBarChart4 = LuBarChart4;
exports.LucideLuBarChartBig = LuBarChartBig;
exports.LucideLuBarChartHorizontal = LuBarChartHorizontal;
exports.LucideLuBarChartHorizontalBig = LuBarChartHorizontalBig;
exports.LucideLuBarcode = LuBarcode;
exports.LucideLuBaseline = LuBaseline;
exports.LucideLuBath = LuBath;
exports.LucideLuBattery = LuBattery;
exports.LucideLuBatteryCharging = LuBatteryCharging;
exports.LucideLuBatteryFull = LuBatteryFull;
exports.LucideLuBatteryLow = LuBatteryLow;
exports.LucideLuBatteryMedium = LuBatteryMedium;
exports.LucideLuBatteryWarning = LuBatteryWarning;
exports.LucideLuBeaker = LuBeaker;
exports.LucideLuBean = LuBean;
exports.LucideLuBeanOff = LuBeanOff;
exports.LucideLuBed = LuBed;
exports.LucideLuBedDouble = LuBedDouble;
exports.LucideLuBedSingle = LuBedSingle;
exports.LucideLuBeef = LuBeef;
exports.LucideLuBeer = LuBeer;
exports.LucideLuBell = LuBell;
exports.LucideLuBellDot = LuBellDot;
exports.LucideLuBellElectric = LuBellElectric;
exports.LucideLuBellMinus = LuBellMinus;
exports.LucideLuBellOff = LuBellOff;
exports.LucideLuBellPlus = LuBellPlus;
exports.LucideLuBellRing = LuBellRing;
exports.LucideLuBetweenHorizonalEnd = LuBetweenHorizontalEnd;
exports.LucideLuBetweenHorizonalStart = LuBetweenHorizontalStart;
exports.LucideLuBetweenHorizontalEnd = LuBetweenHorizontalEnd;
exports.LucideLuBetweenHorizontalStart = LuBetweenHorizontalStart;
exports.LucideLuBetweenVerticalEnd = LuBetweenVerticalEnd;
exports.LucideLuBetweenVerticalStart = LuBetweenVerticalStart;
exports.LucideLuBike = LuBike;
exports.LucideLuBinary = LuBinary;
exports.LucideLuBiohazard = LuBiohazard;
exports.LucideLuBird = LuBird;
exports.LucideLuBitcoin = LuBitcoin;
exports.LucideLuBlend = LuBlend;
exports.LucideLuBlinds = LuBlinds;
exports.LucideLuBlocks = LuBlocks;
exports.LucideLuBluetooth = LuBluetooth;
exports.LucideLuBluetoothConnected = LuBluetoothConnected;
exports.LucideLuBluetoothOff = LuBluetoothOff;
exports.LucideLuBluetoothSearching = LuBluetoothSearching;
exports.LucideLuBold = LuBold;
exports.LucideLuBolt = LuBolt;
exports.LucideLuBomb = LuBomb;
exports.LucideLuBone = LuBone;
exports.LucideLuBook = LuBook;
exports.LucideLuBookA = LuBookA;
exports.LucideLuBookAudio = LuBookAudio;
exports.LucideLuBookCheck = LuBookCheck;
exports.LucideLuBookCopy = LuBookCopy;
exports.LucideLuBookDashed = LuBookDashed;
exports.LucideLuBookDown = LuBookDown;
exports.LucideLuBookHeadphones = LuBookHeadphones;
exports.LucideLuBookHeart = LuBookHeart;
exports.LucideLuBookImage = LuBookImage;
exports.LucideLuBookKey = LuBookKey;
exports.LucideLuBookLock = LuBookLock;
exports.LucideLuBookMarked = LuBookMarked;
exports.LucideLuBookMinus = LuBookMinus;
exports.LucideLuBookOpen = LuBookOpen;
exports.LucideLuBookOpenCheck = LuBookOpenCheck;
exports.LucideLuBookOpenText = LuBookOpenText;
exports.LucideLuBookPlus = LuBookPlus;
exports.LucideLuBookTemplate = LuBookDashed;
exports.LucideLuBookText = LuBookText;
exports.LucideLuBookType = LuBookType;
exports.LucideLuBookUp = LuBookUp;
exports.LucideLuBookUp2 = LuBookUp2;
exports.LucideLuBookUser = LuBookUser;
exports.LucideLuBookX = LuBookX;
exports.LucideLuBookmark = LuBookmark;
exports.LucideLuBookmarkCheck = LuBookmarkCheck;
exports.LucideLuBookmarkMinus = LuBookmarkMinus;
exports.LucideLuBookmarkPlus = LuBookmarkPlus;
exports.LucideLuBookmarkX = LuBookmarkX;
exports.LucideLuBoomBox = LuBoomBox;
exports.LucideLuBot = LuBot;
exports.LucideLuBotMessageSquare = LuBotMessageSquare;
exports.LucideLuBox = LuBox;
exports.LucideLuBoxSelect = LuBoxSelect;
exports.LucideLuBoxes = LuBoxes;
exports.LucideLuBraces = LuBraces;
exports.LucideLuBrackets = LuBrackets;
exports.LucideLuBrain = LuBrain;
exports.LucideLuBrainCircuit = LuBrainCircuit;
exports.LucideLuBrainCog = LuBrainCog;
exports.LucideLuBrickWall = LuBrickWall;
exports.LucideLuBriefcase = LuBriefcase;
exports.LucideLuBriefcaseBusiness = LuBriefcaseBusiness;
exports.LucideLuBriefcaseMedical = LuBriefcaseMedical;
exports.LucideLuBringToFront = LuBringToFront;
exports.LucideLuBrush = LuBrush;
exports.LucideLuBug = LuBug;
exports.LucideLuBugOff = LuBugOff;
exports.LucideLuBugPlay = LuBugPlay;
exports.LucideLuBuilding = LuBuilding;
exports.LucideLuBuilding2 = LuBuilding2;
exports.LucideLuBus = LuBus;
exports.LucideLuBusFront = LuBusFront;
exports.LucideLuCable = LuCable;
exports.LucideLuCableCar = LuCableCar;
exports.LucideLuCake = LuCake;
exports.LucideLuCakeSlice = LuCakeSlice;
exports.LucideLuCalculator = LuCalculator;
exports.LucideLuCalendar = LuCalendar;
exports.LucideLuCalendarCheck = LuCalendarCheck;
exports.LucideLuCalendarCheck2 = LuCalendarCheck2;
exports.LucideLuCalendarClock = LuCalendarClock;
exports.LucideLuCalendarDays = LuCalendarDays;
exports.LucideLuCalendarFold = LuCalendarFold;
exports.LucideLuCalendarHeart = LuCalendarHeart;
exports.LucideLuCalendarMinus = LuCalendarMinus;
exports.LucideLuCalendarMinus2 = LuCalendarMinus2;
exports.LucideLuCalendarOff = LuCalendarOff;
exports.LucideLuCalendarPlus = LuCalendarPlus;
exports.LucideLuCalendarPlus2 = LuCalendarPlus2;
exports.LucideLuCalendarRange = LuCalendarRange;
exports.LucideLuCalendarSearch = LuCalendarSearch;
exports.LucideLuCalendarX = LuCalendarX;
exports.LucideLuCalendarX2 = LuCalendarX2;
exports.LucideLuCamera = LuCamera;
exports.LucideLuCameraOff = LuCameraOff;
exports.LucideLuCandlestickChart = LuCandlestickChart;
exports.LucideLuCandy = LuCandy;
exports.LucideLuCandyCane = LuCandyCane;
exports.LucideLuCandyOff = LuCandyOff;
exports.LucideLuCannabis = LuCannabis;
exports.LucideLuCaptions = LuCaptions;
exports.LucideLuCaptionsOff = LuCaptionsOff;
exports.LucideLuCar = LuCar;
exports.LucideLuCarFront = LuCarFront;
exports.LucideLuCarTaxiFront = LuCarTaxiFront;
exports.LucideLuCaravan = LuCaravan;
exports.LucideLuCarrot = LuCarrot;
exports.LucideLuCaseLower = LuCaseLower;
exports.LucideLuCaseSensitive = LuCaseSensitive;
exports.LucideLuCaseUpper = LuCaseUpper;
exports.LucideLuCassetteTape = LuCassetteTape;
exports.LucideLuCast = LuCast;
exports.LucideLuCastle = LuCastle;
exports.LucideLuCat = LuCat;
exports.LucideLuCctv = LuCctv;
exports.LucideLuCheck = LuCheck;
exports.LucideLuCheckCheck = LuCheckCheck;
exports.LucideLuCheckCircle = LuCircleCheckBig;
exports.LucideLuCheckCircle2 = LuCircleCheck;
exports.LucideLuCheckSquare = LuSquareCheckBig;
exports.LucideLuCheckSquare2 = LuSquareCheck;
exports.LucideLuChefHat = LuChefHat;
exports.LucideLuCherry = LuCherry;
exports.LucideLuChevronDown = LuChevronDown;
exports.LucideLuChevronDownCircle = LuCircleChevronDown;
exports.LucideLuChevronDownSquare = LuSquareChevronDown;
exports.LucideLuChevronFirst = LuChevronFirst;
exports.LucideLuChevronLast = LuChevronLast;
exports.LucideLuChevronLeft = LuChevronLeft;
exports.LucideLuChevronLeftCircle = LuCircleChevronLeft;
exports.LucideLuChevronLeftSquare = LuSquareChevronLeft;
exports.LucideLuChevronRight = LuChevronRight;
exports.LucideLuChevronRightCircle = LuCircleChevronRight;
exports.LucideLuChevronRightSquare = LuSquareChevronRight;
exports.LucideLuChevronUp = LuChevronUp;
exports.LucideLuChevronUpCircle = LuCircleChevronUp;
exports.LucideLuChevronUpSquare = LuSquareChevronUp;
exports.LucideLuChevronsDown = LuChevronsDown;
exports.LucideLuChevronsDownUp = LuChevronsDownUp;
exports.LucideLuChevronsLeft = LuChevronsLeft;
exports.LucideLuChevronsLeftRight = LuChevronsLeftRight;
exports.LucideLuChevronsRight = LuChevronsRight;
exports.LucideLuChevronsRightLeft = LuChevronsRightLeft;
exports.LucideLuChevronsUp = LuChevronsUp;
exports.LucideLuChevronsUpDown = LuChevronsUpDown;
exports.LucideLuChrome = LuChrome;
exports.LucideLuChurch = LuChurch;
exports.LucideLuCigarette = LuCigarette;
exports.LucideLuCigaretteOff = LuCigaretteOff;
exports.LucideLuCircle = LuCircle;
exports.LucideLuCircleAlert = LuCircleAlert;
exports.LucideLuCircleArrowDown = LuCircleArrowDown;
exports.LucideLuCircleArrowLeft = LuCircleArrowLeft;
exports.LucideLuCircleArrowOutDownLeft = LuCircleArrowOutDownLeft;
exports.LucideLuCircleArrowOutDownRight = LuCircleArrowOutDownRight;
exports.LucideLuCircleArrowOutUpLeft = LuCircleArrowOutUpLeft;
exports.LucideLuCircleArrowOutUpRight = LuCircleArrowOutUpRight;
exports.LucideLuCircleArrowRight = LuCircleArrowRight;
exports.LucideLuCircleArrowUp = LuCircleArrowUp;
exports.LucideLuCircleCheck = LuCircleCheck;
exports.LucideLuCircleCheckBig = LuCircleCheckBig;
exports.LucideLuCircleChevronDown = LuCircleChevronDown;
exports.LucideLuCircleChevronLeft = LuCircleChevronLeft;
exports.LucideLuCircleChevronRight = LuCircleChevronRight;
exports.LucideLuCircleChevronUp = LuCircleChevronUp;
exports.LucideLuCircleDashed = LuCircleDashed;
exports.LucideLuCircleDivide = LuCircleDivide;
exports.LucideLuCircleDollarSign = LuCircleDollarSign;
exports.LucideLuCircleDot = LuCircleDot;
exports.LucideLuCircleDotDashed = LuCircleDotDashed;
exports.LucideLuCircleEllipsis = LuCircleEllipsis;
exports.LucideLuCircleEqual = LuCircleEqual;
exports.LucideLuCircleFadingPlus = LuCircleFadingPlus;
exports.LucideLuCircleGauge = LuCircleGauge;
exports.LucideLuCircleHelp = LuCircleHelp;
exports.LucideLuCircleMinus = LuCircleMinus;
exports.LucideLuCircleOff = LuCircleOff;
exports.LucideLuCircleParking = LuCircleParking;
exports.LucideLuCircleParkingOff = LuCircleParkingOff;
exports.LucideLuCirclePause = LuCirclePause;
exports.LucideLuCirclePercent = LuCirclePercent;
exports.LucideLuCirclePlay = LuCirclePlay;
exports.LucideLuCirclePlus = LuCirclePlus;
exports.LucideLuCirclePower = LuCirclePower;
exports.LucideLuCircleSlash = LuCircleSlash;
exports.LucideLuCircleSlash2 = LuCircleSlash2;
exports.LucideLuCircleSlashed = LuCircleSlash2;
exports.LucideLuCircleStop = LuCircleStop;
exports.LucideLuCircleUser = LuCircleUser;
exports.LucideLuCircleUserRound = LuCircleUserRound;
exports.LucideLuCircleX = LuCircleX;
exports.LucideLuCircuitBoard = LuCircuitBoard;
exports.LucideLuCitrus = LuCitrus;
exports.LucideLuClapperboard = LuClapperboard;
exports.LucideLuClipboard = LuClipboard;
exports.LucideLuClipboardCheck = LuClipboardCheck;
exports.LucideLuClipboardCopy = LuClipboardCopy;
exports.LucideLuClipboardEdit = LuClipboardPen;
exports.LucideLuClipboardList = LuClipboardList;
exports.LucideLuClipboardMinus = LuClipboardMinus;
exports.LucideLuClipboardPaste = LuClipboardPaste;
exports.LucideLuClipboardPen = LuClipboardPen;
exports.LucideLuClipboardPenLine = LuClipboardPenLine;
exports.LucideLuClipboardPlus = LuClipboardPlus;
exports.LucideLuClipboardSignature = LuClipboardPenLine;
exports.LucideLuClipboardType = LuClipboardType;
exports.LucideLuClipboardX = LuClipboardX;
exports.LucideLuClock = LuClock;
exports.LucideLuClock1 = LuClock1;
exports.LucideLuClock10 = LuClock10;
exports.LucideLuClock11 = LuClock11;
exports.LucideLuClock12 = LuClock12;
exports.LucideLuClock2 = LuClock2;
exports.LucideLuClock3 = LuClock3;
exports.LucideLuClock4 = LuClock4;
exports.LucideLuClock5 = LuClock5;
exports.LucideLuClock6 = LuClock6;
exports.LucideLuClock7 = LuClock7;
exports.LucideLuClock8 = LuClock8;
exports.LucideLuClock9 = LuClock9;
exports.LucideLuCloud = LuCloud;
exports.LucideLuCloudCog = LuCloudCog;
exports.LucideLuCloudDownload = LuCloudDownload;
exports.LucideLuCloudDrizzle = LuCloudDrizzle;
exports.LucideLuCloudFog = LuCloudFog;
exports.LucideLuCloudHail = LuCloudHail;
exports.LucideLuCloudLightning = LuCloudLightning;
exports.LucideLuCloudMoon = LuCloudMoon;
exports.LucideLuCloudMoonRain = LuCloudMoonRain;
exports.LucideLuCloudOff = LuCloudOff;
exports.LucideLuCloudRain = LuCloudRain;
exports.LucideLuCloudRainWind = LuCloudRainWind;
exports.LucideLuCloudSnow = LuCloudSnow;
exports.LucideLuCloudSun = LuCloudSun;
exports.LucideLuCloudSunRain = LuCloudSunRain;
exports.LucideLuCloudUpload = LuCloudUpload;
exports.LucideLuCloudy = LuCloudy;
exports.LucideLuClover = LuClover;
exports.LucideLuClub = LuClub;
exports.LucideLuCode = LuCode;
exports.LucideLuCode2 = LuCodeXml;
exports.LucideLuCodeSquare = LuSquareCode;
exports.LucideLuCodeXml = LuCodeXml;
exports.LucideLuCodepen = LuCodepen;
exports.LucideLuCodesandbox = LuCodesandbox;
exports.LucideLuCoffee = LuCoffee;
exports.LucideLuCog = LuCog;
exports.LucideLuCoins = LuCoins;
exports.LucideLuColumns = LuColumns2;
exports.LucideLuColumns2 = LuColumns2;
exports.LucideLuColumns3 = LuColumns3;
exports.LucideLuColumns4 = LuColumns4;
exports.LucideLuCombine = LuCombine;
exports.LucideLuCommand = LuCommand;
exports.LucideLuCompass = LuCompass;
exports.LucideLuComponent = LuComponent;
exports.LucideLuComputer = LuComputer;
exports.LucideLuConciergeBell = LuConciergeBell;
exports.LucideLuCone = LuCone;
exports.LucideLuConstruction = LuConstruction;
exports.LucideLuContact = LuContact;
exports.LucideLuContact2 = LuContactRound;
exports.LucideLuContactRound = LuContactRound;
exports.LucideLuContainer = LuContainer;
exports.LucideLuContrast = LuContrast;
exports.LucideLuCookie = LuCookie;
exports.LucideLuCookingPot = LuCookingPot;
exports.LucideLuCopy = LuCopy;
exports.LucideLuCopyCheck = LuCopyCheck;
exports.LucideLuCopyMinus = LuCopyMinus;
exports.LucideLuCopyPlus = LuCopyPlus;
exports.LucideLuCopySlash = LuCopySlash;
exports.LucideLuCopyX = LuCopyX;
exports.LucideLuCopyleft = LuCopyleft;
exports.LucideLuCopyright = LuCopyright;
exports.LucideLuCornerDownLeft = LuCornerDownLeft;
exports.LucideLuCornerDownRight = LuCornerDownRight;
exports.LucideLuCornerLeftDown = LuCornerLeftDown;
exports.LucideLuCornerLeftUp = LuCornerLeftUp;
exports.LucideLuCornerRightDown = LuCornerRightDown;
exports.LucideLuCornerRightUp = LuCornerRightUp;
exports.LucideLuCornerUpLeft = LuCornerUpLeft;
exports.LucideLuCornerUpRight = LuCornerUpRight;
exports.LucideLuCpu = LuCpu;
exports.LucideLuCreativeCommons = LuCreativeCommons;
exports.LucideLuCreditCard = LuCreditCard;
exports.LucideLuCroissant = LuCroissant;
exports.LucideLuCrop = LuCrop;
exports.LucideLuCross = LuCross;
exports.LucideLuCrosshair = LuCrosshair;
exports.LucideLuCrown = LuCrown;
exports.LucideLuCuboid = LuCuboid;
exports.LucideLuCupSoda = LuCupSoda;
exports.LucideLuCurlyBraces = LuBraces;
exports.LucideLuCurrency = LuCurrency;
exports.LucideLuCylinder = LuCylinder;
exports.LucideLuDatabase = LuDatabase;
exports.LucideLuDatabaseBackup = LuDatabaseBackup;
exports.LucideLuDatabaseZap = LuDatabaseZap;
exports.LucideLuDelete = LuDelete;
exports.LucideLuDessert = LuDessert;
exports.LucideLuDiameter = LuDiameter;
exports.LucideLuDiamond = LuDiamond;
exports.LucideLuDiamondPercent = LuDiamondPercent;
exports.LucideLuDice1 = LuDice1;
exports.LucideLuDice2 = LuDice2;
exports.LucideLuDice3 = LuDice3;
exports.LucideLuDice4 = LuDice4;
exports.LucideLuDice5 = LuDice5;
exports.LucideLuDice6 = LuDice6;
exports.LucideLuDices = LuDices;
exports.LucideLuDiff = LuDiff;
exports.LucideLuDisc = LuDisc;
exports.LucideLuDisc2 = LuDisc2;
exports.LucideLuDisc3 = LuDisc3;
exports.LucideLuDiscAlbum = LuDiscAlbum;
exports.LucideLuDivide = LuDivide;
exports.LucideLuDivideCircle = LuCircleDivide;
exports.LucideLuDivideSquare = LuSquareDivide;
exports.LucideLuDna = LuDna;
exports.LucideLuDnaOff = LuDnaOff;
exports.LucideLuDock = LuDock;
exports.LucideLuDog = LuDog;
exports.LucideLuDollarSign = LuDollarSign;
exports.LucideLuDonut = LuDonut;
exports.LucideLuDoorClosed = LuDoorClosed;
exports.LucideLuDoorOpen = LuDoorOpen;
exports.LucideLuDot = LuDot;
exports.LucideLuDotSquare = LuSquareDot;
exports.LucideLuDownload = LuDownload;
exports.LucideLuDownloadCloud = LuCloudDownload;
exports.LucideLuDraftingCompass = LuDraftingCompass;
exports.LucideLuDrama = LuDrama;
exports.LucideLuDribbble = LuDribbble;
exports.LucideLuDrill = LuDrill;
exports.LucideLuDroplet = LuDroplet;
exports.LucideLuDroplets = LuDroplets;
exports.LucideLuDrum = LuDrum;
exports.LucideLuDrumstick = LuDrumstick;
exports.LucideLuDumbbell = LuDumbbell;
exports.LucideLuEar = LuEar;
exports.LucideLuEarOff = LuEarOff;
exports.LucideLuEarth = LuEarth;
exports.LucideLuEarthLock = LuEarthLock;
exports.LucideLuEclipse = LuEclipse;
exports.LucideLuEdit = LuSquarePen;
exports.LucideLuEdit2 = LuPen;
exports.LucideLuEdit3 = LuPenLine;
exports.LucideLuEgg = LuEgg;
exports.LucideLuEggFried = LuEggFried;
exports.LucideLuEggOff = LuEggOff;
exports.LucideLuEllipsis = LuEllipsis;
exports.LucideLuEllipsisVertical = LuEllipsisVertical;
exports.LucideLuEqual = LuEqual;
exports.LucideLuEqualNot = LuEqualNot;
exports.LucideLuEqualSquare = LuSquareEqual;
exports.LucideLuEraser = LuEraser;
exports.LucideLuEuro = LuEuro;
exports.LucideLuExpand = LuExpand;
exports.LucideLuExternalLink = LuExternalLink;
exports.LucideLuEye = LuEye;
exports.LucideLuEyeOff = LuEyeOff;
exports.LucideLuFacebook = LuFacebook;
exports.LucideLuFactory = LuFactory;
exports.LucideLuFan = LuFan;
exports.LucideLuFastForward = LuFastForward;
exports.LucideLuFeather = LuFeather;
exports.LucideLuFence = LuFence;
exports.LucideLuFerrisWheel = LuFerrisWheel;
exports.LucideLuFigma = LuFigma;
exports.LucideLuFile = LuFile;
exports.LucideLuFileArchive = LuFileArchive;
exports.LucideLuFileAudio = LuFileAudio;
exports.LucideLuFileAudio2 = LuFileAudio2;
exports.LucideLuFileAxis3D = LuFileAxis3d;
exports.LucideLuFileAxis3d = LuFileAxis3d;
exports.LucideLuFileBadge = LuFileBadge;
exports.LucideLuFileBadge2 = LuFileBadge2;
exports.LucideLuFileBarChart = LuFileBarChart;
exports.LucideLuFileBarChart2 = LuFileBarChart2;
exports.LucideLuFileBox = LuFileBox;
exports.LucideLuFileCheck = LuFileCheck;
exports.LucideLuFileCheck2 = LuFileCheck2;
exports.LucideLuFileClock = LuFileClock;
exports.LucideLuFileCode = LuFileCode;
exports.LucideLuFileCode2 = LuFileCode2;
exports.LucideLuFileCog = LuFileCog;
exports.LucideLuFileCog2 = LuFileCog;
exports.LucideLuFileDiff = LuFileDiff;
exports.LucideLuFileDigit = LuFileDigit;
exports.LucideLuFileDown = LuFileDown;
exports.LucideLuFileEdit = LuFilePen;
exports.LucideLuFileHeart = LuFileHeart;
exports.LucideLuFileImage = LuFileImage;
exports.LucideLuFileInput = LuFileInput;
exports.LucideLuFileJson = LuFileJson;
exports.LucideLuFileJson2 = LuFileJson2;
exports.LucideLuFileKey = LuFileKey;
exports.LucideLuFileKey2 = LuFileKey2;
exports.LucideLuFileLineChart = LuFileLineChart;
exports.LucideLuFileLock = LuFileLock;
exports.LucideLuFileLock2 = LuFileLock2;
exports.LucideLuFileMinus = LuFileMinus;
exports.LucideLuFileMinus2 = LuFileMinus2;
exports.LucideLuFileMusic = LuFileMusic;
exports.LucideLuFileOutput = LuFileOutput;
exports.LucideLuFilePen = LuFilePen;
exports.LucideLuFilePenLine = LuFilePenLine;
exports.LucideLuFilePieChart = LuFilePieChart;
exports.LucideLuFilePlus = LuFilePlus;
exports.LucideLuFilePlus2 = LuFilePlus2;
exports.LucideLuFileQuestion = LuFileQuestion;
exports.LucideLuFileScan = LuFileScan;
exports.LucideLuFileSearch = LuFileSearch;
exports.LucideLuFileSearch2 = LuFileSearch2;
exports.LucideLuFileSignature = LuFilePenLine;
exports.LucideLuFileSliders = LuFileSliders;
exports.LucideLuFileSpreadsheet = LuFileSpreadsheet;
exports.LucideLuFileStack = LuFileStack;
exports.LucideLuFileSymlink = LuFileSymlink;
exports.LucideLuFileTerminal = LuFileTerminal;
exports.LucideLuFileText = LuFileText;
exports.LucideLuFileType = LuFileType;
exports.LucideLuFileType2 = LuFileType2;
exports.LucideLuFileUp = LuFileUp;
exports.LucideLuFileVideo = LuFileVideo;
exports.LucideLuFileVideo2 = LuFileVideo2;
exports.LucideLuFileVolume = LuFileVolume;
exports.LucideLuFileVolume2 = LuFileVolume2;
exports.LucideLuFileWarning = LuFileWarning;
exports.LucideLuFileX = LuFileX;
exports.LucideLuFileX2 = LuFileX2;
exports.LucideLuFiles = LuFiles;
exports.LucideLuFilm = LuFilm;
exports.LucideLuFilter = LuFilter;
exports.LucideLuFilterX = LuFilterX;
exports.LucideLuFingerprint = LuFingerprint;
exports.LucideLuFireExtinguisher = LuFireExtinguisher;
exports.LucideLuFish = LuFish;
exports.LucideLuFishOff = LuFishOff;
exports.LucideLuFishSymbol = LuFishSymbol;
exports.LucideLuFlag = LuFlag;
exports.LucideLuFlagOff = LuFlagOff;
exports.LucideLuFlagTriangleLeft = LuFlagTriangleLeft;
exports.LucideLuFlagTriangleRight = LuFlagTriangleRight;
exports.LucideLuFlame = LuFlame;
exports.LucideLuFlameKindling = LuFlameKindling;
exports.LucideLuFlashlight = LuFlashlight;
exports.LucideLuFlashlightOff = LuFlashlightOff;
exports.LucideLuFlaskConical = LuFlaskConical;
exports.LucideLuFlaskConicalOff = LuFlaskConicalOff;
exports.LucideLuFlaskRound = LuFlaskRound;
exports.LucideLuFlipHorizontal = LuFlipHorizontal;
exports.LucideLuFlipHorizontal2 = LuFlipHorizontal2;
exports.LucideLuFlipVertical = LuFlipVertical;
exports.LucideLuFlipVertical2 = LuFlipVertical2;
exports.LucideLuFlower = LuFlower;
exports.LucideLuFlower2 = LuFlower2;
exports.LucideLuFocus = LuFocus;
exports.LucideLuFoldHorizontal = LuFoldHorizontal;
exports.LucideLuFoldVertical = LuFoldVertical;
exports.LucideLuFolder = LuFolder;
exports.LucideLuFolderArchive = LuFolderArchive;
exports.LucideLuFolderCheck = LuFolderCheck;
exports.LucideLuFolderClock = LuFolderClock;
exports.LucideLuFolderClosed = LuFolderClosed;
exports.LucideLuFolderCog = LuFolderCog;
exports.LucideLuFolderCog2 = LuFolderCog;
exports.LucideLuFolderDot = LuFolderDot;
exports.LucideLuFolderDown = LuFolderDown;
exports.LucideLuFolderEdit = LuFolderPen;
exports.LucideLuFolderGit = LuFolderGit;
exports.LucideLuFolderGit2 = LuFolderGit2;
exports.LucideLuFolderHeart = LuFolderHeart;
exports.LucideLuFolderInput = LuFolderInput;
exports.LucideLuFolderKanban = LuFolderKanban;
exports.LucideLuFolderKey = LuFolderKey;
exports.LucideLuFolderLock = LuFolderLock;
exports.LucideLuFolderMinus = LuFolderMinus;
exports.LucideLuFolderOpen = LuFolderOpen;
exports.LucideLuFolderOpenDot = LuFolderOpenDot;
exports.LucideLuFolderOutput = LuFolderOutput;
exports.LucideLuFolderPen = LuFolderPen;
exports.LucideLuFolderPlus = LuFolderPlus;
exports.LucideLuFolderRoot = LuFolderRoot;
exports.LucideLuFolderSearch = LuFolderSearch;
exports.LucideLuFolderSearch2 = LuFolderSearch2;
exports.LucideLuFolderSymlink = LuFolderSymlink;
exports.LucideLuFolderSync = LuFolderSync;
exports.LucideLuFolderTree = LuFolderTree;
exports.LucideLuFolderUp = LuFolderUp;
exports.LucideLuFolderX = LuFolderX;
exports.LucideLuFolders = LuFolders;
exports.LucideLuFootprints = LuFootprints;
exports.LucideLuForklift = LuForklift;
exports.LucideLuFormInput = LuRectangleEllipsis;
exports.LucideLuForward = LuForward;
exports.LucideLuFrame = LuFrame;
exports.LucideLuFramer = LuFramer;
exports.LucideLuFrown = LuFrown;
exports.LucideLuFuel = LuFuel;
exports.LucideLuFullscreen = LuFullscreen;
exports.LucideLuFunctionSquare = LuSquareFunction;
exports.LucideLuGalleryHorizontal = LuGalleryHorizontal;
exports.LucideLuGalleryHorizontalEnd = LuGalleryHorizontalEnd;
exports.LucideLuGalleryThumbnails = LuGalleryThumbnails;
exports.LucideLuGalleryVertical = LuGalleryVertical;
exports.LucideLuGalleryVerticalEnd = LuGalleryVerticalEnd;
exports.LucideLuGamepad = LuGamepad;
exports.LucideLuGamepad2 = LuGamepad2;
exports.LucideLuGanttChart = LuGanttChart;
exports.LucideLuGanttChartSquare = LuSquareGanttChart;
exports.LucideLuGauge = LuGauge;
exports.LucideLuGaugeCircle = LuCircleGauge;
exports.LucideLuGavel = LuGavel;
exports.LucideLuGem = LuGem;
exports.LucideLuGhost = LuGhost;
exports.LucideLuGift = LuGift;
exports.LucideLuGitBranch = LuGitBranch;
exports.LucideLuGitBranchPlus = LuGitBranchPlus;
exports.LucideLuGitCommit = LuGitCommitHorizontal;
exports.LucideLuGitCommitHorizontal = LuGitCommitHorizontal;
exports.LucideLuGitCommitVertical = LuGitCommitVertical;
exports.LucideLuGitCompare = LuGitCompare;
exports.LucideLuGitCompareArrows = LuGitCompareArrows;
exports.LucideLuGitFork = LuGitFork;
exports.LucideLuGitGraph = LuGitGraph;
exports.LucideLuGitMerge = LuGitMerge;
exports.LucideLuGitPullRequest = LuGitPullRequest;
exports.LucideLuGitPullRequestArrow = LuGitPullRequestArrow;
exports.LucideLuGitPullRequestClosed = LuGitPullRequestClosed;
exports.LucideLuGitPullRequestCreate = LuGitPullRequestCreate;
exports.LucideLuGitPullRequestCreateArrow = LuGitPullRequestCreateArrow;
exports.LucideLuGitPullRequestDraft = LuGitPullRequestDraft;
exports.LucideLuGithub = LuGithub;
exports.LucideLuGitlab = LuGitlab;
exports.LucideLuGlassWater = LuGlassWater;
exports.LucideLuGlasses = LuGlasses;
exports.LucideLuGlobe = LuGlobe;
exports.LucideLuGlobe2 = LuEarth;
exports.LucideLuGlobeLock = LuGlobeLock;
exports.LucideLuGoal = LuGoal;
exports.LucideLuGrab = LuGrab;
exports.LucideLuGraduationCap = LuGraduationCap;
exports.LucideLuGrape = LuGrape;
exports.LucideLuGrid = LuGrid3x3;
exports.LucideLuGrid2X2 = LuGrid2x2;
exports.LucideLuGrid2x2 = LuGrid2x2;
exports.LucideLuGrid3X3 = LuGrid3x3;
exports.LucideLuGrid3x3 = LuGrid3x3;
exports.LucideLuGrip = LuGrip;
exports.LucideLuGripHorizontal = LuGripHorizontal;
exports.LucideLuGripVertical = LuGripVertical;
exports.LucideLuGroup = LuGroup;
exports.LucideLuGuitar = LuGuitar;
exports.LucideLuHam = LuHam;
exports.LucideLuHammer = LuHammer;
exports.LucideLuHand = LuHand;
exports.LucideLuHandCoins = LuHandCoins;
exports.LucideLuHandHeart = LuHandHeart;
exports.LucideLuHandHelping = LuHandHelping;
exports.LucideLuHandMetal = LuHandMetal;
exports.LucideLuHandPlatter = LuHandPlatter;
exports.LucideLuHandshake = LuHandshake;
exports.LucideLuHardDrive = LuHardDrive;
exports.LucideLuHardDriveDownload = LuHardDriveDownload;
exports.LucideLuHardDriveUpload = LuHardDriveUpload;
exports.LucideLuHardHat = LuHardHat;
exports.LucideLuHash = LuHash;
exports.LucideLuHaze = LuHaze;
exports.LucideLuHdmiPort = LuHdmiPort;
exports.LucideLuHeading = LuHeading;
exports.LucideLuHeading1 = LuHeading1;
exports.LucideLuHeading2 = LuHeading2;
exports.LucideLuHeading3 = LuHeading3;
exports.LucideLuHeading4 = LuHeading4;
exports.LucideLuHeading5 = LuHeading5;
exports.LucideLuHeading6 = LuHeading6;
exports.LucideLuHeadphones = LuHeadphones;
exports.LucideLuHeadset = LuHeadset;
exports.LucideLuHeart = LuHeart;
exports.LucideLuHeartCrack = LuHeartCrack;
exports.LucideLuHeartHandshake = LuHeartHandshake;
exports.LucideLuHeartOff = LuHeartOff;
exports.LucideLuHeartPulse = LuHeartPulse;
exports.LucideLuHeater = LuHeater;
exports.LucideLuHelpCircle = LuCircleHelp;
exports.LucideLuHelpingHand = LuHandHelping;
exports.LucideLuHexagon = LuHexagon;
exports.LucideLuHighlighter = LuHighlighter;
exports.LucideLuHistory = LuHistory;
exports.LucideLuHome = LuHome;
exports.LucideLuHop = LuHop;
exports.LucideLuHopOff = LuHopOff;
exports.LucideLuHospital = LuHospital;
exports.LucideLuHotel = LuHotel;
exports.LucideLuHourglass = LuHourglass;
exports.LucideLuIceCream = LuIceCreamCone;
exports.LucideLuIceCream2 = LuIceCreamBowl;
exports.LucideLuIceCreamBowl = LuIceCreamBowl;
exports.LucideLuIceCreamCone = LuIceCreamCone;
exports.LucideLuImage = LuImage;
exports.LucideLuImageDown = LuImageDown;
exports.LucideLuImageMinus = LuImageMinus;
exports.LucideLuImageOff = LuImageOff;
exports.LucideLuImagePlus = LuImagePlus;
exports.LucideLuImageUp = LuImageUp;
exports.LucideLuImages = LuImages;
exports.LucideLuImport = LuImport;
exports.LucideLuInbox = LuInbox;
exports.LucideLuIndent = LuIndentIncrease;
exports.LucideLuIndentDecrease = LuIndentDecrease;
exports.LucideLuIndentIncrease = LuIndentIncrease;
exports.LucideLuIndianRupee = LuIndianRupee;
exports.LucideLuInfinity = LuInfinity;
exports.LucideLuInfo = LuInfo;
exports.LucideLuInspect = LuSquareMousePointer;
exports.LucideLuInspectionPanel = LuInspectionPanel;
exports.LucideLuInstagram = LuInstagram;
exports.LucideLuItalic = LuItalic;
exports.LucideLuIterationCcw = LuIterationCcw;
exports.LucideLuIterationCw = LuIterationCw;
exports.LucideLuJapaneseYen = LuJapaneseYen;
exports.LucideLuJoystick = LuJoystick;
exports.LucideLuKanban = LuKanban;
exports.LucideLuKanbanSquare = LuSquareKanban;
exports.LucideLuKanbanSquareDashed = LuSquareDashedKanban;
exports.LucideLuKey = LuKey;
exports.LucideLuKeyRound = LuKeyRound;
exports.LucideLuKeySquare = LuKeySquare;
exports.LucideLuKeyboard = LuKeyboard;
exports.LucideLuKeyboardMusic = LuKeyboardMusic;
exports.LucideLuLamp = LuLamp;
exports.LucideLuLampCeiling = LuLampCeiling;
exports.LucideLuLampDesk = LuLampDesk;
exports.LucideLuLampFloor = LuLampFloor;
exports.LucideLuLampWallDown = LuLampWallDown;
exports.LucideLuLampWallUp = LuLampWallUp;
exports.LucideLuLandPlot = LuLandPlot;
exports.LucideLuLandmark = LuLandmark;
exports.LucideLuLanguages = LuLanguages;
exports.LucideLuLaptop = LuLaptop;
exports.LucideLuLaptop2 = LuLaptopMinimal;
exports.LucideLuLaptopMinimal = LuLaptopMinimal;
exports.LucideLuLasso = LuLasso;
exports.LucideLuLassoSelect = LuLassoSelect;
exports.LucideLuLaugh = LuLaugh;
exports.LucideLuLayers = LuLayers;
exports.LucideLuLayers2 = LuLayers2;
exports.LucideLuLayers3 = LuLayers3;
exports.LucideLuLayout = LuPanelsTopLeft;
exports.LucideLuLayoutDashboard = LuLayoutDashboard;
exports.LucideLuLayoutGrid = LuLayoutGrid;
exports.LucideLuLayoutList = LuLayoutList;
exports.LucideLuLayoutPanelLeft = LuLayoutPanelLeft;
exports.LucideLuLayoutPanelTop = LuLayoutPanelTop;
exports.LucideLuLayoutTemplate = LuLayoutTemplate;
exports.LucideLuLeaf = LuLeaf;
exports.LucideLuLeafyGreen = LuLeafyGreen;
exports.LucideLuLibrary = LuLibrary;
exports.LucideLuLibraryBig = LuLibraryBig;
exports.LucideLuLibrarySquare = LuSquareLibrary;
exports.LucideLuLifeBuoy = LuLifeBuoy;
exports.LucideLuLigature = LuLigature;
exports.LucideLuLightbulb = LuLightbulb;
exports.LucideLuLightbulbOff = LuLightbulbOff;
exports.LucideLuLineChart = LuLineChart;
exports.LucideLuLink = LuLink;
exports.LucideLuLink2 = LuLink2;
exports.LucideLuLink2Off = LuLink2Off;
exports.LucideLuLinkedin = LuLinkedin;
exports.LucideLuList = LuList;
exports.LucideLuListChecks = LuListChecks;
exports.LucideLuListCollapse = LuListCollapse;
exports.LucideLuListEnd = LuListEnd;
exports.LucideLuListFilter = LuListFilter;
exports.LucideLuListMinus = LuListMinus;
exports.LucideLuListMusic = LuListMusic;
exports.LucideLuListOrdered = LuListOrdered;
exports.LucideLuListPlus = LuListPlus;
exports.LucideLuListRestart = LuListRestart;
exports.LucideLuListStart = LuListStart;
exports.LucideLuListTodo = LuListTodo;
exports.LucideLuListTree = LuListTree;
exports.LucideLuListVideo = LuListVideo;
exports.LucideLuListX = LuListX;
exports.LucideLuLoader = LuLoader;
exports.LucideLuLoader2 = LuLoaderCircle;
exports.LucideLuLoaderCircle = LuLoaderCircle;
exports.LucideLuLocate = LuLocate;
exports.LucideLuLocateFixed = LuLocateFixed;
exports.LucideLuLocateOff = LuLocateOff;
exports.LucideLuLock = LuLock;
exports.LucideLuLockKeyhole = LuLockKeyhole;
exports.LucideLuLockKeyholeOpen = LuLockKeyholeOpen;
exports.LucideLuLockOpen = LuLockOpen;
exports.LucideLuLogIn = LuLogIn;
exports.LucideLuLogOut = LuLogOut;
exports.LucideLuLollipop = LuLollipop;
exports.LucideLuLuggage = LuLuggage;
exports.LucideLuMSquare = LuSquareM;
exports.LucideLuMagnet = LuMagnet;
exports.LucideLuMail = LuMail;
exports.LucideLuMailCheck = LuMailCheck;
exports.LucideLuMailMinus = LuMailMinus;
exports.LucideLuMailOpen = LuMailOpen;
exports.LucideLuMailPlus = LuMailPlus;
exports.LucideLuMailQuestion = LuMailQuestion;
exports.LucideLuMailSearch = LuMailSearch;
exports.LucideLuMailWarning = LuMailWarning;
exports.LucideLuMailX = LuMailX;
exports.LucideLuMailbox = LuMailbox;
exports.LucideLuMails = LuMails;
exports.LucideLuMap = LuMap;
exports.LucideLuMapPin = LuMapPin;
exports.LucideLuMapPinOff = LuMapPinOff;
exports.LucideLuMapPinned = LuMapPinned;
exports.LucideLuMartini = LuMartini;
exports.LucideLuMaximize = LuMaximize;
exports.LucideLuMaximize2 = LuMaximize2;
exports.LucideLuMedal = LuMedal;
exports.LucideLuMegaphone = LuMegaphone;
exports.LucideLuMegaphoneOff = LuMegaphoneOff;
exports.LucideLuMeh = LuMeh;
exports.LucideLuMemoryStick = LuMemoryStick;
exports.LucideLuMenu = LuMenu;
exports.LucideLuMenuSquare = LuSquareMenu;
exports.LucideLuMerge = LuMerge;
exports.LucideLuMessageCircle = LuMessageCircle;
exports.LucideLuMessageCircleCode = LuMessageCircleCode;
exports.LucideLuMessageCircleDashed = LuMessageCircleDashed;
exports.LucideLuMessageCircleHeart = LuMessageCircleHeart;
exports.LucideLuMessageCircleMore = LuMessageCircleMore;
exports.LucideLuMessageCircleOff = LuMessageCircleOff;
exports.LucideLuMessageCirclePlus = LuMessageCirclePlus;
exports.LucideLuMessageCircleQuestion = LuMessageCircleQuestion;
exports.LucideLuMessageCircleReply = LuMessageCircleReply;
exports.LucideLuMessageCircleWarning = LuMessageCircleWarning;
exports.LucideLuMessageCircleX = LuMessageCircleX;
exports.LucideLuMessageSquare = LuMessageSquare;
exports.LucideLuMessageSquareCode = LuMessageSquareCode;
exports.LucideLuMessageSquareDashed = LuMessageSquareDashed;
exports.LucideLuMessageSquareDiff = LuMessageSquareDiff;
exports.LucideLuMessageSquareDot = LuMessageSquareDot;
exports.LucideLuMessageSquareHeart = LuMessageSquareHeart;
exports.LucideLuMessageSquareMore = LuMessageSquareMore;
exports.LucideLuMessageSquareOff = LuMessageSquareOff;
exports.LucideLuMessageSquarePlus = LuMessageSquarePlus;
exports.LucideLuMessageSquareQuote = LuMessageSquareQuote;
exports.LucideLuMessageSquareReply = LuMessageSquareReply;
exports.LucideLuMessageSquareShare = LuMessageSquareShare;
exports.LucideLuMessageSquareText = LuMessageSquareText;
exports.LucideLuMessageSquareWarning = LuMessageSquareWarning;
exports.LucideLuMessageSquareX = LuMessageSquareX;
exports.LucideLuMessagesSquare = LuMessagesSquare;
exports.LucideLuMic = LuMic;
exports.LucideLuMic2 = LuMicVocal;
exports.LucideLuMicOff = LuMicOff;
exports.LucideLuMicVocal = LuMicVocal;
exports.LucideLuMicroscope = LuMicroscope;
exports.LucideLuMicrowave = LuMicrowave;
exports.LucideLuMilestone = LuMilestone;
exports.LucideLuMilk = LuMilk;
exports.LucideLuMilkOff = LuMilkOff;
exports.LucideLuMinimize = LuMinimize;
exports.LucideLuMinimize2 = LuMinimize2;
exports.LucideLuMinus = LuMinus;
exports.LucideLuMinusCircle = LuCircleMinus;
exports.LucideLuMinusSquare = LuSquareMinus;
exports.LucideLuMonitor = LuMonitor;
exports.LucideLuMonitorCheck = LuMonitorCheck;
exports.LucideLuMonitorDot = LuMonitorDot;
exports.LucideLuMonitorDown = LuMonitorDown;
exports.LucideLuMonitorOff = LuMonitorOff;
exports.LucideLuMonitorPause = LuMonitorPause;
exports.LucideLuMonitorPlay = LuMonitorPlay;
exports.LucideLuMonitorSmartphone = LuMonitorSmartphone;
exports.LucideLuMonitorSpeaker = LuMonitorSpeaker;
exports.LucideLuMonitorStop = LuMonitorStop;
exports.LucideLuMonitorUp = LuMonitorUp;
exports.LucideLuMonitorX = LuMonitorX;
exports.LucideLuMoon = LuMoon;
exports.LucideLuMoonStar = LuMoonStar;
exports.LucideLuMoreHorizontal = LuEllipsis;
exports.LucideLuMoreVertical = LuEllipsisVertical;
exports.LucideLuMountain = LuMountain;
exports.LucideLuMountainSnow = LuMountainSnow;
exports.LucideLuMouse = LuMouse;
exports.LucideLuMousePointer = LuMousePointer;
exports.LucideLuMousePointer2 = LuMousePointer2;
exports.LucideLuMousePointerClick = LuMousePointerClick;
exports.LucideLuMousePointerSquareDashed = LuSquareDashedMousePointer;
exports.LucideLuMove = LuMove;
exports.LucideLuMove3D = LuMove3d;
exports.LucideLuMove3d = LuMove3d;
exports.LucideLuMoveDiagonal = LuMoveDiagonal;
exports.LucideLuMoveDiagonal2 = LuMoveDiagonal2;
exports.LucideLuMoveDown = LuMoveDown;
exports.LucideLuMoveDownLeft = LuMoveDownLeft;
exports.LucideLuMoveDownRight = LuMoveDownRight;
exports.LucideLuMoveHorizontal = LuMoveHorizontal;
exports.LucideLuMoveLeft = LuMoveLeft;
exports.LucideLuMoveRight = LuMoveRight;
exports.LucideLuMoveUp = LuMoveUp;
exports.LucideLuMoveUpLeft = LuMoveUpLeft;
exports.LucideLuMoveUpRight = LuMoveUpRight;
exports.LucideLuMoveVertical = LuMoveVertical;
exports.LucideLuMusic = LuMusic;
exports.LucideLuMusic2 = LuMusic2;
exports.LucideLuMusic3 = LuMusic3;
exports.LucideLuMusic4 = LuMusic4;
exports.LucideLuNavigation = LuNavigation;
exports.LucideLuNavigation2 = LuNavigation2;
exports.LucideLuNavigation2Off = LuNavigation2Off;
exports.LucideLuNavigationOff = LuNavigationOff;
exports.LucideLuNetwork = LuNetwork;
exports.LucideLuNewspaper = LuNewspaper;
exports.LucideLuNfc = LuNfc;
exports.LucideLuNotebook = LuNotebook;
exports.LucideLuNotebookPen = LuNotebookPen;
exports.LucideLuNotebookTabs = LuNotebookTabs;
exports.LucideLuNotebookText = LuNotebookText;
exports.LucideLuNotepadText = LuNotepadText;
exports.LucideLuNotepadTextDashed = LuNotepadTextDashed;
exports.LucideLuNut = LuNut;
exports.LucideLuNutOff = LuNutOff;
exports.LucideLuOctagon = LuOctagon;
exports.LucideLuOctagonAlert = LuOctagonAlert;
exports.LucideLuOctagonPause = LuOctagonPause;
exports.LucideLuOctagonX = LuOctagonX;
exports.LucideLuOption = LuOption;
exports.LucideLuOrbit = LuOrbit;
exports.LucideLuOutdent = LuIndentDecrease;
exports.LucideLuPackage = LuPackage;
exports.LucideLuPackage2 = LuPackage2;
exports.LucideLuPackageCheck = LuPackageCheck;
exports.LucideLuPackageMinus = LuPackageMinus;
exports.LucideLuPackageOpen = LuPackageOpen;
exports.LucideLuPackagePlus = LuPackagePlus;
exports.LucideLuPackageSearch = LuPackageSearch;
exports.LucideLuPackageX = LuPackageX;
exports.LucideLuPaintBucket = LuPaintBucket;
exports.LucideLuPaintRoller = LuPaintRoller;
exports.LucideLuPaintbrush = LuPaintbrush;
exports.LucideLuPaintbrush2 = LuPaintbrush2;
exports.LucideLuPalette = LuPalette;
exports.LucideLuPalmtree = LuTreePalm;
exports.LucideLuPanelBottom = LuPanelBottom;
exports.LucideLuPanelBottomClose = LuPanelBottomClose;
exports.LucideLuPanelBottomDashed = LuPanelBottomDashed;
exports.LucideLuPanelBottomInactive = LuPanelBottomDashed;
exports.LucideLuPanelBottomOpen = LuPanelBottomOpen;
exports.LucideLuPanelLeft = LuPanelLeft;
exports.LucideLuPanelLeftClose = LuPanelLeftClose;
exports.LucideLuPanelLeftDashed = LuPanelLeftDashed;
exports.LucideLuPanelLeftInactive = LuPanelLeftDashed;
exports.LucideLuPanelLeftOpen = LuPanelLeftOpen;
exports.LucideLuPanelRight = LuPanelRight;
exports.LucideLuPanelRightClose = LuPanelRightClose;
exports.LucideLuPanelRightDashed = LuPanelRightDashed;
exports.LucideLuPanelRightInactive = LuPanelRightDashed;
exports.LucideLuPanelRightOpen = LuPanelRightOpen;
exports.LucideLuPanelTop = LuPanelTop;
exports.LucideLuPanelTopClose = LuPanelTopClose;
exports.LucideLuPanelTopDashed = LuPanelTopDashed;
exports.LucideLuPanelTopInactive = LuPanelTopDashed;
exports.LucideLuPanelTopOpen = LuPanelTopOpen;
exports.LucideLuPanelsLeftBottom = LuPanelsLeftBottom;
exports.LucideLuPanelsLeftRight = LuColumns3;
exports.LucideLuPanelsRightBottom = LuPanelsRightBottom;
exports.LucideLuPanelsTopBottom = LuRows3;
exports.LucideLuPanelsTopLeft = LuPanelsTopLeft;
exports.LucideLuPaperclip = LuPaperclip;
exports.LucideLuParentheses = LuParentheses;
exports.LucideLuParkingCircle = LuCircleParking;
exports.LucideLuParkingCircleOff = LuCircleParkingOff;
exports.LucideLuParkingMeter = LuParkingMeter;
exports.LucideLuParkingSquare = LuSquareParking;
exports.LucideLuParkingSquareOff = LuSquareParkingOff;
exports.LucideLuPartyPopper = LuPartyPopper;
exports.LucideLuPause = LuPause;
exports.LucideLuPauseCircle = LuCirclePause;
exports.LucideLuPauseOctagon = LuOctagonPause;
exports.LucideLuPawPrint = LuPawPrint;
exports.LucideLuPcCase = LuPcCase;
exports.LucideLuPen = LuPen;
exports.LucideLuPenBox = LuSquarePen;
exports.LucideLuPenLine = LuPenLine;
exports.LucideLuPenSquare = LuSquarePen;
exports.LucideLuPenTool = LuPenTool;
exports.LucideLuPencil = LuPencil;
exports.LucideLuPencilLine = LuPencilLine;
exports.LucideLuPencilRuler = LuPencilRuler;
exports.LucideLuPentagon = LuPentagon;
exports.LucideLuPercent = LuPercent;
exports.LucideLuPercentCircle = LuCirclePercent;
exports.LucideLuPercentDiamond = LuDiamondPercent;
exports.LucideLuPercentSquare = LuSquarePercent;
exports.LucideLuPersonStanding = LuPersonStanding;
exports.LucideLuPhone = LuPhone;
exports.LucideLuPhoneCall = LuPhoneCall;
exports.LucideLuPhoneForwarded = LuPhoneForwarded;
exports.LucideLuPhoneIncoming = LuPhoneIncoming;
exports.LucideLuPhoneMissed = LuPhoneMissed;
exports.LucideLuPhoneOff = LuPhoneOff;
exports.LucideLuPhoneOutgoing = LuPhoneOutgoing;
exports.LucideLuPi = LuPi;
exports.LucideLuPiSquare = LuSquarePi;
exports.LucideLuPiano = LuPiano;
exports.LucideLuPickaxe = LuPickaxe;
exports.LucideLuPictureInPicture = LuPictureInPicture;
exports.LucideLuPictureInPicture2 = LuPictureInPicture2;
exports.LucideLuPieChart = LuPieChart;
exports.LucideLuPiggyBank = LuPiggyBank;
exports.LucideLuPilcrow = LuPilcrow;
exports.LucideLuPilcrowSquare = LuSquarePilcrow;
exports.LucideLuPill = LuPill;
exports.LucideLuPin = LuPin;
exports.LucideLuPinOff = LuPinOff;
exports.LucideLuPipette = LuPipette;
exports.LucideLuPizza = LuPizza;
exports.LucideLuPlane = LuPlane;
exports.LucideLuPlaneLanding = LuPlaneLanding;
exports.LucideLuPlaneTakeoff = LuPlaneTakeoff;
exports.LucideLuPlay = LuPlay;
exports.LucideLuPlayCircle = LuCirclePlay;
exports.LucideLuPlaySquare = LuSquarePlay;
exports.LucideLuPlug = LuPlug;
exports.LucideLuPlug2 = LuPlug2;
exports.LucideLuPlugZap = LuPlugZap;
exports.LucideLuPlugZap2 = LuPlugZap2;
exports.LucideLuPlus = LuPlus;
exports.LucideLuPlusCircle = LuCirclePlus;
exports.LucideLuPlusSquare = LuSquarePlus;
exports.LucideLuPocket = LuPocket;
exports.LucideLuPocketKnife = LuPocketKnife;
exports.LucideLuPodcast = LuPodcast;
exports.LucideLuPointer = LuPointer;
exports.LucideLuPointerOff = LuPointerOff;
exports.LucideLuPopcorn = LuPopcorn;
exports.LucideLuPopsicle = LuPopsicle;
exports.LucideLuPoundSterling = LuPoundSterling;
exports.LucideLuPower = LuPower;
exports.LucideLuPowerCircle = LuCirclePower;
exports.LucideLuPowerOff = LuPowerOff;
exports.LucideLuPowerSquare = LuSquarePower;
exports.LucideLuPresentation = LuPresentation;
exports.LucideLuPrinter = LuPrinter;
exports.LucideLuProjector = LuProjector;
exports.LucideLuProportions = LuProportions;
exports.LucideLuPuzzle = LuPuzzle;
exports.LucideLuPyramid = LuPyramid;
exports.LucideLuQrCode = LuQrCode;
exports.LucideLuQuote = LuQuote;
exports.LucideLuRabbit = LuRabbit;
exports.LucideLuRadar = LuRadar;
exports.LucideLuRadiation = LuRadiation;
exports.LucideLuRadical = LuRadical;
exports.LucideLuRadio = LuRadio;
exports.LucideLuRadioReceiver = LuRadioReceiver;
exports.LucideLuRadioTower = LuRadioTower;
exports.LucideLuRadius = LuRadius;
exports.LucideLuRailSymbol = LuRailSymbol;
exports.LucideLuRainbow = LuRainbow;
exports.LucideLuRat = LuRat;
exports.LucideLuRatio = LuRatio;
exports.LucideLuReceipt = LuReceipt;
exports.LucideLuReceiptCent = LuReceiptCent;
exports.LucideLuReceiptEuro = LuReceiptEuro;
exports.LucideLuReceiptIndianRupee = LuReceiptIndianRupee;
exports.LucideLuReceiptJapaneseYen = LuReceiptJapaneseYen;
exports.LucideLuReceiptPoundSterling = LuReceiptPoundSterling;
exports.LucideLuReceiptRussianRuble = LuReceiptRussianRuble;
exports.LucideLuReceiptSwissFranc = LuReceiptSwissFranc;
exports.LucideLuReceiptText = LuReceiptText;
exports.LucideLuRectangleEllipsis = LuRectangleEllipsis;
exports.LucideLuRectangleHorizontal = LuRectangleHorizontal;
exports.LucideLuRectangleVertical = LuRectangleVertical;
exports.LucideLuRecycle = LuRecycle;
exports.LucideLuRedo = LuRedo;
exports.LucideLuRedo2 = LuRedo2;
exports.LucideLuRedoDot = LuRedoDot;
exports.LucideLuRefreshCcw = LuRefreshCcw;
exports.LucideLuRefreshCcwDot = LuRefreshCcwDot;
exports.LucideLuRefreshCw = LuRefreshCw;
exports.LucideLuRefreshCwOff = LuRefreshCwOff;
exports.LucideLuRefrigerator = LuRefrigerator;
exports.LucideLuRegex = LuRegex;
exports.LucideLuRemoveFormatting = LuRemoveFormatting;
exports.LucideLuRepeat = LuRepeat;
exports.LucideLuRepeat1 = LuRepeat1;
exports.LucideLuRepeat2 = LuRepeat2;
exports.LucideLuReplace = LuReplace;
exports.LucideLuReplaceAll = LuReplaceAll;
exports.LucideLuReply = LuReply;
exports.LucideLuReplyAll = LuReplyAll;
exports.LucideLuRewind = LuRewind;
exports.LucideLuRibbon = LuRibbon;
exports.LucideLuRocket = LuRocket;
exports.LucideLuRockingChair = LuRockingChair;
exports.LucideLuRollerCoaster = LuRollerCoaster;
exports.LucideLuRotate3D = LuRotate3d;
exports.LucideLuRotate3d = LuRotate3d;
exports.LucideLuRotateCcw = LuRotateCcw;
exports.LucideLuRotateCcwSquare = LuRotateCcwSquare;
exports.LucideLuRotateCw = LuRotateCw;
exports.LucideLuRotateCwSquare = LuRotateCwSquare;
exports.LucideLuRoute = LuRoute;
exports.LucideLuRouteOff = LuRouteOff;
exports.LucideLuRouter = LuRouter;
exports.LucideLuRows = LuRows2;
exports.LucideLuRows2 = LuRows2;
exports.LucideLuRows3 = LuRows3;
exports.LucideLuRows4 = LuRows4;
exports.LucideLuRss = LuRss;
exports.LucideLuRuler = LuRuler;
exports.LucideLuRussianRuble = LuRussianRuble;
exports.LucideLuSailboat = LuSailboat;
exports.LucideLuSalad = LuSalad;
exports.LucideLuSandwich = LuSandwich;
exports.LucideLuSatellite = LuSatellite;
exports.LucideLuSatelliteDish = LuSatelliteDish;
exports.LucideLuSave = LuSave;
exports.LucideLuSaveAll = LuSaveAll;
exports.LucideLuScale = LuScale;
exports.LucideLuScale3D = LuScale3d;
exports.LucideLuScale3d = LuScale3d;
exports.LucideLuScaling = LuScaling;
exports.LucideLuScan = LuScan;
exports.LucideLuScanBarcode = LuScanBarcode;
exports.LucideLuScanEye = LuScanEye;
exports.LucideLuScanFace = LuScanFace;
exports.LucideLuScanLine = LuScanLine;
exports.LucideLuScanSearch = LuScanSearch;
exports.LucideLuScanText = LuScanText;
exports.LucideLuScatterChart = LuScatterChart;
exports.LucideLuSchool = LuSchool;
exports.LucideLuSchool2 = LuUniversity;
exports.LucideLuScissors = LuScissors;
exports.LucideLuScissorsLineDashed = LuScissorsLineDashed;
exports.LucideLuScissorsSquare = LuSquareScissors;
exports.LucideLuScissorsSquareDashedBottom = LuSquareBottomDashedScissors;
exports.LucideLuScreenShare = LuScreenShare;
exports.LucideLuScreenShareOff = LuScreenShareOff;
exports.LucideLuScroll = LuScroll;
exports.LucideLuScrollText = LuScrollText;
exports.LucideLuSearch = LuSearch;
exports.LucideLuSearchCheck = LuSearchCheck;
exports.LucideLuSearchCode = LuSearchCode;
exports.LucideLuSearchSlash = LuSearchSlash;
exports.LucideLuSearchX = LuSearchX;
exports.LucideLuSend = LuSend;
exports.LucideLuSendHorizonal = LuSendHorizontal;
exports.LucideLuSendHorizontal = LuSendHorizontal;
exports.LucideLuSendToBack = LuSendToBack;
exports.LucideLuSeparatorHorizontal = LuSeparatorHorizontal;
exports.LucideLuSeparatorVertical = LuSeparatorVertical;
exports.LucideLuServer = LuServer;
exports.LucideLuServerCog = LuServerCog;
exports.LucideLuServerCrash = LuServerCrash;
exports.LucideLuServerOff = LuServerOff;
exports.LucideLuSettings = LuSettings;
exports.LucideLuSettings2 = LuSettings2;
exports.LucideLuShapes = LuShapes;
exports.LucideLuShare = LuShare;
exports.LucideLuShare2 = LuShare2;
exports.LucideLuSheet = LuSheet;
exports.LucideLuShell = LuShell;
exports.LucideLuShield = LuShield;
exports.LucideLuShieldAlert = LuShieldAlert;
exports.LucideLuShieldBan = LuShieldBan;
exports.LucideLuShieldCheck = LuShieldCheck;
exports.LucideLuShieldClose = LuShieldX;
exports.LucideLuShieldEllipsis = LuShieldEllipsis;
exports.LucideLuShieldHalf = LuShieldHalf;
exports.LucideLuShieldMinus = LuShieldMinus;
exports.LucideLuShieldOff = LuShieldOff;
exports.LucideLuShieldPlus = LuShieldPlus;
exports.LucideLuShieldQuestion = LuShieldQuestion;
exports.LucideLuShieldX = LuShieldX;
exports.LucideLuShip = LuShip;
exports.LucideLuShipWheel = LuShipWheel;
exports.LucideLuShirt = LuShirt;
exports.LucideLuShoppingBag = LuShoppingBag;
exports.LucideLuShoppingBasket = LuShoppingBasket;
exports.LucideLuShoppingCart = LuShoppingCart;
exports.LucideLuShovel = LuShovel;
exports.LucideLuShowerHead = LuShowerHead;
exports.LucideLuShrink = LuShrink;
exports.LucideLuShrub = LuShrub;
exports.LucideLuShuffle = LuShuffle;
exports.LucideLuSidebar = LuPanelLeft;
exports.LucideLuSidebarClose = LuPanelLeftClose;
exports.LucideLuSidebarOpen = LuPanelLeftOpen;
exports.LucideLuSigma = LuSigma;
exports.LucideLuSigmaSquare = LuSquareSigma;
exports.LucideLuSignal = LuSignal;
exports.LucideLuSignalHigh = LuSignalHigh;
exports.LucideLuSignalLow = LuSignalLow;
exports.LucideLuSignalMedium = LuSignalMedium;
exports.LucideLuSignalZero = LuSignalZero;
exports.LucideLuSignpost = LuSignpost;
exports.LucideLuSignpostBig = LuSignpostBig;
exports.LucideLuSiren = LuSiren;
exports.LucideLuSkipBack = LuSkipBack;
exports.LucideLuSkipForward = LuSkipForward;
exports.LucideLuSkull = LuSkull;
exports.LucideLuSlack = LuSlack;
exports.LucideLuSlash = LuSlash;
exports.LucideLuSlashSquare = LuSquareSlash;
exports.LucideLuSlice = LuSlice;
exports.LucideLuSliders = LuSlidersVertical;
exports.LucideLuSlidersHorizontal = LuSlidersHorizontal;
exports.LucideLuSlidersVertical = LuSlidersVertical;
exports.LucideLuSmartphone = LuSmartphone;
exports.LucideLuSmartphoneCharging = LuSmartphoneCharging;
exports.LucideLuSmartphoneNfc = LuSmartphoneNfc;
exports.LucideLuSmile = LuSmile;
exports.LucideLuSmilePlus = LuSmilePlus;
exports.LucideLuSnail = LuSnail;
exports.LucideLuSnowflake = LuSnowflake;
exports.LucideLuSofa = LuSofa;
exports.LucideLuSortAsc = LuArrowUpNarrowWide;
exports.LucideLuSortDesc = LuArrowDownWideNarrow;
exports.LucideLuSoup = LuSoup;
exports.LucideLuSpace = LuSpace;
exports.LucideLuSpade = LuSpade;
exports.LucideLuSparkle = LuSparkle;
exports.LucideLuSparkles = LuSparkles;
exports.LucideLuSpeaker = LuSpeaker;
exports.LucideLuSpeech = LuSpeech;
exports.LucideLuSpellCheck = LuSpellCheck;
exports.LucideLuSpellCheck2 = LuSpellCheck2;
exports.LucideLuSpline = LuSpline;
exports.LucideLuSplit = LuSplit;
exports.LucideLuSplitSquareHorizontal = LuSquareSplitHorizontal;
exports.LucideLuSplitSquareVertical = LuSquareSplitVertical;
exports.LucideLuSprayCan = LuSprayCan;
exports.LucideLuSprout = LuSprout;
exports.LucideLuSquare = LuSquare;
exports.LucideLuSquareActivity = LuSquareActivity;
exports.LucideLuSquareArrowDown = LuSquareArrowDown;
exports.LucideLuSquareArrowDownLeft = LuSquareArrowDownLeft;
exports.LucideLuSquareArrowDownRight = LuSquareArrowDownRight;
exports.LucideLuSquareArrowLeft = LuSquareArrowLeft;
exports.LucideLuSquareArrowOutDownLeft = LuSquareArrowOutDownLeft;
exports.LucideLuSquareArrowOutDownRight = LuSquareArrowOutDownRight;
exports.LucideLuSquareArrowOutUpLeft = LuSquareArrowOutUpLeft;
exports.LucideLuSquareArrowOutUpRight = LuSquareArrowOutUpRight;
exports.LucideLuSquareArrowRight = LuSquareArrowRight;
exports.LucideLuSquareArrowUp = LuSquareArrowUp;
exports.LucideLuSquareArrowUpLeft = LuSquareArrowUpLeft;
exports.LucideLuSquareArrowUpRight = LuSquareArrowUpRight;
exports.LucideLuSquareAsterisk = LuSquareAsterisk;
exports.LucideLuSquareBottomDashedScissors = LuSquareBottomDashedScissors;
exports.LucideLuSquareCheck = LuSquareCheck;
exports.LucideLuSquareCheckBig = LuSquareCheckBig;
exports.LucideLuSquareChevronDown = LuSquareChevronDown;
exports.LucideLuSquareChevronLeft = LuSquareChevronLeft;
exports.LucideLuSquareChevronRight = LuSquareChevronRight;
exports.LucideLuSquareChevronUp = LuSquareChevronUp;
exports.LucideLuSquareCode = LuSquareCode;
exports.LucideLuSquareDashedBottom = LuSquareDashedBottom;
exports.LucideLuSquareDashedBottomCode = LuSquareDashedBottomCode;
exports.LucideLuSquareDashedKanban = LuSquareDashedKanban;
exports.LucideLuSquareDashedMousePointer = LuSquareDashedMousePointer;
exports.LucideLuSquareDivide = LuSquareDivide;
exports.LucideLuSquareDot = LuSquareDot;
exports.LucideLuSquareEqual = LuSquareEqual;
exports.LucideLuSquareFunction = LuSquareFunction;
exports.LucideLuSquareGanttChart = LuSquareGanttChart;
exports.LucideLuSquareKanban = LuSquareKanban;
exports.LucideLuSquareLibrary = LuSquareLibrary;
exports.LucideLuSquareM = LuSquareM;
exports.LucideLuSquareMenu = LuSquareMenu;
exports.LucideLuSquareMinus = LuSquareMinus;
exports.LucideLuSquareMousePointer = LuSquareMousePointer;
exports.LucideLuSquareParking = LuSquareParking;
exports.LucideLuSquareParkingOff = LuSquareParkingOff;
exports.LucideLuSquarePen = LuSquarePen;
exports.LucideLuSquarePercent = LuSquarePercent;
exports.LucideLuSquarePi = LuSquarePi;
exports.LucideLuSquarePilcrow = LuSquarePilcrow;
exports.LucideLuSquarePlay = LuSquarePlay;
exports.LucideLuSquarePlus = LuSquarePlus;
exports.LucideLuSquarePower = LuSquarePower;
exports.LucideLuSquareRadical = LuSquareRadical;
exports.LucideLuSquareScissors = LuSquareScissors;
exports.LucideLuSquareSigma = LuSquareSigma;
exports.LucideLuSquareSlash = LuSquareSlash;
exports.LucideLuSquareSplitHorizontal = LuSquareSplitHorizontal;
exports.LucideLuSquareSplitVertical = LuSquareSplitVertical;
exports.LucideLuSquareStack = LuSquareStack;
exports.LucideLuSquareTerminal = LuSquareTerminal;
exports.LucideLuSquareUser = LuSquareUser;
exports.LucideLuSquareUserRound = LuSquareUserRound;
exports.LucideLuSquareX = LuSquareX;
exports.LucideLuSquircle = LuSquircle;
exports.LucideLuSquirrel = LuSquirrel;
exports.LucideLuStamp = LuStamp;
exports.LucideLuStar = LuStar;
exports.LucideLuStarHalf = LuStarHalf;
exports.LucideLuStarOff = LuStarOff;
exports.LucideLuStars = LuSparkles;
exports.LucideLuStepBack = LuStepBack;
exports.LucideLuStepForward = LuStepForward;
exports.LucideLuStethoscope = LuStethoscope;
exports.LucideLuSticker = LuSticker;
exports.LucideLuStickyNote = LuStickyNote;
exports.LucideLuStopCircle = LuCircleStop;
exports.LucideLuStore = LuStore;
exports.LucideLuStretchHorizontal = LuStretchHorizontal;
exports.LucideLuStretchVertical = LuStretchVertical;
exports.LucideLuStrikethrough = LuStrikethrough;
exports.LucideLuSubscript = LuSubscript;
exports.LucideLuSubtitles = LuCaptions;
exports.LucideLuSun = LuSun;
exports.LucideLuSunDim = LuSunDim;
exports.LucideLuSunMedium = LuSunMedium;
exports.LucideLuSunMoon = LuSunMoon;
exports.LucideLuSunSnow = LuSunSnow;
exports.LucideLuSunrise = LuSunrise;
exports.LucideLuSunset = LuSunset;
exports.LucideLuSuperscript = LuSuperscript;
exports.LucideLuSwatchBook = LuSwatchBook;
exports.LucideLuSwissFranc = LuSwissFranc;
exports.LucideLuSwitchCamera = LuSwitchCamera;
exports.LucideLuSword = LuSword;
exports.LucideLuSwords = LuSwords;
exports.LucideLuSyringe = LuSyringe;
exports.LucideLuTable = LuTable;
exports.LucideLuTable2 = LuTable2;
exports.LucideLuTableCellsMerge = LuTableCellsMerge;
exports.LucideLuTableCellsSplit = LuTableCellsSplit;
exports.LucideLuTableColumnsSplit = LuTableColumnsSplit;
exports.LucideLuTableProperties = LuTableProperties;
exports.LucideLuTableRowsSplit = LuTableRowsSplit;
exports.LucideLuTablet = LuTablet;
exports.LucideLuTabletSmartphone = LuTabletSmartphone;
exports.LucideLuTablets = LuTablets;
exports.LucideLuTag = LuTag;
exports.LucideLuTags = LuTags;
exports.LucideLuTally1 = LuTally1;
exports.LucideLuTally2 = LuTally2;
exports.LucideLuTally3 = LuTally3;
exports.LucideLuTally4 = LuTally4;
exports.LucideLuTally5 = LuTally5;
exports.LucideLuTangent = LuTangent;
exports.LucideLuTarget = LuTarget;
exports.LucideLuTelescope = LuTelescope;
exports.LucideLuTent = LuTent;
exports.LucideLuTentTree = LuTentTree;
exports.LucideLuTerminal = LuTerminal;
exports.LucideLuTerminalSquare = LuSquareTerminal;
exports.LucideLuTestTube = LuTestTube;
exports.LucideLuTestTube2 = LuTestTubeDiagonal;
exports.LucideLuTestTubeDiagonal = LuTestTubeDiagonal;
exports.LucideLuTestTubes = LuTestTubes;
exports.LucideLuText = LuText;
exports.LucideLuTextCursor = LuTextCursor;
exports.LucideLuTextCursorInput = LuTextCursorInput;
exports.LucideLuTextQuote = LuTextQuote;
exports.LucideLuTextSearch = LuTextSearch;
exports.LucideLuTextSelect = LuTextSelect;
exports.LucideLuTextSelection = LuTextSelect;
exports.LucideLuTheater = LuTheater;
exports.LucideLuThermometer = LuThermometer;
exports.LucideLuThermometerSnowflake = LuThermometerSnowflake;
exports.LucideLuThermometerSun = LuThermometerSun;
exports.LucideLuThumbsDown = LuThumbsDown;
exports.LucideLuThumbsUp = LuThumbsUp;
exports.LucideLuTicket = LuTicket;
exports.LucideLuTicketCheck = LuTicketCheck;
exports.LucideLuTicketMinus = LuTicketMinus;
exports.LucideLuTicketPercent = LuTicketPercent;
exports.LucideLuTicketPlus = LuTicketPlus;
exports.LucideLuTicketSlash = LuTicketSlash;
exports.LucideLuTicketX = LuTicketX;
exports.LucideLuTimer = LuTimer;
exports.LucideLuTimerOff = LuTimerOff;
exports.LucideLuTimerReset = LuTimerReset;
exports.LucideLuToggleLeft = LuToggleLeft;
exports.LucideLuToggleRight = LuToggleRight;
exports.LucideLuTornado = LuTornado;
exports.LucideLuTorus = LuTorus;
exports.LucideLuTouchpad = LuTouchpad;
exports.LucideLuTouchpadOff = LuTouchpadOff;
exports.LucideLuTowerControl = LuTowerControl;
exports.LucideLuToyBrick = LuToyBrick;
exports.LucideLuTractor = LuTractor;
exports.LucideLuTrafficCone = LuTrafficCone;
exports.LucideLuTrain = LuTramFront;
exports.LucideLuTrainFront = LuTrainFront;
exports.LucideLuTrainFrontTunnel = LuTrainFrontTunnel;
exports.LucideLuTrainTrack = LuTrainTrack;
exports.LucideLuTramFront = LuTramFront;
exports.LucideLuTrash = LuTrash;
exports.LucideLuTrash2 = LuTrash2;
exports.LucideLuTreeDeciduous = LuTreeDeciduous;
exports.LucideLuTreePalm = LuTreePalm;
exports.LucideLuTreePine = LuTreePine;
exports.LucideLuTrees = LuTrees;
exports.LucideLuTrello = LuTrello;
exports.LucideLuTrendingDown = LuTrendingDown;
exports.LucideLuTrendingUp = LuTrendingUp;
exports.LucideLuTriangle = LuTriangle;
exports.LucideLuTriangleAlert = LuTriangleAlert;
exports.LucideLuTriangleRight = LuTriangleRight;
exports.LucideLuTrophy = LuTrophy;
exports.LucideLuTruck = LuTruck;
exports.LucideLuTurtle = LuTurtle;
exports.LucideLuTv = LuTv;
exports.LucideLuTv2 = LuTv2;
exports.LucideLuTwitch = LuTwitch;
exports.LucideLuTwitter = LuTwitter;
exports.LucideLuType = LuType;
exports.LucideLuUmbrella = LuUmbrella;
exports.LucideLuUmbrellaOff = LuUmbrellaOff;
exports.LucideLuUnderline = LuUnderline;
exports.LucideLuUndo = LuUndo;
exports.LucideLuUndo2 = LuUndo2;
exports.LucideLuUndoDot = LuUndoDot;
exports.LucideLuUnfoldHorizontal = LuUnfoldHorizontal;
exports.LucideLuUnfoldVertical = LuUnfoldVertical;
exports.LucideLuUngroup = LuUngroup;
exports.LucideLuUniversity = LuUniversity;
exports.LucideLuUnlink = LuUnlink;
exports.LucideLuUnlink2 = LuUnlink2;
exports.LucideLuUnlock = LuLockOpen;
exports.LucideLuUnlockKeyhole = LuLockKeyholeOpen;
exports.LucideLuUnplug = LuUnplug;
exports.LucideLuUpload = LuUpload;
exports.LucideLuUploadCloud = LuCloudUpload;
exports.LucideLuUsb = LuUsb;
exports.LucideLuUser = LuUser;
exports.LucideLuUser2 = LuUserRound;
exports.LucideLuUserCheck = LuUserCheck;
exports.LucideLuUserCheck2 = LuUserRoundCheck;
exports.LucideLuUserCircle = LuCircleUser;
exports.LucideLuUserCircle2 = LuCircleUserRound;
exports.LucideLuUserCog = LuUserCog;
exports.LucideLuUserCog2 = LuUserRoundCog;
exports.LucideLuUserMinus = LuUserMinus;
exports.LucideLuUserMinus2 = LuUserRoundMinus;
exports.LucideLuUserPlus = LuUserPlus;
exports.LucideLuUserPlus2 = LuUserRoundPlus;
exports.LucideLuUserRound = LuUserRound;
exports.LucideLuUserRoundCheck = LuUserRoundCheck;
exports.LucideLuUserRoundCog = LuUserRoundCog;
exports.LucideLuUserRoundMinus = LuUserRoundMinus;
exports.LucideLuUserRoundPlus = LuUserRoundPlus;
exports.LucideLuUserRoundSearch = LuUserRoundSearch;
exports.LucideLuUserRoundX = LuUserRoundX;
exports.LucideLuUserSearch = LuUserSearch;
exports.LucideLuUserSquare = LuSquareUser;
exports.LucideLuUserSquare2 = LuSquareUserRound;
exports.LucideLuUserX = LuUserX;
exports.LucideLuUserX2 = LuUserRoundX;
exports.LucideLuUsers = LuUsers;
exports.LucideLuUsers2 = LuUsersRound;
exports.LucideLuUsersRound = LuUsersRound;
exports.LucideLuUtensils = LuUtensils;
exports.LucideLuUtensilsCrossed = LuUtensilsCrossed;
exports.LucideLuUtilityPole = LuUtilityPole;
exports.LucideLuVariable = LuVariable;
exports.LucideLuVault = LuVault;
exports.LucideLuVegan = LuVegan;
exports.LucideLuVenetianMask = LuVenetianMask;
exports.LucideLuVerified = LuBadgeCheck;
exports.LucideLuVibrate = LuVibrate;
exports.LucideLuVibrateOff = LuVibrateOff;
exports.LucideLuVideo = LuVideo;
exports.LucideLuVideoOff = LuVideoOff;
exports.LucideLuVideotape = LuVideotape;
exports.LucideLuView = LuView;
exports.LucideLuVoicemail = LuVoicemail;
exports.LucideLuVolume = LuVolume;
exports.LucideLuVolume1 = LuVolume1;
exports.LucideLuVolume2 = LuVolume2;
exports.LucideLuVolumeX = LuVolumeX;
exports.LucideLuVote = LuVote;
exports.LucideLuWallet = LuWallet;
exports.LucideLuWallet2 = LuWalletMinimal;
exports.LucideLuWalletCards = LuWalletCards;
exports.LucideLuWalletMinimal = LuWalletMinimal;
exports.LucideLuWallpaper = LuWallpaper;
exports.LucideLuWand = LuWand;
exports.LucideLuWand2 = LuWandSparkles;
exports.LucideLuWandSparkles = LuWandSparkles;
exports.LucideLuWarehouse = LuWarehouse;
exports.LucideLuWashingMachine = LuWashingMachine;
exports.LucideLuWatch = LuWatch;
exports.LucideLuWaves = LuWaves;
exports.LucideLuWaypoints = LuWaypoints;
exports.LucideLuWebcam = LuWebcam;
exports.LucideLuWebhook = LuWebhook;
exports.LucideLuWebhookOff = LuWebhookOff;
exports.LucideLuWeight = LuWeight;
exports.LucideLuWheat = LuWheat;
exports.LucideLuWheatOff = LuWheatOff;
exports.LucideLuWholeWord = LuWholeWord;
exports.LucideLuWifi = LuWifi;
exports.LucideLuWifiOff = LuWifiOff;
exports.LucideLuWind = LuWind;
exports.LucideLuWine = LuWine;
exports.LucideLuWineOff = LuWineOff;
exports.LucideLuWorkflow = LuWorkflow;
exports.LucideLuWrapText = LuWrapText;
exports.LucideLuWrench = LuWrench;
exports.LucideLuX = LuX;
exports.LucideLuXCircle = LuCircleX;
exports.LucideLuXOctagon = LuOctagonX;
exports.LucideLuXSquare = LuSquareX;
exports.LucideLuYoutube = LuYoutube;
exports.LucideLuZap = LuZap;
exports.LucideLuZapOff = LuZapOff;
exports.LucideLuZoomIn = LuZoomIn;
exports.LucideLuZoomOut = LuZoomOut;
exports.createLucideIcon = createLucideIcon;
exports.icons = index;
//# sourceMappingURL=lucide-react.js.map
